<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.facetValue.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * A facet value.
 */
class cmfFacetValue
{
    /**
     * The value (used when generating the facets query fragment).
     * @var mixed
     */
    public $value;

    /**
     * The caption (the value that is displayed to the user).
     * @var string
     */
    public $caption;

    /**
     * The number of items in the search result that matches this value.
     * @var int
     */
    public $count;

    public $extraData;

    /**
     * Construct a facet value.
     * @param string $value The value (required).
     * @param string $caption The caption. If not specified (or null), $value is used.
     * @param int $count The number of result items that match the value (default: 0).
     */
    public function __construct($value, $caption = null, $count = 0)
    {
        $this->value = $value;
        $this->caption = null != $caption ? $caption : $value;
        $this->count = $count;
    }

    /**
     * Compares two facet values in decreasing order of count.
     *
     * @param cmfFacetValue $facetValue1 The first facet value.
     * @param cmfFacetValue $facetValue2 The second facet value.
     *
     * @return int The difference $facetValue2->count - $facetValue1->count
     */
    public static function compareFacetValuesByCount(cmfFacetValue $facetValue1, cmfFacetValue $facetValue2)
    {
        return $facetValue2->count - $facetValue1->count;
    }

    /**
     * Returns true if the provided facet value has hits ($count is greater than 0).
     * @param cmfFacetValue $facetValue The facet value.
     * @return boolean True if the facet value has hits.
     */
    public static function hasHits(cmfFacetValue $facetValue)
    {
        return $facetValue->count > 0;
    }
}
