<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.searchEngine.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * The search engine.
 */
class cmfSearchEngine
{
    /**
     * The search configuration object.
     * @var cmfSearchConfig
     */
    public $configuration;

    /**
     * The base lucene query that is appended to the search query
     * (to restrict the results).
     * @var string
     */
    public $baseQuery = '';

    /**
     * The search plugin instance (created on demand).
     * @var cmfSearchPlugin|null
     */
    private $plugin = null;

    /**
     * Public constructor.
     *
     * @param cmfSearchConfig $configuration The search configuration.
     */
    public function __construct(cmfSearchConfig $configuration)
    {
        $this->configuration = $configuration;
    }

    /***************************
     * Search related methods. *
     ***************************/

    /**
     * Return the search plugin instance.
     * @return cmfSearchPlugin
     */
    public function getSearchPlugin()
    {
        if (null === $this->plugin)
        {
            $arguments = array();
            $arguments['facetDefinitions'] = $this->configuration->facetDefinitions;
            if (null !== $this->configuration->indexDefinitions)
            {
                $arguments['indexDefinitions'] = $this->configuration->indexDefinitions;
            }

            $this->plugin = cmfPluginFactory::createPlugin(
                $this->configuration->searchPluginInfo,
                'cmfSearchPlugin',
                $arguments
            );
        }
        return $this->plugin;
    }

    /**
     * Execute the search.
     * @param cmfSearchQuery $query The query.
     * @return cmfSearchResult The search result.
     */
    public function search(cmfSearchQuery $query)
    {
        $queryFilterFragments = array();

        if ($this->baseQuery)
        {
            $queryFilterFragments[] = '(' . $this->baseQuery . ')';
        }

        if ($query->areFacetsApplied())
        {
            $facetsQueryFragment = $query->buildFacetsQueryFragment();
            if ($facetsQueryFragment)
            {
                $queryFilterFragments[] = '(' . $facetsQueryFragment . ')';
            }
        }

        $filterQuery = implode(' AND ', $queryFilterFragments);

        $searchPlugin = $this->getSearchPlugin();

        $resultCount = $searchPlugin->initSearch($query->searchId, $query->queryString, $filterQuery, $query->sortClause);

        return new cmfSearchResult($query, $resultCount, $this->configuration, $searchPlugin);
    }
}
