<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.toolbox.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * CMF toolbox.
 */
class cmfToolbox
{
    /**
     * Return the appropriate value if the specified key
     * exists in the provided array, otherwise return the 
     * specified default value.
     * @param array $array The array.
     * @param mixed $key The key.
     * @param mixed $defaultValue The default value (default: null).
     * @return mixed The array value, or the default value if
     * the value does not exist in the array.
     */
    public static function getArrayParameter($array, $key, $defaultValue = null)
    {
        if (isset($array[$key]))
        {
            return $array[$key];
        }

        return $defaultValue;
    }

    /**
     * Determine if a given path is absolute.
     * @param string $path The path.
     * @return boolean True if the given path is absolute, 
     * false otherwise.
     */
    public static function isAbsolutePath($path)
    {
        return preg_match('@^([a-zA-Z]:|(\\\){2,2}|\/)@', $path);
    }
    
    /**
     * If the PHP session has not been started, start it.
     * @return void
     */
    public static function ensureSessionStarted()
    {
        if ('' === session_id())
        {
            session_start();
        }
    }

    /**
     * Generate a password.
     * @param int $length
     * @param int $strength
     * @return string The password.
     */
    public static function generatePassword($length = 9, $strength = 0)
    {
        $vowels = 'aeuy';
        $consonants = 'bdghjmnpqrstvz';
        if ($strength & 1)
        {
            $consonants .= 'BDGHJLMNPQRSTVWXZ';
        }
        if ($strength & 2)
        {
            $vowels .= 'AEUY';
        }
        if ($strength & 4)
        {
            $consonants .= '23456789';
        }
        if ($strength & 8)
        {
            $consonants .= '@#$%';
        }

        $password = '';
        $alt = time() % 2;
        for ($i = 0; $i < $length; $i++)
        {
            if ($alt == 1)
            {
                $password .= $consonants[(rand() % strlen($consonants))];
                $alt = 0;
            }
            else
            {
                $password .= $vowels[(rand() % strlen($vowels))];
                $alt = 1;
            }
        }
        return $password;
    }

    /*
    * Get the first X words from a string.
    * @param int $str The string.
    * @param int $length The number of words to be returned.
    * @return string
    */
    public static function firstXWords($str, $length)
    {
        $words = explode(' ', $str);
        if (count($words) > $length)
        {
            return implode(' ', array_slice($words, 0, $length));
        }
        return $str;
    }
    
    /**
     * Append a path to the PHP include path.
     * @param string $path A path.
     * @return void
     */
    public static function addIncludePath($path)
    {
        set_include_path(get_include_path() . PATH_SEPARATOR . $path);
    }
}