<?php

class cmfPhotoController extends cmfController
{
    /**
     * The media manager REST client.
     * @var Nstein_Cmf_Mediamanager_Client
     */
    private $mediaManagerClient;
    
    public function injectDependencies(cmfContainer $container)
    {
        parent::injectDependencies($container);
        if ($this->getMode() === cmfFrontDispatcher::MODE_PREVIEW)
        {
            $this->mediaManagerClient = cmfToolbox::getArrayParameter($container, 'sampleMediaManagerPreviewClient');
        }
        else
        {
            $this->mediaManagerClient = cmfToolbox::getArrayParameter($container, 'sampleMediaManagerClient');
        }
    }
    
    /**
     * Make sure that the required photo is published, otherwise
     * output a HTTP 404 Not Found and exit the request.
     * @return void
     */
    public function always()
    {
        if (!$this->doPhotoExists())
        {
            header($_SERVER['SERVER_PROTOCOL'] . ' 404 Not Found');
            echo 'Not Found';
            exit();
        }
    }
    
    /**
     * Get the media manager REST client.
     * @return Nstein_Cmf_Mediamanager_Client
     */
    public function getMediaManagerClient()
    {
        return $this->mediaManagerClient;
    }
    
    /**
     * Do a cURL call using the HEAD method to see if the required
     * photo exists in the media manager.
     * @return boolean True if the photo exists in the media
     * manager (meaning it has been published), false otherwise.
     */
    public function doPhotoExists()
    {
        $request = $this->getRequest();
        $url = $this->mediaManagerClient->getImageUrl($request['id']);
        
        $curl = curl_init();

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_NOBODY, true);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        
        curl_exec($curl);
        $status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        
        curl_close($curl);
        
        return 200 == $status;
    }
}