<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 * Test strategy:
 * 1.Get the number of objects that are indexed for a given class
 * 2.Create an object, delete its index and try and retrieve it(should fail)
 * 3.Create an object, de-index it, try and retrieve it(should fail), re-index it and try and retrieve it(should succeed);
 *
 * TODO: Redo the refactoring, especially those hard coded values that get complicated very quickly...
 */
class indexTest extends WcmTest
{
    // An array of article ids that are created during the tests
    private static $articleIdArray = array();

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
    }

    /*
     * Called after all tests have executed, regardless of success or failure
     */
    public static function tearDownAfterClass()
    {
        parent::tearDownAfterClass();
        /*
         * Try and delete all articles that where created for the tests
         * in case one wasn't deleted during a test failure
         */
        foreach (self::$articleIdArray as $id)
        {
            self::deleteArticle($id);
        }
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
    }

    //--------------------------------------------------------//
    // RETRIEVING THE NUMBER OF OBJECTS OF A CLASS THAT ARE INDEXED
    //--------------------------------------------------------//

    /*
     * Valid request
     *
     * Get the number of objects that are indexed for a given class
     *
     * 1. Create an article so that at least one object exists
     * 2. Get the number of indexed articles
     * 3. Preform a search for all articles
     * 4. Verify the number of results for the search is equal to the number of indexed objects
     */
    public function testGetIndexArticle200Sessionid()
    {
        // Create an article so that at least one object is indexed
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // Get the object count of indexed articles
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXml();

        // Get the number of indexed objects of the specified class
        $numOfIndexedObjects = $this->getXmlElement($this, self::INDEX_OBJECT_COUNT);

        // Perform a search for all objects of the class
        $rt = $this->search(self::CLASSNAME_LUCENE . self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS);

        // Get the number of results the search produced
        $numSearchResults = $this->getXmlElement($rt, self::NUM_RESULTS_SEARCH_XML);

        // Verify that the number of indexed objects and the number of results for the search are the same for the same class
        $this->assertEquals($numSearchResults, $numOfIndexedObjects);

        // Delete the article
        $this->deleteArticle($id);
    }

    /*
     * Missing className
     */
    public function testGetIndex400Sessionid()
    {
        $this->setResource(self::INDEX_CONTROLLER);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

//    /*
//     *
//     */
//    public function testGetIndex401()
//    {
//        //TODO: Figure out how to get WCM to respond with a 401, in the code the condition is $count = null and  $count = $search->getObjectCount($className);
//    }

    /*
     * Invalid classname
     */
    public function testGetIndexInvalid404Sessionid()
    {
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }





    //--------------------------------------------------------//
    // DELETING THE INDEX OF A SPECIFIC OBJECT
    //--------------------------------------------------------//

    /*
     * Valid request
     * 1. Create an object
     * 2. Delete the objects index
     * 3. Search for the object(should fail)
     */
    public function testDeleteIndexArticleId204Sessionid()
    {
        // Create an article so that at least one object is indexed
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // Delete its index
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(204);

        $rt = $this->search(
            self::CLASSNAME_LUCENE . self::SEPERATOR_LUCENE .
            self::ARTICLE_BIZ_CLASS . ' ' . self::AND_LUCENE . ' ' .
            self::ID_LUCENE . self::SEPERATOR_LUCENE . $id
        );

        $rt->validateBodyIsXML();

        // Validate that the returned resultset element is empty
        // Start by creating a simpleXML object with the returned body
        try
        {
            $sxml = new SimpleXMLElement($rt->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $rt->getBody());
        }

        // Check to make sure the resultSet is empty
        $this->assertObjectNotHasAttribute('result', $sxml->resultSet, 'The resultSet of the search of the de-indexed object is not empty.');

        // delete the article
        $this->deleteArticle($id);
    }

    /*
     * Missing Classname
     */
    public function testDeleteIndexId400Sessionid()
    {
        $this->markTestIncomplete('A missing classname can\'t be' . 
        	'picked up by the apache rewrite rule so a missing classname' . 
        	'will return a 405 method not allowd.'
        );
        // Create an article so that at least one object is indexed
        //$id = $this->createArticle();

        // Store the newly created articles id in the id array
        //self::$articleIdArray[] = $id;
        
        $this->setResource(self::INDEX_CONTROLLER . '//1');

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);

        // delete the article
        //$this->deleteArticle($id);
    }

//    /*
//     * De-index an object that isn't indexed
//     */
//    public function testDeleteIndexArticleId401Sessionid()
//    {
//        $this->markTestIncomplete('Solr doesn\'t return an error when' .
//            ' deleting an object that doesn\'t exist so this test is pointless.'
//        );
//
//        // Create an article
//        $id = $this->createArticle();
//
//        // Store the newly created articles id in the id array
//        self::$articleIdArray[] = $id;
//
//        // Delete its index of the deleted article
//        $this->setResource(
//            self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE .
//            self::SEPERATOR . $id
//        );
//
//        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));
//
//        $this->executeRequest();
//
//        // Verify that the object was successfully de-indexed
//        $this->validateReturnStatus(204);
//
//        // Delete the index of the de-indexed article
//        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);
//
//        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));
//
//        $this->executeRequest();
//
//        // Veify the return status
//        $this->validateReturnStatus(401);
//
//        $this->deleteArticle($id);
//    }

    /*
     * De-index an object that doesn't exist
     */
    public function testDeleteIndexArticleId404Sessionid()
    {
        // Create an article
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // Delete the article
        $this->deleteArticle($id);

        // Delete its index of the deleted article
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        // Veify that it was not found
        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // INDEXING ALL OBJECTS OF A CLASS
    //--------------------------------------------------------//

    /*
     * Valid request
     *
     * 1. Create an article
     * 2. De-index the article
     * 3. Search for all articles(as to know which ones where indexed to begin with)
     * 4. Index all articles
     * 5. Search all articles and verfiy the created article has been indexed along with the previously indexed articles
     * 6. De-index the articles that weren't indexed before the test
     *
     * @depends testDeleteIndexArticleId204Sessionid
     */
    public function testPostIndexArticle201Sessionid()
    {
        // Create an article
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // De-index the article
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(204);

        // Do a search for all articles
        $rt = $this->search(self::CLASSNAME_LUCENE . self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS);

        // Remember the returned ids of the search
        $searchIndexId = $this->getXmlElements($rt, self::ARTICLE_ID_SEARCH_XML);

        // Index all objects of the class
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // Preform a search and verify that the created object is returned as well as previously indexed objects
        $rt = $this->search(self::CLASSNAME_LUCENE . self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS);

        $searchAllId = $this->getXmlElements($rt, self::ARTICLE_ID_SEARCH_XML);

        $searchIndexId[] = $id;

        foreach ($searchIndexId as $indexedId)
        {
            $this->assertContains($indexedId, $searchAllId, 'An article meant to be indexed was not; Article id: ' . $indexedId);
        }

        // Calculate the ids that weren't indexed to start with
        $idArrayToDeindex = array_diff($searchAllId, $searchIndexId);

        // De-index any objects that where returned from the second search but not the first
        foreach ($idArrayToDeindex as $deindexId)
        {
            $this->setResource(
                self::INDEX_CONTROLLER . self::SEPERATOR .
                self::ARTICLE_RESOURCE . self::SEPERATOR . $deindexId
            );

            $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

            $this->executeRequest();

            $this->validateReturnStatus(204);
        }

        // Delete the article
        $this->deleteArticle($id);
    }

    /*
     * Missing classname
     */
    public function testPostIndex400Sessionid()
    {
        $this->setResource(self::INDEX_CONTROLLER);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

//    /*
//     * Unauthorized
//     * Can't seem to test this...
//     */
//    public function testPostIndex401()
//    {
//
//    }

    /*
     * Invalid classname
     */
    public function testPostIndexInvalid404Sessionid()
    {
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // INDEXING A SPECIFIC OBJECT
    //--------------------------------------------------------//

    /*
     * Valid request
     *
     * 1. Create an object
     * 2. De-index the object
     * 3. Search for the object(should fail)
     * 4. Re-index the object
     * 5. Search for the object(should succeed);
     */
    public function testPostIndexArticleId201SessionId()
    {
        // Create an article
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // De-index the article
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(204);

        // Try and retrieve the de-indexed article with a search, should return an empty result set
        $this->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS .
                ' ' . self::AND_LUCENE . ' ' .
                self::ID_LUCENE . self::SEPERATOR_LUCENE . $id
            )
        );

        $this->executeRequest();

        // Make sure the search was successful(does not mean that the search returned a result)
        $this->validateReturnStatus(200);

        // Validate that the returned resultset element is empty
        try
        {
            $sxml = new SimpleXMLElement($this->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $this->getBody());
        }

        // Check to make sure the resultSet is empty
        $this->assertObjectNotHasAttribute('result', $sxml->resultSet, 'The resultSet of the search of the de-indexed object is not empty.');

        // Index the article
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $id);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // Search for the article, should be returned now
        $this->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS .
                ' ' . self::AND_LUCENE . ' ' .
                self::ID_LUCENE . self::SEPERATOR_LUCENE . $id
            )
        );

        $this->executeRequest();

        // Make sure the search was successful(does not mean that the search returned a result)
        $this->validateReturnStatus(200);

        // Validate that the returned resultset element is NOT empty
        try
        {
            $sxml = new SimpleXMLElement($this->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $this->getBody());
        }

        // Check to make sure the resultSet is NOT empty
        $this->assertObjectHasAttribute('result', $sxml->resultSet, 'The resultSet of the search of the de-indexed object is not empty.');

        // Delete the article
        $this->deleteArticle($id);
    }

    /*
     * Missing classname
     */
    public function testPostIndexId400Sessionid()
    {
        $this->markTestIncomplete('A missing classname can\'t be' . 
        	'picked up by the apache rewrite rule so a missing classname' . 
        	'will return a 405 method not allowd.'
        );
        // Create an article
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::SEPERATOR . $id);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);

        $this->deleteArticle($id);
    }

//    /*
//     * Still haven't figured out how to test this...
//     */
//    public function testPostIndexId401()
//    {
//    }

    /*
     *
     */
    public function testPostIndexInvalidId404SessionId()
    {
        // Create an article
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE . self::SEPERATOR . $id);

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);

        $this->deleteArticle($id);
    }

    //--------------------------------------------------------//
    // DELETING THE INDEX FOR ALL OBJECTS OF A CLASS
    //--------------------------------------------------------//
    /*
     * Valid request
     *
     * This is going to be complicated...
     * 1. Do a search for all article
     * 2. Store the ids of all the articles returned by the search
     * 3. Create an article in case there are none
     * 4. Delete all indexes by classname:article
     * 5. Verify the objects have been de-indexed by performing a new search and insuring it returns an empty resultSet element
     * 6. Re-index all articles that were previously indexed by using the array of ids from step 2
     *
     * Create an object, delete its index and try and retrieve it(should fail)
     */
    public function testDeleteIndexArticle204Sessionid()
    {
        // An array for keeping track of what objects were indexed before doing the test
        $idArray = Array();

        // Create an article to ensure that at least one exists
        $id = $this->createArticle();

        // Store the newly created articles id in the id array
        self::$articleIdArray[] = $id;

        // Execute a search for all articles
        $this->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        // Transform the result to a simplexml object to use xpath traversal
        try
        {
            $sxml = new SimpleXMLElement($this->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $this->getBody());
        }

        // Retrieve the article ids and store them in the $idArray
        foreach ($sxml->xpath('//' . self::ARTICLE_ID_SEARCH_XML) as $xpathId)
        {
            $idArray[] = (String)$xpathId;
        }

        // Delete indexes of all articles
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(204);

        //Perform another search and make sure no articles are returned
        $this->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        // Validate that the returned resultset element is empty
        try
        {
            $sxml = new SimpleXMLElement($this->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $this->getBody());
        }

        // Check to make sure the resultSet is empty
        $this->assertObjectNotHasAttribute('result', $sxml->resultSet, 'The resultSet of the search of the de-indexed object is not empty.');

        // Re-index all the articles that were previously indexed
        foreach ( $idArray as $idArticle )
        {
            $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::ARTICLE_RESOURCE . self::SEPERATOR . $idArticle);

            $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

            $this->executeRequest();

            $this->validateReturnStatus(201);
        }

        // Search for the articles and verify they are returned
        $this->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        // Transform the result to a simplexml object to use xpath traversal
        try
        {
            $sxml = new SimpleXMLElement($this->getBody());
        }
        catch (Exception $e)
        {
            $this->asserttrue(false, 'The xml is not valid:' . "\n\n" . $this->getBody());
        }

        // Retrieve the article ids and store them in the $idArray
        foreach ($sxml->xpath('//' . self::ARTICLE_ID_SEARCH_XML) as $xpathId2)
        {
            $idArrayTwo[] = (String)$xpathId2;
        }

        $this->assertEquals($idArray, $idArrayTwo, 'The original indexed articles were not successfuly re-indexed.');

        // delete the previously created article
        $this->deleteArticle($id);
    }

    /*
     * Invalid Id
     */
    public function testDeleteIndex404Sessionid()
    {
        $id = self::createArticle();
        self::deleteArticle($id);
        
        // Delete index of deleted article, should fail
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . 'article/' . $id);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

//    /*
//     * Can't figure out how to test a 401
//     */
//    public function testDeleteIndex401()
//    {
//    }

    /*
     * Invalid className
     */
    public function testDeleteIndexInvalid404SessionId()
    {
        // Delete indexes of all articles
        $this->setResource(self::INDEX_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE);

        $this->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }



    // HELPER FUNCTIONS

    /*
     * Preforms a search in WCM based on the query passed as a parameter
     *
     * @param $query The lucene syntax query for the search
     *
     * @return $rt WcmTest The WcmTest object object used for the search
     */
    private function search($query)
    {
        // create a new WcmTest object as not to modify the state of the calling object
        $rt = new WcmTest;
        // Try and retrieve the de-indexed article with a search, should return an empty result set
        // Get the newly created object
        $rt->setResource(self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE);

        $rt->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => $query
            )
        );

        $rt->executeRequest();

        // Make sure the search was successful(does not mean that the search returned a result)
        $rt->validateReturnStatus(200);

        return $rt;
    }
}