<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 * TODO: Test all image type and image manipulation
 * TODO: CLean up hard coded values
 */
class photoTest extends WcmTest
{

    // CONSTANTS

    const IMAGE_NAME = 'test';
    const IMAGE_EXTENSION = 'jpg';//jpg or jpeg


    // The REST resource controller
    const CONTROLLER = self::PHOTO_CONTROLLER; // the resource controller

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
        //TODO: Ensure that any created photos are dleeted
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
    }

    //--------------------------------------------------------//
    // CREATE/UPDATE A PHOTO
    //--------------------------------------------------------//
    /*
     * Upload a photo
     */
    public function testPostPhoto201Sessionid()
    {
        $imageName = self::IMAGE_NAME . '.jpg';
        
        $siteId = self::createSite();
      
        $photoId = self::createPhoto($siteId, $imageName);
        
        $this->setResource(self::CONTROLLER);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId,
            'content' => '@' . dirname(__FILE__) . '/../data/' . $imageName,
            'name'    => self::IMAGE_NAME,
            'id'      => $photoId
            ), null, array(self::SESSION_ID_HEADER . ': ' . self::$sessionId), true
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // rememeber the id of the newly created object
        self::$idArray[self::PHOTO_BIZ_CLASS][] = $photoId;
        self::$idArray[self::SITE_BIZ_CLASS][] = $siteId;
    }

    /*
     * No content
     */
    public function testPostPhoto400Sessionid()
    {
        $this->setResource(self::CONTROLLER . '/testphoto');

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);

    }

    //--------------------------------------------------------//
    // RETRIEVING A PHOTO
    //--------------------------------------------------------//

    /*
     * 1. Create a Site
     * 2. Create a photo
     * 3. Retrieve the photo
     * 4. Test that the correct photo was retrieved
     * 5. Delete the photo
     * 6. Delete the Site
     *
     * @depends testPostPhoto201Sessionid
     */
    public function testGetPhotoId201Sessionid()
    {
        $imageName = self::IMAGE_NAME . '.jpg';
        
        $siteId = self::createSite();
      
        $photoId = self::createPhoto($siteId, $imageName);

        // Upload a test photo
        $this->setResource(self::CONTROLLER . '/' . self::IMAGE_NAME);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId,
            'content' => '@' . dirname(__FILE__) . '/../data/' . $imageName,
            'name'    => self::IMAGE_NAME,
            'id'      => $photoId
            ), null, array(self::SESSION_ID_HEADER . ': ' . self::$sessionId), true
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        // GET the photo and compare to original

        $this->setResource(self::CONTROLLER . self::SEPERATOR . $photoId);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $originalImage = file_get_contents(dirname(__FILE__) . '/../data/test.jpg');

        $returnedImage = $this->getBody();

        $this->assertEquals(
            $originalImage, $returnedImage,
            'The returned image was not the same as the original'
        );

        $this->validateReturnStatus(200);

        // rememeber the id of the newly created object
        self::$idArray[self::PHOTO_BIZ_CLASS][] = $photoId;
        self::$idArray[self::SITE_BIZ_CLASS][] = $siteId;
    }


    public function testGetPhotoId201SessionidRatio()
    {
        $imageName = self::IMAGE_NAME . '.jpg';
        
        $siteId = self::createSite();
      
        $photoId = self::createPhoto($siteId, $imageName);

        // Upload a test photo
        $this->setResource(self::CONTROLLER . '/' . self::IMAGE_NAME);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId,
            'content' => '@' . dirname(__FILE__) . '/../data/' . $imageName,
            'name'    => self::IMAGE_NAME,
            'id'      => $photoId
            ), null, array(self::SESSION_ID_HEADER . ': ' . self::$sessionId), true
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        // GET the photo of the specified ratio
        $this->setResource(self::CONTROLLER . self::SEPERATOR . $photoId);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId, 'ratio' =>  'thumb_square_small'));

        $this->executeRequest();

        $returnedImage = $this->getBody();

        // this is the expected photo that conforms with the ratio thumb_square_small
        $expectedImage = file_get_contents(dirname(__FILE__) . '/../data/returned_thumbnail.jpg');
        
        // Assert that the thumbnail that was just created is the same as the one returned by WCM
        $this->assertEquals(
            $returnedImage, $expectedImage,
            'The returned image was not the specified thumbnail of the original'
        );

        $this->validateReturnStatus(200);

        // rememeber the id of the newly created object
        self::$idArray[self::PHOTO_BIZ_CLASS][] = $photoId;
        self::$idArray[self::SITE_BIZ_CLASS][] = $siteId;
    }

    public function testGetPhotoId201SessionidWidthHeight()
    {
        $imageName = self::IMAGE_NAME . '.jpg';
        
        $siteId = self::createSite();
      
        $photoId = self::createPhoto($siteId, $imageName);

        // Upload a test photo
        $this->setResource(self::CONTROLLER . '/' . self::IMAGE_NAME);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId,
            'content' => '@' . dirname(__FILE__) . '/../data/' . $imageName,
            'name'    => self::IMAGE_NAME,
            'id'      => $photoId
            ), null, array(self::SESSION_ID_HEADER . ': ' . self::$sessionId), true
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        // GET the photo of the specified ratio
        $this->setResource(self::CONTROLLER . self::SEPERATOR . $photoId);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId, 'width' => 100, 'height' =>  100));

        $this->executeRequest();

        $returnedImage = $this->getBody();

        // this is the expected photo that conforms with the ratio thumb_square_small
        $expectedImage = file_get_contents(dirname(__FILE__) . '/../data/returned_100x100.jpg');
        
        // Assert that the thumbnail that was just created is the same as the one returned by WCM
        $this->assertEquals(
            $returnedImage, $expectedImage,
            'The returned image was not the specified thumbnail of the original'
        );

        $this->validateReturnStatus(200);

        // rememeber the id of the newly created object
        self::$idArray[self::PHOTO_BIZ_CLASS][] = $photoId;
        self::$idArray[self::SITE_BIZ_CLASS][] = $siteId;
    }
    
    public function testGetPhotoId201Sessionid2()
    {

        // TODO:
        // Create a photo with invalid id, should fail..
        // WCM returns code and finishes, but the test hangs.
        // Something is messed up with the test suite.

        /*
        $siteId = 'garbage!%';

        // Upload a test photo
        $this->setResource(self::CONTROLLER . '/' . self::IMAGE_NAME);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            array('content' => '@' . dirname(__FILE__) . '/../data/test.jpg')
        );

        $this->executeRequest();

        $photoId = $this->createPhoto($siteId, self::IMAGE_NAME . '.jpeg');

        $this->setResource(self::CONTROLLER . self::SEPERATOR . $photoId);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $originalImage = file_get_contents(dirname(__FILE__) . '/../data/test.jpg');

        $returnedImage = $this->getBody();

        $this->assertEquals(
            $originalImage, $returnedImage,
            'The returned image was not the same as the original'
        );

        $this->validateReturnStatus(200);

        $this->deletePhoto($photoId);
        */

    }



    /*
     * Missing Photo id
     */
    public function testGetPhoto400Sessionid()
    {
        $this->setResource(self::CONTROLLER);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid photo id
     */
    public function testGetPhotoInvalid404Sessionid()
    {
        $this->setResource(self::CONTROLLER . self::SEPERATOR . '00');

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }
}