<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

class searchTest extends WcmTest
{

    private static $searchId;

    // Lucene search parameter names
    const SEARCH_ID = 123456789;

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
    }

    //--------------------------------------------------------//
    // RETRIEVING THE RESULTS OF A NEW SEARCH
    //--------------------------------------------------------//
    /*
     * TODO:Create content before search then test it
     */
    public function testGetSearchResults200SessionidQueryArticle()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    /*
     * Missing search query
     */
    public function testGetSearchResults400Sessionid()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR . self::RESULTS_RESOURCE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER  => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid resource
     */
    public function testGetSearchInvalid404SessionidQueryArticle()
    {

        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING THE RESULTS OF A PREVIOUS SEARCH
    //--------------------------------------------------------//
    /*
     * TODO: Create the content the search should return and test against it, do the same above
     * TODO: Test that sort, limit and offset are returning the correct objects
     */
    public function testGetSearchResultsSearchid200SessionidQueryArticle()
    {
        // Preform an initial search with an id
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::RESULTS_RESOURCE . self::SEPERATOR . self::SEARCH_ID
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

        // Retrieve the results of the previous search
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::RESULTS_RESOURCE . self::SEPERATOR . self::SEARCH_ID
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER  => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    /*
     * Sort parameter without a query parameter
     */
    public function testGetSearchResultsSearchid400SessionidSort()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::RESULTS_RESOURCE . self::SEPERATOR . self::SEARCH_ID
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::SORT_PARAMETER      => self::SORT_DESC_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid resource
     */
    public function testGetSearchInvalidSearchid404Sessionid()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::INVALID_RESOURCE . self::SEPERATOR . rand()
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    /*
     * Invalid resource
     */
    public function testGetSearchResultsInvalid500Sessionid()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::RESULTS_RESOURCE  . self::SEPERATOR .
            self::INVALID_RESOURCE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER  => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(500);
    }

    //--------------------------------------------------------//
    // RETRIEVING THE RESULTS OF A NEW FACETED SEARCH
    //--------------------------------------------------------//

    /*
     * TODO: Use the facets parameter
     */
    public function testGetSearchFacets200SessionidQueryArticle()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::FACETS_RESOURCE
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

    }

    /*
     * Missing search query
     */
    public function testGetSearchFacets400Sessionid()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::FACETS_RESOURCE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER  => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);

    }

    //--------------------------------------------------------//
    // RETRIEVING THE FACETS OF A PREVIOUS FACETED SEARCH
    //--------------------------------------------------------//
    /*
     * TODO: Use the facets parameter
     */
    public function testGetSearchFacetsSearchid200SessionidQueryArticle()
    {
        // Preform an initial search with an id
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::FACETS_RESOURCE   . self::SEPERATOR .
            self::SEARCH_ID
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::QUERY_PARAMETER     => self::CLASSNAME_LUCENE .
                self::SEPERATOR_LUCENE . self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

        // Retrieve the results of the previous search
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::FACETS_RESOURCE . self::SEPERATOR . self::SEARCH_ID
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER  => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    /*
     * Sort parameter without a query parameter
     */
    public function testGetSearchFacetsSearchid400SessionidSort()
    {
        $this->setResource(
            self::SEARCH_CONTROLLER . self::SEPERATOR .
            self::FACETS_RESOURCE
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::SORT_PARAMETER      => self::SORT_DESC_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }
}