<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

class sessionTest extends WcmTest
{

    const INVALID_SESSION_ID = 'Fg+W/LVKqI6dYva12xdRNQVht/bedfI=';
    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
        $this->setResource(self::SESSION_CONTROLLER);
    }

    /*
     * Valid request to retrieve a new session id in XML
     */
    public function testPutSession201UsernamePassword()
    {
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => USERNAME,
                self::PASSWORD_PARAMETER => PASSWORD
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // make sure the body of the response is valid xml
        $this->validateBodyIsXml();

        // validate the session id header is present in the response
        $this->validateHeader(self::SESSION_ID_HEADER);

        // validate the location header is present in the response
        $url = $this->validateHeader(self::LOCATION_HEADER);

        // double url encode the returned location as to "fix" Apaches pre url decoding
        $url = $this->doubleURLEncodeSessionId($url);

        // validate that the location is valid
        $response = $this->validateLocation($url);
        
        // Retrieve the sessions internal id(database primary key)
        $pattern = '/\<id\>(.*?)\<\/id\>/';
        $match = preg_match($pattern, $response, $result);
        $value = $result[1];
        
        // save the session id in the id array
        self::$idArray[self::SESSION_BIZ_CLASS][] = $value;
    }

    /*
     * Valid request to retrieve a new session id in JSON
     */
    public function testPutSession201UsernamePasswordJson()
    {
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => USERNAME,
                self::PASSWORD_PARAMETER => PASSWORD,
                self::JSON_PARAMETER     => 'true'
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // make sure the body of the response is valid xml
        $this->validateBodyIsJson();

        // validate the session id header is present in the response
        $this->validateHeader(self::SESSION_ID_HEADER);

        // validate the location header is present in the response
        $url = $this->validateHeader(self::LOCATION_HEADER);

        // double url encode the returned location as to "fix" Apaches pre url decoding
        $url = $this->doubleURLEncodeSessionId($url);

        // set up the url qith the json parameter
        $url = $url . '?' . self::JSON_PARAMETER . '=true';

        // validate that the location is valid
        $response = $this->validateLocation($url, null, null, null, true);
        
        // Retrieve the sessions internal id(database primary key)
        $pattern = '/"id":"(.*?)"/';
        $match = preg_match($pattern, $response, $result);
        // save the session id in the id array
        self::$idArray[self::SESSION_BIZ_CLASS][] = $result[1];
    }

    /*
     * Invalid - No username and password parameters
     */
    public function testPutSession400()
    {
        $this->setupPUT();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

     /*
     * Invalid - No password parameter
     */
    public function testPutSession400Username()
    {
        $this->setupPUT(array(self::USERNAME_PARAMETER => USERNAME));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

     /*
     * Invalid - No username parameter
     */
    public function testPutSession400Password()
    {
        // no username
        $this->setupPUT(array(self::PASSWORD_PARAMETER => PASSWORD));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - invalid password
     */
    public function testPutSession401UsernamePasswordinvalid()
    {
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => USERNAME,
                self::PASSWORD_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);

    }

    /*
     * Invalid - invalid username
     */
    public function testPutSession401UsernameinvalidPassword()
    {
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => self::INVALID_PARA_VALUE,
                self::PASSWORD_PARAMETER => PASSWORD
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

    /*
     * Invalid - invalid username and password
     */
    public function testPutSession401UsernameinvalidPasswordinvalid()
    {
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => self::INVALID_PARA_VALUE,
                self::PASSWORD_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);

    }

    /*
     * Validate a session id using a url query string parameter
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession302UsernamePasswordSessionid()
    {

        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(302);

        $this->validateBodyIsXML();

        // validate headers
        $this->validateHeader(self::SESSION_ID_HEADER);
        $url = $this->validateHeader(self::LOCATION_HEADER);

        // double url encode the url because of the apache "bug"
        $url = $this->doubleURLEncodeSessionId($url);

        // validate location
        $this->validateLocation($url);

    }

    /*
     * Validate a session id with a x_nstein_session_id header
     *
     * @depends testPutSession201UsernamePassword
     * @testdox toto
     *
     */
    public function testPutSession302UsernamePasswordHeaderXnsteinsessionid()
    {
        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => USERNAME,
                self::PASSWORD_PARAMETER => PASSWORD
            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(302);

        $this->validateBodyIsXML();

        $sessionId = $this->validateHeader(self::SESSION_ID_HEADER);

        /*
         * For the moment the returned session id will not be the same as the one we are validating
         */
        // Verify if the returned sessionId is the same as the one in the request
//        if (trim($sessionId) != trim(self::$sessionId))
//        {
//            $mes = 'The validated session id does not match ';
//            $mes .= 'the returned session id.';
//            $mes .= "\nSession id to validate:  " . self::$sessionId;
//            $mes .= "\nThe returned session Id: " . $sessionId;
//            $this->assertTrue(false, $mes);;
//        }

        $url = $this->validateHeader(self::LOCATION_HEADER);

        // double url encode to bypass apache "bug" and validate the location
        $url = $this->doubleURLEncodeSessionId($url);
        $this->validateLocation($url);
    }

    /*
     * Invalid - missing username
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400PasswordSessionid()
    {

        self::getSessionId();

        // missing username parameter
        $this->setupPUT(
            array(
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - missing username with session id sent as header
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400PasswordHeaderXnsteinsessionid()
    {

        self::getSessionId();

        // missing username parameter
        $this->setupPUT(
            array(
                self::PASSWORD_PARAMETER  => PASSWORD
            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - missing password
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400UsernameSessionid()
    {

        self::getSessionId();

        // missing username parameter
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - missing password with sessionId sent in a header
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400UsernameHeaderXnsteinsessionid()
    {

        self::getSessionId();

        // missing username parameter
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME
            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - invalid sessionId parameter
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400UsernamePasswordSessionidinvalid()
    {
        /*
         * Corrupt sessionId
         */
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - invalid sessionId parameter passed in a header
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession400UsernamePasswordHeaderXnsteinsessionidinvalid()
    {
        /*
         * Corrupt sessionId
         */
        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD
            ), array(self::SESSION_ID_HEADER . ': ' . self::INVALID_PARA_VALUE)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - invalid username
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession401UsernameinvalidPasswordSessionid()
    {
        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => self::INVALID_PARA_VALUE,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

    /*
     * Invalid - invalid username with sessionId sent in a header
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession401UsernameinvalidPasswordHeaderXnsteinsessionid()
    {
        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => self::INVALID_PARA_VALUE,
                self::PASSWORD_PARAMETER  => PASSWORD
            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

    /*
     * Invalid - invalid password
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession401UsernamePasswordinvalidSessionid()
    {
        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => self::INVALID_PARA_VALUE,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

    /*
     * Invalid - invalid username with sessionId sent in a header
     *
     * @depends testPutSession201UsernamePassword
     */
    public function testPutSession401UsernamePasswordinvalidHeaderXnsteinsessionid()
    {
        self::getSessionId();

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => self::INVALID_PARA_VALUE
            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

//    /*
//     * Invalid - invalid sessionId passed in the url query string
//     */
//    public function testPutSession404Sessionid()
//    {
//        $this->markTestIncomplete('Can\'t test a corrupt session id');
//        /*
//         * Invalid sessionId
//         */
//        $this->setupPUT(
//            array(
//                self::USERNAME_PARAMETER => USERNAME,
//                self::PASSWORD_PARAMETER => PASSWORD,
//                self::SESSIONID_PARAMETER => self::INVALID_SESSION_ID
//            )
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(404);
//    }
//
//    /*
//     * Invalid - invalid sessionId passed in a header
//     */
//    public function testPutSession404HeaderInvalid()
//    {
//        $this->markTestIncomplete('Can\'t test a corrupt session id');
//        /*
//         * Invalid sessionId
//         */
//        $this->setupPUT(
//            array(
//                self::USERNAME_PARAMETER => USERNAME,
//                self::PASSWORD_PARAMETER => PASSWORD
//            ), array(self::SESSION_ID_HEADER . ': ' . self::INVALID_SESSION_ID)
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(404);
//    }

    /*
     * Valid - Retrieve a wcmSession object
     *
     * @depends testPutSessionWithoutSessionId
     */
    public function testGetSession200UsernamePasswordSessionid()
    {
        self::getSessionId();

        $this->setupGET(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

//    /*
//     * Should this work?
//     *
//     * @depends testPutSessionWithoutSessionId
//     */
//    public function testGetSession200HeaderX_nstein_session_id()
//    {
//        // Stop here and mark this test as incomplete.
//        $this->markTestIncomplete(
//            'This test has not been implemented yet.'
//        );
//
//        self::getSessionId();
//
//        $this->setupGET(
//            array(
//                self::USERNAME_PARAMETER  => USERNAME,
//                self::PASSWORD_PARAMETER  => PASSWORD
//            ), array(self::SESSION_ID_HEADER . ': ' . self::$sessionId)
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(200);
//
//        $this->validateBodyIsXML();
//    }

    /*
     * Invalid - invalid session id passed as a url query string parameter
     */
    public function testGetSession400Sessionidinvalid()
    {
        $this->setupGET(
            array(self::SESSIONID_PARAMETER => self::INVALID_PARA_VALUE)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

//    /*
//     * Invalid - invalid session id passed in a header
//     * Does not work with session id passed as a header, should it?
//     */
//    public function testGetSession400HeaderInvalid()
//    {
//        // Stop here and mark this test as incomplete.
//        $this->markTestIncomplete(
//            'This test has not been implemented yet.'
//        );
//        $this->setupGET(
//            array(),
//            array(self::SESSION_ID_HEADER . ': ' . self::INVALID_PARA_VALUE)
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(400);
//    }

//    /*
//     * @depends testPutSessionWithoutSessionId
//     */
//    public function testGetSession401()
//    {
//        // Stop here and mark this test as incomplete.
//        $this->markTestIncomplete(
//            'This test has not been implemented yet.'
//        );
//    }

//    /*
//     * corrupt session id
//     * @depends testPutSessionWithoutSessionId
//     */
//    public function testGetSession404()
//    {
//        $this->markTestIncomplete('Can\'t test a corrupt session id');
//
//        $this->setupGET(
//            array(self::SESSIONID_PARAMETER => self::INVALID_SESSION_ID)
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(404);
//    }

    /*
     * @depends testPutSessionWithoutSessionId
     */
    public function testDeleteSession204UsernamePasswordSessionid()
    {
        self::getSessionId();

        $this->setupDELETE(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(204);
    }

    /*
     * Invalid - invalid sessionId
     *
     * @depends testPutSessionWithoutSessionId
     */
    public function testDeleteSession400UsernamePasswordSessionidinvalid()
    {
        self::getSessionId();

        $this->setupDELETE(
            array(
                self::USERNAME_PARAMETER  => USERNAME,
                self::PASSWORD_PARAMETER  => PASSWORD,
                self::SESSIONID_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid - expired sessionId
     *
     * @depends testPutSessionWithoutSessionId
     */
    public function testDeleteSession410Sessionid()
    {

        self::getSessionId();

        $this->setupDELETE(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId
            )
        );

        // Delete it once, causing the sessionId end date to be created
        $this->executeRequest();

        // Try and delete it again, this time it is expired
        $this->executeRequest();

        $this->validateReturnStatus(410);
    }

//    /*
//     * Invalid - corrupt sessionId sent in url query string
//     *
//     * @depends testPutSessionWithoutSessionId
//     */
//    public function testDeleteSession404()
//    {
//        $this->markTestIncomplete('Can\'t test a corrupt session id');
//
//        self::getSessionId();
//
//        $this->setupDELETE(
//            array(
//                self::USERNAME_PARAMETER  => USERNAME,
//                self::PASSWORD_PARAMETER  => PASSWORD,
//                self::SESSIONID_PARAMETER => self::INVALID_SESSION_ID
//            )
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(404);
//    }
}