<?php
require_once(dirname(__FILE__) . '/WcmRestToolbox.php');

class WcmTest extends WcmRestToolbox
{
    const USERNAME = 'admin';
    const PASSWORD = 'admin';

    // Declare me
    protected $sessionIdParameter;

    // a session Id
    protected static $sessionId;

    // error message generated when getting a sessionId with the getSessionId method TODO:Get this out of here maybe... or at least make it usful, as it is now im not checking for errors afetr calling getSessionId()
    protected static $sessionIdError;

    /*
     * An associative array of classnames and ids that have been created
     * throughout the tests that need to be deleted at the end to leave the
     * database in the same state as before the tests
     */
    protected static $idArray = array(
        self::ARTICLE_BIZ_CLASS  => array(),
        self::WORKFLOW_BIZ_CLASS => array(),
        self::SESSION_BIZ_CLASS  => array()
        );

    const SEPERATOR = '/';

    // HEADERS
    const SESSION_ID_HEADER = 'x-nstein-session-id';
    const LOCATION_HEADER   = 'location';

    // REST CONTROLLERS
    const CONTENT_CONTROLLER       = 'content';
    const SESSION_CONTROLLER       = 'session';
    const WORKFLOW_CONTROLLER      = 'workflow';
    const AUTHORIZATION_CONTROLLER = 'authorization';
    const SEARCH_CONTROLLER        = 'search';
    const PERMISSIONS_CONTROLLER   = 'permissions';
    const INDEX_CONTROLLER         = 'index';
    const GENERATION_CONTROLLER    = 'generation';
    const PHOTO_CONTROLLER         = 'photo';

    // RESOURCES
    const PRIVILEGE_RESOURCE = 'privilege';
    const RESULTS_RESOURCE   = 'results';
    const INVALID_RESOURCE   = 'invalid';
    const FACETS_RESOURCE    = 'facets';
    const ARTICLE_RESOURCE   = 'article';
    const USER_RESOURCE      = 'wcmUser';
    const WORKFLOW_RESOURCE  = 'wcmWorkflow';
    const SET_RESOURCE       = 'set'; // child resource of generation
    const CONTENT_RESOURCE   = 'content'; // child resource of generation

    // WCM BIZ CLASSES
    const WORKFLOW_BIZ_CLASS           = 'wcmWorkflow';
    const ARTICLE_BIZ_CLASS            = 'article';
    const USER_BIZ_CLASS               = 'wcmUser';
    const PHOTO_BIZ_CLASS              = 'photo';
    const SITE_BIZ_CLASS               = 'site';
    const SESSION_BIZ_CLASS            = 'wcmSession';
    const GENERATION_BIZ_CLASS         = 'wcmGeneration';
    const GENERATION_SET_BIZ_CLASS     = 'wcmGenerationSet';
    const GENERATION_CONTENT_BIZ_CLASS = 'wcmGenerationContent';

    //query string parameter names
    const SESSIONID_PARAMETER  = 'sessionId';
    const USERNAME_PARAMETER   = 'username';
    const PASSWORD_PARAMETER   = 'password';
    const CLASSNAME_PARAMETER  = 'className';
    const OBJECT_ID_PARAMETER  = 'objectId';
    const USER_ID_PARAMETER    = 'userId';
    const QUERY_PARAMETER      = 'query';
    const SORT_PARAMETER       = 'sort';
    const WHERE_PARAMETER      = 'where';
    const JSON_PARAMETER       = 'json';

    // URL Query string values
    const INVALID_PARA_VALUE     = 'invalid';
    const SORT_DESC_PARA_VALUE   = 'DESC';
    const ID_PARA_VALUE          = 'id';
    const FACETS_PARA_VALUE      = 'facets';

    // POST parameter names
    const CONTENT_POST_PARA = 'content=';
    const CODE_POST_PARA    = 'code';

    // Lucene query string values
    const CLASSNAME_LUCENE = 'className';
    const SEPERATOR_LUCENE = ':';
    const AND_LUCENE       = 'AND';
    const ID_LUCENE        = 'id';

    // Search response XML elements in xpath format
    const NUM_RESULTS_SEARCH_XML = 'numResults';
    const RESULT_SET_SEARCH_XML  = 'resultSet';
    const RESULT_SEARCH_XML      = 'resultSet/result';
    const ARTICLE_SEARCH_XML     = 'resultSet/result/article';
    const ARTICLE_ID_SEARCH_XML  = 'resultSet/result/article/id';

    // Indexation response elements
    const INDEX_OBJECT_COUNT = 'objectCount';

    /*
     * Called after all tests are completed regardless of success or failure
     */
    public static function tearDownAfterClass()
    {
        parent::tearDownAfterClass();

        // Get a sessionId if none is present
        if (empty(self::$sessionId))
        {
            self::getSessionId();
        }
        
        /*
         * Try and delete all objects that where created for the tests
         * in case one wasn't deleted during a test failure
         */
        foreach (self::$idArray as $className => $values)
        {
            foreach ($values as $id)
            {
                self::deleteContent($className, $id);
            }
        }
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        // Sanity check
        if (!file_exists(dirname(__FILE__) . '/../config/config.php'))
        {
            die('Cannot find config, aborting test');
        }
        if (!function_exists('curl_close'))
        {
            die("The function 'curl_init' not found, aborting test");
        }
        if (!function_exists('curl_setopt'))
        {
            die("The function 'curl_setopt' not found, aborting test");
        }
        if (!function_exists('curl_exec'))
        {
            die("The function 'curl_exec' not found, aborting test");
        }
        if (!function_exists('curl_init'))
        {
            die("The function 'curl_init' not found, aborting test");
        }

        parent::setUp();
    }

    //========================================================================//
    // HELPER METHODS
    //========================================================================//
    /*
     * Preform a GET request for a sessionId and url encode it
     * This method will set self::$sessionIdError if any errors occurred
     *
     * @return String url encoded session id
     */
    public static function getSessionId()
    {
        // clear the error message
        self::$sessionIdError = null;

        // set up the url
        $ch = curl_init(
            BASE_URI . self::SEPERATOR . self::SESSION_CONTROLLER . '?'
            . self::USERNAME_PARAMETER . '=' . urlencode(USERNAME) . '&'
            . self::PASSWORD_PARAMETER . '=' . urlencode(PASSWORD)
        );

        // Curl options for a PUT request
        curl_setopt($ch, CURLOPT_PUT, true);
        curl_setopt($ch, CURLOPT_INFILESIZE, 0);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HEADER, true);

        // execute the request
        $response = curl_exec($ch);

        // retreive and test if a curl error occurred
        $error = curl_error($ch);

        if ($error != '' || $error != null)
        {
            self::$sessionIdError = 'The following Curl error occurred while ';
            self::$sessionIdError .= 'trying to execute the request: \'';
            self::$sessionIdError .= $error . '\'';

            curl_close($ch);
            return;
        }

        // get the http response status code
        $returned_status_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

        // test the status code
        if ($returned_status_code != 201)
        {
            self::$sessionIdError = 'Returned status code should be 201 but is: ';
            self::$sessionIdError .= $returned_status_code . '\n';
            self::$sessionIdError .= 'The requested url was: ';
            self::$sessionIdError .= curl_getinfo($ch, CURLINFO_EFFECTIVE_URL);
            self::$sessionIdError .= '\n';

            curl_close($ch);
            return;
        }

        // Retrieve the sessionId from the headers
        $pattern = '/' . self::SESSION_ID_HEADER  . ':(.*?)\n/';
        $match = preg_match($pattern, $response, $result);
        
        // test that the session id was found in the response headers
        if ($match != 1)
        {
            self::$sessionIdError =  'The response header \'';
            self::$sessionIdError .= self::SESSION_ID_HEADER;
            self::$sessionIdError .= '\' was not found';

            curl_close($ch);
            return;
        }
        
        self::$sessionId = trim($result[1]);

        curl_close($ch);
        
//        /*
//         * Get the location of the newly created session, GET the session
//         * and extract the id(primary key id in the DB, not the sessionId token)
//         * Store the id in the idArray for deletion after completion of the tests
//         */
//        
//        
//        // Retrieve the location header value
//        $pattern = '/location: (.*?)\n/';
//        $match = preg_match($pattern, $response, $result);
//     
//        // test that the location header was found in the response headers
//        if ($match != 1)
//        {
//            self::$sessionIdError =  'The response header \'';
//            self::$sessionIdError .= self::LOCATION_HEADER;
//            self::$sessionIdError .= '\' was not found';
//
//            curl_close($ch);
//            return;
//        }
//        
//        // remember the session id
//        $locationUrl = $result[1];
//
//        // set up the url
//        $ch = curl_init($locationUrl);
//        
//        // Setup the Curl for a GET request
//        curl_setopt($ch, CURLOPT_POST, false);
//        curl_setopt($ch, CURLOPT_PUT, false);
//        curl_setopt($ch, CURLOPT_HTTPGET, true);
//        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
//        
//        // execute the request
//        $response = curl_exec($ch);
//
//        // retreive and test if a curl error occurred
//        $error = curl_error($ch);
//
//        if ($error != '' || $error != null)
//        {
//            self::$sessionIdError = 'The following Curl error occurred while ';
//            self::$sessionIdError .= 'trying to execute the request: \'';
//            self::$sessionIdError .= $error . '\'';
//
//            curl_close($ch);
//            return;
//        }
//
//        // get the http response status code
//        $returned_status_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
//
//        // test the status code
//        if ($returned_status_code != 200)
//        {
//            self::$sessionIdError = 'Returned status code should be 200 but is: ';
//            self::$sessionIdError .= $returned_status_code . '\n';
//            self::$sessionIdError .= 'The requested url was: ';
//            self::$sessionIdError .= curl_getinfo($ch, CURLINFO_EFFECTIVE_URL);
//            self::$sessionIdError .= '\n';
//
//            curl_close($ch);
//            return;
//        }
//
//        curl_close($ch);
//        
//        // Retrieve the sessions internal id(database primary key)
//        $pattern = '/\<id\>(.*?)\<\/id\>/';
//        $match = preg_match($pattern, $response, $result);
//        $id = $result[1];
//
//        // save the session id in the id array
//        self::$idArray[self::SESSION_BIZ_CLASS][] = $id;
    }

    /*
     * Creates a WCM article object in WCM
     *
     * @param $workflowState Optional parameter specifying the workflow state of
     *                       the article, default is null
     *
     * @returns The id of the newly created article
     */
    protected function createArticle($workflowState = null)
    {
        $article = '<article>';
        $article .= '<siteId>3</siteId>';
        $article .= '<title>test title</title>';
        $article .= '<workflowState>' . $workflowState . '</workflowState>';
        $article .= '<className>article</className>';
        $article .= '<objectType>article</objectType>';
        $article .= '</article>';

        $id = $this->createContent(self::ARTICLE_BIZ_CLASS, $article);
        self::assertTrue(is_numeric($id), 'Article could not be created');
        
        // rememeber the id of the newly created article
        self::$idArray[self::ARTICLE_BIZ_CLASS][] = $id;
        
        return $id;
    }

    /*
     * Creates a WCM workflow object in WCM
     *
     * @param $initialState The initial state that the workflow should be in,
     *                      default is null
     *
     * @returns The id of the newly created workflow
     */
    protected function createWorkflow($initialState = null)
    {
        $workflow = '<wcmWorkflow>';
        $workflow .= '<name>Test workflow</name>';
        $workflow .= '<initialState>' . $initialState . '</initialState>';
        $workflow .= '<script>publicationWorkflow.php</script>';
        $workflow .= '<className>wcmWorkflow</className>';
        $workflow .= '<objectType>wcmWorkflow</objectType>';
        $workflow .= '</wcmWorkflow>';

        $id = $this->createContent(self::WORKFLOW_BIZ_CLASS, $workflow);
        self::assertTrue(is_numeric($id), 'Workflow could not be created');
        
        self::$idArray[self::WORKFLOW_BIZ_CLASS][] = $id;
        
        return $id;
    }

    /*
     * Creates a WCM user object in WCM
     *
     * getSessionId
     *
     * @return The id of the newly created user
     *
     * @return int The identifier of the newly created user object
     */
    protected static function createUser()
    {
        $user = '<wcmUser>';
        $user .= '<name></name>';
        $user .= '<login>' . rand() . '</login>';
        $user .= '<email>emailadress</email>';
        $user .= '<password>21232f297a57a5a743894a0e4a801fc3</password>';
        $user .= '<className>wcmUser</className>';
        $user .= '<objectType>wcmUser</objectType>';
        $user .= '</wcmUser>';

        $id = self::createContent(self::USER_BIZ_CLASS, $user);
        self::assertTrue(is_numeric($id), 'User could not be created');

        self::$idArray[self::USER_BIZ_CLASS][] = $id;
        
        return $id;
    }

    /*
     * Creates a WCM photo object in WCM
     *
     * @return int The identifier of the newly created photo object
     */
    protected static function createPhoto($siteId, $imageName)
    {
        $photo = '<photo>';
        $photo .= '<siteId>' . $siteId . '</siteId>';
        $photo .= '<title>test photo</title>';
        $photo .= '<original>img/photos/biz/' . $imageName . '</original>';
        $photo .= '</photo>';

        $id = self::createContent(self::PHOTO_BIZ_CLASS, $photo);
        self::assertTrue(is_numeric($id), 'User could not be created');
        
        self::$idArray[self::PHOTO_BIZ_CLASS][] = $id;
        
        return $id;
    }

    /*
     * Creates a WCM site object in WCM
     *
     * @return int The identifier of the newly created site object
     */
    protected static function createSite()
    {
        $uniq = md5(time() . uniqid());

        $site = '<site>';
        $site .= '<title>My web site</title>';
        $site .= '<code>' . $uniq . '</code>';
        $site .= '</site>';

        $id = self::createContent(self::SITE_BIZ_CLASS, $site);
        self::assertTrue(is_numeric($id), 'Site could not be created');

        self::$idArray[self::SITE_BIZ_CLASS][] = $id;
        
        return $id;
    }

    /*
     * Deletes a WCM user object from WCM
     *
     * @param $id int The id of the user to delete
     */
    protected static function deleteUser($id)
    {
        self::deleteContent(self::USER_BIZ_CLASS, $id);
    }

    /*
     * Deletes a WCM photo object from WCM
     */
    protected static function deletePhoto($id)
    {
        self::deleteContent(self::PHOTO_BIZ_CLASS, $id);
    }

    /*
     * Deletes a WCM article object from WCM
     *
     * @param $id The identifier of the article to delete
     */
    protected static function deleteArticle($id)
    {
        // create an object as not to modify the state of the calling object
        $rt = new WcmTest;

        $rt->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::ARTICLE_BIZ_CLASS . self::SEPERATOR . $id
        );

        $rt->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $rt->executeRequest();
    }

    /*
     * Deletes a WCM workflow object from WCM
     *
     * @param $id The identifier of the workflow to delete
     */
    protected static function deleteWorkflow($id)
    {
        self::deleteContent(self::WORKFLOW_BIZ_CLASS, $id);
    }

    /*
     * Deletes a WCM site object from WCM
     */
    protected static function deleteSite($id)
    {

        self::deleteContent(self::SITE_BIZ_CLASS, $id);
    }

    /*
     * Deletes a WCM generation object from WCM
     */
    protected function deleteGeneration($id)
    {
        self::deleteContent(self::GENERATION_BIZ_CLASS, $id);
    }

    /*
     * Deletes a WCM generationSet object from WCM
     */
    protected function deleteGenerationSet($id)
    {
        self::deleteContent(self::GENERATION_SET_BIZ_CLASS, $id);
    }

    /*
     * Helper function for creating a SQL WHERE query string
     * where id={id} OR id={id} OR ...
     *
     *
     * @param $idArray An array of ids to include in the where query string
     *                 being built be the function
     *
     * @return String The SQL query string
     *
     */
    protected function getSqlWhereIdEqualsQuery($idArray)
    {
        // prepare the ids for the WHERE query string
        $whereQuery = null;
        foreach ($idArray as $id)
        {
            $whereQuery .= 'id=' . $id . ' OR ';
        }

        // get rid of the last ' OR '
        $whereQuery = substr($whereQuery, 0, -4);

        return $whereQuery;
    }

    /*
     * Retrieves an xml elements value, must be a first level element that is
     * unique.
     *
     *
     * @param $rt The WcmTest object that contains the response body to extract
     *            the element from
     * @param $elementName String The name of the element to try and retrieve
     *                            the value
     *
     * @return The value of the element that was found
     *
     */
    protected function getXmlElement($rt, $elementName)
    {
        // Transform the result to a simplexml object to use xpath traversal
        try
        {
            $sxml = new SimpleXMLElement($rt->getBody());
        }
        catch (Exception $e)
        {
            $this->assertTrue(
                false, 'The xml is not valid:' . "\n\n" . $rt->getBody()
            );
        }

        return (String)$sxml->$elementName;

    }

    /*
     * Retrieves xml element values defined by an xpath from a WcmTest object
     *
     *
     * @param $rt The WcmTest object whos body is used to find the elements
     * @param $xpath String The xpath where the elements are located
     *
     * @return An array of the element values
     *
     */
    protected function getXmlElements($rt, $xpath)
    {
        $result = array(); // The array of element values to be returned

        // Transform the result to a simplexml object to use xpath traversal
        try
        {
            $sxml = new SimpleXMLElement($rt->getBody());
        }
        catch (Exception $e)
        {
            $this->assertTrue(
                false, 'The xml is not valid:' . "\n\n" . $rt->getBody()
            );
        }

        // Get the elements defined by the xpath and put their value into $result
        foreach ($sxml->xpath($xpath) as $element) {

            $result[] = (String)$element;

        }

        return $result;
    }

    /*
     * Validates that the body of the http represents the correct object
     *
     * @param $expectedObject The expected object
     * @param $expectedId The expected id of the actual object
     * @param $response The actual object to test against, if none is given then the body of the last response is used
     */
    protected function validateReturnedJsonObject($expectedObject, $expectedId, $response = null)
    {
        // set the actual object, if no argument was given then use the body of
        // the last response
        $actual = null;
        if ($response == null)
        {
            $actual .= $this->getBody();
        }
        else
        {
            $actual .= $response;
        }

        // only test if there is an actual object to test against
        if ($actual !== null && $actual !== '')
        {
            // build the object
            if (($actualObject = json_decode($actual)) === null)
            {
                $this->assertTrue(false, 'The json of the body was not valid: ' . $actual);
            }

        }
        // validate that the actual object has the same id as expected
        $this->assertEquals($actualObject->{'id'}, $expectedId);
    }

    /*
     * Validates that the body of the http represents the correct object
     *
     * @param $expectedObject String The string representation of the object we
     *                        are excpecting in the response body
     * @param $expectedid int The id the returned object should have, needs to
     *                        be passed as a paramneter because WCM returned
     *                        it after the object was created
     * @param $response String An optionnal string to compare the expected object
     *                         to, usful for testing returned locations without
     *                         modifying the state of $this and the original
     *                         request/response
     *
     */
    protected function
    validateReturnedXmlObject($expectedObject, $expectedId, $response = null)
    {
        // set the actual object
        if ($response == null)
        {
            $actual = $this->getBody();
        }
        else
        {
            $actual = $response;
        }

        // only test if there is an actual object to test against
        if ($actual != null && $actual != '')
        {
            // build the objects(actual and expected) into simpleXML objects
            try
            {
                $sxmlResponseBody   = new SimpleXMLElement($actual);
            }
            catch (Exception $e)
            {
                $this->assertTrue(
                    false, 'The xml of the body was not valid: ' . $actual
                );
            }

            try
            {
                $sxmlexpectedObject = new SimpleXMLElement($expectedObject);
            }
            catch (Exception $e)
            {
                $this->assertTrue(
                    false, 'The xml of the body was not valid: ' .
                    $expectedObject
                );
            }

            // Get the values to compare
            try
            {
                $expectedNames = $sxmlexpectedObject->xpath('//name');
                $expectedName = (String)$expectedNames[0];
                $responseNames = $sxmlResponseBody->xpath('//name');
                $responseName = (String)$responseNames[0];

                $expectedClassNames = $sxmlexpectedObject->xpath('//className');
                $expectedClassName = (String)$expectedClassNames[0];
                $responseClassNames = $sxmlResponseBody->xpath('//className');
                $responseClassName = (String)$responseClassNames[0];

                $expectedObjectTypes = $sxmlexpectedObject->xpath('//objectType');
                $expectedObjectType = (String)$expectedObjectTypes[0];
                $responseObjectTypes = $sxmlResponseBody->xpath('//objectType');
                $responseObjectType = (String)$responseObjectTypes[0];

                $responseIds = $sxmlResponseBody->xpath('//id');
                $responseId = (Integer)$responseIds[0];
            }
            catch (Exception $e)
            {
                $this->assertTrue(false, 'Error with the xml structure.');
            }

            // Validate that the expected values and the actual values are the same
            if ($responseId     != $expectedId         ||
                $responseObjectType != $expectedObjectType ||
                $responseClassName  != $expectedClassName  ||
                $responseName       != $expectedName
                )
            {

                $this->assertTrue(
                    false, 'The returned body is not the same as expected.' .
                    "\n" . '$responseId:\'' . $responseId . "'\n" .
                    '$expectedId:\'' . $expectedId . "'\n" .
                    '$responseObjectType:\'' . $responseObjectType . "'\n" .
                    '$expectedObjectType:\'' . $expectedObjectType . "'\n" .
                    '$responseClassName:\'' . $responseClassName . "'\n" .
                    '$expectedClassName:\'' . $expectedClassName . "'\n" .
                    '$responseName:\'' . $responseName . "'\n" .
                    '$expectedName:\'' . $expectedName . "'\n"
                );
            }
        }

    }

    /*
     * TODO: Do we need to add the sessionId in here? it's broken now but in the
     *       future will it need the sessionId?
     */
    protected function validateLocationHeader()
    {
        // get the location header
        $url = $this->getHeader(self::LOCATION_HEADER);

        // validate the location
        $this->validateLocation($url);
    }

    /*
     * Method for retrieving and validating the id in the body of the response
     */
    protected function getId()
    {
        $this->assertTrue(
            is_numeric($this->getBody()),
            'The body of the response was meant to be an integer representing the id of the object. Instead, this was returned: ' . $this->getBody()
        );
        return $this->getBody();
    }

    /*
     * Creates a business/system object in WCM
     *
     *
     * @param $resource String The ReST resource to create(a wcm biz/sys class)
     * @param $id int          The identifier of the object to create
     */
    private static function createContent($resource, $content)
    {
        // create a new object as not to modify the state of the calling object
        $rt = new WcmTest;

        $rt->setResource(self::CONTENT_CONTROLLER . self::SEPERATOR . $resource);

        $rt->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($content)
        );

        $rt->executeRequest();

        //TODO: store the id in the idArray, can we check to make sure and id is returned in the body?
        return $rt->getBody();
    }
    /*
     * Deletes a business/system object from WCM
     *
     *
     * @param $resource String The ReST resource to delete(a wcm biz/sys class)
     * @param $id int          The identifier of the object to delete
     *
     */
    private static function deleteContent($resource, $id)
    {
        // new WcmTest object as not to modify the state of the calling object
        $rt = new WcmTest;

        $rt->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            $resource . self::SEPERATOR . $id
        );

        if (empty(self::$sessionId))
        {
            self::getSessionId();
        }
        
        $rt->setupDELETE(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $rt->executeRequest();
    }
}