<?php
/**
 * Project:     WCM
 * File:        $Id: biz.article.php 9358 2010-04-01 15:12:10Z berejeba $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Definition of an article
 */
class article extends bizobject
{
    /**
    * Last chapter rank used
    * @var int
    */
    private $lastChapterRank = 0;


    /**
    * site id
    * @var int
    */
    public $siteId;

    /**
    * channel id
    * @var int
    */
    public $channelId;

    /**
    * template id
    * @var int
    */
    public $templateId;

    /**
    * Title
    * @var string
    */
    public $title;

    /**
    * Sup-title
    * @var string
    */
    public $suptitle;

    /**
    * Sub-title
    * @var string
    */
    public $subtitle;

    /**
    * Keywords
    * @var string
    */
    public $keywords;

    /**
    * Abstract (HTML)
    * @var string
    */
    public $abstract;

    /**
    * Text (HTML)
    * @var string
    */
    public $text;

    /**
    * Publication date
    * @var string
    */
    public $publicationDate;

    /**
    * Expiration date
    * @var string
    */
    public $expirationDate;

    /**
    * Author
    * @var string
    */
    public $author;

    /**
    * Credits for original article
    * @var string
    */
    public $credits;

    //
    // Printed publication properties
    //

    /**
    * Id of the publication which current article belongs to
    * @var int
    */
    public $publicationId;

    /**
    * Id of the issue which current article belongs to
    * @var int
    */
    public $issueId;

    /*
    * First page number of article (in current issue)
    * @var int
    */
    public $pageNumber;

    //
    // Web 2.0 properties (moderation / contribution / rating / hits)
    //

    /**
    * Article moderation kind - see getModerationKindList()
    * @var string
    */
    public $moderationKind;

    /**
    * Contribution mode - see getContributionStateList()
    * @var string
    */
    public $contributionState;

    /**
    * Number of rating done
    * @var int
    */
    public $ratingCount;

    /**
    * Total of ratings
    * @var int
    */
    public $ratingTotal;

    /**
    * Rating value (average: ratingTotal/ratingCount)
    * @var float
    */
    public $ratingValue;

    /**
    * Total number of hits (popularity)
    * @var int
    */
    public $hitCount;


    /**
    * Set all initial values of an object
    * This method is invoked by the constructor
    */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->moderationKind    = 'a_priori';
        $this->contributionState = 'none';
        $this->publicationDate    = null;

        $this->siteId = $this->channelId = null;
        $this->publicationId = $this->issueId = null;
        $this->pageNumber = $this->ratingCount = $this->ratingTotal = $this->ratingValue = 0;
        $this->hitCount = 0;
    }

    /**
    * CheckIn object in database and update search table
    *
    * @param array $source array for binding to class vars (or null)
    * @param int    $userId id of user who create ou update the document
    *
    * @return bool true on success, false otherwise
    *
    */
    public function checkin($source = null, $userId = null)
    {
        // Insert or update the article object
        if (!parent::checkin($source, $userId))
        {
            return false;
        }

        return true;
    }

    /**
    * Exposes 'chapters' to the getAssocArray
    *
    * @param bool $toXML TRUE if method is called in the context of toXML()
    *
    * @return array An array of chapters getAssocArray
    */
    public function getAssoc_chapters($toXML = false)
    {
        $chapters = array();
        if (!empty($this->id))
        {
            foreach ($this->getChapters() as $chapter)
            {
                $chapterAssoc = $chapter->getAssocArray($toXML);
                if ($toXML)
                {
                    $chapterAssoc = $chapterAssoc->toArray();
                }

                $chapters[] = $chapterAssoc;
            }
        }

        return $chapters;
    }

    /**
    * Exposes 'chapters text' to the getAssocArray
    *
    * @param bool $toXML TRUE if method is called in the context of toXML()
    *
    * @return array An array of chapters getAssocArray
    */
    public function getAssoc_chaptersText($toXML = false)
    {
        $chaptersText = '';
        if (!empty($this->id))
        {
            foreach ($this->getChapters() as $chapter)
            {
                $chaptersText.= $chapter->title . ' ' . $chapter->text . PHP_EOL;
            }
        }
        return $chaptersText;
    }



    /**
    * Expose 'fulltext' to getAssocArray by computing a default full-text
    * string used for indexing
    *
    * Remark: this method is exposed by getAssocArray and may be
    * overloaded by inherited classes
    *
    * @param bool $toXML TRUE if method is called in the context of toXML()
    *
    * @return string A full-text representation of the object
    */
    public function getAssoc_fulltext($toXML = false)
    {
        // => Retrieve all string keys
        // => Remove all tags (html, xml)
        // => Parse result text and discard stop words
        $fulltext = null;
        foreach (getPublicProperties($this) as $value)
        {
            if (is_string($value))
            {
                $fulltext .= ' ' . strip_tags($value);
            }
        }

        // => Add chapter's content
        foreach ($this->getChapters() as $chapter)
        {
            $fulltext .= ' ' . $chapter->title;
            $fulltext .= ' ' . strip_tags($chapter->text);
        }

        // Parse text (no stop word, retrieve a single occurence for each word)
        return trim(implode(' ', parseText(getRawText($fulltext), null, true)));
    }

    /**
    * Returns the chapters of the article
    *
    * @return  array An array containing all the bizchapters of the article
    */
    public function getChapters()
    {
        if ($chapters = bizobject::getObjects('chapter', 'articleId=' . $this->id, 'rank'))
        {
            return $chapters;
        }

        return array();
    }

    /**
    * Returns a new rank to sur for a new chapter
    * @return int Rank for chapter
    */
    public function getNewChapterRank()
    {
        if (0 == $this->lastChapterRank)
        {
            $sql = 'SELECT MAX(rank)+1 FROM #__chapter WHERE articleId=' . $this->id;
            $this->lastChapterRank = $this->database->executeScalar($sql);
        }
        else
        {
            $this->lastChapterRank++;
        }

        return $this->lastChapterRank;
    }

    /**
    * Gets the 'semantic' text that will be passed to the Text-Mining Engine
    *
    * @return string The semantic text to mine
    */
    public function getSemanticText()
    {
        $content = '';
        if ($this->suptitle)
        {
            $content .= trim($this->suptitle, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->title)
        {
            $content .= trim($this->title, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->subtitle)
        {
            $content .= trim($this->subtitle, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->keywords)
        {
            $content .= trim($this->keywords, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->abstract)
        {
            $content .= trim($this->abstract, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->text)
        {
            $content .= trim($this->text, " \t\n\r\0\x0B.") . ".\n";
        }

        if ($this->id)
        {
            $chapters = $this->getChapters();
            if (0 == count($chapters))
            {
                if (isset($this->serialStorage['chapters']))
                {
                    foreach ($this->serialStorage['chapters'] as $chapter)
                    {
                        if ($chapter['title'])
                        {
                            $content .= trim($chapter['title'], " \t\n\r\0\x0B.") . ".\n";
                        }
                        if ($chapter['text'])
                        {
                            $content .= trim($chapter['text'], " \t\n\r\0\x0B.") . ".\n";
                        }
                    }
                }
            }
            else
            {
                foreach ($chapters as $chapter)
                {
                    if ($chapter->title)
                    {
                        $content .= trim($chapter->title, " \t\n\r\0\x0B.") . ".\n";
                    }
                    if ($chapter->text)
                    {
                        $content .= trim($chapter->text, " \t\n\r\0\x0B.") . ".\n";
                    }
                }
            }
        }
        return $content;
    }

    /**
    * Computes the sql where clause matching foreign constraints
    * => This method must be overloaded by child class
    *
    * @param array $of Assoc Array with foreign constrains (key=className, value=id)
    *
    * @return string Sql where clause matching "of" constraints or null
    */
    function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'site':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'siteId=' . $value;
                    break;

                case 'channel':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'channelId=' . $value;
                    break;
                case 'id':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'id=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
    * Deletes object from database
    *
    * @return bool true on success or an error message (string)
    */
    public function delete()
    {
        // Delete all children chapters of this article
        $this->deleteChapters();
        return parent::delete();
    }

    /**
    * Delete all the chapters from the database
    */
    public function deleteChapters()
    {
        $this->database->executeStatement('DELETE FROM #__chapter WHERE articleId=?', array($this->id));
    }

    /**
    * Update all the chapters by the chapters given in the array
    *
    * @param array $newChapters  Array of new chapters
    */
    public function updateChapters($newChapters)
    {
        $this->serialStorage['chapters'] = $newChapters;
    }

    /**
    * Gets object ready to store by getting modified date, creation date etc
    * Will execute transition.
    * @return bool TRUE on success
    */
    protected function store()
    {
        if (!parent::store())
        {
            return false;
        }

        $newChapters = getArrayParameter($this->serialStorage, 'chapters');

        if ($newChapters)
        {
            $this->deleteChapters();

            $chapter = wcmObjectFactory::create('chapter');
            $chapter->articleId = $this->id;
            $chapter->rank = 0;

            foreach ($newChapters as $newChapter)
            {
                $chapter->id = 0;
                $chapter->rank++;

                $newChapter['articleId'] = $chapter->articleId;
                $newChapter['id'] = $chapter->id;
                $newChapter['rank'] = $chapter->rank;

                if (!$chapter->save($newChapter))
                {
                    $this->lastErrorMsg = $chapter->lastErrorMsg;
                    return false;
                }
            }
        }
        return true;
    }

    /**
    * Check validity of object
    *
    * A generic method which can (should ?) be overloaded by the child class
    *
    * @return bool true when object is valid
    */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' == trim($this->title))
        {
               $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        if ($this->author  && 255 < strlen($this->author))
        {
            $this->lastErrorMsg = _BIZ_ERROR_AUTHOR_TOO_LONG;
            return false;
        }

        if ($this->credits  && 255 < strlen($this->credits))
        {
            $this->lastErrorMsg = _BIZ_ERROR_CREDITS_TOO_LONG;
            return false;
        }

        if ($this->keywords  && 255 < strlen($this->keywords))
        {
            $this->lastErrorMsg = _BIZ_ERROR_KEYWORDS_TOO_LONG;
            return false;
        }

        if ($this->suptitle  && 255 < strlen($this->suptitle))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SUPTITLE_TOO_LONG;
            return false;
        }

        if ($this->subtitle  && 255 < strlen($this->subtitle))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SUBTITLE_TOO_LONG;
            return false;
        }

        return true;
    }

    /**
    * Fill-in public properties of the sysobject from a valid XML DOMDocument
    * If a XSL is defined, apply the XSL transformation
    *
    * TODO This override of wcmObject::initFromXMLDocument() is only
    * temporary - see the end of the function definition for more
    * details.
    *
    * @param DOMDocument $domXml    XML DOMDocument representing the object
    * @param string        $xslFile  XSL xsl file (if defined, apply the XSL transformation)
    *
    * @return bool True on success, false otherwise
    * @throws Exception
    */
    public function initFromXMLDocument($domXml, $xslFile = null)
    {
        // If XSL, Transform XML document
        if ($xslFile)
        {
            // Create XSL document
            $xslDoc = new DOMDocument();
            $xslDoc->load($xslFile);

            // Create XSLT processor
            $xsltProc = new XSLTProcessor;
            $xsltProc->importStyleSheet($xslDoc);

            // Transform XML document
            $xml = $xsltProc->transformToXML($domXml);

            // Create XML document
            $domXml = new DOMDocument();
            if (!$domXml->loadXML($xml))
            {
                throw new Exception(_BIZ_INVALID_XML);
            }
        }

        $className = $this->getType();
        $domXPath = new DOMXPath($domXml);

        // Set object default values
        $this->setDefaultValues();

        // Expected format is <$className> <$propertyName> $propertyValue </$propertyName> ... </$className>
        foreach (getPublicProperties($this) as $property => $value)
        {
            $xpath = '/' . $className . '/' . $property;
            $node = wcmXML::getXPathFirstNode($domXPath, null, $xpath);
            if ($node)
            {
                // Use custom initialization for this property
                $this->initPropertyFromXMLNode($property, $node);
            }
        }

        // Handle chapters
        //
        // TODO: When $chapters is implemented (holding the serialized
        // contents of the chapters), remove this function!
        //
        $chapterNodes = $domXPath->query('/' . $className . '/chapters/item');
        if ($chapterNodes && $chapterNodes->length > 0)
        {
            $chapters = array();
            foreach ($chapterNodes as $chapterNode)
            {
                $xml = wcmXML::getOuterXml($chapterNode);
                $className = 'item'; // that's what it is in the XML

                $chapter = wcmObjectFactory::create('chapter');
                if (!$chapter->initFromXML($xml, null, $className))
                {
                    return false;
                }

                $chapters[] = $chapter->getAssocArray()->toArray();
            }

            $this->updateChapters($chapters);
        }

        return true;
    }

    /**
    * Fill-in public properties of the sysobject from a JSON fragment
    * as returned by the toJSON method.
    *
    * TODO This override of wcmObject::initFromJSON() is only
    * temporary - see the end of the function definition for more
    * details.
    *
    * @param string $json JSON fragment representing the object
    *
    * @return bool True on success, false otherwise
    */
    public function initFromJSON($json)
    {
        // Decode the JSON representation to an assoc array
        $assocArray = json_decode($json, true);

        // Initialize basic object properties
        if (!$this->initFromJSONAssocArray($assocArray))
        {
            return false;
        }

        // Handle chapters
        //
        // TODO: When $chapters is implemented (holding the serialized
        // contents of the chapters), remove this function!
        //
        if (isset($assocArray['chapters']))
        {
            $chapterAssocs = $assocArray['chapters'];
            if ($chapterAssocs)
            {
                $chapters = array();
                foreach ($chapterAssocs as $chapterAssoc)
                {
                    $chapter = wcmObjectFactory::create('chapter');
                    if (!$chapter->initFromJSONAssocArray($chapterAssoc))
                    {
                        return false;
                    }

                    $chapters[] = $chapter->getAssocArray()->toArray();
                }

                $this->updateChapters($chapters);
            }
        }

        return true;
    }

    /**
    * Adds a user rating to the rank of the object.
    *
    * @param int $rateValue The user rating (usually from 1 to 5)
    */
    public function addRank($rateValue)
    {
        ++$this->ratingCount;
        $this->ratingTotal += $rateValue;
        $this->ratingValue = (1.0 * $this->ratingTotal) / $this->ratingCount;
        $this->store();
    }

    /**
    * Adds a hit to the hit count of the object.
    */
    public function addHit()
    {
        // add new hit count
        ++$this->hitCount;
        $this->store();
    }
}
