<?php
/**
 * Project:     WCM
 * File:        $Id: biz.newsitem.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * This class represents a news item (e.g. a news from AFP, Reuters, AP or else)
 * This class can also be used as a simple article (e.g. without multiple chapters)
 */
class newsitem extends bizobject
{
    /**
    * site id
    * @var int
    */
    public $siteId;

    /**
    * channel id
    * @var int
    */
    public $channelId;

    /**
    * template id
    * @var int
    */
    public $templateId;

    /**
    * Title
    * @var string
    */
    public $title;

    /**
    * Keywords
    * @var string
    */
    public $keywords;

    /**
    * Text
    * @var string
    */
    public $text;

    /**
    * Release date and time
    * @var string
    */
    public $releaseDateTime;

    /**
    * News priority (from 1 to 9)
    * @var int
    */
    public $priority;


    //
    // Web 2.0 properties (moderation / contribution / rating / hits)
    //

    /**
     * Article moderation kind - see getModerationKindList()
     * @var string
     */
    public $moderationKind;

    /**
     * Contribution mode - see getContributionStateList()
     * @var string
     */
    public $contributionState;

    /**
     * Set all initial values of an object
     * This method is invoked by the constructor
     */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->moderationKind    = 'a_priori';
        $this->contributionState = 'none';
        $this->releaseDateTime    = date('Y-m-d H:i');
        $this->priority          = 9;

        $this->siteId = $this->channelId = null;
    }

    /**
     * Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'site':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'siteId=' . $value;
                    break;

                case 'channel':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'channelId=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
     * Gets the 'semantic' text that will be passed to the Text-Mining Engine
     *
     * @return string The semantic text to mine
     */
    public function getSemanticText()
    {
        $content = '';

        if ($this->title)
        {
            $content .= trim($this->title, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->keywords)
        {
            $content .= trim($this->keywords, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->text)
        {
            $content .= trim($this->text, " \t\n\r\0\x0B.") . ".\n";
        }

        return $content;
    }

    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        if ($this->keywords  && 255 < strlen($this->keywords))
        {
            $this->lastErrorMsg = _BIZ_ERROR_KEYWORDS_TOO_LONG;
            return false;
        }

        return true;
    }
}
