<?php
/**
 * Project:     WCM
 * File:        $Id: biz.3SServer.php 9386 2010-04-06 19:10:39Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Simple implementation of the 3S Server
 * This class allows indexing and deindexing from a 3S Server
 *
 */
class biz3SServer
{
    /**
     * the REST client
     * 
     * @var mixed
     */
    private $client;

    /**
     * Sets the rest client from config params
     * 
     * @param  site       $site   The website
     */
    public function __construct(site $site)
    {
        
        $site           = ($site) ? $site : $object->getSite();
        $url            = $site->getConfig('SSS.URL') . '/?' . http_build_query($site->getConfig('SSS.params'));
        $user           = $site->getConfig('SSS.user');
        $password       = $site->getConfig('SSS.password');
        $this->client   = new Nstein_REST_Client($url, $user, $password);
    }

    /**
     * indexes an object in 3S
     * 
     * @param  wcmObject  $object The object to be indexed
     * @Exception Exception with the response error when the indexing fails.
     * @return bool true if the object has been indexed
     */
    public function indexObject(wcmObject $object)
    {
        $response = $this->client->post($this->client->getBaseURI()->getUri(), 'data=' . $object->toXML());
        $parsedResponse = @simplexml_load_string($response->body);
        if (!$parsedResponse)
        {
            $errorMsg  = 'Unable to load XML';
            throw new Exception($errorMsg);
        } 
        elseif (isset($parsedResponse->error))
        {
            $errorMsg  = $parsedResponse->error;
            $errorMsg .= (isset($parsedResponse->report)) ? ' - Error Detail : ' . $parsedResponse->report : '';
            throw new Exception($errorMsg);
        }
        else
        {
            return true;
        }    
    }


    /**
     * deindexes an object 
     *
     * @param  wcmObject  $object The object to be indexed 
     * @return Nstein_REST_Response
     */
    public function deindexObject(wcmObject $object)
    {
        $url = $this->client->getBaseURI()->getUri();
        $params = array('action' =>'delete', 'id' =>$object->id);
        $response =  $this->client->post($url, http_build_query($params));
        $parsedResponse = simplexml_load_string($response->body);
        if (isset($parsedResponse->error))
        {
            $errorMsg  = $parsedResponse->error;
            $errorMsg .= (isset($parsedResponse->report)) ? ' - Error Detail : ' . $parsedResponse->report : '';
            throw new Exception($errorMsg);
        }
        else
        {
            return true;
        } 
    }

}
