<?php
/**
 * Project:     WCM
 * File:        $Id: biz.sqlAliasDataAccess.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * The SQL alias data access layer.
 */
class sqlAliasDataAccess
{
    /**
     * The wcmDatabase instance used to connect to
     * the SQL alias front-end database.
     * @var wcmDatabase
     */
    private $database;

    /**
     * The name of the database table.
     * @var string
     */
    private $tableName;

    /**
     * Public constructor.
     * @param wcmDatabase $database The wcmDatabase 
     * instance used to connect to the SQL alias 
     * front-end database.
     * @param string $tableName The name of the 
     * database table.
     */
    public function __construct(wcmDatabase $database, $tableName)
    {
        $this->database = $database;
        $this->tableName = $tableName;
    }

    /**
     * Set the aliases for a given destination URL.
     * @param string $referentClass The class of the referent object
     * @param string $referentId    The Id of the referent object
     * @param string $destination The destination URL.
     * @param array $aliases The aliases.
     * @return void
     */
    public function setAliases($referentClass, $referentId, $destination, array $aliases)
    {
        $this->deleteAliases($referentClass, $referentId, $aliases);
        $this->addAliases($referentClass, $referentId, $destination, $aliases);
    }

    /**
     * Add a list of aliases for a single destination.
     * @param string $referentClass The class of the referent object
     * @param string $referentId    The Id of the referent object
     * @param array $aliases The aliases to add.
     * @return void
     * @exception InvalidArgumentException If 
     * $destination is empty.
     */
    public function addAliases($referentClass, $referentId, $destination, array $aliases)
    {
        if (!$aliases)
        {
            return;
        }

        if (!$destination)
        {
            throw new InvalidArgumentException('Destination is empty');
        }

        $sql = 'INSERT IGNORE INTO ' . $this->tableName . ' VALUES ';
        $values = '';
        $params = array();
        foreach ($aliases as $alias)
        {
            if ($values)
            {
                $values .= ',';
            }
            $values .= '(?, ?, ?, ?, ?)';
            $params[] = $alias;
            $params[] = $destination;
            $params[] = '';
            $params[] = $referentClass;
            $params[] = $referentId;
        }
        $sql .= $values;

        $this->database->executeQuery($sql, $params);
    }

    /**
     * Delete all aliases for a given destination URL that
     * are not in the provided alias list.
     * @param string $referentClass The class of the referent object
     * @param string $referentId    The Id of the referent object
     * @param array $excludeAliases The aliases not to delete.
     * @return void
     */
    public function deleteAliases($referentClass, $referentId, array $excludeAliases = array())
    {
        $sql = 'DELETE FROM ' . $this->tableName . ' WHERE referentClass=? AND referentId=?';
        $params = array($referentClass, $referentId);
        if (count($excludeAliases) > 0)
        {
            $sql .= 'AND alias NOT IN (';
            $values = '';
            foreach ($excludeAliases as $alias)
            {
                if ($values)
                {
                    $values .= ',';
                }
                $values .= '?';
                $params[] = $alias;
            }
            $sql .= $values . ')';
        } 
        $this->database->executeQuery($sql, $params);
    }
}
