<?php
/**
 * Project:     WCM
 * File:        $Id: biz.toolbox_user.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */
/**
 * Generic functions to authenticate against the webuser database or otherwise
 *
 */


/**
 * Simple function to create a user with the least amount of information possible.
 *
 * This requires a username, password and email. If $argConfirm is set to true
 * then the user status is seting to webuser::STATUS_WAITING automatically. If a
 * username is the same as an email address, just supply the email address for
 * both username and email.
 *
 * @param string $argUser Username
 * @param string $argPass Password
 * @param string $argEmail Email Address
 * @param bool $argConfirm Whether or not user needs to be validated first.
 * @return int The new ID created.
 */
function basicCreateUser($argUser, $argPass, $argEmail, $argConfirm = false)
{
    $wu = new webuser;
    $wu->username = $argUser;
    $wu->email = $argEmail;
    $wu->setPassword($argPass);

    if ($argConfirm)
    {
        $wu->workflowState = webuser::STATUS_WAITING;
    }
    else
    {
        $wu->workflowState = webuser::STATUS_VALID;
    }
    $wu->store();

    return $wu->id;
}

/**
 * Checks to see if a username/password is valid in the biz_webuser table.
 *
 * @param string $argUser Username
 * @param string $argPass Password
 * @return int The webuser ID OR false if failed to authenticate.
 */
function basicAuthenticate($argUser, $argPass)
{
    $id = webuser::checkCredentials($argUser, $argPass);
    return $id ? $id : false;
}

/**
 * Determins if a user is logged in right now
 *
 * @return bool True if logged in, false if not.
 */
function isLoggedIn()
{
    return isset($_SESSION['wcm']['auth']) ? true : false;
}

