<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.masterClassRegistry.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

class wcmMasterClassRegistry
{
    /**
     * Array of all instanciated masterClasses
     * @var array
     */
    public static $_masterClasses = array();

    /**
     * Get the master class of a given object
     *
     * @param wcmObject $object object for which we want to retrieve the masterclass
     * @return wcmSysclass Masterclass object
     */
    public static function getMC($object)
    {
        if (!isset(self::$_masterClasses[get_class($object)]['mc']))
        {
            self::getMasterClasses($object);
        }

        return self::$_masterClasses[get_class($object)]['mc'];
    }

    /**
     * Get the workflow class of a given object
     *
     * @param wcmObject $object object for which we want to retrieve the workflow class
     * @return wcmWorkflow Workflow object
     */
    public static function getWorkflow($object)
    {
        if (!isset(self::$_masterClasses[get_class($object)]['workflow']))
        {
            self::getMasterClasses($object);
        }

        return self::$_masterClasses[get_class($object)]['workflow'];
    }
    
    /**
     * Get the workflow script assigned to the class of a given object.
     * @param wcmObject $object The object.
     * @return wcmIWorkflowScript
     */
    public static function getWorkflowScript($object)
    {
        if (!isset(self::$_masterClasses[get_class($object)]['workflowScript']))
        {
            self::getMasterClasses($object);
        }
        $project = wcmProject::getInstance();
        $scriptPath = self::$_masterClasses[get_class($object)]['workflowScript'];
        if (!$scriptPath)
        {
            return null;
        }
        return $project->workflowManager->createWorkflowScript($scriptPath, $object);
    }

    /**
     * Get the database object of a given object
     *
     * @param wcmObject $object object for which we want to retrieve the database object
     * @return wcmDatabase Database object
     */
    public static function getDatabase($object)
    {
        if (!isset(self::$_masterClasses[get_class($object)]['database']))
        {
            self::getMasterClasses($object);
        }

        return self::$_masterClasses[get_class($object)]['database'];
    }

    /**
     * Get the table name of a specific object
     *
     * @param wcmObject $object object for which we want to retrieve the table name
     * @return string table name
     */
    public static function getTableName($object)
    {
        if (!isset(self::$_masterClasses[get_class($object)]['tableName']))
        {
            self::getMasterClasses($object);
        }

        return self::$_masterClasses[get_class($object)]['tablename'];
    }

    /**
     * Define if the object is using optimistic lock or not
     *
     * @param wcmObject $object object for which we want to now lock mechanism
     * @return bool true if lock is optimistic
     */
    public static function getIsLockOptimistic($object)
    {
        $class = get_class($object);
        if (!isset(self::$_masterClasses[$class]['isLockOptimistic']))
        {
            self::getMasterClasses($object);
        }

        return self::$_masterClasses[$class]['isLockOptimistic'];
    }

    /**
     * Retrieve all masterclass for a specific object
     *
     * @param wcmObject $object object for which we want to retrieve all the masterclass
     * @throws Exception    Configuration errors
     */
    public static function getMasterClasses($object)
    {
        $class = get_class($object);
        $project = wcmProject::getInstance();

        // Not having the sysclass/bizclass is a fatal error!
        if ($object instanceOf wcmBizobject)
        {
            $mc = $project->bizlogic->getBizclassByClassName($object->getType());
            if (!$mc)
            {
                throw new exception('FATAL ERROR: WCM is not well configured: Cannot find bizclass for ' . $object->getType());
            }

            $connector = $mc->getConnector();
            if (!$connector)
            {
                throw new exception('FATAL ERROR: Invalid connector reference for bizclass ' . $object->getType());
            }

            self::$_masterClasses[$class]['database'] = $connector->getBusinessDatabase();
        }
        else
        {
            $mc = $project->bizlogic->getSysclassByClassName($object->getType());

            if (!$mc)
            {
                throw new exception('FATAL ERROR: WCM is not well configured: Cannot find sysclass for ' . $object->getType());
            }

            self::$_masterClasses[$class]['database'] = $project->database;
        }

        self::$_masterClasses[$class]['mc'] = $mc;

        // Retrieve connector table, lock mode and workflow
        self::$_masterClasses[$class]['tableName'] = $mc->connectorTable;
        self::$_masterClasses[$class]['isLockOptimistic'] = $mc->allowOptimisticLock;

        // A workflow cannot load dynamically a workflow to avoid recursion (endless loop)
        if (($object instanceOf wcmWorkflow) || !property_exists(get_class($mc), 'workflowId') || !$mc->workflowId)
        {
            self::$_masterClasses[$class]['workflow'] = null;
            self::$_masterClasses[$class]['workflowScript'] = null;
        }
        else
        {
            self::$_masterClasses[$class]['workflow'] = $project->workflowManager->getWorkflowById($mc->workflowId);
            self::$_masterClasses[$class]['workflowScript'] = $mc->workflowScript;
        }
    }
}

