<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.resultSet.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * Result set class
 *
 */

class wcmResultSet extends wcmAbstractResultSet
{

    /**
     * PDOStatement taken from wcmStatement::getQuery()
     *
     * @var PDOStatement
     */
    protected $pdo;

    /**
     * Constructor
     * @param wcmStatement $argStatement Statement executed
     * @param int $argFetchMode Fetch mode
     * @param mixed $argFetchParam Fetch parameters
     *
     */
    public function __construct(wcmStatement $argStatement, $argFetchMode = null, $argFetchParam = null)
    {
        parent::__construct($argStatement, $argFetchMode, $argFetchParam);
        $this->pdo = $this->statement->getQuery();
    }

    /**
     * Rewind iterator pointer
     * @return bool Always TRUE
     */
    public function rewind()
    {
        return true;
    }

    /**
     * Advance iterator pointer to next record
     *
     * @return mixed Next record
     */
    public function next()
    {
        $this->currentRowNumber++;
        $this->currentRow = $this->pdo->fetch($this->fetchMode);
        return $this->currentRow;
    }

    /**
     * Get record at current pointer position
     *
     * @return mixed Current record
     */
    public function current()
    {
        return $this->currentRow;
    }

    /**
     * Get current record key
     *
     * @return int Current record key
     */
    public function key()
    {
        return $this->currentRowNumber;
    }

    /**
     * Check if current record is valid
     *
     * @return bool TRUE if valid, false if not
     */
    public function valid()
    {
        return (isset($this->currentRow));
    }

    /**
     * Get number of records in result set
     *
     * @return int Number of records
     */
    public function count()
    {
        return $this->statement->rowCount();
    }

    /**
     * Called on serialization
     */
    public function __sleep()
    {
        return array();
    }

}

