<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.datalayer.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The wcmDatalayer class is an helper class used to manage connectors and tables
 */
class wcmDatalayer
{
    /**
     * Returns an array of database tables used by the system
     *
     * @return array An array of all table names used by the system
     */
    public static function getSystemDBTables()
    {
        return array('biz__relation', 'biz__list', 'biz__search');
    }

    /**
     * Returns a connector by its id
     *
     * @param int $id The connector id
     *
     * @return wcmConnector A wcmConnector object with given id (or null if id is invalid)
     */
    public function getConnectorById($id)
    {
        // Get list from cache
        return getArrayParameter($this->getConnectors(), $id, null);
    }

    /**
     * Returns a connector by its reference
     *
     * @param string $reference The connector reference
     *
     * @return wcmConnector A wcmConnector matching given reference (or null if none found)
     */
    public function getConnectorByReference($reference)
    {
        // Get list from cache
        foreach ($this->getConnectors() as $connector)
        {
            if (0 == strcasecmp($connector->reference, $reference))
            {
                return $connector;
            }
        }
        return null;
    }

    /**
     * Returns an array of connectors matching specific conditions
     *
     * @param bool $resetCache (optional) whether to reset the cache, ie. load from DB (default is false)
     *
     * @return array An associative array of connectors (keys are connectors id) or null on error
     */
    public function getConnectors($resetCache = false)
    {
        // Cache objects
        $cached = wcmCacheRegistry::get()->fetch('wcmConnector');
        if ($resetCache || $cached === false)
        {
            $cached = array();
            $enum = new wcmEnumeration('wcmConnector', null, 'name');

            foreach ($enum as $connector)
            {
                $cached[$connector->id] = $connector;
            }

            // Cache objects
            wcmCacheRegistry::get()->store('wcmConnector', $cached);
        }

        return $cached;
    }
}
