<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.generationAutogen.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class represents a Autogen object.
 * the autogen object manages the association between generation
 * content and objects
 */
class wcmGenerationAutogen extends wcmSecureObject
{
    /**
     * @var (int) The generation content id
     */
    public $generationContentId = null;

    /**
     * @var (string) The object classname
     */
    public $objectClass = null;

    /**
     * @var (int) The generation priority.
     */
    public $priority = null;

    /**
     * Get the database used to store/fetch object
     *
     * IMPORTANT: This method is called by the constructor
     * Therefore, you may need to override this method to
     * define your database and tableName the first time.
     *
     * @return wcmDatabase Database used to store/fetch object
     */
    public function getDatabase()
    {
        if (!$this->database)
        {
            $this->database = wcmProject::getInstance()->database;
            $this->tableName = '#__generation_autogen';
        }

        return $this->database;
    }

    /**
     * returns all available generations for a contentId
     *
     * @param (int) $autogenId The generationContent id.
     *
     * @return (array) Assoc array filled with key => obejctClassName value => priority.
     */
    public function getAutogens($autogenId)
    {
        $return = array();
        if ($autogenId)
        {
            $sql = 'SELECT objectClass, priority FROM `' . $this->getTableName() . '` WHERE generationContentId =' . $autogenId;
            if ($results = $this->getDatabase()->executeQuery($sql))
            {
                while ($results->next())
                {
                    $row = $results->current();
                    $return[$row['objectClass']] = $row['priority'];
                }
            }
        }

        return $return ;
    }

    /**
     * Method used to delete all generationContentAutogen of a specific generationContentId.
     *
     * @param (int) $generationContentId The generationContentId.
     *
     * @return (boolean) true if the delete succed / false otherwise.
     */
    public function deleteByGenerationContentId($generationContentId)
    {
        if (is_numeric($generationContentId) && 0 < $generationContentId)
        {
            $sql = 'DELETE FROM `' . $this->getTableName() . '` WHERE generationContentId =' . $generationContentId;
            return $this->getDatabase()->executeQuery($sql);
        }

        return false;
    }
}
