<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.cachePluginAPC.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class supports different caching mechanism based on configuration file.
 * The best practice is to use the 'APC' extension, However, if APC is not set,
 * wcmCache will use Cache_Lite (as 'Lite' mode)
 */
class wcmCachePluginAPC implements wcmICachePlugin
{
    /**
     * Store a variable in cache
     *
     * @param string $key Unique key used to retrieve (fetch) variable
     * @param mixed $var Variable to cache
     * @param int $ttl Optional time to live (default is configuration ttl)
     *
     * @return bool FALSE on failure, TRUE on success
     */
    public function store($key, $var, $ttl = 0)
    {
        return apc_store($key, serialize($var), $ttl);
    }

    /**
     * Fetch a cached variable
     *
     * @param string $key Unique key used to retrieve (fetch) variable
     *
     * @return mixed Variable value or else FALSE on failure
     */
    public function fetch($key)
    {
        $cached = unserialize(apc_fetch($key));
        return $cached ? $cached : false;
    }

    /**
     * Delete a cached variable
     *
     * @param string $key Unique key representing the variable to delete
     *
     * @return bool FALSE on failure, TRUE on success
     */
    public function delete($key)
    {
        return apc_delete($key);
    }

    /**
     * Clear the entire cache
     * @return bool TRUE on success
     */
    public function clear()
    {
        return apc_clear_cache('user');
    }
}
