<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.savedSearch.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

class wcmSavedSearch extends wcmObject
{
    /**
     * Name of saved search
     *
     * @var string
     */
    public $name;

    /**
     * Description of saved search
     *
     * @var string
     */
    public $description;

    /**
     * userId of saved search owner
     *
     * @var int
     */
    public $userId;

    /**
     * Lucene-syntax query string
     *
     * @var string
     */
    public $queryString;

    /**
     * Search URL
     *
     * @var string
     */
    public $url;

    /**
     * Boolean to indicate whether the saved search is part of the dashboard or not
     * @var bool
     */
    public $dashboard;

    /**
     * Boolean to indicate whether the saved search is accessible to all the users or just the creator
     * @var bool
     */
    public $shared;

    /**
     * array that indicates whether the saved search is accessible to all the users or just the creator
     * @var array
     */
    public $showui;

    /**
     * Constructor
     *
     * @param int $id Optional id to load existing saved search
     */
    function __construct($id=null)
    {
        $this->database = wcmProject::getInstance()->database;
        $this->tableName = '#__user_savedsearch';
        $this->objectType = 'wcmSavedSearch';
        parent::__construct($id);
    }


    /**
     * Unserialize some properties if needed
     * This method is called by nextEnum() and refresh()
     */
    public function unserializeProperties()
    {
        parent::unserializeProperties();

        $this->showui = ($this->showui) ? unserialize($this->showui) : array();

    }

    /** Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    function ofClause($of)
    {
        if ($of == null || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'user':
                    if ($sql != null)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'userId=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
     * Return Class type
     *
     * @see api/core/wcmObject#getType()
     */
    public function getType()
    {
        return 'wcmSavedSearch';
    }
}
