<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.enumeration.php 9392 2010-04-06 21:02:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class is used to enumerate wcmObjects
 */
class wcmEnumeration implements Iterator, Countable
{
    private $current   = null;
    private $where     = null;
    private $resultSet = null;
    private $orderby   = null;
    private $offset    = null;
    private $limit     = null;
    private $of        = null;
    private $key       = -1;

    public function __construct($object, $where = null, $orderby = null, $offset = 0, $limit = 0, $of = null)
    {
        if ($object instanceof wcmObject)
        {
            $this->current = $object;
        } 
        else
        {
            $this->current = wcmObjectFactory::create($object);
        }
        $this->where   = $where;
        $this->orderby = $orderby;
        $this->offset  = $offset;
        $this->limit   = $limit;

        $ofClause = $this->current->ofClause($of);
        if ($ofClause != null)
        {
            if ($this->where)
            {
                $this->where = '(' . $where . ') AND ' . $ofClause;
            }
            else
            {
                $this->where = $ofClause;
            }
        }
    }

    public function rewind() 
    {
        $sql = 'SELECT * FROM ' . $this->current->getTableName();
        if ($this->where !== null && trim($this->where) != '')
        {
            $sql .= ' WHERE ' . $this->where;
        }
        if ($this->orderby != null)
        {
            $sql .= ' ORDER BY ' . $this->orderby;
        }

        // Load resultset
        $this->resultSet = $this->current->getDatabase()->executeQuery($sql, null, $this->offset, $this->limit, wcmDatabase::FETCH_INTO, $this->current);
        $this->key = 0;
    }

    public function current() 
    {
        return clone($this->current);
    }

    public function key() 
    {
        return $this->key;
    }

    public function next() 
    {
        $this->key++;
    }

    public function valid() 
    {
        // Erase existing property
        $properties = getPublicProperties($this->current);
        foreach ($properties as $property => $value)
        {
            $this->current->$property = null;
        }

        if ($this->resultSet && $this->resultSet->next())
        {
            $this->current->unserializeProperties();
            return true;
        } 
        else
        {
            return false;
        }
    }

    public function count()
    {
        // Compute number of wcmSysObject matching the query
        $sql = 'SELECT COUNT(*) FROM ' . $this->current->getTableName();

        if ($this->where != null && trim($this->where) != '')
        {
            $sql .= ' WHERE ' . $this->where;
        }
        
        $result = $this->current->getDatabase()->executeScalar($sql);
        if (!is_numeric($result)) 
        {
            throw new Exception('Error in ' . __METHOD__);
        }
        return ($this->limit > 0 && $result > $this->limit) ? $this->limit : $result;
    }
}
