<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.workflow.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The wcmWorkflow is used to describe and create workflows
 */
class wcmWorkflow extends wcmSysobject
{
    /**
     * name of this workflow
     * @var string
     */
    public $name;

    /**
     * (unique) code of initial wcm_workflowState
     * @var string
     */
    public $initialState;

    /**
     * Check validity of object
     *
     * @return bool TRUE if object is valid
     */
    public function checkValidity()
    {
        if (trim($this->name . ' ') == '')
        {
            $this->lastErrorMsg = _ERROR_NAME_IS_MANDATORY;
            return false;
        }

        if (strlen($this->name) > 255)
        {
            $this->lastErrorMsg = _ERROR_NAME_TOO_LONG;
            return false;
        }

        if ($this->initialState  && strlen($this->initialState) > 64)
        {
            $this->lastErrorMsg = _ERROR_INITIALSTATE_TOO_LONG;
            return false;
        }

        return true;
    }

    /**
     * Inserts or Updates object in database
     *
     * @return bool true on success, false on failure
     */
    protected function store()
    {
        if (!parent::store())
        {
            return false;
        }

        // Update cache
        wcmCacheRegistry::get()->setElem($this->getType(), $this->id, $this);
        return true;
    }

    /**
     * Deletes current object from database
     *
     * @return bool true on success or an error message (string)
     */
    public function delete()
    {
        $sql = 'SELECT count(*) FROM #__bizclass WHERE workflowId=?';
        $count = $this->database->executeScalar($sql, array($this->id));
        if ($count > 0)
        {
            $this->lastErrorMsg = 'This workflow (' . $this->name . ') is used in a content type and cannot be deleted';
            return false;
        }

        // Delete related transitions
        foreach (wcmProject::getInstance()->workflowManager->getTransitions() as $transition)
        {
            if ($transition->workflowId == $this->id)
            {
                $transition->delete();
            }
        }

        // Update cache
        wcmCache::unsetElem($this->getType(), $this->id);

        return parent::delete();
    }
}
