<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.workflowState.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The wcmWorkflowState is used to describe and create workflows
 */
class wcmWorkflowState extends wcmSysobject
{
    /**
     * name of this workflow
     * @var string
     */
    public $name;

    /**
     * Code of this workflow
     * @var string
     */
    public $code;

    /**
     * Check validity of object
     *
     * @return bool TRUE if object is valid
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if (!$this->checkUniqueCode())
        {
            return false;
        }

        if (trim($this->name . ' ') == '')
        {
            $this->lastErrorMsg = _ERROR_NAME_IS_MANDATORY;
            return false;
        }

        if (strlen($this->name) > 255)
        {
            $this->lastErrorMsg = _ERROR_NAME_TOO_LONG;
            return false;
        }

        if (trim($this->code . ' ') == '')
        {
            $this->lastErrorMsg = _ERROR_CODE_IS_MANDATORY;
            return false;
        }

        if (strlen($this->code) > 64)
        {
            $this->lastErrorMsg = _ERROR_CODE_TOO_LONG;
            return false;
        }

        return true;
    }

    /**
     * Inserts or Updates object in database
     *
     * @param int   $userId Id of the wcmUser who is creating or updating the object
     *
     * @return bool true on success, false on failure
     */
    protected function store($userId = null)
    {
        if (!parent::store($userId))
        {
            return false;
        }

        // Update cache
        wcmCacheRegistry::get()->setElem($this->getType(), $this->id, $this);
        return true;
    }

    /**
     * CheckIn for workflow states
     * As code must be unique, validates that it doesn't exist before storing.
     *
     * @param array $source An assoc array for binding to class vars (or null)
     *
     * @return bool true on success, false otherwise
     */
    public function checkin($source = null)
    {
        $wkfManager = wcmSession::getInstance()->getProject()->workflowManager;
        if ($wkfManager->getWorkflowStateByCode($source['code']) != null)
        {
            $this->lastErrorMsg = 'The code "' . $source['code'] . '" is already used. Please choose another.';
            return false;
        }
        return parent::checkin($source);
    }

    /**
     * Deletes current object from database
     *
     * @return bool true on success or an error message (string)
     */
    public function delete()
    {
        // @todo: could these 2 queries be optimized?
        $sql = 'SELECT count(*) FROM #__workflow_transition WHERE fromState=? OR toState=?';
        $count = $this->database->executeScalar($sql, array($this->code, $this->code));
        if ($count > 0)
        {
            $this->lastErrorMsg = _WKF_STATE_IN_TRANSITION;
            return false;
        }

        $sql2 = 'SELECT count(*) FROM #__workflow WHERE initialState=?';
        $count2 = $this->database->executeScalar($sql2, array($this->code));
        if ($count2 > 0)
        {
            $this->lastErrorMsg = _WKF_STATE_INITIAL_STATE;
            return false;
        }

        // Update cache
        wcmCache::unsetElem($this->getType(), $this->id);

        return parent::delete();
    }
}
