<?php
/**
 * Project:     WCM
 * File:        messenger.php
 *
 * @copyright   (c)2008 Nstein Technologies
 * @package     WCM
 * @version     4.x
 *
 */

/**
  Plugin Name: WCM Messenger
  Description: Sends messages to WCM
  Version: 4.1
  Author: NStein
 */

/**
  License goes here
 */

require_once('wcm.restForPlugins.php');


/*****************************************************************************
 * ERROR HELPER FUNCTIONS
 *
 * WordPress has no real error hanlding (as of v2.6.3) so these
 * functions create error messages, stores them into configuration
 * options so that when the page refreshes, if those config options
 * exist, they will be displayed to the user.
 *
 *****************************************************************************/

/**
 * Output a server not found error
 */
function wcm_error_serverNotFound()
{
    wcm_error_msg('WCM Server could not be contacted.');
}

/**
 * Output an authentication error
 */
function wcm_error_authentication()
{
    wcm_error_msg('WCM Plugin could not authenticate with the WCM server. Please double check your plugin configuration.');
}

/**
 * Output a bad config error
 */
function wcm_error_badConfig()
{
    wcm_error_msg('The WCM plugin is not configured properly. Please double check your WCM configuration and fill in any missing values.');
}

/**
 * This function is what displays the message
 * @param string $message Message to display
 */
function wcm_error_msg($message)
{
    ?>
        <div id="wcm_error" class="updated" style="background-color: #ea8585; font-weight: bold"><p><?php echo $message; ?></p></div>
        <?php
}

/**
 * Authenticate user
 * @return string Session ID, or FALSE on error
 */
function wcm_authenticate()
{
    $user = get_option('wcm_username');
    $pass = get_option('wcm_password');

    $wcm = new wcmRestForPlugins(get_option('wcm_backoffice_url'), $user, $pass);
    $sessionId = $wcm->authenticate();

    if (!$sessionId)
    {
        add_option('wcm_error', 'wcm_error_authentication');
        return false;
    }
    elseif (0 > $sessionId)
    {
        add_option('wcm_error', 'wcm_error_serverNotFound');
        return false;
    }
    return $sessionId;
}

/**
 * Display user warnings
 */
function wcm_user_warning()
{
    $warning = get_option('wcm_error');
    if (!empty($warning))
    {
        $warning();
        delete_option('wcm_error');
    }
}

/**
 * Send an item for publish
 * @param int $post_ID Post ID
 * @return int That same post ID
 */
function wcm_send_publish($post_ID)
{
    $sourceName = get_option('wcm_sourceName');
    $siteId = get_option('wcm_siteId');

    if (!$sourceName || !$siteId)
    {
        add_option('wcm_error', 'wcm_error_badConfig');
        return $post_ID;
    }

    $post = get_post($post_ID);

    $xml = '<item>';
    $xml .= '<title>' . $post->post_title . '</title>';
    $xml .= '<text>' . urlencode(htmlspecialchars(strip_tags($post->post_content))) . '</text>';
    $xml .= '<location>' . $post->guid . '</location>';
    $xml .= '<type>html</type>';
    $xml .= '<source>' . $sourceName . '</source>';
    $xml .= '<sourceId>' . $post_ID . '</sourceId>';
    $xml .= '<siteId>' . $siteId . '</siteId>';
    $xml .= '<workflowState>published</workflowState>';
    $xml .= '</item>';

    $user = get_option('wcm_username');
    $pass = get_option('wcm_password');

    $wcm = new wcmRestForPlugins(get_option('wcm_backoffice_url'), $user, $pass);
    $wcm->sendMessage('/content/item', 'post', array('content' => $xml), false, 'wcm_error_badConfig');

    return $post_ID;
}

/**
 * Delete a post
 * @param int $post_ID Post ID
 * @return int That same post ID
 */
function wcm_delete_post($post_ID)
{
    $sourceName = get_option('wcm_sourceName');
    $siteId = get_option('wcm_siteId');

    $post = get_post($post_ID);
    if ($post->post_type == 'post' && $post->post_status == 'publish')
    {

        if (!$sourceName || !$siteId)
        {
            add_option('wcm_error', 'wcm_error_badConfig');
            return $post_ID;
        }

        $data = 'source="' . $sourceName . '" AND sourceId="' . $post_ID . '"';

        $user = get_option('wcm_username');
        $pass = get_option('wcm_password');

        $wcm = new wcmRestForPlugins(get_option('wcm_backoffice_url'), $user, $pass);
        $wcm->sendMessage('/content/item', 'delete', array('where' => $data));

    }
    return $post_ID;
}

/**
 * Output admin options
 */
function wcm_admin_options()
{
    ?>
        <div class="wrap">
        <h2>WCM Hook</h2>

        <form method="post" action="options.php">
        <?php wp_nonce_field('update-options'); ?>

        <table class="form-table">
        <tr valign="top">
        <th scope="row">WCM URL</th>
        <td><input type="text" name="wcm_backoffice_url" value="<?php echo get_option('wcm_backoffice_url'); ?>"></td>
        </tr>

        <tr align="top">
        <th scope="row">WCM Site ID</th>
        <td><input type="text" name="wcm_siteId" value="<?php echo get_option('wcm_siteId'); ?>"></td>
        </tr>

        <tr valign="top">
        <th scope="row">Username</th>
        <td><input type="text" name="wcm_username" value="<?php echo get_option('wcm_username'); ?>"></td>
        </tr>

        <tr valign="top">
        <th scope="row">Password</th>
        <td><input type="password" name="wcm_password" value="<?php echo get_option('wcm_password'); ?>"></td>
        </tr>

        <tr valign="top">
        <th scope="row">Source Name</th>
        <td><input type="text" name="wcm_sourceName" value="<?php echo get_option('wcm_sourceName'); ?>"></td>
        </tr>


        </table>
        <input type="hidden" name="page_options" value="wcm_backoffice_url,wcm_siteId,wcm_username,wcm_password,wcm_sourceName" />

        <input type="hidden" name="action" value="update" />
        <p class="submit">
        <input type="submit" name="Submit" value="<?php _e('Save Changes'); ?>" />
        </p>
        </form>
        </div>
        <?php
}

/**
 * Setup administration options
 */
function wcm_setup_admin()
{
    add_options_page('WCM', 'WCM', 'manage_options', __FILE__, 'wcm_admin_options');
}

add_action('admin_notices', 'wcm_user_warning');
add_action('admin_menu', 'wcm_setup_admin');
add_action('publish_post', 'wcm_send_publish');
add_action('delete_post', 'wcm_delete_post');
