<?php
/**
 * Project:     WCM
 * File:        $Id$
 *
 * @copyright   (c)2010 Nstein Technologies
 * @version     4.x
 * @package     Indexation script
 */

/**
 * Multithread indexation script
 */

require(dirname(__FILE__) . '/../../initWcmApi.php');
require('wcm.cli.php');

$HELP = <<<EOH
Usage: php {$_SERVER['argv'][0]} [className1 [className2 [...]]] [-v] [-l] [-a]
-a, --all                 index all objects
-l, --list                list all objects
-h, --help                print a summary of the options
-j, --thread              Number of threads
-b, --batch               Number of assets to index per process

EOH;

$max_process = 1;
$doc_per_proc = 100;
$classes = array();
$workers = array();
$pipes = array();

if ($_SERVER['argc'] <= 1)
{
    die($HELP);
}

for ($i = 1 ; $i < $_SERVER['argc'] ; $i++)
{
    switch ($_SERVER['argv'][$i])
    {
        case '-h':
        case '--help':
            die($HELP);
        case '-a':
        case '--all':
            $classes = array_keys(getClassList());
            break;
        case '-l':
        case '--list':
            die('List of indexable objects :' . PHP_EOL . implode(PHP_EOL . "\t - ", array_keys(getClassList())) . PHP_EOL);
            break;
        case '-j':
        case '--thread':
            $max_process = $_SERVER['argv'][++$i];
            break;
        case '-b':
        case '--batch':
            $doc_per_proc = $_SERVER['argv'][++$i];
            break;
        default:
            $classes[] = $_SERVER['argv'][$i];
            break;
    }
}

$start_time = microtime(true);

$search = wcmSearch::getInstance();
$config = wcmConfig::getInstance();

echo PHP_EOL . 'Starting indexation' . PHP_EOL;
foreach ($classes as $className)
{
    if (!class_exists($className))
    {
        continue;
    }

    $start = 0;

    echo 'Indexing ' . $className . '... ' . PHP_EOL;
    echo '(' . $max_process . ' processes - batch ' . $doc_per_proc . ')' . PHP_EOL;
    $object_start_time = microtime(true);

    // Reindex all implies removing previously indexed content
    $search->deindexObjects($className);

    $enum = new wcmEnumeration($className);
    $count = count($enum);
    $indexed = 0;

    if ($count == 0)
    {
        echo 'Nothing to index for this object.' . PHP_EOL;
    } 
    else
    {

        $running = true;
        $streams = array();
        $lol = NULL;

        while ($running && (count($streams) == 0 || (stream_select($streams, $lol, $lol, 1) || true)))
        {
            $streams = array();

            $running = $start < $count;
            for ($i = 0 ; $i < $max_process ; $i++)
            {
                if (isset($workers[$i]))
                {
                    $status = proc_get_status($workers[$i]);
                    if (!$status['running'])
                    {
                        $proc_stats = unserialize(stream_get_contents($pipes[$i][1]));
                        $indexed += $proc_stats[$className]['count'];
                        proc_close($workers[$i]);
                        unset($workers[$i]);
                    } 
                    else
                    {
                        $running = true;
                        $streams[] = $pipes[$i][1];
                    }
                }

                if (!isset($workers[$i]) && $start < $count)
                {
                    $descriptor = array(0 => array ("pipe", "r"),
                            1 => array ("pipe", "w"),
                            2 => array ("pipe", "w"));

                    $cmd  = $config['php.exe'] . ' -q -c "' . $config['php.ini'] . '" -f indexation.php -- '; 
                    $cmd .= '-w ' . $className . ' --offset ' . $start . ' --limit ' . $doc_per_proc;
                    $workers[$i] = proc_open($cmd, $descriptor, $proc_pipes);
                    $pipes[$i] = $proc_pipes;
                    $streams[] = $pipes[$i][1];
                    $start += $doc_per_proc;
                    $running = true;
                }
            }
            if ($count != 0)
            {
                echo wcmCli::displayProgress(round(($indexed / $count) * 100));
            }
        }
    }

    echo PHP_EOL . 'Indexed in ' . round(microtime(true) - $object_start_time, 2). 's';
    echo PHP_EOL . PHP_EOL;
}

echo 'Done.' .  PHP_EOL . 'Total time : ' . round(microtime(true) - $start_time, 2) . 's' . PHP_EOL . PHP_EOL;
