<?php
/**
 * Project:     WCM
 * File:        $Id: export.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

// get required parameters
$response = getArrayParameter($_REQUEST, 'response', null);
$className = getArrayParameter($_REQUEST, 'className', null);
$bizobjects = getArrayParameter($_SESSION, 'tempBin', null);
$isNew = getArrayParameter($_REQUEST, 'isNew', null);
$bizobjectId = getArrayParameter($_REQUEST, 'bizobjectId', null);

// required parameters to create a new object;
$bizobjectName = getArrayParameter($_REQUEST, 'bizobjectName', null);
$parentChannel = getArrayParameter($_REQUEST, 'parentChannel', null);
$bizobjectDescription = getArrayParameter($_REQUEST, 'bizobjectDescription', null);

// put specific object labels in array. We can extend it when needed
$labels = array();
switch ($className)
{
    case 'channel':
        $labels['choose'] = _BIZ_CHOOSE_CHANNEL;
        break;
    case 'collection':
        $labels['choose'] = _BIZ_CHOOSE_COLLECTION;
        break;
    case 'slideshow':
        $labels['choose'] = _BIZ_CHOOSE_SLIDESHOW;
        break;
}

// displays first modal (choose object type and if it's a new bizobject)
if (!isset($className))
{
    // objects to export
    $exportObjects = array();
    // list of objects to which we can export
    $exportList = array('collection' => _BIZ_COLLECTION, 'channel' => _BIZ_CHANNEL);
    foreach ($bizobjects as $bizobject => $value)
    {
        $object = explode('_', $bizobject);
        $newObject = wcmObjectFactory::create($object[0]);
        $newObject->refresh($object[1]);
        $exportObjects[$newObject->getType()][] = $newObject;
    }
    // need to know if there's only photos. If yes, we can add a slideshow as export target
    if (array_key_exists('photo', $exportObjects) && 1 == count($exportObjects))
    {
        $exportList['slideshow'] = _BIZ_SLIDESHOW;
    }
    wcmGUI::openForm('_wcmExportBizobjects', '', null, array('class' => 'mainForm'));
    wcmGUI::openFieldset('', array('class' => 'modal'));
    wcmGUI::renderDropdownField('_wcmClassName', $exportList, null, _BIZOBJECTS, array('class' => 'small'));
    wcmGUI::renderBooleanField('_wcmNewObject', false, _BIZ_CREATE_NEW);
    wcmGUI::closeFieldset();
    wcmGUI::closeForm();
}
// displays second modal - We create a new object
elseif ($className && $isNew && !$bizobjectId)
{
    wcmGUI::openForm('_wcmExportBizobjects', '', null, array('class' => 'mainForm'));
    wcmGUI::openFieldset('', array('class' => 'modal'));
    wcmGUI::renderTextField('_wcmObjectName', '', _BIZ_NAME . ' *', array('class' => 'small type-req'));
    if ('channel' == $className)
    {
        $channel = wcmObjectFactory::create('channel');
        $channels = array('0' => _BIZ_ROOT_ELEMENT );
        $channel->getChannelHierarchy($channels);
        wcmGUI::renderDropdownField('_wcmParent', $channels, null, _BIZ_CHANNEL, array('class' => 'small'));
    }
    wcmGUI::renderTextArea('_wcmObjectDescription', '', _BIZ_DESCRIPTION, array('class' => 'small'));
    wcmGUI::closeFieldset();
    wcmGUI::closeForm();
}
elseif ($className && $bizobjectName)
{
    $exportTarget = wcmObjectFactory::create($className);
    $exportTarget->title = $bizobjectName;
    $exportTarget->description = $bizobjectDescription;
    $exportTarget->siteId = wcmSession::getInstance()->getSiteId();
    if ('channel' == $className)
    {
        $exportTarget->parentId = $parentChannel;
    }

    if (exportToBizobject($exportTarget, $bizobjects, array()))
    {
        echo _BIZ_EXPORT_SUCCESFULL_TO . getObjectLabel($exportTarget);

        // reset selected items from cache
        if (isset($_SESSION['tempBin']))
        {
            unset($_SESSION['tempBin']);
        }
    }
}
// displays second modal. Choose an existing object and then let user
// choose if new items are to be added or replaced
elseif ($className && !$isNew && !$bizobjectId)
{
    $bizobjects = wcmBizobject::getObjects($className, 'siteId=' . wcmSession::getInstance()->getSiteId());
    $bizobjectList[0] = '(' . _SELECT . ')';
    foreach ($bizobjects as $bizobject)
    {
        $bizobjectList[$bizobject->id] = getObjectLabel($bizobject);
    }
    wcmGUI::openForm('_wcmExportBizobjects', '', null, array('class' => 'mainForm'));
    wcmGUI::openFieldset('', array('class' => 'modal'));
    wcmGUI::renderDropdownField('_wcmBizobjectId', $bizobjectList, null, $labels['choose'], array('class' => 'small'));
    wcmGUI::renderHiddenField('_wcmClassName', $className);
    wcmGUI::closeFieldset();
    wcmGUI::closeForm();
}
// adding objects to the existing object
elseif ($className && $bizobjectId)
{
    $exportTarget = wcmObjectFactory::create($className, $bizobjectId);
    if ('ADD' == $response || 'REPLACE' == $response)
    {
        $rels = array();
        $relatedObjects = array();
        $relCheck = array();
        if ('ADD' == $response)
        {
            foreach ($exportTarget->getRelations() as $bizRel)
            {
                if ($bizRel->kind == bizrelation::IS_COMPOSED_OF)
                {
                    $rels['destinationId'][] = $bizRel->destinationId;
                    $rels['destinationClass'][] = $bizRel->destinationClass;
                    $rels['title'][] = isset($bizRel->title) ? $bizRel->title : '';
                    $rels['validityDate'][] = $bizRel->validityDate;
                    $relCheck[] = $bizRel->destinationId . $bizRel->destinationClass;
                }
            }
        }
        if (exportToBizobject($exportTarget, $bizobjects, $rels, $relCheck))
        {
            echo _BIZ_EXPORT_SUCCESFULL_TO . getObjectLabel($exportTarget);
            
            // reset selected items from cache
            if (isset($_SESSION['tempBin']))
            {
                unset($_SESSION['tempBin']);
            }
        }
    }
    // we should never get into this else
    else
    {
        echo '<p>' . _BIZ_EXPORT_ERROR . '</p>';
    }
}
// we should never get into this else
else
{
    echo '<p>' . _BIZ_EXPORT_ERROR . '</p>';
}

/**
 * Function to export to bizobjects
 *
 * @param bizobject $exportTarget   bizobject to wich current selection will be exported
 * @param array $bizobjects         array of bizobjects to export
 * @param array $rels               final new relations to create
 * @param array $relCheck           helper array to see existing relations
 * @return bool true on success
 */
function exportToBizobject($exportTarget, $bizobjects, $rels, $relCheck = array())
{
    foreach ($bizobjects as $key => $val)
    {
        $obj = explode('_', $key);
        $relatedObject =  wcmObjectFactory::create($obj[0], $obj[1]);
        // Change channelId of object
        /*
        if ('channel' == $exportTarget->getType())
        {
            $relatedObject->channelId = $exportTarget->id;
            $relatedObject->save();
        }
        */
        $relatedObjects[] = $relatedObject;
    }

    // add the relations
    foreach ($relatedObjects as $relatedObject)
    {
        // only add the new relations if they don't exist
        if (!in_array($relatedObject->id . $relatedObject->getType(), $relCheck))
        {
            $rels['destinationId'][] = $relatedObject->id;
            $rels['destinationClass'][] = $relatedObject->getType();
            $rels['title'][] = getObjectLabel($relatedObject);
            $rels['validityDate'][] = date('Y-m-d');
        }
    }
    $exportTarget->updateBizrelations('_br_' . bizrelation::IS_COMPOSED_OF, $rels);
    if ($exportTarget->save())
    {
        return true;
    }

    return false;
}
