<?php
/**
 * Project:     WCM
 * File:        $Id: site.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

/**
 * This class implements the action controller for the site
 */
class siteAction extends mvcAction
{
    /**
     * Save permissions based on $_REQUEST
     */
    private function savePermissions()
    {
        $permissionTypes = getArrayParameter($_REQUEST, 'permissionTypes');
        $permissions     = getArrayParameter($_REQUEST, 'permissions');
        $this->context->updatePermissions($permissionTypes, $permissions);
    }

    protected function beforeSave($session, $project)
    {
        parent::beforeSave($session, $project);

        $this->savePermissions();
    }

    /**
     * is called on checkin and on save before the store
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function afterSave($session, $project)
    {
        parent::afterSave($session, $project);

        if (isset($_REQUEST['path']))
        {
            $this->generateSitemap($_REQUEST);
        }
        $session->setSiteId($session->getSiteId());
    }

    /**
     * is called on delete
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function onDelete($session, $project)
    {
        parent::onDelete($session, $project);
        $session->setSiteId($session->getSiteId());
    }

    /**
     * Generate site map
     *
     * @param array $rq Request array
     */
    protected function generateSitemap($rq)
    {
        $data->siteId = $this->context->id;
        $data->path = isset($rq['path']) ? $rq['path'] : null;
        $data->domain = isset($rq['domain']) ? $rq['domain'] : null;
        $data->urls = isset($rq['urls']) ? $rq['urls'] : null;
        $data->searchEngines = isset($rq['searchEngines']) ? $rq['searchEngines'] : array('google' => true);
        $sitemap = new wcmSitemap($this->context->id);
        $sitemap->setConfig($data);
    }
}
