<?php
/**
 * Project:     WCM
 * File:        $Id: uploadPhoto.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

$config = wcmConfig::getInstance();
$session = wcmSession::getInstance();

// get the action
$action = getArrayParameter($_POST, 'actionPhoto', 'step1');
if (!isset($_FILES['photo']) && $action=='step2')
{
    $action = 'step1';
}

// error message
$errMsg = null;

$html = '<script type="text/javascript">';
switch ($action)
{
    // cancel the upload
    case 'stepCancel':
        break;

    case 'step1':
        break;

        // upload photo in the create/media
    case 'step2Photo':
        // upload photo in media tab in article
    case 'step2':

        // check errors in the upload file process
        $errMsg = fileUploadValidation();

        // check if the file is a valid image
        if (!checkFileExtension($_FILES['photo']['name']))
        {
            $errMsg = _BIZ_ERROR_UPLOAD_EXTENSION;
        }

        if (!isset($errMsg))
        {
            if (is_uploaded_file($_FILES['photo']['tmp_name']))
            {
                $dir = WCM_WWW_BACKOFFICE_DIR . '/system/public/';
                $tempName = $config['wcm.backOffice.uploadDir'] . uniqid();
                $tempThumb = $tempName . 'thumb';

                // move file in wcm.backOffice.photosPath directory with temp name
                if (move_uploaded_file($_FILES['photo']['tmp_name'], $dir . $tempName))
                {
                    // get the dimension
                    list($width, $height) = getimagesize($dir . $tempName);
                    try
                    {
                        // create thumbnail
                        $img = new wcmImageHelper($dir . $tempName);
                        $img->thumb($dir . $tempThumb, WCM_THUMB_WIDTH, WCM_THUMB_HEIGHT);
                    }
                    catch (Exception $e)
                    {
                        $errMsg = _BIZ_ERROR_UPLOAD_PARTIAL;
                    }
                }
                else
                {
                    $errMsg = _BIZ_ERROR_UPLOAD_CANT_WRITE;
                }
            }
            else
            {
                $errMsg = UPLOAD_ERR_NO_TMP_DIR;
            }

            if (!isset($errMsg))
            {
                // show the upload photo
                $html .= 'parent.$(\'imgPhoto\').innerHTML = \'<img src="' . $config['wcm.backOffice.url'] . $tempThumb . '" />\';';
                $html .= 'parent.$(\'width\').value = \'' . $width . '\';';
                $html .= 'parent.$(\'height\').value = \'' . $height . '\';';

                if ($action == 'step2Photo')
                {
                    $html .= 'parent.$(\'originalWidth\').innerHTML = \'' . $width . '\';';
                    $html .= 'parent.$(\'originalHeight\').innerHTML = \'' . $height . '\';';
                    // set the dimensions, path and start the cropping
                    $html .= 'parent.$(\'original\').value = \'' . $_FILES['photo']['name'] . '\';';
                    $html .= 'parent.$(\'sourcePath\').value = \'' . $tempName . '\';';
                    $html .= 'if (parent.$(\'cropHider\')) { parent.$(\'cropHider\').setStyle({display: \'block\'}); }';
                    $html .= 'parent.CropImageManager.init(\'' . $tempName . '\');';
                    $html .= 'parent.CropImageManager.setImage(\'' . $config['wcm.backOffice.url'] . $tempName . '\');';
                    $html .= 'parent.$(\'thumbWidth\').value = \'' . WCM_THUMB_WIDTH . '\';';
                    $html .= 'parent.$(\'thumbHeight\').value = \'' . WCM_THUMB_HEIGHT . '\';';
                }
                else
                {
                    $html .= 'parent.$(\'fileName\').value = \'' . $_FILES['photo']['name'] . '\';';
                    $html .= 'parent.$(\'sourcePath\').value = \'' . $tempName . '\';';
                }
            }
        }
        break;

        // save the photo
    case 'step3':
        // check if the file is a valid image
        if (!checkFileExtension($_POST['fileName']))
        {
            $errMsg = _BIZ_ERROR_UPLOAD_EXTENSION;
        }

        if (!isset($_POST['fileName']) || empty($_POST['fileName']))
        {
            $errMsg = _BIZ_ERROR_UPLOAD_NO_FILE;
        }

        if (!isset($errMsg))
        {
            $tmpPrefix = 'tmp' . $session->userId . '-';
            $fileName = $_POST['fileName'];
            $tempFile = $_POST['sourcePath'];

            // create photo
            $photo = wcmObjectFactory::create('photo');
            $photo->original = $fileName;
            $photo->width = $_POST['width'];
            $photo->height =  $_POST['height'];

            $photo->caption = $_POST['caption'];
            $photo->title = $_POST['title'];
            $photo->workflowState = 'published';
            $photo->siteId = $session->getSiteId();

            // Save it, providing the image file path.
            $args = array(
                'sourcePath' => WCM_WWW_BACKOFFICE_DIR . '/system/public/' . $_POST['sourcePath']
            );
            if (!$photo->save($args))
            {
                $errMsg = $photo->getErrorMsg();
            }
        }
        break;
}

// check error, if error show it to user
if (isset($errMsg))
{
    $html .= 'parent.wcmMessage.error(\'' . $errMsg . '\');';
    $html .= 'if(document.getElementById(\'uploadPhotoForm\')) document.getElementById(\'uploadPhotoForm\').enable();';
}
elseif ($action=='step3') // if not, call _finishUploadPhoto() and show "save completed" message to user
{
    $html .= 'parent.wcmMessage.info(parent.$I18N.SAVE_COMPLETED);';
    $html .= 'parent._finishUploadPhoto();';
}

$html .= '</script>';
echo $html;

/**
 * Valid the upload file
 * @return string Error message if any
 */
function fileUploadValidation()
{
    $errFileMsg = null;
    switch ($_FILES['photo']['error'])
    {
        case UPLOAD_ERR_INI_SIZE:
        case UPLOAD_ERR_FORM_SIZE:
            $errFileMsg = sprintf(_BIZ_ERROR_UPLOAD_SIZE, (isset($_POST['MAX_FILE_SIZE'])) ? $_POST['MAX_FILE_SIZE'] : ini_get('upload_max_filesize'));
            break;
        case UPLOAD_ERR_PARTIAL:
            $errFileMsg = _BIZ_ERROR_UPLOAD_PARTIAL;
            break;
        case UPLOAD_ERR_NO_FILE:
            $errFileMsg = _BIZ_ERROR_UPLOAD_NO_FILE;
            break;
        case UPLOAD_ERR_NO_TMP_DIR:
            $errFileMsg = _BIZ_ERROR_UPLOAD_NO_TMP_DIR;
            break;
        case UPLOAD_ERR_CANT_WRITE:
            $errFileMsg = _BIZ_ERROR_UPLOAD_CANT_WRITE;
            break;
        case UPLOAD_ERR_EXTENSION:
            $errFileMsg = _BIZ_ERROR_UPLOAD_EXTENSION;
            break;
        default:
            $errFileMsg = null;
    }
    return $errFileMsg;
}

/**
 * Check the valid image extension
 *
 * @param $fileName the filename
 * @return bool TRUE if valid
 */
function checkFileExtension($fileName)
{
    $ext = strtolower(substr($fileName, strrpos($fileName, '.') + 1));
    if ($ext == 'jpg' || $ext == 'jpeg' || $ext == 'gif' || $ext == 'bmp' || $ext == 'png')
    {
        return true;
    }
    else
    {
        return false ;
    }
}

