<?php
/**
 * Project:     WCM
 * File:        $Id: step.class.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

/**
 * Installer step class
 */
abstract class wcmInstall_step
{
    /**
     * Step output
     * @var string
     */
    protected $output = false;

    /**
     * Redirect
     * @var string
     */
    protected $redirect = false;

    /**
     * Title
     * @var string
     */
    protected $title;

    /**
     * Description
     * @var string
     */
    protected $desc;

    /**
     * Errors
     * @var array
     */
    protected $errors = array();

    /**
     * Error fields
     * @var array
     */
    protected $errorFields = array();

    /**
     * Has error occured?
     * @var bool
     */
    protected $error = false;

    /**
     * Missing fields
     * @var bool
     */
    protected $missingFields = false;

    /**
     * Load a template
     * @param string $argTpl Template to load
     * @param array $options Extra options
     * @param bool Output a wrapper
     */
    protected function loadTemplate($argTpl, $options = array(), $argWrapper = true)
    {
        ob_start();
        if ($argWrapper)
        {
            require_once('templates/ui-header.php');
        }
        require_once($argTpl);
        if ($argWrapper)
        {
            require_once('templates/ui-footer.php');
        }
        $this->output .= ob_get_contents();
        ob_end_clean();
    }

    /**
     * Add an error
     * @param string $argMsg Error message
     */
    public function error($argMsg)
    {
        $this->errors[] = $argMsg;
        wcmInstall_session::getInstance()->log($argMsg);
        $this->error = true;
    }

    /**
     * Get the output
     * @return string Output
     */
    public function output()
    {
        return $this->output;
    }

    /**
     * Output an html error
     * @param string $argField Field where error occured
     */
    public function htmlError($argField)
    {
        if (isset($this->errorFields[$argField]))
        {
            echo 'class="error"';
        }
    }

    /**
     * Get the redirect
     * @return string Redirect
     */
    public function redirect()
    {
        return $this->redirect;
    }

    /**
     * Get step title
     * @return string Title
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Get step description
     * @return string Description
     */
    public function getDesc()
    {
        return $this->desc;
    }

    /**
     * Check if an error has occured
     * @return bool True if error occured
     */
    public function hasError()
    {
        return $this->error;
    }

    /**
     * Check if there are missing fields
     * @return bool True if there are missing fields
     */
    public function hasMissing()
    {
        return $this->missingFields;
    }

    /**
     * Get the error list
     * @return array Error list as array
     */
    public function getErrors()
    {
        return $this->errors;
    }

    /**
     * Get the default value for a POST key if it is not set, or the value if it is set
     * @param string $argKey POST key name
     * @param string $argDefault Default value for key
     * @return string Value
     */
    protected function getDefaultValue($argKey, $argDefault)
    {
        return isset($_POST[$argKey]) ? $_POST[$argKey] : $argDefault;
    }

}
