<?php
/**
 * Project:     WCM
 * File:        $Id: stepOne.class.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */
class wcmInstallSteps_stepOne extends wcmInstall_step
{
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->title = 'Step One';
        $this->desc = '<u>Sanity check</u>: Verifying if your system meets the software requirements to run WCM';

        $session = wcmInstall_session::getInstance();
        $config = $session->getConfig();
        $wrong = array();
        $phpMods  = array();
        $apache = array();
        $error = false;

        if (-1 === version_compare(PHP_VERSION, '5.2.0'))
        {
            $error = true;
            $session->log('Incompatible PHP version. Should be 5.2.0 or higher, version is: ' . PHP_VERSION);
            $this->error('Your version of PHP (' . PHP_VERSION . ') is not compatible. Please upgrade to PHP version 5.2.0 or higher.');
        }

        foreach ($config['reqPhpIni'] as $ini => $setting)
        {
            $currentSetting = ini_get($ini);

            if ('off' == strtolower($currentSetting) || !$currentSetting)
            {
                $currentSetting = 'Off';
            }

            $session->log('Sanity check: PHP Config [' . $ini . '] = ' . $currentSetting);

            if ($currentSetting != $setting)
            {
                $error = true;
                $wrong[$ini] = array($setting => $currentSetting);
            }
        }

        foreach ($config['reqPhpMods'] as $mod)
        {
            if (!extension_loaded($mod))
            {
                $error = true;
                $phpMods[] = $mod;
            }
            else
            {
                $session->log('Sanity check: PHP module [' . $mod . '] loaded');
            }
        }

        if (function_exists('apache_get_modules'))
        {
            $mods = apache_get_modules();
            foreach ($config['reqApacheMods'] as $mod)
            {
                if (!in_array($mod, $mods))
                {
                    $error = true;
                    $apache[] = $mod;
                }
            }
        }
        if ($error)
        {
            $this->error('Some of the prerequisites are either missing or misconfigured. Please review the list and make the appropriate changes.');
        }

        $this->loadTemplate('templates/stepOne.php', array('phpIni' => $wrong, 'mods' => $phpMods, 'apache' => $apache, 'errFlag' => $error));
    }
}