<?php
/**
 * Project:     WCM
 * File:        $Id: stepThree.class.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

class wcmInstallSteps_stepThree extends wcmInstall_step
{
    /**
     * Fields that are errorneous
     * @var array
     */
    private $badFields = array();

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->title = 'Step Three';
        $this->desc = '<u>General installation settings</u>';

        if (isset($_GET['process']))
        {
            $this->process();
        }

        // See if there is a timezone we can select
        $session = wcmInstall_session::getInstance();
        $tz = $session->getWcmConfigValue('config_wcm_default_timezone');
        if (empty($tz))
        {
            $tz = date_default_timezone_get();
        }


        // Setup some default values for this page
        $tplVars = array(
            'config_wcm_project_title' => $this->getDefaultValue('config_wcm_project_title', $session->getWcmConfigValue('config_wcm_project_title')),
            'config_wcm_default_timezone' => $tz,

            'config_wcm_backOffice_url' => $this->getDefaultValue('config_wcm_backOffice_url', $this->getUrl()),
            'config_wcm_path' => $this->getDefaultValue('config_wcm_path', $this->getPath()),

            'config_php_exe' => $this->getDefaultValue('config_php_exe', $this->getPhpExe()),
            'config_php_ini' => $this->getDefaultValue('config_php_ini', php_ini_loaded_file()),
        
            'config_wcm_default_media-manager_url' => $this->getDefaultValue('config_wcm_default_media-manager_url', $session->getWcmConfigValue('config_wcm_default_media-manager_url')),
            'config_wcm_default_media-manager_login' => $this->getDefaultValue('config_wcm_default_media-manager_login', $session->getWcmConfigValue('config_wcm_default_media-manager_login')),
            'config_wcm_default_media-manager_password' => $this->getDefaultValue('config_wcm_default_media-manager_password', $session->getWcmConfigValue('config_wcm_default_media-manager_password')),
        );


        // Figure out which databases are available and which aren't.
        // this done by comparing the list of supported databases
        // in install.conf.php to available PHP modules.
        $config = $session->getConfig();
        while (list($mod, $name) = each($config['supportedDatabases']))
        {
            if (extension_loaded($mod))
            {
                $db['avail'][$mod] = $name;
            }
            else
            {
                $db['notAvail'][$mod] = $name;
            }
        }

        $tplVars['db'] = $db;
        $tplVars['indexers'] =& $config['indexers'];
        $tplVars['config_wcm_webSite_SSS_enabled'] = $this->getDefaultValue('config_wcm_webSite_SSS_enabled', $session->getWcmConfigValue('config_wcm_webSite_SSS_enabled'));
        $tplVars['selectedDb'] = $this->getDefaultValue('wcmConfig_db', $session->getWcmConfigValue('wcmConfig_db'));
        $tplVars['config_wcm_search_engine'] = $this->getDefaultValue('config_wcm_search_engine', $session->getWcmConfigValue('config_wcm_search_engine'));

        // If nothing is selected, and there is only one db/indexer, then automatically select it
        if (empty($tplVars['selectedDb']) && count($db['avail']) < 2)
        {
            $tplVars['selectedDb'] = key($db['avail']);
        }
        if (empty($tplVars['selectedIndexer']) && count($tplVars['indexers']) < 2)
        {
            $tplVars['selectedIndexer'] = key($tplVars['indexers']);
        }
        $this->loadTemplate('templates/stepThree.php', $tplVars);
    }

    /**
     * Find PHP binary
     * @return string Location of PHP binary
     */
    private function getPhpExe()
    {
        $session = wcmInstall_session::getInstance();
        $phpExecutablePath = $session->getWcmConfigValue('wcmConfig_phpExecutablePath');
        if (empty($phpExecutablePath))
        {
            $isWindows = 'WINDOWS' == strtoupper(substr(php_uname(), 0, 7));

            if ($isWindows)
            {
                $paths = isset($_ENV['Path']) ? $_ENV['Path'] : getenv('Path');
                if (empty($paths))
                {
                    $paths = getenv('PATH');
                }
                $php_exe = 'php.exe';
            }
            else
            {
                $paths = isset($_ENV['PATH']) ? $_ENV['PATH'] : getenv('PATH');
                $php_exe = 'php';
            }
            $paths = explode(PATH_SEPARATOR, $paths);
            $phpExecutablePath = '';

            foreach ($paths as $path)
            {
                $path = str_replace('\\', '/', $path);
                if ('/' != substr($path, -1))
                {
                    $path .= '/';
                }

                if (file_exists($path . $php_exe))
                {
                    $phpExecutablePath = $path;
                }
            }

            $phpExecutablePath = trim($phpExecutablePath) . $php_exe;
        }
        return $phpExecutablePath;
    }

    /**
     * Get the installation URL
     * @return string Url
     */
    private function getUrl()
    {
        $session = wcmInstall_session::getInstance();
        $url = $session->getWcmConfigValue('wcmConfig_url');
        if (empty($url))
        {
            // Assume installation script is one dir up from main website
            $uri = explode('/', $_SERVER['REQUEST_URI'], -2);
            $url = 'http://' . $_SERVER['HTTP_HOST'] . implode('/', $uri) . '/system/public';
        }

        return $url . '/';
    }

    /**
     * Get the installation path
     * @return string Path
     */
    private function getPath()
    {
        $session = wcmInstall_session::getInstance();
        $path = $session->getWcmConfigValue('wcmConfig_path');
        if (empty($path))
        {
            $path = str_replace('\\', '/', realpath(dirname(__FILE__) . '/../../../'));
        }
        if ('/' != $path{strlen($path) - 1})
        {
            $path = $path . '/';
        }
        return $path;
    }

    /**
     * Process the step
     */
    private function process()
    {
        $session = wcmInstall_session::getInstance();

        /**
         * MISSING FIELDS CHECK
         */
        foreach ($_POST as $key => $value)
        {
            if (stristr($key, 'config_') && empty($value))
            {
                $this->errorFields[$key] = true;
            }
        }
        if (count($this->errorFields) > 0)
        {
            $this->error('All highlighted fields must be filled in');
            $this->missingFields = true;
        }
        // -- END

        if (!$this->hasMissing())
        {
            // Check system paths
            $p = $_POST['config_wcm_path'];
            $p = rtrim($p, '/');
            $this->writeAccess($p, 'config_wcm_path', 'Your backoffice directory does not exist', false, true);
            $this->writeAccess($_POST['config_php_exe'], 'config_php_exe', 'Could not find your PHP executable at the location you provided', false, true);
            $this->writeAccess($_POST['config_php_ini'], 'config_php_ini', 'Could not find your PHP configuration file at the location you provided', false, true);
        }

        if (empty($_POST['admin_pw1']) || $_POST['admin_pw1'] != $_POST['admin_pw2'])
        {
            $this->error('Your administration passwords are invalid. Please type them in again.');
            $this->errorFields['admin_pw1'] = true;
            $this->errorFields['admin_pw2'] = true;
        }

        if (!isset($_POST['wcmConfig_db']))
        {
            $this->error('You must select a storage engine to continue.');
        }

        if (!isset($_POST['config_wcm_search_engine']))
        {
            $this->error('You must select an indexer to continue.');
        }

        if (!$this->error)
        {
            foreach ($_POST as $key => $value)
            {
                if (stristr($key, 'config_'))
                {
                    $session->addWcmConfigVar($key, $value);
                }
            }
            $session->registerInstruction(new wcmInstallInstructions_setAdminPassword($_POST['admin_pw1']));

            $this->redirect = '?step=stepFour';
        }
    }

    /**
     * Check whether or not a file is writable
     * @param string $argFile file to check
     * @param string $argKey Key name
     * @param string $argErrorNotFound Not found error string
     * @param string $argErrorNotWritable Not writable error string
     * @param bool $argExistsOnly When TRUE, will just check if target exists
     * @return bool TRUE on success
     */
    private function writeAccess($argFile, $argKey, $argErrorNotFound, $argErrorNotWritable, $argExistsOnly = false)
    {
        if (is_dir($argFile))
        {
            if (!$argExistsOnly)
            {
                if ('/' != substr($argFile, -1))
                {
                    $argFile .= '/';
                }

                $testFile = realpath($argFile) . '/' . uniqid(mt_rand());
                wcmInstall_session::getInstance()->log('Trying to write: ' . $testFile);
                if (!@touch($testFile))
                {
                    $this->error($argErrorNotWritable);
                    $this->errorFields[$argKey] = true;
                    return false;
                }
                else
                {
                    unlink($testFile);
                    return true;
                }
            }
            return true;
        }
        elseif (is_file($argFile))
        {
            if (!$argExistsOnly)
            {
                if (!is_writable($argFile))
                {
                    $this->error($argErrorNotWritable);
                    $this->errorFields[$argKey] = true;
                    return false;
                }
                else
                {
                    return true;
                }
            }
            return true;
        }
        else
        {
            $this->error($argErrorNotFound);
            $this->errorFields[$argKey] = true;
            return false;
        }
    }
}
