<?php
/**
 * Project:     WCM
 * File:        $Id: index.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */

// Initialize system
require_once dirname(__FILE__) . '/../private/initWebApp.php';

$pluginManager = new wcmPluginManager();
$pluginManager->initConfig('authenticate');

// Execute special action
$action = $session->getCurrentAction();
switch ($action)
{
    case 'login':

        // This is done because without a user in session, the action will always
        // be 'login'
        if (isset($_REQUEST['_wcmAction']) && $_REQUEST['_wcmAction'] == 'processLogin')
        {
            if (!isset($_REQUEST['_authPlugin']))
            {
                wcmMVC_Action::setError('Not a valid method of authentication');
            }

            /** TODO : Use a standalone factory class that would build the plugin object */

            $auth = $pluginManager->getPluginConfig('authenticate', $_REQUEST['_authPlugin']);
            $authClass = $auth['general']['className'];
            $authInstance = new $authClass();

            $auth = new wcmAuth($authInstance);
            if ($auth->authenticate($_REQUEST))
            {
                // Ok, the authentication provider worked, but does it apply to WCM?
                $user_id = $auth->getWcmUser();
                if ($user_id > 0)
                {
                    // The user id appears valid
                    $session->startSession($user_id);
                    if (!$session->getSiteId() || !$session->isAllowed($session->getSite(), wcmPermission::P_READ))
                    {
                        $sites = wcmObject::getObjects('site');
                        foreach ($sites as $site)
                        {
                            // Find first allowed website
                            if ($session->isAllowed($site, wcmPermission::P_READ))
                            {
                                $session->setSite($site);
                                break;
                            }
                        }

                        if ($session->getSiteId() == 0)
                        {
                            $session->logout();
                            wcmMVC_Action::setError(_NO_SITE_ALLOWED);
                        }
                    }

                    if (isset($_REQUEST['lastPage']) && $req = $_REQUEST['lastPage'])
                    {
                        header('Location: ' . $req);
                    }
                    else
                    {
                        header('Location: index.php');
                    }
                }
                else
                {
                    wcmMVC_Action::setMessage('A valid WCM user could not be found from the authentication provider');
                }
            }
            else
            {
                wcmMVC_Action::setMessage(_LOGIN_FAILED);
            }
        }

        break;
    case 'logout':
        // Close session
        if ($session != null)
        {
            $session->logout();
            wcmMVC_Action::setMessage(_LOGGED_OUT);
        }
        break;

    default:
        break;
}

// Load page for current action
$action = $session->getCurrentAction();
$session->ping(); // Ping session to keep it active
if (substr($action, 0, 9) == 'business/')
{
    /**
     * TODO : Put constant here
     */
    $page = WCM_WWW_BACKOFFICE_DIR . '/business/private/views/pages/' . substr($action, 9) . '.php';
}
else
{
    $page = WCM_WWW_BACKOFFICE_DIR . '/system/private/views/pages/' . $action . '.php';
}

if (!file_exists($page))
{
    header('Location: ' . wcmMVC_Action::computeURL('404'));
}
else
{
    try
    {
        require_once($page);
    }
    catch (Exception $e)
    {
        $_EXCEPTION = $e;
        $page = WCM_WWW_BACKOFFICE_DIR . '/system/private/views/pages/exception.php';
        require_once($page);
    }
}

// Display debug bar only if xdebug is enabled and user is an admin
if (extension_loaded('xdebug') && $session->isAdministrator())
{
    cmsDebugBar::display(array('cmsDebugProfile','cmsDebugIncludeFile','cmsDebugQuery', 'cmsDebugRequest', 'cmsDebugSession', 'cmsDebugCache'));
}
