<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.fileCache.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * File-based cache implementation.
 */
class cmfFileCache implements cmfCache
{
    /**
     * The directory where the cache files are stored.
     */
    private $directory;

    /**
     * Public constructor.
     * @param string $directory The directory where the
     * cache files are stored.
     */
    public function __construct($directory = null)
    {
        $this->directory = $directory;
    }

    /**
     * Get the directory where the cache files are stored.
     * @return string
     */
    public function getDirectory()
    {
        return $this->directory;
    }

    /**
     * She directory where the cache files are stored.
     * @param string $value The new value.
     * @return void
     */
    public function setDirectory($value)
    {
        $this->directory = $value;
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#set($key, $value, $ttl)
     */
    public function set($key, $content, $ttl = null)
    {
        if ((!is_string($key) || '' == $key) || is_numeric($key))
        {
            throw new InvalidArgumentException();
        }
        
        // Make sure the directory exists.
        if (!file_exists($this->directory))
        {
            mkdir($this->directory, 0777, true);
        }
        return $this->setFileContent($this->directory . md5($key), $ttl, $content);
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#get($key)
     */
    public function get($key)
    {
        // Build the cache file path.
        $filePath = $this->directory . md5($key);

        if (!file_exists($filePath))
        {
            // Cache file doesn't exist.
            return false;
        }

        $content = $this->getFileContent($filePath);
        if (false === $content)
        {
            // Cannot read cache file content.
            return false;
        }

        list($ttl, $value) = $content;
        if ($ttl && (filemtime($filePath) + $ttl <= $_SERVER['REQUEST_TIME']))
        {
            // Cache entry has expired. Delete the file.
            unlink($filePath);
            return false;
        }

        return $value;
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#delete($key)
     */
    public function delete($key)
    {
        $filePath = $this->directory . md5($key);

        if (file_exists($filePath))
        {
            // Delete the cache file.
            return unlink($filePath);
        }

        return true;
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#clear()
     */
    public function clear()
    {
        if (unlink($this->directory))
        {
            return mkdir($this->directory, 0777);
        }

        return false;
    }

    /**
     * Get the content of a cache file.
     * @param string $path The path of the cache file.
     * @return array An array containing the time to live
     * of the cached value and the cached value itself, or
     * false if an error occurs.
     */
    private function getFileContent($path)
    {
        $content = file_get_contents($path);
        if (false !== $content)
        {
            return explode("\n", $content, 2);
        }
        return false;
    }

    /**
     * Set the content of a cache file.
     * @param string $path The path of the cache file.
     * @param int $ttl The time to live of the cached
     * value.
     * @param string $value The cached value.
     * @return boolean True if the write was
     * successfull, false otherwise.
     */
    private function setFileContent($path, $ttl, $value)
    {
        return (bool)file_put_contents($path, $ttl . "\n" . $value);
    }
}
