<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.facetDefinition.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * The definition of a facet.
 */
class cmfFacetDefinition
{
    /**
     * The single-valued facet type.
     * @var string
     */
    const FACET_TYPE_SINGLE_VALUE = 'single';

    /**
     * The multiple-valued facet type.
     * @var string
     */
    const FACET_TYPE_MULTIPLE_VALUE = 'multiple';

    /**
     * The hierarchical-valued facet type.
     * @var string
     */
    const FACET_TYPE_HIERARCHICAL = 'hierarchical';

    /**
     * The name of the facet.
     * @var string
     */
    public $name;

    /**
     * The title (caption) of the facet.
     * @var string
     */
    public $title;

    /**
     * The index used to retrieve the values.
     * @var string
     */
    public $index;

    /**
     * The index on which the search is done when applying a facet value.
     * @var string
     */
    public $searchIndex;

    /**
     * Indicate if the facet values should be sorted (by hit count).
     * @var boolean
     */
    public $sort;

    /**
     * The type of the facet.
     * @var string
     */
    public $type;

    /**
     * The maximum number of values for the facet.
     * @var int
     */
    public $maxValues;

    /**
     * The plugin info of the facet processor (or null).
     * @var cmfPluginInfo
     */
    private $processorPluginInfo;

    /**
     * The cache for the processor plugin.
     * @var cmfFacetProcessor
     */
    private $processorPlugin = null;

    /**
     * The plugin info of the facet values provider (or null).
     * The $index is not used (can be null) if a provider is used.
     * @var cmfPluginInfo
     */
    private $providerPluginInfo;

    /**
     * The cache for the provider plugin.
     * @var cmfFacetValuesProvider
     */
    private $providerPlugin = null;

    /**
     * Construct a facet definition.
     * @param array $parameters The parameters for the facet definition.
     */
    public function __construct($name, $title, $index, $searchIndex = null, $sort = false, $type = self::FACET_TYPE_SINGLE_VALUE, $maxValues = 0, cmfPluginInfo $processor = null, cmfPluginInfo $provider = null)
    {
        $this->name = $name;
        $this->title = $title;
        $this->index = $index;
        $this->searchIndex = $searchIndex ? $searchIndex : $this->index;
        $this->sort = $sort;
        $this->type = $type;
        $this->maxValues = $maxValues;
        $this->processorPluginInfo = $processor;
        $this->providerPluginInfo = $provider;
    }

    /**
     * Get the facet processor plugin instance.
     * @return cmfFacetProcessor
     */
    public function getProcessor()
    {
        if (null !== $this->processorPluginInfo && null === $this->processorPlugin)
        {
            $this->processorPlugin = cmfPluginFactory::createPlugin(
                $this->processorPluginInfo,
                'cmfFacetProcessor'
            );
        }
        return $this->processorPlugin;
    }

    /**
     * Get the facet values provider plugin instance.
     * @return cmfFacetValuesProvider
     */
    public function getProvider()
    {
        if (null !== $this->providerPluginInfo && null === $this->providerPlugin)
        {
            $this->providerPlugin = cmfPluginFactory::createPlugin(
                $this->providerPluginInfo,
                'cmfFacetValuesProvider'
            );
        }
        return $this->providerPlugin;
    }
}
