<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.ugcHit.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * A ugc Hit class
 * Can be used to handle page hit / views
 */
class cmfUgcHit
{
    /**
     * ugcDatabase
     *
     * @var mysqlI
     */
    private $ugcDatabase;

    /**
     * tablename
     *
     * @var mixed
     */
    private $tablename;

    /**
     * __construct
     *
     * @param mixed $mysqli
     * @param mixed $tableName
     * @return void
     */
    public function __construct($mysqli, $tableName)
    {
        $this->ugcDatabase = $mysqli;
        $this->tableName = $tableName;
    }

    /**
     * add
     *
     * @param mixed $className
     * @param mixed $classId
     * @return void
     */
    public function add($className, $classId)
    {
        $sql = 'INSERT INTO ' . $this->tableName . ' (`className`, `classId`, `date`) VALUES(?,?,?)';

        $stmt = $this->ugcDatabase->prepare($sql);
        $date = date('Y-m-d H:i:s');
        $stmt->bind_param('sis', $className, $classId, $date);

        return $stmt->execute();
    }

    /**
     * get
     *
     * @param mixed $className
     * @param mixed $classId
     * @return void
     */
    public function get($className, $classId, $date)
    {
        $sql = 'SELECT count(*) FROM ' . $this->tableName  . 'WHERE className=? AND classId=? AND date>=?';

        $stmt = $this->ugcDatabase->prepare($sql);
        $stmt->bind_param('sis', $className, $classId, $date);

        $stmt->execute();
        mysqli_stmt_bind_result($stmt, $avg);
        $stmt->fetch();

        return $avg;
    }

    /**
     * getMostHit
     *
     * @param mixed $className
     * @param mixed $classId
     * @param mixed $date
     * @param mixed $startTime
     * @param mixed $endTIme
     * @return void
     */
    public function getMostHit($className, $classId, $date, $startTime, $endTIme)
    {
        $sql = 'SELECT max(*) FROM ' . $this->tableName  . ' WHERE className=? AND classId=? AND date>=? AND date<=? GROUP BY className, classId';

        $stmt = $this->ugcDatabase->prepare($sql);
        $stmt->bind_param('siss', $className, $classId, $date, $date);

        $stmt->execute();
        mysqli_stmt_bind_result($stmt, $avg);
        $stmt->fetch();

        return $avg;
    }
}
