<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.articleController.php 9252 2010-03-12 20:30:36Z guilbaultm $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-www-sampleapp
 * @version     4.1.5
 */

/**
 * CMF Sample Article controller
 */
class cmfArticleController extends cmfMainController
{
    /**
     * wcm Rest Client used to add / flag comments
     * @var wcmRestClient 
     */
    public $wcmRestClient = null;

    /**
     * injectDependencies 
     * 
     * @param cmfContainer $container 
     * @return void
     */
    public function injectDependencies(cmfContainer $container)
    {
        parent::injectDependencies($container);
        $this->wcmRestClient = cmfToolbox::getArrayParameter($container, 'mvcRestClient');
    }

    /**
     * Make sure that the required article is published, otherwise
     * output a HTTP 404 Not Found and exit the request.
     * @return void
     */
    public function always()
    {
        if (cmfFrontDispatcher::MODE_PREVIEW != $this->getMode() && !$this->doArticleExists())
        {
            header($_SERVER['SERVER_PROTOCOL'] . ' 404 Not Found');
            echo 'Not Found';
            exit();
        }
    }

    /**
     * This method will retrieve the data from the POST and add a
     * comment related to the current article using the WCM Rest WS 
     */
    public function onAddComment()
    {
        $commentName    = filter_input(INPUT_POST, 'commentName', FILTER_SANITIZE_SPECIAL_CHARS);
        $commentMail    = filter_input(INPUT_POST, 'commentMail', FILTER_VALIDATE_EMAIL);
        $commentTitle   = filter_input(INPUT_POST, 'commentTitle', FILTER_SANITIZE_SPECIAL_CHARS);
        $commentText    = filter_input(INPUT_POST, 'commentText', FILTER_SANITIZE_SPECIAL_CHARS);
        $commentRefId   = filter_input(INPUT_POST, 'commentRefId', FILTER_VALIDATE_INT);

        $headers = array('Content-Type' => 'application/json');

        $body = json_encode(
            array(
                'title' => $commentTitle,
                'text' => $commentText,
                'nickname' => $commentName,
                'email' => $commentMail,
                'siteId' => 3,
                'referentClass' => 'article',
                'referentId' => $this['id']
            )
        );
    
        if (!$this->wcmRestClient->login())
        {
            throw new Exception();
        }

        $response = $this->wcmRestClient->put('/content/contribution', null, $body, $headers);
        if (!preg_match('/^2[0-9][0-9]$/', $response->status))
        {
            $this['error']= $response->body;
        }    
    }

    /**
     * When the comment is added we want to regen the comment block 
     */
    public function afterAddComment()
    {
        if (empty($this['error']))
        {    
            $this->regenCommentBlock();
            header("Location: /article/{$this['id']}");
            exit();
        }
    }

    /**
     * When someone want to flag a comment, we call the WCM Rest WS to 
     * execute the notify transition on the contribution object 
     */
    public function onFlag()
    {
        if (!$this->wcmRestClient->login())
        {
            throw new Exception();
        }

        $request = $this->getRequest();

        $headers = array();
        $body = http_build_query(
            array(
                'className' => 'contribution',
                'objectId' => $request['commentId'],
                'code' => 'notify'
            )
        );
        $this->wcmRestClient->post('/workflow/transition', null, $body, $headers);
    }

    /**
     * When the contribution is flagged we want to regen the comment block 
     */
    public function afterFlag()
    {
        $this->regenCommentBlock();
    }

    /**
     * This method will be called automatically by the CMF when
     * someone will try to access to $this['id'].
     * 
     * @return int Id of the current article 
     */
    public function getId()
    {
        return cmfToolbox::getArrayParameter($this->getRequest(), 'id');
    }

    /**
     * This method will regenerate the comment block of the 
     * current article 
     */
    private function regenCommentBlock()
    {
        $context = array('id' => $this['id']);
        if ($content = $this->generateWcmBlock('wcmSampleSiteArticleComments', cmfFrontDispatcher::MODE_NORMAL, array('id' => $this['id']), self::GEN_MODE_MULTIPLE))
        {
            $blockName = $this->computeWcmBlockName('article/article_comments', self::GEN_MODE_MULTIPLE, $context);
            $filePath = $this->computeBlockPath($blockName);
            file_put_contents($filePath, $content);
        }
    }
    
    /**
     * Check if the article's main block has been generated 
     * (published) or not.
     * @return boolean True if the article's main block has been
     * generated (published) or not.
     */
    protected function doArticleExists()
    {
        $context = array('id' => $this['id']);
        $blockName = $this->computeWcmBlockName('article/article', self::GEN_MODE_MULTIPLE, $context);
        $filePath = $this->computeBlockPath($blockName);
        return file_exists($filePath);
    }
}
