<?php
/**
 * Nstein REST application framework
 *
 * @category   Nstein
 * @package    Nstein_REST
 * @copyright  Copyright (c) 2008 Nstein Technologies (http://www.nstein.com)
 * @version    1.0
 */

/**
 * The Nstein_REST_Response class emcapsulates a response from a REST API.
 *
 * @category   Nstein
 * @package    Nstein_REST
 * @copyright  Copyright (c) 2008 Nstein Technologies (http://www.nstein.com)
 */
final class Nstein_REST_Response extends Nstein_Http_Response
{
    // Custom headers (normalize to lowercase to follow Zend's convention)
    const H_X_NSTEIN_SESSION_ID = 'x-nstein-session-id';

    /**
     * Returns the "400 Bad Request" response for a missing parameter.
     *
     * @param string $name Parameter name
     *
     * @return Nstein_REST_Response Corresponding error response
     */
    public static function missingParameter($name)
    {
        return new Nstein_REST_Response(Nstein_REST_Response::S_BAD_REQUEST,
                                        array('%s: %s', _REST_MISSING_PARAMETER, $name));
    }

    /**
     * Returns the "400 Bad Request" response for two or more missing mutually exclusive parameters.
     *
     * @param string $name1 First parameter name
     * @param string $name2 Second parameter name
     * @param string ...    Other parameter names
     *
     * @return Nstein_REST_Response Corresponding error response
     */
    public static function missingExclusiveParameters($name1, $name2 /*, ...*/)
    {
        $names = func_get_args();
        return new Nstein_REST_Response(Nstein_REST_Response::S_BAD_REQUEST,
                                        array('%s: %s', _REST_MISSING_EXCLUSIVE_PARAMETERS,
                                              implode(', ', $names)));
    }

    /**
     * Returns the "404 Not Found" response for an invalid parameter value.
     *
     * @param string $name  Parameter name
     * @param string $value Parameter value
     *
     * @return Nstein_REST_Response Corresponding error response
     */
    public static function invalidParameter($name, $value)
    {
        return new Nstein_REST_Response(Nstein_REST_Response::S_NOT_FOUND,
                                        array('%s: %s=%s', _REST_INVALID_PARAMETER, $name, $value));
    }

    /**
     * Returns the "400 Bad Request" response for two or more conflicting parameters.
     *
     * @param string $name1 First parameter name
     * @param string $name2 Second parameter name
     * @param string ...    Other parameter names
     *
     * @return Nstein_REST_Response Corresponding error response
     */
    public static function conflictingParameters($name1, $name2 /*, ...*/)
    {
        $names = func_get_args();
        return new Nstein_REST_Response(Nstein_REST_Response::S_BAD_REQUEST,
                                        array('%s: %s', _REST_CONFLICTING_PARAMETERS,
                                              implode(', ', $names)));
    }
}