<?php

/**
 * 
 */
abstract class CacheTest extends PHPUnit_Framework_TestCase
{
    /**
     * The cache implementation being tested.
     * @var cmfCache
     */
    protected $cache;
    
    /**
     * 
     * @return array
     */
    public static function validProvider()
    {
        return array(
            array('key', 'value')
        );
    }
    
    /**
     * 
     * @return array
     */
    public static function invalidProvider()
    {
        return array(
            array(null, 'value'),
            array('', 'value'),
            array(false, 'value'),
            array(new DateTime(), 'value')
        );
    }
    
    /**
     * Clear the cache implementation.
     * @return void
     */
    public function tearDown()
    {
        $this->cache = null;
    }
    
    /**
     * Test a get on a key that doesn't exist in cache.
     * @return void
     * @dataProvider validProvider
     */
    public function testEmptyGet($key)
    {
        $this->assertNull($this->cache->get($key));
    }
    
    /**
     * Test a set using invalid key values.
     * @param $key
     * @param $value
     * @return void
     * @dataProvider invalidProvider
     * @expectedException InvalidArgumentException
     */
    public function testSetInvalidKey($key, $value)
    {
        $this->cache->set($key, $value);
    }
    
    /**
     * Test a set of a value (with no time to live).
     * @return void
     * @dataProvider validProvider
     */
    public function testSet($key, $value)
    {
        $this->cache->set($key, $value);
        $this->assertEquals(
            $value,
            $this->cache->get($key)
        );
    }
    
    /**
     * Test a set, with a 2 seconds time to live.
     * @return void
     * @dataProvider validProvider
     */
    public function testSetWithTTL($key, $value)
    {
        $ttl = 2;
        $this->cache->set($key, $value, $ttl);
        $this->assertEquals(
            $value,
            $this->cache->get($key)
        );
        
        sleep($ttl);
        $this->assertNull(
            $this->cache->get($key)
        );
    }
    
    /**
     * Test a delete of a cache entry.
     * @return void
     * @dataProvider validProvider
     */
    public function testDelete($key, $value)
    {
        $this->cache->set($key, $value);
        $this->cache->delete($key);
        $this->assertNull(
            $this->cache->get($key)
        );
    }
    
    /**
     * Test a clear operation.
     * @return void
     * @dataProvider validProvider
     */
    public function testClear($key, $value)
    {
        $this->cache->set($key, $value);
        $this->cache->clear();
        $this->assertNull(
            $this->cache->get($key)
        );
    }
}