<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 *  TODO: Verify everything that gets created gets deleted also
 *  TODO: Should the SQL style queries be tested? this applies to most rest controllers
 *  TODO: Verify thee returned objects are what is expected
 */
class authorizationTest extends WcmTest
{
    private static $userId;

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
        self::$userId = self::createUser();
    }

    // called after all tests have been executed
    public static function tearDownAfterClass()
    {
        self::deleteUser(self::$userId);
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
        $this->setResource(self::AUTHORIZATION_CONTROLLER);
    }

    //--------------------------------------------------------//
    // RETRIEVING PERMISSION MASK BY CLASS
    //--------------------------------------------------------//
    /*
    * Valid request
    */
    public function testGetAuthorization200SessionidClassname()
    {
        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    public function testGetAuthorization200SessionidClassnameJson()
    {
        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                'json'                    => 'true'
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsJSON();
    }

    /*
     * Missing parameter: className
     */
    public function testGetAuthorization400Sessionid()
    {
        $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid className
     */
    public function testGetAuthorization404SessionidClassname()
    {
        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING PERMISSION MASK BY CLASS FOR A SPECIFIED USER
    //--------------------------------------------------------//
    /*
    * Valid request
    */
    public function testGetAuthorizationPrivilege200SessionidClassnameUserid()
    {
        $this->setResource(
            self::AUTHORIZATION_CONTROLLER .
            self::SEPERATOR .
            self::PRIVILEGE_RESOURCE
        );

        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                self::USER_ID_PARAMETER   => self::$userId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    /*
     * Missing parameter: className
     */
    public function testGetAuthorizationPrivilege400SessionidUserid()
    {
        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::USER_ID_PARAMETER   => self::$userId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid className
     */
    public function testGetAuthorizationPrivilege404SessionidClassnameUserid()
    {
        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::INVALID_PARA_VALUE,
                self::USER_ID_PARAMETER   => self::$userId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }
}