<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 * WCM Rest permission controller PHPUnit test class
 *
 */
class permissionTest extends WcmTest
{
    // An array of workflow ids created during the tests
    private static $workflowIdArray = array();

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
        // point the local workflow id array to the inheritted $idArray[wcmWorkflow]
        self::$workflowIdArray =& self::$idArray[self::WORKFLOW_BIZ_CLASS];
    }

    /*
     * Called after all tests are completed regardless of success or failure
     */
    public static function tearDownAfterClass()
    {
        parent::tearDownAfterClass();
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
    }

    //--------------------------------------------------------//
    // RETRIEVING PERMISSIONS BY CLASS
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetPermissionsArticle200Sessionid()
    {
        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::ARTICLE_RESOURCE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
    }

    /*
     * Request without sessionId parameter
     */
    public function testGetPermissionsArticle400()
    {
        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::ARTICLE_RESOURCE
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Request with an invalid className
     */
    public function testGetPermissionsInvalid404Sessionid()
    {
        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::INVALID_RESOURCE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING PERMISSIONS BY OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetPermissionsWorkflowId200Sessionid()
    {
        $id = $this->createWorkflow();

        self::$workflowIdArray[] = $id;

        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_RESOURCE . self::SEPERATOR .
            $id
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

        $this->deleteWorkflow($id);
    }

    /*
     * Request without sessionId parameter
     */
    public function testGetPermissionsWokflowId400()
    {
        $id = $this->createWorkflow();

        self::$workflowIdArray[] = $id;

        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_RESOURCE . self::SEPERATOR .
            $id
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);

        $this->deleteWorkflow($id);
    }

    /*
     * Request with an invalid className
     */
    public function testGetPermissionsInvalidId404Sessionid()
    {
        $this->setResource(
            self::PERMISSIONS_CONTROLLER . self::SEPERATOR .
            self::INVALID_RESOURCE . self::SEPERATOR .
            '777'
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

}