<?php

require_once(dirname(__FILE__) . '/includes/WcmTest.php');

class SystemTest extends WcmTest
{

    function testMessageLog()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/log')]");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Message log');
    }

    function testCreateModifyDeleteGroup()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/group')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $this->type('name', 'group');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('group');

        // Modify
        $this->type('name', 'group modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('group modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteUser()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/group')]");
        $this->waitForWcmToLoad();
        $this->click("//a[@title='Administrators']");
        $this->waitForWcmToLoad();
        $this->click('link=New user');
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('name', 'name');
        $this->type('login', $uniq);
        $this->type('password', 'password');
        $this->type('email', 'change@me.com');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name');

        // Modify
        $this->type('name', 'name modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testDisallowDuplicateUser()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/group')]");
        $this->waitForWcmToLoad();
        $this->click("//a[@title='Administrators']");
        $this->waitForWcmToLoad();
        $this->click('link=New user');
        $this->waitForWcmToLoad();

        // Duplicate
        $this->type('name', 'name');
        $this->type('login', 'admin');
        $this->type('password', 'password');
        $this->type('email', 'change@me.com');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('This login exists');
        $this->click('id=sysmessage');

    }

    function testCreateModifyDeleteContentTypes()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/bizclass')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('Classname is mandatory');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('name', 'content');
        $this->type('className', $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('content');

        // Modify
        $this->type('name', 'content modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('content modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testDisallowDuplicateContentTypes()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/bizclass')]");
        $this->waitForWcmToLoad();

        // Duplicate
        $this->type('name', 'article');
        $this->type('className', 'article');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('This class name already exists');
        $this->click('id=sysmessage');

    }

    function testCreateModifyDeleteSystemTypes()
    {
        // TODO
        // Write this test...
    }

    function testCreateModifyDeleteMenu()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/menu')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $this->type('name', 'menu');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('menu');

        // Modify
        $this->type('name', 'menu modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('menu modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteDatasource()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/connector')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        /*
        * NOTE: If the connectionString can not return true on getConnection(),
        * then this test will fail. The DB must exist.
        */

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('reference', $uniq);
        $this->type('name', 'name');
        $this->type('connectionString', $GLOBALS['CONFIG']['CONNECTOR']);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name');

        // Modify
        $this->type('name', 'name modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testDisallowDuplicateDatasource()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/connector')]");
        $this->waitForWcmToLoad();

        // Duplicate
        $this->type('reference', 'biz');
        $this->type('name', 'name');
        $this->type('connectionString', 'mysql://test:test@localhost/test');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('Code is already in use');
        $this->click('id=sysmessage');

    }


    function testCreateModifyDeleteWorkflow()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/workflow')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $this->type('name', 'name');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name');

        // Modify
        $this->type('name', 'name modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteWorkflowState()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/workflow')]");
        $this->waitForWcmToLoad();
        $this->click("//a[@title='Workflow states']");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('name', 'name');
        $this->type('code', $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name');

        // Modify
        $this->type('name', 'name modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteWorkflowTransition()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/workflow')]");
        $this->waitForWcmToLoad();
        $this->click("//a[@title='Publication workflow']");
        $this->waitForWcmToLoad();
        $this->click('link=New transition');
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('name', 'name');
        $this->type('code', $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name');

        // Modify
        $this->type('name', 'name modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('name modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testTextMiningEngine()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/tme')]");
        $this->waitForWcmToLoad();

        $this->check('_wcmBoxmerge');

        // TODO: Revert this
        // we don't want to re-index 100,000 documents

        // $this->clickAt('link=Start');
        // $this->waitForWcmToLoad(90000);
        // $this->assertTrue($this->isTextPresent('Total computation time:'));

    }

    function testReindex()
    {

        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/business/indexation')]");
        $this->waitForWcmToLoad();

        $this->check("//input[@name='classList' and @value='article']");
        $this->check("//input[@name='classList' and @value='collection']");
        $this->check("//input[@name='classList' and @value='contribution']");
        $this->check("//input[@name='classList' and @value='forum']");
        $this->check("//input[@name='classList' and @value='issue']");
        $this->check("//input[@name='classList' and @value='item']");
        $this->check("//input[@name='classList' and @value='newsitem']");
        $this->check("//input[@name='classList' and @value='newsletter']");
        $this->check("//input[@name='classList' and @value='photo']");
        $this->check("//input[@name='classList' and @value='poll']");
        $this->check("//input[@name='classList' and @value='publication']");
        $this->check("//input[@name='classList' and @value='channel']");
        $this->check("//input[@name='classList' and @value='slideshow']");
        $this->check("//input[@name='classList' and @value='site']");
        $this->check("//input[@name='classList' and @value='webuser']");

        // TODO: Revert this
        // we don't want to re-index 100,000 documents

        // $this->clickAt('link=Begin re-indexing');
        // $this->waitForWcmToLoad(90000);
        // $this->assertTrue($this->isTextPresent('Done'));

    }

    function testUnlockContent()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/lock')]");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Unlock content');
    }

    function testPurgeContent()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='system']/li[1]//a[contains(@href,'/business/maintenance')]");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Purge content');
    }

}