<?php
/**
 * Project:     WCM
 * File:        $Id: biz.collection.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Definition of a collection
 */
class collection extends bizobject
{
    /**
     * site id
     * @var int
     */
    public $siteId;

    /**
     * channel id
     * @var int
     */
    public $channelId;

    /**
     * title
     * @var string
     */
    public $title;

    /**
     * description
     * @var string
     */
    public $description;

    /**
     * publication date
     * @var string
     */
    public $publicationDate;

    /**
     * expiration date
     * @var string
     */
    public $expirationDate;

    /**
     * template id
     * @var int
     */
    public $templateId;


    /**
     * Set all initial values of an object
     * This method is invoked by the constructor
     */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->publicationDate = null; 
        $this->expirationDate = null;
    }

    /**
     * Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    public function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'site':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'siteId=' . $value;
                    break;

                case 'channel':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'channelId=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
     * Get the documents part of the collection.
     *
     * @return array An array of objects
     */
    public function getDocuments()
    {
        return bizrelation::getBizobjectRelations($this, bizrelation::IS_COMPOSED_OF);
    }

    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if (''  == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        return true;
    }
}
