<?php
/**
 * Project:     WCM
 * File:        $Id: biz.newsletter.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/*
 * The newsletter object is a basic business object used to
 * manage newsletter. Each newsletter has a list of subscribers
 * (some webuser bizobjects) and have associated a text and an HTML
 * template
 */
class newsletter extends bizobject
{
    /**
     * site id
     * @var int
     */
    public $siteId;

    /**
     * unique code
     * @var string
     */
    public $code;

    /**
     * newsletter title
     * @var string
     */
    public $title;

    /**
     * newsletter description
     * @var string
     */
    public $description;

    /**
     * human readable sender's name
     * @var string
     */
    public $sender;

    /**
     * newsletter sender's email address
     * @var string
     */
    public $from;

    /**
     * newsletter replyTo email address
     * @var string
     */
    public $replyTo;

    /**
     * Id of template used for the HTML newsletter
     * @var string
     */
    public $htmlTemplate;

    /**
     * Id of template used for the TEXT newsletter
     * @var string
     */
    public $textTemplate;

    /**
     * Refresh object from unique code
     *
     * @param string $code Code used to refresh newsletter
     *
     * @return true on success, false otherwise
     */
    public function refreshByCode($code)
    {
        $sql = 'SELECT id FROM ' . $this->tableName . ' WHERE code=?';
        $id = $this->database->executeScalar($sql, array($code));
        return $this->refresh($id);
    }


    /**
     * Gets the subscriptions to the newsletter.
     *
     * @param bool $toXML TRUE if called by toXML() method
     *
     * @return array An array of the newsletter's subscriptions (as subscription objects)
     */
    public function getAssoc_subscriptions($toXML = false)
    {
        if ($toXML)
        {
            return null;
        }

        $return = array();
        $subscriptions = $this->getSubscriptions();
        if ($subscriptions)
        {
            foreach ($subscriptions as $subscription)
            {
                $return[] = $subscription->getAssocArray($toXML);
            }
        }
        return $return;
    }


    /**
     * Gets the subscriptions to the newsletter.
     *
     * @return array An array of the newsletter's subscriptions (as subscription objects)
     */
    public function getSubscriptions()
    {
        $where  = 'subscribedId="' . $this->id . '" AND subscribedClass="' . $this->getType() . '"';

        return bizobject::getObjects('subscription', $where);
    }


    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' == trim($this->code))
        {
            $this->lastErrorMsg = _BIZ_ERROR_CODE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->code))
        {
            $this->lastErrorMsg = _BIZ_ERROR_CODE_TOO_LONG;
            return false;
        }

        if ('' == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        if ($this->sender && 128 < strlen($this->sender))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SENDER_TOO_LONG;
            return false;
        }

        if ($this->from && 128 < strlen($this->from))
        {
            $this->lastErrorMsg = _BIZ_ERROR_FROM_TOO_LONG;
            return false;
        }

        if ($this->replyTo && 128 < strlen($this->replyTo))
        {
            $this->lastErrorMsg = _BIZ_ERROR_REPLY_TO_TOO_LONG;
            return false;
        }
        return true;
    }
}
