<?php
/**
 * Project:     WCM
 * File:        $Id: biz.publication.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * This class represents a print publication
 *
 * A publication has issues which contains several articles, photos and pages
 */
class publication extends bizobject
{
    /**
     * site id
     * @var int
     */
    public $siteId;

    /**
     * Title
     * @var string
     */
    public $title;

    /**
     * Description
     * @var string
     */
    public $description;

    /**
     * Returns an array of existing publication's titles
     *
     * @return array An associative array as (publicationId => publicationTitle)
     */
    static function getPublicationList()
    {
        $publications = array('' => '(' . _NONE . ')');
        foreach (bizobject::getObjects('publication') as $publication)
        {
            $publications[$publication->id] = $publication->title;
        }
        return $publications;
    }

    /**
     * Returns list of issue's titles for a specific publication
     *
     * @param int $publicationId Id of publication
     *
     * @return array Assoc array of issueId => issueTitle
     */
    static function getIssueList($publicationId)
    {
        $issues = array('' => '(' . _NONE . ')');

        if ($publicationId)
        {
            $publication = wcmObjectFactory::create('publication', $publicationId);
            if ($publication->id)
            {
                foreach ($publication->getIssues() as $issue)
                {
                    $issues[$issue->id] = $issue->title;
                }
            }
        }

        return $issues;
    }

    /**
    * Returns the issues of the publication
    *
    * @return  array An array containing all the issues of the publication
    */
    public function getIssues()
    {
        return bizobject::getObjects('issue', 'publicationId=' . $this->id, 'issueDate');
    }

    /**
     * Exposes 'issues' to the getAssocArray
     *
     * @param bool $toXML TRUE if method is called in the context of toXML()
     *
     * @return array An array of Issues getAssocArray
     */
    public function getAssoc_issues($toXML = false)
    {
        $issues = array();
        if ($this->getIssues())
        {
            foreach ($this->getIssues() as $issue)
            {
                $issues[] = $issue->getAssocArray($toXML);
            }
        }

        return $issues;
    }

    /**
     * Deletes current object from database
     * Also delete related issues
     *
     * @return bool true on success or an error message (string)
     */
    public function delete()
    {
        // Delete related issues
        foreach ($this->getIssues() as $issue)
        {
            if ($issue->publicationId == $this->id)
            {
                $issue->delete();
            }
        }

        if (!parent::delete())
        {
            return false;
        }

        return true;
    }


    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        return true;
    }
}
