<?php
/**
 * Project:     WCM
 * File:        $Id: biz.slideshow.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Slideshow object
 * This is the basic slideshow object
 *
 */
class slideshow extends bizobject
{
    /**
     * channel id
     * @var int
     */
    public $channelId;

    /**
     * site id
     * @var int
     */
    public $siteId;

    /**
     * Slideshow title
     * @var string
     */
    public $title;

    /**
     * Keywords
     * @var string
     */
    public $keywords;

    /**
     * Slideshow description
     * @var string
     */
    public $description;

    /**
     * Slideshow HTML text
     * @var string
     */
    public $text;

    /**
     * publication date
     * @var string
     */
    public $publicationDate = null;

    /**
     * expiration date
     * @var string
     */
    public $expirationDate = null;

    /**
     * Article moderation kind - see getModerationKindList()
     * @var string
     */
    public $moderationKind;

    /**
     * Contribution mode - see getContributionStateList()
     * @var string
     */
    public $contributionState;

    /**
     * template id
     * @var int
     */
    public $templateId;


    /**
     * Set all initial values of an object
     * This method is invoked by the constructor
     */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->publicationDate = null; 
        $this->moderationKind    = 'a_priori';
        $this->contributionState = 'none';
    }

    /**
     * Returns the number of photos associated to this slideshow
     *
     * @param bool $toXML TRUE if method is called in the context of toXML()
     *
     * @return int Total number of photos
     */
    function getAssoc_photoCount($toXML = false)
    {
        return $this->getPhotoCount();
    }

    /**
     * Exposes 'photos' in the getAssocArray()
     *
     * @param bool $toXML TRUE if method is called in the context of toXML()
     *
     * @return array An array of photos getAssocArray()
     */
    public function getAssoc_photos($toXML = false)
    {
        $photos = array();

        foreach ($this->getPhotos() as $photo)
        {
            $photoAssoc = $photo->getAssocArray($toXML);
            if ($toXML)
            {
                $photoAssoc = $photoAssoc->toArray();
            }

            $photos[] = $photoAssoc;
        }

        return $photos;
    }

    /**
     * Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'site':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'siteId=' . $value;
                    break;

                case 'channel':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'channelId=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
     * Returns the number of photos associated to this slideshow
     *
     * @return int Total number of photos
     */
    function getPhotoCount()
    {
        $result = 0;

        $where = 'sourceId=' . $this->id . ' AND sourceClass="' . $this->getType() . '" AND destinationClass="photo" AND kind=3';
        $enum = new wcmEnumeration('bizrelation', $where, 'rank');
        return count($enum);
    }


    /**
     * Retrieve photos associated to slideshow
     *
     * @param int $offset Index of first photo to retrieve (default is 0)
     * @param int $limit  Maximum number of photos to retrieve (default iz 0 for all)
     *
     * @return array An array of photo objects belonging to slideshow
     */
    function getPhotos($offset=0, $limit=-1)
    {
        $photos = array();

        $where = 'sourceId=' . $this->id . ' AND sourceClass="' . $this->getType() . '" AND destinationClass="photo" AND kind=3';
        $enum = new wcmEnumeration('bizrelation', $where, 'rank', $offset, $limit);

        foreach ($enum as $bizrelation)
        {
            $photos[] = wcmObjectFactory::create('photo', $bizrelation->destinationId);
        }
        return $photos;
    }


    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        if ($this->keywords  && 255 < strlen($this->keywords))
        {
            $this->lastErrorMsg = _BIZ_ERROR_KEYWORDS_TOO_LONG;
            return false;
        }

        return true;
    }
}
