<?php
/**
 * Project:     WCM
 * File:        $Id: biz.site.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Site object
 * This is the basic site object
 *
 */
class site extends bizobject
{
    /**
     * Site title
     * @var string
     */
    public $title;

    /**
     * Site description
     * @var string
     */
    public $description;

    /**
     * Site language (ISO two-letters code)
     * @var string
     */
    public $language;


    /**
     * Site Code
     * 
     * @var string
     */
    public $code;

    /**
     * Site config
     */
    protected $config = array();
    
    /**
     * Load the site config.
     */
    protected function loadConfig()
    {
        $configs = siteConfigProvider::getArray($this->code);
        $this->config = new siteConfig($configs);
    }

    /**
     * Load or refresh object content
     *
     * @param int $id the id of the site
     */
    public function refresh($id)
    {
        if (!parent::refresh($id))
        {
            return false;
        }
        $this->loadConfig();
        return true;
    }

    /**
     * (non-PHPdoc)
     * @see src/api/core/wcmObject#nextEnum()
     */
    public function nextEnum()
    {
        $result = parent::nextEnum();
        if ($result)
        {
            $this->loadConfig();
        }
        return $result;
    }

    /**
     * Method used to get the configuration info, if exist
     *
     * @param (string) the configuration array key to get it's value from.
     *
     * @return  it the key exists it return the value otherwise it return false.
     */
    public function getConfig($element)
    {
        if (isset($this->config[$element]))
        {
            return $this->config[$element];
        }

        return false;
    }

    /**
     * Method used to get the site configs as an array
     *
     * @return (array) the site configs
     */
    public function getConfigs()
    {
        if ($this->config instanceof siteConfig)
        {
            return $this->config->getAssocArray();
        }

        return $this->config;
    }

    /**
     * Set all initial values of an object
     * This method is invoked by the constructor
     */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->loadConfig();
        $this->language = $this->getConfig('wcm.default.language');
    }

    /**
     * Deletes the object from database.
     *
     * @return bool True on success, false on failure
     *
     */
    public function delete()
    {
        if ($this->id != $_SESSION['siteId'])
        {
            return parent::delete();
        }
        else
        {
            $this->lastErrorMsg = _BIZ_SITE_CANT_DELETE_CURRENT;
            return false;
        }
    }

    /**
     * Returns an array containing all the bizchannel of the site
     *
     * @return array Array of channels
     */
    public function getChannels()
    {
        return bizobject::getObjects('channel', 'siteId = "' . $this->id . '"', null);
    }

    /**
    * List (assoc array) of languages
    * @return array Array of language strings in format code=>string
    */
    public function getLanguageList()
    {
        return array(
            'fr' => _BIZ_FRENCH,
            'en' => _BIZ_ENGLISH
            );
    }


    /**
     * Gets object ready to store by getting modified date, creation date etc
     * Will execute transition.
     * @return bool TRUE on success
     */
    protected function store()
    {
        if (!parent::store())
        {
            return false;
        }

        if (isset($this->serialStorage['permissionTypes']))
        {
            // Erase permissions for the sysclass and all its related objects
            $project = wcmProject::getInstance();
            $sql = 'DELETE FROM #__permission WHERE target=?';
            $params = array($this->getPermissionTarget());
            $project->database->executeStatement($sql, $params);
            if ($this->getType())
            {
                $sql = 'DELETE FROM #__permission WHERE target LIKE "' . $this->getType() . '_' . $this->id . '%"';
                $project->database->executeStatement($sql);
            }

            // insert the new permissions
            $newPermissions = getArrayParameter($this->serialStorage, 'permissions');
            if ($newPermissions)
            {
                $permsArray = array();
                foreach ($newPermissions as $permission)
                {
                    // get values
                    $perms = explode('*', $permission, 2);
                    $permsArray[$perms[0]][] = $perms[1];
                }

                foreach ($permsArray as $wcmObject => $permissionMask)
                {
                    $securedObject = explode('_', $wcmObject);
                    $groupId   = $securedObject[0];

                    $finalMask = 0;
                    foreach ($permissionMask as $mask)
                    {
                        // get group and values
                        $values = explode('#', $mask);
                        $finalMask += $values[0];

                        // when a permission is set (WRITE, EXECUTE, DELETE)
                        // permission P_READ is always available
                        if ($finalMask)
                        {
                            $finalMask |= wcmPermission::P_READ;
                        }

                        // when a permission is none keep only that one!
                        if ($finalMask & wcmPermission::P_NONE)
                        {
                            $finalMask = wcmPermission::P_NONE;
                        }

                        // set permissions
                        $this->setGroupPermission($groupId, $finalMask);
                    }
                }
            }
        }

        return true;
    }

    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ('' === trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        return true;
    }
}
