<?php
/**
 * Project:     WCM
 * File:        $Id: resizingManager.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * This class is used to do the photo preiew. 
 */
class resizingManager
{

    /**
     * Photo object
     * @var photo
     */
    private $photoObj = null;

    /**
     * Width of the photo to generate
     * @var int
     */
    private $width = 0;

    /**
     * Height of the photo to generate
     * @var int
     */
    private $height = 0;

    /**
     * Constructor
     *
     * @param photo $photo Photo to resize
     * @param int $width width of the generated photo
     * @param int $height Height of the generated photo
     */
    public function __construct($photo, $width, $height)
    {
        $this->photoObj = $photo;
        $this->width = $width;
        $this->height = $height;
    }

    /**
     * Get the base 64 encoded photo to put in an <img src="" /> photo tag
     *
     * @return string base 64 encoded photo string
     */
    public function getPhotoUrl()
    {
        $config = wcmConfig::getInstance();
        $publicSystemDir = WCM_WWW_BACKOFFICE_DIR . '/system/public/';
        $photoPath = $publicSystemDir . $this->photoObj->original;

        $img_size = getimagesize($photoPath);
        switch ($img_size[2])
        {
            case 1 :
                if (imagetypes() & IMG_GIF)
                {
                    $image = imagecreatefromgif($photoPath);

                }
                $img_type = IMG_GIF;
                break;

            case 2 :
                if (imagetypes() & IMG_JPG)
                {
                    $image = imagecreatefromjpeg($photoPath);
                }
                $img_type = IMG_JPG;
                break;

            case 3 :
                if (imagetypes() & IMG_PNG)
                {
                    $image = imagecreatefrompng($photoPath);
                }
                $img_type = IMG_PNG;
                break;

        }
       
        $height = $this->height;
        $width = $this->width; 
        $w = $img_size[0];
        $h = $img_size[1];

        $ratioFull = ($h != 0) ? $w/$h : 0;
        $ratioThumb = ($height != 0) ? $width/$height : 0;

        if ($ratioThumb > $ratioFull)
        {
            $src_w = $w;
            $src_h = $src_w / $ratioThumb;
            $src_x = 0;
            $src_y = 0;
        }
        else
        {
            $src_h = $h;
            $src_w = $src_h * $ratioThumb;
            $src_y = 0;
            $src_x = 0;
        }
        
        $destsrc = imagecreatetruecolor($width, $height);
        $bgc = imagecolorallocate($destsrc, 255, 255, 255);
        imagefilledrectangle($destsrc, 0, 0, $width, $height, $bgc);
        if ($image != null)
        {
            imagecopyresampled($destsrc, $image, 0, 0, $src_x, $src_y, $width, $height, $src_w, $src_h);
        }

        ob_start();
        imagepng($destsrc);
        $contents =  ob_get_contents();
        ob_end_clean();

        return 'data:image/png;base64,' . base64_encode($contents);
    }
}
