<?php
/**
 * Project:     WCM
 * File:        $Id: biz.toolbox_html.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Fill in an html select with options containing all channels
 * @param wcmProject $project       the project
 * @param int $selectedId    contains the id of the selected item, if there is any
 * @param string $where         contains the clause where for the query to the database
 * @param string $prefix        contains the string used to prefix the children name in the select box
 * @param int $excludeId     contains the id of an item we dont want to display
 */
function renderHtmlChannelOptions($project, $selectedId = null, $where = null, $prefix = null, $excludeId = null)
{
    if (null == $where)
    {
        $where = 'parentId IS NULL OR parentId = 0';
    }

    // Recover the channels in an array of object
    $channels = bizobject::getObjects('channel', $where, 'rank');
    if (null === $channels)
    {
        return;
    }

    // Loop through the array of channels and display
    foreach ($channels as $channel)
    {
        if ($channel->id != $excludeId)
        {
            echo "<option value='" . $channel->id . "'";
            if ($selectedId == $channel->id)
            {
                echo ' selected="selected" ';
            }
            echo '>' . $prefix . textH8($channel->title) . ' (id:' . $channel->id . ')</option>';

            // Display subchannels with new prefix
            renderHtmlChannelOptions($project, $selectedId, 'parentId = ' . $channel->id, ($prefix . _BIZ_CHANNEL_INDENT_SYMBOL), $excludeId);
        }
    }
}

/**
 * Fill in an html select with options containing all sites
 * @param wcmProject $project       the project
 * @param int $selected      contains the id of the selected item, if there is any
 * @param string $where         contains the clause where for the query to the database
 * @param string $orderBy       contains the orderBy for the quere to the database
 * @param string $exclude       contains the id of an item we dont want to display
 */
function renderHtmlBizclassOptions($project, $selected = null, $where = null, $orderBy = 'title', $exclude = null)
{
    $project = wcmProject::getInstance();
    $bizlogic = new wcmBizlogic($project);

    // Recover the sites in an array of object
    $bizClasses = $bizlogic->getBizclasses();
    if (null === $bizClasses)
    {
        return;
    }

    // Loop through the array of sites and display
    foreach ($bizClasses as $bizClass)
    {
        //On enlève le webuser car il existe un onglet.
        if (('webuser' != $bizClass->className) && ('newsletter' != $bizClass->className) && ('channel' != $bizClass->className))
        {
            if (wcmSession::getInstance()->isAllowed($bizClass, wcmPermission::P_READ))
            {
                $bizClassNames[] = textH8(getConst($bizClass->className));
                $option = "<option value='" . textH8(getConst($bizClass->className)) . "'";
                if ($selected == $bizClass->className)
                {
                    $option .= ' selected="selected" ';
                }
                $option .= '>';
                $option .= textH8(getConst($bizClass->title)) . ' (id:' . $bizClass->id . ')</option>';
                $options[] = $option;
            }
        }
    }
    echo '<option value="' . implode(',', $bizClassNames) . '">(' . _BIZ_ALL . ')</option>';
    echo implode('', $options);
}

/**
 * Renders a business object as HTML by executing a given template.
 *
 * @param bizobject  $bizobject    the business object to render
 * @param string     $templateCode the code of the template to execute
 * @param array      $parameters   the parameters for the template execution
 *
 * @return string the rendered business object as HTML
 */
function renderBizobject($bizobject, $templateCode = null, $parameters = null)
{
    $project   = wcmProject::getInstance();
    $generator = $project->generator;

    $templateId = 'renderBizobject.tpl';
    if (!is_array($parameters))
    {
        $parameters = array();
    }

    $templateParameters = array();
    $templateParameters['obizobject'] = $bizobject;
    $templateParameters['parameters'] = $parameters;

    $templateGenerator = new wcmTemplateGenerator();
    $template = new wcmTemplate();
    $template->refresh($templateId);
    return $templateGenerator->executeTemplate($template, $templateParameters);
}

/**
 * Renders a business object as HTML by executing a given template.
 *
 * @param string $bizclass     the class name of the business object to render
 * @param int    $bizid        the ID of the business object to render
 * @param string $templateCode the code of the template to execute
 * @param array  $parameters   the parameters for the template execution
 *
 * @return string the rendered business object as HTML
 */
function renderBizobjectById($bizclass, $bizid, $templateCode = null, $parameters = null)
{
    if ('' != $bizclass)
    {
        $bizobject = wcmObjectFactory::create($bizclass, $bizid);

        if (is_string($parameters))
        {
            $parameters = wcmXML::xmlToArray($parameters);
        }

        return renderBizobject($bizobject, $templateCode, $parameters);
    }
}

/**
 * Renders a business object as HTML by transforming its XML
 * representation using a given XSL. If the latter is not given, uses
 * the XSL corresponding to the object's class name.
 *
 * @param bizobject  $bizobject  the business object to render
 * @param string     $xsl        the XSL to use, or null to use the default
 * @param array      $parameters the parameters for the transformation
 *
 * @return string the business object rendered as HTML
 * @throws Exception
 */
function renderBizobjectFromXSL($bizobject, $xsl = null, $parameters = null)
{
    $bizclass = $bizobject->getType();
    $bizid = $bizobject->id;

    // Select XSL to use
    if (!$xsl)
    {
        $xslPrefix = WCM_WWW_BACKOFFICE_DIR . '/business/private/xsl/';
        $xslSuffix = '.xsl';

        if (!isset($parameters['view']))
        {
            $xsl = $xslPrefix . $bizclass . $xslSuffix;
            $parameters['view'] = $xsl;
        }
        else
        {
            //if an xsl template definition is sent, set the xsl file accordingly - new search UI

            // Load the search_configuration into the session if it's not aleady done
            if (!isset($_SESSION['search_configuration']))
            {
                loadSearchConfiguration();
            }

            // Get the xsl from the xml config file using the $parameters['view'] and the bizobject class $bizclass
            $domDoc = new DOMDocument();
            $xsl_not_found = false;
            if (!$domDoc->load($_SESSION['search_configuration']))
            {
                throw new Exception(_BIZ_INVALID_XML);
            }

            // The corresponding XPath object
            // Get the XSL representation of the current bizobject.
            $domXPath = new DOMXPath($domDoc);
            $nodeList = $domXPath->query("//searches/search[@id='1']/resultPage/resultSet/view[@name='" . $parameters['view'] . "']/bizObjects/bizObject[@name='" . $bizclass . "']");

            if ($nodeList->length > 0)
            {
                $nd = $nodeList->item(0);
                $xsl = $xslPrefix . trim($nd->nodeValue);
            }
            else
            {
                $xsl_not_found = true;
            }

            // If we don't find the XSL file related to the bizobject we get the default's bizobject XSL
            if ((!file_exists($xsl)) || ($xsl_not_found))
            {
                $nodeList = $domXPath->query("//searches/search[@id='1']/resultPage/resultSet/view[@name='" . $parameters['view'] . "']/bizObjects/bizObject[@name='default']");

                if ($nodeList->length > 0)
                {
                    $nd = $nodeList->item(0);
                    $xsl = $xslPrefix . trim($nd->nodeValue);
                }
                else
                {
                    echo "Error in search configuration file XPATH query: //searches/search[@id='1']/resultSet/views/view[@name='" . $parameters['view'] . "']/bizObjects/bizObject[@name='default']";
                }
            }
            // If the default XSL doesn't exist, we search for the XSL named bizobject.xsl
            if (!file_exists($xsl))
            {
                $xsl = $xslPrefix . 'bizobject' . $xslSuffix;
            }
       }
    }

    // Create XSL document
    $xslDoc = new DOMDocument();
    $xslDoc->load($xsl);

    // Create XSLT processor
    $xsltProc = new XSLTProcessor;
    $xsltProc->importStyleSheet($xslDoc);

    $xsltProc->registerPHPFunctions();

    $xsltProc->setParameter('', 'bizclass', $bizclass . '_' . $parameters['view']);
    $xsltProc->setParameter('', 'bizid', $bizid);
    if (method_exists($bizobject, 'isLocked') && $bizobject->isLocked())
    {
        $locked = 'TRUE';
    }
    elseif (method_exists($bizobject, 'getLockInfo'))
    {
        $lock = $bizobject->getLockInfo();
        if ($lock->userId == wcmSession::getInstance()->userId)
        {
            $locked = 'ME';
        }
        else
        {
            $locked = 'FALSE';
        }
    }
    else
    {
        $locked = 'FALSE';
    }
    $xsltProc->setParameter('', 'locked', $locked);

    if ($parameters)
    {
        foreach ($parameters as $name => $value)
        {
            $xsltProc->setParameter('', $name, $value);
        }
    }

    // Create XML document
    $xml = $bizobject->toXML();

    // Load XML into DOM document
    $xmlDoc = new DOMDocument();
    if (!$xmlDoc->loadXML($xml))
    {
        throw new Exception(_BIZ_INVALID_XML);
    }

    // Transform XML document into HTML
    $html = $xsltProc->transformToXML($xmlDoc);

    return $html;
}
