<?php
/**
 * Project:     WCM
 * File:        $Id: photoWorkflow.php 9370 2010-04-02 15:03:46Z berejeba $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

require_once(dirname(__FILE__) . '/publicationWorkflow.php');

/**
 * The publication workflow, specialized for photo objects.
 */
class photoWorkflow extends publicationWorkflow
{
    /**
     * The media manager REST client.
     * @var Nstein_Cmf_Mediamanager_Client
     */
    private $mediaManagerClient = null;
    
    /**
     * Get the media manager REST client.
     * @return Nstein_Cmf_Mediamanager_Client
     */
    private function getMediaManagerClient()
    {
        if (null === $this->mediaManagerClient)
        {
            /*
             * Create an instance of the media manager
             * using the current object's site config.
             */
            $site = $this->wcmObject->getSite();
            $this->mediaManagerClient = new Nstein_Cmf_Mediamanager_Client(
                $site->getConfig('media-manager.rest-url'),
                $site->getConfig('media-manager.username'),
                $site->getConfig('media-manager.password')
            );
        }
        return $this->mediaManagerClient;
    }
    
    public function onPublish()
    {
        parent::onPublish();
       
        // Get image URL from photo manager.
        $factory = new photoManagerFactory();
        $photoManager = $factory->createDefaultPhotoManager();
        $url = $photoManager->getImageUrl($this->wcmObject);
        
        if (!$photoManager->imageExists($this->wcmObject))
        {
            wcmMVC_Action::setError('Image Url : ' . $url . ' is not a valid photo ressource, You should upload an image');
            return false;
        }    
        // Push image file to front-end media manager.
        $this->getMediaManagerClient()->addImage(
            $this->wcmObject->id,
            $this->wcmObject->ratios,
            $url
        );
    }
    
    public function onUnpublish()
    {
        parent::onUnpublish();
        
        // Remove image file from front-end media manager.
        $this->getMediaManagerClient()->deleteImage(
            $this->wcmObject->id
        );
    }
    
    public function onDelete()
    {
        parent::onDelete();
        
        // Delete image file from photo manager.
        $factory = new photoManagerFactory();
        $photoManager = $factory->createDefaultPhotoManager();
        $photoManager->deleteImage($this->wcmObject);
    }
}
