<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.auth.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * WCM Authentication
 *
 * The WCM Authetication system is a fully pluggable
 * system for passing arbitrary credentials and getting
 * a WCM user id from them.
 */
class wcmAuth
{

    /**
     * Authetication plugin
     *
     * @var wcmIAuthPlugin
     */
    private $plugin;

    /**
     * Constructor
     *
     * The constructor must be called with the instance of the
     * plugin you plan on using.
     *
     * @param wcmIAuthPlugin $argPlugin Plugin object
     */
    public function __construct(wcmIAuthPlugin $argPlugin)
    {
        $this->plugin = $argPlugin;
    }

    /**
     * Authenticate credentials
     *
     * Often times authentication is handled by a user submitting
     * a form, and in these cases, the plugin should allow you to just
     * pass $_REQUEST or $_POST.
     *
     * Returns true if the credentials are valid, false if not.
     *
     * @param array $credentials Credentials
     * @return bool True on success, false on failure
     */
    public function authenticate(Array $credentials)
    {
        return $this->plugin->authenticate($credentials);
    }

    /**
     * Get the last reported error message
     *
     * @return string Error message
     */
    public function getLastError()
    {
        return $this->plugin->getErrorMsg();
    }

    /**
     * Get a WCM User ID
     *
     * If the credentials are authentic, the plugin should then
     * be able to map the credentials to a WCM User ID somehow.
     *
     * @return int User ID
     */
    public function getWcmUser()
    {
        return $this->plugin->getWcmUser();
    }

}
