<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.bizlogic.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The wcmBizlogic class is an helper class used to manage system classes and business classes
 *
 * Remark: sysClasses and bizClasses are store in cache through static variables
 */
class wcmBizlogic
{
    /**
     * Returns the bizclass corresponding to a specific id
     *
     * @param int $id Id of bizclass to retrieve
     *
     * @return wcmBizclass Corresponding bizclass or NULL
     */
    public function getBizclassById($id)
    {
        // Use cache
        foreach ($this->getBizclasses() as $bizClass)
        {
            if ($bizClass->id == $id)
            {
                return $bizClass;
            }
        }

        return null;
    }

    /**
     * Returns the bizclass corresponding to a specific className
     *
     * @param string $className Classname of bizclass to retrieve
     *
     * @return wcmBizclass Corresponding bizclass or NULL
     */
    public function getBizclassByClassName($className)
    {
        // Use cache
        return getArrayParameter($this->getBizclasses(), $className, null);
    }

    /**
     * Returns an array of bizclasses matching a specific where clause
     *
     * @param bool $resetCache Whether to reset the cache, ie. reload from DB (default is false)
     *
     * @return array An assoc array of {@link wcmBizclass} objects (keys are ids)
     */
    public function getBizclasses($resetCache = false)
    {
        $cached = wcmCacheRegistry::get()->fetch('wcmBizclass');
        if ($resetCache || false === $cached)
        {
            $project = wcmProject::getInstance();

            $cached = array();
            $enum = new wcmEnumeration('wcmBizclass');
            foreach ($enum as $bizclass)
            {
                $cached[$bizclass->className] = $bizclass;
            }

            // Update cache
            wcmCacheRegistry::get()->store('wcmBizclass', $cached);
        }

        return $cached;
    }

    /**
     * Returns the sysclass corresponding to a specific id
     *
     * @param int $id Id of sysclass to retrieve
     *
     * @return wcmSysclass Corresponding sysclass or NULL
     */
    public function getSysclassById($id)
    {
        // Use cache
        foreach ($this->getSysclasses() as $sysClass)
        {
            if ($sysClass->id == $id)
            {
                return $sysClass;
            }
        }

        return null;
    }

    /**
     * Returns the sysclass corresponding to a specific className
     *
     * @param string $className Classname of sysclass to retrieve
     *
     * @return wcmSysclass Corresponding sysclass or NULL
     */
    public function getSysclassByClassName($className)
    {
        // Use cache
        return getArrayParameter($this->getSysclasses(), $className, null);
    }

    /**
     * Returns an array of sysclasses matching a specific where clause
     *
     * @param bool $resetCache When true, resets cache before operation
     * @return array An assoc array of {@link wcmSysclass} objects (keys are ids)
     */
    public function getSysclasses($resetCache = false)
    {
        $cached = wcmCacheRegistry::get()->fetch('wcmSysclass');
        if ($resetCache || false === $cached)
        {
            $project = wcmProject::getInstance();
            $cached = array();
            
            $enum = new wcmEnumeration('wcmSysclass');
            foreach ($enum as $sysclass)
            {
                $cached[$sysclass->className] = $sysclass;
            }

            // Update cache
            wcmCacheRegistry::get()->store('wcmSysclass', $cached);
        }

        return $cached;
    }
}
