<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.config.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * Holds the configuration of a project
 */
class wcmConfig implements ArrayAccess
{
    /**
     * Singleton instance
     * @var	wcmConfig
     */
    protected static $singleton = null;

    /**
     * Assoc array
     * @var array
     */
    protected static $assocArray = null;

    /**
     * Cache array
     * @var array
     */
    protected static $cacheArray = array();

    /**
     * Configuration data
     * @var array
     */
    private $config = null;

    /**
     * Implements interface ArrayAcccess
     *
     * @param string $key Configuration key
     *
     * @return bool True is key exists
     */
    public function offsetExists($key)
    {
        return null !== $this->offsetGet($key);
    }

    /**
     * Implements interface ArrayAcccess
     *
     * @param string $key Configuration key
     * @param mixed  $defaultValue Default value if key was not found
     *
     * @return mixed Configuration key value
     */
    public function offsetGet($key, $defaultValue = null)
    {
        if (!array_key_exists($key, self::$cacheArray))
        {
            $xml = $this->config;
            foreach (explode('.', $key) as $elem)
            {
                if (!$xml)
                {
                    break;
                }
                elseif (is_numeric($elem))
                {
                    $xml = $xml[intval($elem)];
                }
                else
                {
                    $xml = $xml->$elem;
                }
            }
            self::$cacheArray[$key] = $xml ? (string)$xml : $defaultValue;
        }
        return self::$cacheArray[$key];
    }

    /**
     * Implements interface ArrayAcccess
     *
     * @param string $key Configuration key
     *
     */
    public function offsetSet($key, $value)
    {
        trigger_error('Invalid access: configuration is read only!');
    }

    /**
     * Implements interface ArrayAcccess
     *
     * @param string $key Configuration key
     *
     */
    public function offsetUnset($key)
    {
        trigger_error('Invalid access: configuration is read only!');
    }

    /**
     * Constructor
     * Builds configuration from XML config file
     *
     * @param string Optional path to configuration file
     */
    private function __construct($configFile = null)
    {
        // Determine which config file to use
        if (defined('WCM_CONFIG_FILE'))
        {
            $configFile = WCM_CONFIG_FILE;
        }
        else
        {
            $configFile = WCM_BACKOFFICE_CONF_DIR . '/configuration.xml';
        }

        $array = array();
        $this->config = simplexml_load_file($configFile);
    }

    /**
     *  Clone method set as private for singleton design pattern
     */
    private function __clone()
    {
    }

    /**
     * Implements Singleton
     *
     * @return wcmConfig Unique configuration instance
     */
    public static function getInstance()
    {
        // Build singleton
        if (!isset(self::$singleton))
        {
            self::$singleton = new self();
        }

        return self::$singleton;
    }

    /**
     * Returns an assoc array of (recursive) array for templates
     *
     * @return array Config as array of array
     */
    public function getAssocArray()
    {
        // Determine which config file to use
        if (defined('WCM_CONFIG_FILE'))
        {
            $configFile = WCM_CONFIG_FILE;
        }
        else
        {
            $configFile = WCM_BACKOFFICE_CONF_DIR . '/configuration.xml';
        }

        // Build an associative array for smarty templates
        if (!isset(self::$assocArray))
        {
            self::$assocArray = object2Array(simplexml_load_file($configFile));
        }

        return self::$assocArray;
    }

    /**
     * Convert an object to an assoc array
     *
     * @param array $array Result array (referenced)
     * @param string $prefix Prefix to XML elements
     * @param object $object Object to convert
     *
     * @return array Associative array representing the object
     */
    private function xml2Array(&$array, $prefix, $object)
    {
        if (is_array($object))
        {
            foreach ($object as $key => $value)
            {
                $key = ($prefix) ? $prefix . '.' . $key : $key;
                $this->xml2Array($array, $key, $value);
            }
        }
        else
        {
            if (is_object($object))
            {
                $var = get_object_vars($object);

                foreach ($var as $key => $value)
                {
                    $key = ($prefix) ? $prefix . '.' . $key : $key;
                    $this->xml2Array($array, $key, $value);
                }
            }
            else
            {
                $array[$prefix] = strval($object);
            }
        }
    }
}
