<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.project.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * Main class for managing Plug'n Web project
 *
 */
class wcmProject
{
    /**
     * Singleton object
     * @var object
     */
    protected static $singleton = null;

    /**
     * Project title (use as default HTML title)
     * @var string
     */
    public $title;

    /**
     * Datalayer (manages connectors and tables)
     * @var wcmDatalayer
     */
    public $datalayer = null;

    /**
     * Membership (manages groups, users, roles and permissions)
     * @var wcmMembership
     */
    public $membership = null;

    /**
     * Business logic (manages sysclass, bizclasses and workflow)
     * @var wcmBizlogic
     */
    public $bizlogic = null;

    /**
     * Workflow manager (manages workflows, workflow states, workflow transitions and workflow scripts)
     * @var wcmWorkflowManager
     */
    public $workflowManager = null;

    /**
     * Generator (manages generations, generationContents, templateCategories and templates)
     * @var wcmGenerator
     */
    public $generator = null;

    /**
     * Layout (manages menus and zones)
     * @var wcmLayout
     */
    public $layout = null;

    /**
     * Database (wcmDatabase object linked to the system database)
     *
     * @var wcmDatabase
     */
    public $database = null;

    /**
     * Logger (main logger used to store/display session information and errors)
     * @var wcmLogger
     */
    public $logger = null;

    /**
     * Retrieves the singleton instance of this class
     *
     * @return wcmProject A wcmProject instance
     */
    public static function getInstance()
    {
        // Build singleton
        if (!isset(self::$singleton))
        {
            self::$singleton = new wcmProject();
        }

        return self::$singleton;
    }

    /**
     * Constructor
     */
    private function __construct()
    {
        // Retrieve configuration
        $config = wcmConfig::getInstance();
        // Set project name
        $this->title = $config['wcm.project.title'];

        // Set logger (verbose, debug, log filename, handle error)
        $this->logger = new wcmLogger($config['wcm.logging.verbose'], $config['wcm.logging.debug'],
                                      getLogFilename(), $config['wcm.errorHandling.enabled']);

        // Open database (and set logger for debug trace)
        $this->database = new wcmDatabase($config['wcm.systemDB.connectionString'],
                                          $config['wcm.systemDB.tablePrefix'],
                                          $this->logger);

        // Initialize members
        $this->membership   = new wcmMembership();
        $this->datalayer    = new wcmDatalayer();
        $this->bizlogic     = new wcmBizlogic();
        $this->generator    = new wcmGenerator();
        $this->layout       = new wcmLayout();
        $this->workflowManager = new wcmWorkflowManager();
    }

    /**
     *  Clone method set as private for singleton design pattern
     */
    private function __clone()
    {
    }
}
