<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.contextHelp.php 9387 2010-04-06 19:48:13Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * Context help class
 */
class wcmContextHelp
{
    /**
     * Resource type constant
     */
    const RESOURCE_TYPE = 'file'; // file or dir

    /**
     * Tabs
     * @var array
     */
    protected $tabs;

    /**
     * Currently selected tab
     * @var string
     */
    protected $currentTab;

    /**
     * Mode
     * @var string
     */
    protected $mode;

    /**
     * Current action
     * @var string
     */
    protected $action;

    /**
     * ID prefix
     * @var string
     */
    protected $idPrefix;

    /**
     * Resource
     * @var string
     */
    protected $resource;

    /**
     * Context help parts
     * @var array
     */
    protected $helpGibs;

    /**
     * Base URL
     * @var string
     */
    protected $baseUrl;

    /**
     * Build a table of contents Html from an array
     * @param array $toc TOC array
     * @return string Html code
     * @see wcmContextHelp::buildToArray()
     */
    public function buildTocHtmlFromArray(Array $toc)
    {
        // The TOC can only be three levels
        // We know that we must start with WCM first
        // height is for IE8
        $html = '<ul class="help-toc" style="height:1px;">';
        $html .= '<li><a href="' . $this->baseUrl . $toc['wcm']['_file'] . '" target="helpIframe">' . $toc['wcm']['_title'] . '</a><ul>';

        unset($toc['wcm']['_file']);
        unset($toc['wcm']['_title']);

        foreach ($toc['wcm'] as $secondLevel)
        {
            if (isset($secondLevel['_file']))
            {
                $html .= '<li><a href="' . $this->baseUrl . $secondLevel['_file'] . '" target="helpIframe">' . $secondLevel['_title'] . '</a><ul>';
                unset($secondLevel['_file']);
                unset($secondLevel['_title']);
            }
            foreach ($secondLevel as $thirdLevel)
            {
                $html .= '<li><a href="' . $this->baseUrl . $thirdLevel['_file'] . '" target="helpIframe">' . $thirdLevel['_title'] . '</a></li>';
            }
            $html .= '</ul></li>';

        }

        $html .= '</ul></li></ul>';

        return $html;

    }

    /**
     * Build a table of contents array
     * @return array TOC array
     */
    public function buildTocArray()
    {
        // Find files
        // Extract heirarchy information
        // Extract title

        $path = WCM_WWW_BACKOFFICE_DIR . '/system/private/views/help/context/' . $this->lang;

        $dir = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($path), RecursiveIteratorIterator::SELF_FIRST);

        foreach ($dir as $file)
        {
            if (is_file($file))
            {
                // Check the file name.
                $fileParts = explode('.', basename($file));
                if (array_pop($fileParts) == 'html')
                {
                    // At this point, if the array has a count of 4, then
                    // the help file is for a tab. We don't want that file.
                    $hierarchy = count($fileParts);
                    if ($hierarchy <= 3)
                    {

                        // Check to see if this is shared documentation. We
                        // don't want that because shared stuff can't be properly
                        // placed inside the table of contents
                        if ($fileParts[$hierarchy-1] != 'shared')
                        {
                            // Ok, we have a valid file for processing. Since we can't rely
                            // on the accuracy of the HTML, we will have to go the slower route
                            // and load the file as a string, and regexp the contents of <title></title>
                            // out of it.
                            $contents = file_get_contents($file);
                            $regexp = '/\<title\>(.*)\<\/title\>/im';
                            $matches = array();
                            preg_match($regexp, $contents, $matches);
                            $title = array_pop($matches);

                            switch ($hierarchy)
                            {
                                case 1:
                                    $toc[$fileParts[$hierarchy-1]]['_file'] = basename($file);
                                    $toc[$fileParts[$hierarchy-1]]['_title'] = $title;
                                    break;
                                case 2:
                                    $toc[$fileParts[$hierarchy-2]][$fileParts[$hierarchy-1]]['_file'] = basename($file);
                                    $toc[$fileParts[$hierarchy-2]][$fileParts[$hierarchy-1]]['_title'] = $title;
                                    break;
                                case 3:
                                    $toc[$fileParts[$hierarchy-3]][$fileParts[$hierarchy-2]][$fileParts[$hierarchy-1]]['_file'] = basename($file);
                                    $toc[$fileParts[$hierarchy-3]][$fileParts[$hierarchy-2]][$fileParts[$hierarchy-1]]['_title'] = $title;
                                    break;
                            }
                        }
                    }
                }
            }
        }
        return $toc;
    }

    /**
     * Constructor
     * @param array $argRequest Request array
     */
    public function __construct(Array $argRequest)
    {
        // Clean the request
        $request = $this->cleanRequest($argRequest);
        $this->lang = wcmSession::getInstance()->getLanguage();

        // We do this because _activeTabs is a json object, as javascript
        // differentiates between hashes and arrays
        if (is_object($request['_activeTabs']))
        {
            $this->tabs = get_object_vars($request['_activeTabs']);
        }

        $this->currentTab = $request['_currentTab'];
        $this->mode = $request['_mode'];
        $this->action = $request['_action'];
        $this->idPrefix = $request['_idPrefix'];

        $config = wcmConfig::getInstance();
        $this->baseUrl = $config['wcm.backOffice.url'] . 'help/context/' . $this->lang . '/';

    }

    /**
     * Change the current tab
     * @param string $argTab Tab to change to
     *
     */
    public function changeTab($argTab)
    {
        $this->helpGibs = null;
        $this->currentTab = $argTab;
    }

    /**
     * Get current mode
     * @return string Current mode
     */
    public function getMode()
    {
        return $this->mode;
    }

    /**
     * Clean the request array
     * @param array $argRequest Raw request array
     * @return array Clean request array
     */
    private function cleanRequest(Array $argRequest)
    {
        $request = array();

        // Lets make some general assumptions here
        // 1) If the value is {} then it is an empty JSON value.
        // 2) If the value starts with { and ends with } then it is a JSON value.
        // 3) the value 'undefined' means javascript passed a blank value

        foreach ($argRequest as $key => $value)
        {
            if (empty($value)) 
            {
                continue;
            }

            if ($value{0} == '{' && $value{strlen($value) - 1} == '}')
            {
                if ($value == '{}')
                {
                    $request[$key] = false;
                    continue;
                }
                else
                {
                    $request[$key] = json_decode($value);
                    continue;
                }
            }

            if ($value == 'undefined')
            {
                $request[$key] = false;
                continue;
            }

            $request[$key] = $value;
        }

        return $request;
    }

    /**
     * Get a resource name
     * @param array $resourceParts Resource parts array
     * @return string Resource name
     */
    public function getResourceName(Array $resourceParts)
    {
        if (self::RESOURCE_TYPE == 'file')
        {
            $flat = join('.', $resourceParts) . '.html';
            // Normalize file name to something more manageable
            $flat = preg_replace('/\s/', '', $flat); // Get rid of whitespaces
            $flat = strtolower($flat); // Lower case
        }
        elseif (self::RESOURCE_TYPE == 'dir')
        {
            $flat = join('/', $resourceParts) . '/index.html';
        }

        return $flat;
    }

    /**
     * Get a resource file
     * @param array $customGibs Resource parts array
     * @return string Resource file
     */
    public function getResourceFile(Array $customGibs = null)
    {
        $gibs = (isset($customGibs)) ? $customGibs : $this->getHelpParts();
        $resourceName = $this->getResourceName($gibs);

        $base = WCM_WWW_BACKOFFICE_DIR . '/system/private/views/help/context/' . $this->lang;

        if (file_exists($base . '/' . $resourceName))
        {
            return $resourceName;
        }
        elseif (count($gibs) == 4)
        {
            $gibs[2] = 'shared';
            $resourceName = $this->getResourceName($gibs);
            if (file_exists($base . '/' . $resourceName))
            {
                return $resourceName;
            }
        }

        // Well, a help file could not be found. We need to use our 404 script now
        // to handle this.
        $gib = array_pop($gibs);

        return '&view=help/context/404&altGib=' . $gib . '&fullResource=' . join('.', $gibs) . '&h=' . count($gibs);
    }

    /**
     * Get a resource
     * @param array $customGibs Resource parts array
     * @return string Resource
     */
    public function getResource(Array $customGibs = null)
    {
        if (!isset($customGibs) && !empty($this->resource))
        {
            return $this->resource;
        }

        $base = WCM_WWW_BACKOFFICE_DIR . '/system/private/views/help/context/' . $this->lang;

        $resNameParts = (isset($customGibs)) ? $customGibs : $this->getHelpParts();

        for ($i = count($resNameParts); $i >= 1; $i--)
        {
            if ($file = $this->getResourceFile(array_slice($resNameParts, 0, $i)))
            {
                if (!isset($customGibs))
                {
                    $this->resource = $base . '/' . $file;
                }
                return $base . '/' . $file;
            }
        }

        // if we're here, no help file or anything was found.
        return false;
    }

    /**
     * Get help parts
     * @return array Resource parts
     */
    public function getHelpParts()
    {
        if (!$this->helpGibs)
        {
            $resNameParts[] = 'wcm';
            $resNameParts[] = (!$this->action) ? 'system' : (substr($this->action, 0, 8) == 'business') ? 'business' : 'system';

            if ($this->action)
            {
                $resNameParts[] = array_pop(explode('/', $this->action));
            }

            if ($this->currentTab)
            {

                if (empty($this->currentTab->title))
                {
                    $this->currentTab->title = '...'; // Set some default on the off chance that this is empty
                }

                // Check for the current tab id
                if (empty($this->currentTab->id))
                {
                    // Nothing here, use the title instead
                    $resNameParts[] = $this->currentTab->title;
                }
                elseif (preg_match('/^t\d+$/i', $this->currentTab->id))
                {
                    // @TODO
                    // Hack
                    // Sometimes the id is something like T1, T2, T3, etc...
                    // In this case we want $this->currentTab->title instead
                    // Probably not the best idea...
                    $resNameParts[] = $this->currentTab->title;
                }
                else
                {
                    // Default
                    $resNameParts[] = $this->currentTab->id;
                }
            }
            $this->helpGibs = $resNameParts;
        }
        return $this->helpGibs;
    }

    /**
     * Get tabs array
     * @return array Array of tabs
     */
    public function getTabs()
    {
        return $this->tabs;
    }

    /**
     * Get the current tab
     * @return string Current tab key
     */
    public function getCurrentTab()
    {
        return $this->currentTab;
    }
}
