<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.tabAcl.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * wcmTabAcl class extends wcmAcl
 */
class wcmTabAcl extends wcmAcl
{

    /**
     * addRoles: adds roles to the ACL from the configuration file
     *			 Extended to add specific roles
     *
     * The method is extended to add all possible roles
     * (group ids) in WCM. This prevents us from having to
     * manually add each and every group id to the ACL file
     *
     * Add a current-user user role as well for the user in session
     *
     * @param array $config Parsed configuration file
     */
    public function addRoles($config)
    {
        parent::addRoles($config);

        $membership = new wcmMembership;
        $groups = $membership->getGroups();
        foreach ($groups as $group)
        {
            $this->addRole(new Zend_Acl_Role($group->id));
        }

        $session = wcmSession::getInstance();
        $user = new wcmUser;

        // add only valid roles!
        $roles = array();
        if ($user->refresh($session->userId))
        {
            foreach ($user->getGroups() as $role)
            {
                $roles[] = $role;
            }
        }

        $this->addRole(new Zend_Acl_Role('current-user'), $roles);

    }

    /**
     * isAllowed: adds roles to the ACL from the configuration file
     *			 Extended for specific tab functionality
     *
     *
     * The isAllowed method is extended to automatically define inheritance
     * instead of having the user define them explicitely in the tabs.ini file
     *
     * For example, instead of defining:
     *
     * [resources]
     * tabs =
     * tabs.overview = tabs
     * tabs.overview.article = tabs.overview
     *
     * Whenever we try to access a resource, let's say tabs.overview.article
     * isAllowed will first check if the resource is defined, if it isn't,
     * it will check for the resource tabs.overview, then tabs.
     * For the found resource, it will verify the permission given the role.
     *
     * So by default, all the tabs are allowed. To restrict a given tab, or group of tab (overview)
     * a resource and a premission should be added
     * add to resources:
     * [resource]
     * tabs.overview = tabs
     * tabs.overview.article = tabs.overview
     *
     * [permissions]
     * allow.tabs.overview = 3,5,6
     * allow.tabs.overview.article = 3
     *
     * So, groups 3,5,6 can view all the overview tabs, but group 3 will only be able
     * to see the article overview tab
     *
     * @param  Zend_Acl_Role_Interface|string     $role
     * @param  Zend_Acl_Resource_Interface|string $resource
     * @param  string                             $privilege
     * @uses   Zend_Acl::get()
     * @uses   Zend_Acl_Role_Registry::get()
     *
     * @return boolean is allowed
     *
     */
    //add inheritance resources implicitely instead of writing them in the config file
    public function isAllowed($role = null, $resource = null, $privilege = null)
    {
        //If the resource is not found, check the parent permission
        if ($resource !== null && !$this->has($resource))
        {
            //if there is a parent resource
            $rolearr = explode('.', $resource);
            if (count($rolearr) > 1)
            {
                array_pop($rolearr);
                $parent_resource = implode('.', $rolearr);
                return $this->isAllowed($role, $parent_resource, $privilege);
            }
            //otherwise, allow
            else
            {
                return true;
            }
        }
        else
        {
            return parent::isAllowed($role, $resource, $privilege);
        }

    }
}
