<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.default.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * Default WCM Authentication plugin
 *
 * This authentication plugin takes a username and password
 * as credentials and checks them against the wcm_user database
 * table.
 *
 * The credentials must be in this format:
 * array(
 *     'username' => 'Your Username',
 *     'password' => 'Your Password
 * );
 *
 */
class wcmAuthenticateDefault implements wcmIAuthPlugin
{

    /**
     * User ID
     * @var int
     */
    private $user_id;

    /**
     * Last error message
     * @var string
     */
    private $errorMsg;

    /**
     * Authenticate credentials
     *
     * @param array $argCredentials
     * @return bool True on sucess, false on failure
     */
    public function authenticate(Array $argCredentials)
    {
        // Try to get the user id with username and password
        $query = 'SELECT id FROM wcm_user WHERE login=:username AND password=:password';
        $db = wcmProject::getInstance()->database;
        $user_id = $db->executeScalar($query, array('username' => $argCredentials['username'], 'password' => md5($argCredentials['password'])));

        if ($user_id)
        {
            $this->user_id = $user_id;
            return true;
        }
        else
        {
            return false;
        }
    }

    /**
     * Get last reported error messag
     *
     * @return string Error message
     */
    public function getErrorMsg()
    {
        return $this->errorMsg;
    }

    /**
     * Get the WCM User ID that matches the supplied credentials
     *
     * @return int User ID
     */
    public function getWcmUser()
    {
        return $this->user_id;
    }

    /**
     * Ouptut login form
     *
     */
    static public function loginForm()
    {
        wcmGUI::openFieldset(_SIGN_IN, array('id' => 'usernamePassword'));
        wcmGUI::renderTextField('username', getArrayParameter($_REQUEST, 'username', null), _USERNAME);
        wcmGUI::renderPasswordField('password', null, _PASSWORD);
        wcmGUI::closeFieldset();


    }
}
