<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.cachePluginLite.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class supports different caching mechanism based on configuration file.
 * The best practice is to use the 'APC' extension, However, if APC is not set,
 * wcmCache will use Cache_Lite (as 'Lite' mode)
 */
class wcmCachePluginLite implements wcmICachePlugin
{

    private $cacheDir = null;

    public function __construct()
    {
        require_once(WCM_INCLUDES_DIR . '/CacheLite/Lite.php');
        $this->cacheDir = $this->getCacheDir();
    }

    /**
     * Returns the configured cache directory, ensuring that it exists.
     *
     * @return string The configured cache directory
     */
    private function getCacheDir()
    {
        $config = wcmConfig::getInstance();
        $cacheDir = sys_get_temp_dir() . '/' . $config['wcm.project.guid'] . '/wcm/Lite/';
        if (!is_dir($cacheDir))
        {
            mkdir($cacheDir, 0777, true);
        }
        return $cacheDir;
    }

    /**
     * Store a variable in cache
     *
     * @param string $key Unique key used to retrieve (fetch) variable
     * @param mixed $var Variable to cache
     * @param int $ttl Optional time to live (default is configuration ttl)
     *
     * @return bool FALSE on failure, TRUE on success
     */
    public function store($key, $var, $ttl = 0)
    {
        $cache = new Cache_Lite(
                array(
                    'caching' => true,
                    'cacheDir' => $this->cacheDir,
                    'automaticSerialization' => true,
                    'lifeTime' => $ttl
                    )
                );
        return $cache->save($var, $key);
    }

    /**
     * Fetch a cached variable
     *
     * @param string $key Unique key used to retrieve (fetch) variable
     *
     * @return mixed Variable value or else FALSE on failure
     */
    public function fetch($key)
    {
        $config = wcmConfig::getInstance();
        $cache = new Cache_Lite(
                array(
                    'caching' => true,
                    'cacheDir' => $this->cacheDir,
                    'automaticSerialization' => true,
                    )
                );
        return $cache->get($key);
    }

    /**
     * Delete a cached variable
     *
     * @param string $key Unique key representing the variable to delete
     *
     * @return bool FALSE on failure, TRUE on success
     */
    public function delete($key)
    {
        $cache = new Cache_Lite(array(
                    'caching' => true,
                    'cacheDir' => $this->cacheDir,
                    'automaticSerialization' => true,
                    )
                );
        return $cache->remove($key);
    }

    /**
     * Clear the entire cache
     * @return bool TRUE on success
     */
    public function clear()
    {
        $cache = new Cache_Lite(array(
                    'caching' => true,
                    'cacheDir' => $this->cacheDir,
                    'automaticSerialization' => true,
                    )
                );
        return $cache->clean();
    }
}
