<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.objectUrlGeneratorFactory.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The factory to create object URLs generators.
 * It uses the WCM configuration to know which
 * class it should use as default URL generator.
 */
class wcmObjectUrlGeneratorFactory
{
    /**
     * The WCM configuration.
     * @var wcmConfig
     */
    private $config;

    /**
     * The default URL generator instance.
     * @var wcmObjectUrlGenerator
     */
    private $defaultGenerator = null;

    /**
     * Public constructor.
     * @param wcmConfig $config The WCM configuration.
     */
    public function __construct(wcmConfig $config)
    {
        $this->config = $config;
    }

    /**
     * Get the default URL generator according to the
     * WCM configuration. 
     * @return wcmObjectUrlGenerator The default URL
     * generator instance.
     * @exception Exception If the URL generator class
     * in the config does not implements the 
     * wcmObjectUrlGenerator interface.
     */
    public function getDefaultGenerator()
    {
        if (null === $this->defaultGenerator)
        {
            $this->defaultGenerator = $this->createDefaultGenerator();
        }
        return $this->defaultGenerator;
    }

    /**
     * Create the default URL generator according
     * to the WCM configuration.
     * @return wcmObjectUrlGenerator The default URL
     * generator instance.
     * @exception Exception If the URL generator class
     * in the config does not implements the 
     * wcmObjectUrlGenerator interface.
     */
    private function createDefaultGenerator()
    {
        $class = $this->config['wcm.default.urlGenerator'];
        $generator = new $class();
        if (!($generator instanceof wcmObjectUrlGenerator))
        {
            throw new Exception('Invalid URL generator class: ' . $class);
        }
        return $generator;
    }
}
