<?php
/**
 * Project:     WCM
 * File:        widget.php
 *
 * @copyright   (c)2008 Nstein Technologies
 * @package     WCM
 * @version     4.x
 *
 */

/**
 * Get the configuration
 * @return array Configuration array
 */
function wcm_getConfig()
{
    global $db;

    $query = 'SELECT opt_name, opt_value FROM wcm_setup';
    $res = $db->query($query);
    while ($row = $db->fetch_array($res))
    {
        $wcmGlobalOptions[$row['opt_name']] = $row['opt_value'];
    }
    return $wcmGlobalOptions;
}

/**
 * Get the site list
 * @return array Site list
 */
function wcm_getSiteList()
{

    global $vbulletin, $db;

    if (!isset($GLOBALS['wcmGlobalOptions']))
    {
        $GLOBALS['wcmGlobalOptions'] = wcm_getConfig();
    }

    global $wcmGlobalOptions;

    if (empty($_COOKIE['wcm_vb_siteList']) || !is_array(unserialize($_COOKIE['wcm_vb_siteList'])))
    {
        $wcm = new wcmRestForPlugins($wcmGlobalOptions['wcm-url'], $wcmGlobalOptions['wcm-username'], $wcmGlobalOptions['wcm-password']);
        $return = $wcm->sendMessage('/content', 'GET', array('className' => 'site'), true, 'print_cp_message');

        $xml = simplexml_load_string($return[1]);

        foreach ($xml->location as $loc)
        {
            $location = parse_url((string)$loc);
            $sitedata = json_decode(array_pop($wcm->sendMessage("/$loc", 'GET', array('json' => 1), true, 'print_cp_message')));
            $sites[$sitedata->id] = $sitedata->title;
        }

        setcookie('wcm_vb_siteList', serialize($sites), mktime() + 3600, '/');
        return $sites;
    }

    return unserialize($_COOKIE['wcm_vb_siteList']);

}

/**
 * Get a siteId for a forum
 * @param int $argForumId Forum ID
 * @return int Site ID
 */
function wcm_getSiteIdForForum($argForumId)
{
    global $vbulletin;
    $config = wcm_getConfig();
    $forumId = $threadinfo['forumid'];

    $query = 'SELECT site_id FROM wcm_maps WHERE forum_id=' . $argForumId;
    $res = $vbulletin->db->query($query);

    if ($vbulletin->db->num_rows($res) > 0)
    {
        $row = $vbulletin->db->fetch_array($res);

        // Site ID in maps could be 0, represents "global setting", hence config
        $siteId = ($row['site_id'] > 0) ? $row['site_id'] : $config['wcm-site-id'];
    }
    else
    {
        $siteId = $config['wcm-site-id'];
    }
    return $siteId;
}

/**
 * Determine if forum has filters
 * @return bool TRUE if it does
 */
function wcm_hasForumFilters()
{
    global $vbulletin;

    $query = 'SELECT id FROM wcm_forums';
    $res = $vbulletin->db->query($query);
    return ($vbulletin->db->num_rows($res) > 0);
}

/**
 * Check if thread is user filtered
 * @param int $userid User ID
 * @return bool TRUE if filtered
 */
function wcm_threadUserFiltered($userid)
{
    global $vbulletin;

    $query = 'SELECT COUNT(*) FROM wcm_groups, ' . TABLE_PREFIX . 'user AS user
        WHERE user.userid = ' . $userid . ' AND (
                user.usergroupid = wcm_groups.group_id OR wcm_groups.group_id IN(user.membergroupids)
                )';
    $res = $vbulletin->db->query($query);
    $row = $vbulletin->db->fetch_array($res, DBARRAY_NUM);
    return ($row[0] > 0);
}

/**
 * Check if a bulletin has user filters
 * @return bool TRUE if it has filters
 */
function wcm_hasUserFilters()
{
    global $vbulletin;

    $query = 'SELECT id FROM wcm_groups';
    $res = $vbulletin->db->query($query);
    return ($vbulletin->db->num_rows($res) > 0);
}

/**
 * Check if a thread is forum filtered
 * @param int $forumid Forum ID
 * @return bool TRUE if filtered
 */
function wcm_threadForumFiltered($forumid)
{
    global $vbulletin;

    $query = 'SELECT indexing FROM wcm_maps WHERE forum_id=' . $forumid;
    $res = $vbulletin->db->query($query);
    $row = $vbulletin->db->fetch_row($res);
    return $row[0];
}

/**
 * Check if thread is filtered
 * @param array $threadinfo Thread data array
 * @return bool TRUE if filtered
 */
function wcm_threadPassesFiltered(array $threadinfo)
{
    // Automatically decide that the thread made it through filters

    if (!wcm_threadForumFiltered($threadinfo['forumid']))
    {
        return false;
    }

    if (wcm_hasUserFilters())
    {
        if (!wcm_threadUserFiltered($threadinfo['postuserid']))
        {
            return false;
        }
    }

    return true;
}

/**
 * Check if setup is complete
 * @return bool TRUE if setup completed
 */
function wcm_setupComplete()
{
    global $wcmGlobalOptions;

    // First make sure we have all the settings we need.
    if (!$wcmGlobalOptions['wcm-url'] || !$wcmGlobalOptions['wcm-username'] || !$wcmGlobalOptions['wcm-password'])
    {
        return false;
    }
    else
    {
        return true;
    }
}
