<?php
/**
 * Requirements:
 *	- a per site xml configuration file to use front end solr functionnality.
 *	- a mysql connection string to a general TME extracted database
 *
 * TODO: remove hardcoded values that can used with parameters)
 *	- configurable general TME extracted database connectionString
 * 	- configurable solrFrontendXmlConfigs name.
 *	- configurable NB_RECORDS_PER_LOOP
 * 	- configurable NB_INDEX_BEFORE_COMMIT
 */

if (1 >= $_SERVER['argc'])
{
    help();
}

/**
 * TODO: short description.
 *
 * @return TODO
 */
function help()
{
    $help = <<<EOH

Usage:\n
php {$_SERVER['argv'][0]} [siteCode] [--connectionString] [--engine] [--queue] [--help] [--verbose]

\t-c, --createSQLFilePath\t\tThe full path of the sql insert statement sql file to produce
\t-C, --channelId\t\t\tThe channelId to insert the article into
\t-f, --fromConnectionString\tThe mysql connection string to use to get data from. (ex: mysql://[user]:[password]@[ip]:[port]/[database])
\t-fu, --fromUsername\t\tThe mysql username
\t-fp, --fromPassword\t\tThe mysql password
\t-h, --help\t\t\tprint a summary of the options
\t-n, --nbRecords\t\t\tThe number of record to get
\t-s, --startAt\t\t\tStart at element id number x
\t-S, --siteId\t\t\tSite ids to insert data into. (multiple = comma seperated list)
\t-t, --toConnectionString\tThe mysql connection string to use to import data into. (ex: mysql://[user]:[password]@[ip]:[port]/[database])
\t-t, --toUsername\t\tThe mysql username
\t-tp, --toPassword\t\tThe mysql password
\t-v, --verbose\t\t\tenable verbose mode (true/false) (default: false)

Example:\n
\tHere is the one to use actually. (source database info)
\tphp {$_SERVER['argv'][0]} -f "mysql:host=172.18.4.186;port=3306;dbname=solr_timespast" -fu root -fp root -c "/tmp/createSQL.sql" -n 1 -S 3\n
EOH;

    die($help . "\n");
}

// Affect parameters
$verbose = false;
$sourceConnectionString = null;
$sourceUsername = null;
$sourcePassword = null;
$destinationConnectionString = null;
$destinationUsername = null;
$destinationPassword = null;
$startAt = 0;
$nbRecords = 1000;
$createSQL = false;
$siteIds = array();
$channelIds = array();
for ($i = 1 ; $i < $_SERVER['argc'] ; $i++)
{
    switch($_SERVER['argv'][$i])
    {
        case '--createSQLFilePath':
        case '-c':
            $createSqlFilePath = $_SERVER['argv'][++$i];
            $createSQL = true;
            break;
        case '--channelId':
        case '-C':
            $channelIds = explode(',', $_SERVER['argv'][++$i]);
            break;
        case '--fromConnectionString':
        case '-f':
            $sourceConnectionString = $_SERVER['argv'][++$i];
            break;
        case '--fromUsername':
        case '-fu':
            $sourceUsername = $_SERVER['argv'][++$i];
            break;
        case '--fromPassword':
        case '-fp':
            $sourcePassword = $_SERVER['argv'][++$i];
            break;
        case '--help':
        case '-h':
            help();
            break;
        case '--nbRecords':
        case '-n':
            $nbRecords = $_SERVER['argv'][++$i];
            break;
        case '--startAt':
        case '-s':
            $startAt = $_SERVER['argv'][++$i];
            break;
        case '--siteId':
        case '-S':
            $siteIds = explode(',', $_SERVER['argv'][++$i]);
            break;
        case '--destinationConnectionString':
        case '-t':
            $destinationConnectionString = $_SERVER['argv'][++$i];
            break;
        case '--toUsername':
        case '-tu':
            $destinationUsername = $_SERVER['argv'][++$i];
            break;
        case '--toPassword':
        case '-tp':
            $destinationPassword = $_SERVER['argv'][++$i];
            break;
        case '--verbose':
        case '-v':
            $verbose = (bool)$_SERVER['argv'][++$i];
            break;
    }
}

if (null === $sourceConnectionString)
{
    die('The source mysql connection string is required');
}
elseif (null === $sourceUsername)
{
    die('The source mysql username is required');
}
elseif (null === $sourcePassword)
{
    die('The source mysql password is required');
}

if (false === $createSQL)
{
    if (null === $destinationConnectionString)
    {
        die('The destination connection string is required if you are not creating a sql file');
    }
    elseif (null === $destinationUsername)
    {
        die('The destination mysql username is required');
    }
    elseif (null === $destinationPassword)
    {
        die('The destination mysql password is required');
    }
}

if (!$siteIds)
{
    die('At least 1 site id is required.');
}

if (true === $createSQL && !touch($createSqlFilePath))
{
    die('unable to create the file');
}

require(dirname(__FILE__) . '/../initWcmApi.php');
$session = wcmSession::getInstance();
$session->setLanguage();

$stopAt = $startAt + $nbRecords;

set_time_limit(0);
$startTime = microtime(true);

define('NB_RECORDS_PER_LOOP', 10000); // don't put this to high it will consume ram.  (select *)
define('TRACE', false); // debug purpose
define('TRACE_FILE', sys_get_temp_dir() . '/createSqlInsertArticles.trace'); // debug purpose
define('FAILED_DIR', 'failed/'); // debug purpose

$sourceDBH = new PDO($sourceConnectionString, $sourceUsername, $sourcePassword);

if (false === $createSQL)
{
    $destinationDBH = new PDO($destinationConnectionString, $destinationUsername, $destinationPassword);
}

if (!$channelIds)
{
    if (false === $createSQL)
    {
        $destinationDBH->query("INSERT INTO biz_channel (title) VALUES('dummy channel')");
        $channelIds[] = $destinationDBH->query('SELECT MAX(id) FROM biz_chapter')->fetch();
    }
    else
    {
        file_put_contents($createSqlFilePath, "INSERT INTO biz_channel (title) VALUES('dummy channel');\nSET @channelId = (SELECT MAX(id) FROM biz_channel);\n\n", FILE_APPEND);
        $channelIds[] = '@channelId';
    }
}

$articleInsertStatement = 'INSERT INTO biz_article (siteId, channelId, source, title, abstract, createdAt, publicationDate, workflowState, semanticData) VALUES';
$chapterInsertStatement = 'INSERT INTO biz_chapter (articleId, rank, title, text) VALUES';

$nbLoops = ($nbRecords > NB_RECORDS_PER_LOOP) ? ceil($nbRecords/NB_RECORDS_PER_LOOP) : 1;
$recordProcessed = $failed = 0;
for ($i=0; $i<$nbLoops; $i++)
{
    $query = 'SELECT * FROM documents ORDER BY IndexedDate ASC LIMIT '.$startAt.','.($nbRecords > NB_RECORDS_PER_LOOP ? NB_RECORDS_PER_LOOP : $nbRecords);
    if (TRACE)
    {
        trace('data query:'.$query);
    }

    $site = $channel = 0;
    foreach ($sourceDBH->query($query) as $row)
    {
        ++$recordProcessed;

        if (1 > count($siteIds))
        {
            ++$site;
            if ($site >= count($siteIds))
            {
                $site = 0;
            }
        }
        $siteId = $siteIds[$site];

        if (1 > count($channelIds))
        {
            $channel++;
            if ($channel >= count($channelIds))
            {
                $channel = 0;
            }
        }
        $channelId = $channelIds[$channel];

        try
        {
            $row['ObjectXml'] = iconv('ISO-8859-1', 'UTF-8', $row['ObjectXml']);

            $publish = explode('<PUBLISHDATE>', $row['ObjectXml']);
            $publish = explode('</PUBLISHDATE>', $publish[1]);
            $date = date('y-m-d H:i:s', strtotime($publish[0]));

            // Fill semantic object using the TME result xml
            if (!$row['TmeResult'])
            {
                ++$skipped;
                continue;
            }
            $row['TmeResult'] = iconv('ISO-8859-1', 'UTF-8', $row['TmeResult']);
            $semantic = new wcmSemanticData(wcmXML::processXSLT($row['TmeResult'], WCM_DIR . '/conf/backoffice/tme/methods.xsl'));

            $titleD = explode('<HEADLINE>', $row['ObjectXml']);
            $titleD = explode('</HEADLINE>', $titleD[1]);
            $title = $titleD[0];
            $summaryD = explode('<Summary>', $row['TmeResult']);
            $summaryD = explode('</Summary>', $summaryD[1]);
            $summary = $summaryD[0];

            $articleQueryValues = $articleInsertStatement . '(' . $siteId . ',' . $channelId . ",'" . $row['Id'] . "','" . addslashes(trim($title)) . "','" . addslashes(trim($summary)) . "','" . $date . "','" . $date . "','published', '" . addslashes(serialize($semantic)) . "');";

            if (false === $createSQL)
            {
                $destinationDBH->query($articleQueryValues);
                $articleId = $destinationDBH->lastInsertId();
            }
            else
            {
                file_put_contents($createSqlFilePath, $articleQueryValues."\n", FILE_APPEND);
                file_put_contents($createSqlFilePath, "SET @articleId = (SELECT MAX(id) FROM `biz_article`);\n", FILE_APPEND);
                $articleId = '@articleId';
            }

            $textD = explode('<BODY>', $row['ObjectXml']);
            $textD = explode('</BODY>', $textD[1]);
            $text = $textD[0];

            $chapterQueryValues = $chapterInsertStatement . '(' . $articleId . ", 1, '" . addslashes(trim($title)) . "', '" . addslashes(trim($text)) . "');";

            if (false === $createSQL)
            {
                $destinationDBH->query($chapterQueryValues);
            }
            else
            {
                file_put_contents($createSqlFilePath, $chapterQueryValues."\n", FILE_APPEND);
            }

            if (!($recordProcessed % 1000))
            {
                trace('rendu a: '.$recordProcessed);
                trace($recordProcessed.' records executed in: '.(microtime(true)-$startTime));
            }

            if ($stopAt && $recordProcessed >= $stopAt)
            {
                break 2;
            }
        }
        catch (exception $e)
        {
            ++$failed;
            if (TRACE)
            {
                trace('Error found: '.$e.' on id: '.$row['Id']);
            }
        }
    }
}

function trace($string)
{
    file_put_contents(TRACE_FILE, $string."\n", FILE_APPEND);
}

function writeFailed($id, $xml)
{
    file_put_contents(FAILED_DIR.$id.'.xml', $xml);
}

function writeMissingTME($string)
{
    file_put_contents('missingTME.log', $string."\n", FILE_APPEND);
}
