<?php

// ----------------------------------------------------------------------------
// Files to change
// ----------------------------------------------------------------------------

$files = array(
    '/wcm-www-backoffice/install/modrewrite/.htaccess' => '/wcm-www-backoffice/install/modrewrite/',
    '/wcm-www-backoffice/system/public/.htaccess'      => '/wcm-www-backoffice/system/public/',
    '/wcm-www-restws/public/.htaccess'                 => '/wcm-www-restws/public/',
    );

// ----------------------------------------------------------------------------
// Help
// ----------------------------------------------------------------------------

ob_start();

echo '
### Usage ###

$ php ' . $_SERVER['argv'][0] . ' /path/to/base

### About ###

For the WCM to work with Apache Mod Alias, you must add RewriteBase to
the .htaccess files. This script attempts to do it automatically. In the
above usage example, change \'/path/to/base\' accordingly.
';

echo "\n### Example Modifications ### \n\n";
foreach ($files as $file => $base)
{
    echo '* ' . $file . "\n";
    echo "> RewriteEngine on \n";
    echo '> RewriteBase /path/to/base' . $base . "\n\n";
}

$HELP = ob_get_contents();
ob_end_clean();

// ----------------------------------------------------------------------------
// Procedure
// ----------------------------------------------------------------------------

function go($rewrite_path)
{
    global $files;
    $pwd = dirname(__FILE__);
    foreach ($files as $file => $base)
    {
        // Check if we can find and write to the file
        $file = $pwd . '/..' . $file;
        if (!is_file($file) || !is_writable($file))
        {
            echo "\n";
            echo "ERROR: \n";
            echo "Can't find/write to file: \n";
            echo '> ' . $file . "\n";
            continue;
        }
        $file = realpath($file);

        // Load the contents of the file
        // Verify that that RewriteBase is not already set
        $placeholder = array();
        $contents = file($file);
        foreach ($contents as $key => $line)
        {
            if (stripos($line, 'RewriteEngine on') !== false)
            {
                $placeholder[$key] = $line;
            }
            if (stripos($line, 'RewriteBase') !== false)
            {
                echo "\n";
                echo "ERROR: \n";
                echo "RewriteBase already set for file: \n";
                echo '> ' . $file . "\n";
                echo '> ' . trim($line) . "\n";
                continue 2;
            }
        }

        // Check the integrity of the contents
        if (count($placeholder) > 1)
        {
            echo "\n";
            echo "ERROR: \n";
            echo "RewriteEngine declared more than once in file: \n";
            echo '> ' . $file . "\n";
            continue;
        }
        if (count($placeholder) < 1)
        {
            echo "\n";
            echo "ERROR: \n";
            echo "RewriteEngine not declared in file: \n";
            echo '> ' . $file . "\n";
            continue;
        }

        // Get the key
        $key = array_keys($placeholder);
        $key = array_shift($key);

        // First part
        $tmp = '';
        for ($i = 0; $i < $key + 1; ++$i)
        {
            $tmp .= $contents[$i];
        }

        // What we add
        $tmp .= "\t";
        $tmp .= 'RewriteBase /' . trim($rewrite_path, '/') . $base;
        $tmp .= "\n";

        // Second part
        for ($i = $key + 1; $i < count($contents); ++$i)
        {
            $tmp .= $contents[$i];
        }

        // Write to file
        file_put_contents($file, $tmp);

    }
}

if ($_SERVER['argc'] <= 1)
{
    die($HELP);
}

go($_SERVER['argv'][1]);

echo "\nDone! \n";

