<?php
/**
 * Class for Nice CLI 
 */
class wcmCli
{
    const COLOR_GREEN   = "\033[1;32m";
    const COLOR_RED     = "\033[1;31m";
    const COLOR_NORMAL  = "\033[0;39m";

    const POS_END       = "\033[60G";
    const POS_START     = "\033[0G";

    const OK            = "  OK  ";
    const FAILED        = "FAILED";

    const PROGRESS_WIDTH = 65;
    const SCREEN_WIDTH   = 80;

	public static $outputHtml = false;

	public static function setOutputHtml($bool)
	{
		self::$outputHtml = true;
	}

	public static function displayState($state)
    {
        $output  = self::POS_END . '[';
        $output .= ($state === true) ?  self::COLOR_GREEN . self::OK : self::COLOR_RED . self::FAILED;
        $output .= self::COLOR_NORMAL . ']' . PHP_EOL;
        return $output;
    }

    public static function displayProgress($pourcentage, $msg = null)
    {
        static $steps = array('|', '/', '-', '\\');
        static $step = 0;

		if(self::$outputHtml)
		{
			$html = "\t\t" . $msg . "\t" . $pourcentage . '%' . PHP_EOL;
			return $html;	
		}

		$output  = self::POS_START;
		$output .= '[' ;

        $output .= str_pad('', (int)($pourcentage * self::PROGRESS_WIDTH / 100), '=');
        $output .= str_pad('', self::PROGRESS_WIDTH - (int)($pourcentage * self::PROGRESS_WIDTH / 100), ' ');

        $output .= '] ';

        $step = ($step+1)%count($steps);
		$output .= $steps[$step] . ' ' . str_pad((int)$pourcentage, 3, ' ', STR_PAD_LEFT) . '%';
		$output .= $msg;

        return $output;
    }

    public static function clearLine()
	{
		if(!self::$outputHtml)
			return;

        return self::POS_START . str_pad('', self::SCREEN_WIDTH, ' ') . self::POS_START;
    }
}
