-- -----------------------------------------------------
-- Table `biz_article_versions`
-- -----------------------------------------------------
  CREATE TABLE `biz_article_versions`(
  `id` integer not null auto_increment,
  `objectId` integer,
  `objectContent` text,
  `createdAt` datetime,
  `createdBy` integer,
  `versionNumber` integer,
  `revisionNumber` integer,
  `comment` text default null,
  PRIMARY KEY (`id`),
  KEY `objectId` (`objectId`),
  KEY `versionNumber` (`versionNumber`))
  ENGINE=InnoDB
  DEFAULT CHARSET=utf8;

-- -----------------------------------------------------
-- Table `biz__relation`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz__relation` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `title` TINYTEXT NULL DEFAULT NULL ,
  `header` VARCHAR(128) NULL DEFAULT NULL ,
  `sourceClass` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `destinationClass` VARCHAR(150) NULL DEFAULT NULL ,
  `destinationId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `kind` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `rank` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `validityDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz__search`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz__search` (
  `classname` VARCHAR(255) NOT NULL ,
  `id` INT(10) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdat` DATETIME NULL ,
  `createdby` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `modifiedat` DATETIME NULL ,
  `modifiedby` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `workflowstate` VARCHAR(64) NULL DEFAULT NULL ,
  `fulltext` TEXT NULL DEFAULT NULL ,
  `fulltext_tokens` TEXT NULL DEFAULT NULL ,
  `mustgenerate` TINYINT(1) NULL DEFAULT '0' ,
  `siteid` SMALLINT(6) NULL DEFAULT '0' ,
  `channelid` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `publicationdate` DATE NULL DEFAULT NULL ,
  `title` TINYTEXT NULL DEFAULT NULL ,
  `author` VARCHAR(128) NULL DEFAULT NULL ,
  `title_sort` VARCHAR(255) NULL DEFAULT NULL ,
  `ratingcount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `ratingtotal` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `ratingvalue` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `hitcount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `simpleconcept` TEXT NULL DEFAULT NULL ,
  `complexconcept` TEXT NULL DEFAULT NULL ,
  `entity_on` TEXT NULL DEFAULT NULL ,
  `entity_pn` TEXT NULL DEFAULT NULL ,
  `entity_gl` TEXT NULL DEFAULT NULL ,
  `list_on` TEXT NULL DEFAULT NULL ,
  `list_pn` TEXT NULL DEFAULT NULL ,
  `list_gl` TEXT NULL DEFAULT NULL ,
  `category` TEXT NULL DEFAULT NULL ,
  `list_category` TEXT NULL DEFAULT NULL ,
  `concept` TEXT NULL DEFAULT NULL ,
  `list_concept` TEXT NULL DEFAULT NULL ,
  `tag` TEXT NULL DEFAULT NULL ,
  `list_tag` VARCHAR(255) NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `list_source` VARCHAR(255) NULL DEFAULT NULL ,
  `username` VARCHAR(255) NULL DEFAULT NULL ,
  `country` VARCHAR(128) NULL DEFAULT NULL ,
  `email` VARCHAR(128) NULL DEFAULT NULL ,
  `createdat_time` TIME NULL DEFAULT NULL ,
  PRIMARY KEY (`id`, `classname`, `modifiedat`) ,
  INDEX `mustgenerate` (`mustgenerate` ASC) ,
  INDEX `siteid` (`siteid` ASC) ,
  INDEX `channelid` (`channelid` ASC) ,
  INDEX `createdat` (`createdat` ASC) ,
  INDEX `modifiedat` (`modifiedat` ASC) ,
  INDEX `workflowstate` (`workflowstate` ASC) ,
  FULLTEXT INDEX `fulltext_tokens` (`fulltext_tokens` ASC) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_site`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_site` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '0' ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `language` VARCHAR(64) NULL DEFAULT NULL ,
  `code` VARCHAR(16) NOT NULL,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_site_createdBy` (`createdBy` ASC) ,
  INDEX `biz_site_modifiedBy` (`modifiedBy` ASC) ,
  UNIQUE INDEX `biz_site_code` (`code`),
  UNIQUE KEY `site_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_site_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_site_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_site_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
AUTO_INCREMENT = 5
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_publication`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_publication` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '0' ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_publication_createdBy` (`createdBy` ASC) ,
  INDEX `biz_publication_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_publication_siteId` (`siteId` ASC) ,
  UNIQUE KEY `publication_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_publication_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_publication_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_publication_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_publication_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_channel`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_channel` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `publicationId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `parentId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `keywords` VARCHAR(255) NULL DEFAULT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `templateId` VARCHAR(255) NULL DEFAULT NULL ,
  `rank` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `managementKind` VARCHAR(255) NULL DEFAULT NULL ,
  `request` TEXT NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_channel_createdBy` (`createdBy` ASC) ,
  INDEX `biz_channel_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_channel_worfkowState` (`workflowState` ASC) ,
  INDEX `biz_channel_publicationId` (`publicationId` ASC) ,
  INDEX `biz_channel_siteId` (`siteId` ASC) ,
  UNIQUE KEY `channel_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_channel_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_channel_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_channel_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_channel_publicationId`
    FOREIGN KEY (`publicationId` )
    REFERENCES `biz_publication` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_channel_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_issue`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_issue` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `publicationId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `issueNumber` TEXT NULL DEFAULT NULL ,
  `issueDate` DATETIME NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_issue_createdBy` (`createdBy` ASC) ,
  INDEX `biz_issue_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_issue_worfkowState` (`workflowState` ASC) ,
  INDEX `biz_issue_siteId` (`siteId` ASC) ,
  INDEX `biz_issue_publicationId` (`publicationId` ASC) ,
  UNIQUE KEY `issue_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_issue_publicationId`
    FOREIGN KEY (`publicationId` )
    REFERENCES `biz_publication` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_issue_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_issue_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_issue_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_issue_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_article`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_article` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `publicationId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `issueId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `pageNumber` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `ratingCount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `ratingTotal` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `ratingValue` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `hitCount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `title` TINYTEXT NOT NULL ,
  `suptitle` TINYTEXT NULL DEFAULT NULL ,
  `subtitle` TINYTEXT NULL DEFAULT NULL ,
  `author` VARCHAR(128) NULL DEFAULT NULL ,
  `abstract` TEXT NULL DEFAULT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `url` VARCHAR(255) NULL DEFAULT NULL ,
  `keywords` VARCHAR(255) NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `templateId` VARCHAR(255) NULL DEFAULT NULL ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `commentCount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `moderationKind` VARCHAR(64) NULL DEFAULT '' ,
  `credits` VARCHAR(255) NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`, `createdAt`, `modifiedAt`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `biz_article_createdBy` (`createdBy` ASC) ,
  INDEX `biz_article_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_article_worfkowState` (`workflowState` ASC) ,
  INDEX `biz_article_publicationId` (`publicationId` ASC) ,
  INDEX `biz_article_issueId` (`issueId` ASC) ,
  INDEX `biz_article_siteId` (`siteId` ASC) ,
  INDEX `biz_article_channelId` (`channelId` ASC) ,
  UNIQUE KEY `article_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_article_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_article_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_article_issueId`
    FOREIGN KEY (`issueId` )
    REFERENCES `biz_issue` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_article_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_article_publicationId`
    FOREIGN KEY (`publicationId` )
    REFERENCES `biz_publication` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_article_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_article_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_chapter`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_chapter` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `articleId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `rank` INT(10) UNSIGNED NULL DEFAULT '1' ,
  `title` TINYTEXT NULL DEFAULT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_chapter_articleId` (`articleId` ASC) ,
  CONSTRAINT `biz_chapter_articleId`
    FOREIGN KEY (`articleId` )
    REFERENCES `biz_article` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_collection`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_collection` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `templateId` VARCHAR(255) NULL DEFAULT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_collection_createdBy` (`createdBy` ASC) ,
  INDEX `biz_collection_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_collection_worfkowState` (`workflowState` ASC) ,
  INDEX `biz_collection_siteId` (`siteId` ASC) ,
  INDEX `biz_collection_channelId` (`channelId` ASC) ,
  UNIQUE KEY `collection_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_collection_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_collection_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_collection_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_collection_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_collection_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_contribution`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_contribution` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `webuserId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `nickname` VARCHAR(255) NULL DEFAULT NULL ,
  `email` VARCHAR(128) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `referentId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `referentClass` VARCHAR(64) NULL DEFAULT NULL ,
  `parentId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `parentId` (`parentId` ASC) ,
  INDEX `webuserId` (`webuserId` ASC) ,
  INDEX `nickname` (`nickname` ASC) ,
  INDEX `referentClass` (`referentClass` ASC) ,
  INDEX `referentId` (`referentId` ASC) ,
  INDEX `biz_contribution_createdBy` (`createdBy` ASC) ,
  INDEX `biz_contribution_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_contribution_siteId` (`siteId` ASC) ,
  INDEX `biz_contribution_channelId` (`channelId` ASC) ,
  UNIQUE KEY `contribution_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_contribution_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_contribution_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_contribution_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_contribution_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_contribution_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_forum`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_forum` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `title` TINYTEXT NOT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `kind` VARCHAR(64) NULL DEFAULT NULL ,
  `moderationKind` VARCHAR(64) NULL DEFAULT NULL ,
  `restrictedTopics` SMALLINT(6) UNSIGNED NULL DEFAULT '0' ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `aGenerer` (`mustGenerate` ASC) ,
  INDEX `statut` (`workflowState` ASC) ,
  INDEX `biz_forum_createdBy` (`createdBy` ASC) ,
  INDEX `biz_forum_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_forum_siteId` (`siteId` ASC) ,
  INDEX `biz_forum_channelId` (`channelId` ASC) ,
  UNIQUE KEY `forum_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_forum_channelId`
    FOREIGN KEY (`channelId`)
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_forum_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_forum_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_forum_siteId`
    FOREIGN KEY (`siteId`)
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_forum_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_item`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_item` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `type` TEXT NULL DEFAULT NULL ,
  `location` TEXT NULL DEFAULT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `isURL` TINYINT(1) UNSIGNED NULL DEFAULT '0' ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `access` TINYINT(1) UNSIGNED NOT NULL DEFAULT '1' ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `moderationKind` VARCHAR(64) NULL DEFAULT '' ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_item_createdBy` (`createdBy` ASC) ,
  INDEX `biz_item_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_item_worfkowState` (`workflowState` ASC) ,
  INDEX `biz_item_siteId` (`siteId` ASC) ,
  INDEX `biz_item_channelId` (`channelId` ASC) ,
  UNIQUE KEY `item_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_item_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_item_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_item_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_item_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_item_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_item_downloads`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_item_downloads` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `itemId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `webuserId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `downloadDate` DATETIME NOT NULL ,
  `ipAddress` VARCHAR(15) NOT NULL ,
  PRIMARY KEY (`id`),
  CONSTRAINT `biz_item_downloads_item`
    FOREIGN KEY (`itemId` )
    REFERENCES `##DB_PREFIX##_biz`.`biz_item` (`id`)
    ON DELETE SET NULL
    ON UPDATE CASCADE
  )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_newsitem`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_newsitem` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `releaseDateTime` DATETIME NULL DEFAULT NULL ,
  `keywords` VARCHAR(255) NULL DEFAULT NULL ,
  `priority` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `templateId` VARCHAR(255) NULL DEFAULT NULL ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `moderationKind` VARCHAR(64) NULL DEFAULT '' ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `releaseDateTime` (`releaseDateTime` ASC) ,
  INDEX `priority` (`priority` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_newsitem_createdBy` (`createdBy` ASC) ,
  INDEX `biz_newsitem_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_newsitem_siteId` (`siteId` ASC) ,
  INDEX `biz_newsitem_channelId` (`channelId` ASC) ,
  UNIQUE KEY `newsitem_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_newsitem_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsitem_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsitem_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsitem_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsitem_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_newsletter`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_newsletter` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `code` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `sender` VARCHAR(128) NULL DEFAULT NULL ,
  `from` VARCHAR(128) NULL DEFAULT NULL ,
  `replyTo` VARCHAR(128) NULL DEFAULT NULL ,
  `htmlTemplate` VARCHAR(255) NULL DEFAULT NULL ,
  `textTemplate` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `code` (`code` ASC) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_newsletter_createdBy` (`createdBy` ASC) ,
  INDEX `biz_newsletter_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_newsletter_siteId` (`siteId` ASC) ,
  UNIQUE KEY `newsletter_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_newsletter_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsletter_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsletter_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_newsletter_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `biz_photo`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_photo` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '1' ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `caption` TEXT NULL DEFAULT NULL ,
  `credits` VARCHAR(255) NULL DEFAULT NULL ,
  `keywords` VARCHAR(255) NULL DEFAULT NULL ,
  `height` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `width` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `original` VARCHAR(255) NULL DEFAULT NULL ,
  `kind` VARCHAR(64) NULL DEFAULT NULL ,
  `thumbWidth` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `thumbHeight` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `thumbnail` VARCHAR(255) NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `commentCount` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `moderationKind` VARCHAR(64) NULL DEFAULT '' ,
  `publicationId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `issueId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `pageNumber` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `ratios` TEXT NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_photo_createdBy` (`createdBy` ASC) ,
  INDEX `biz_photo_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_photo_siteId` (`siteId` ASC) ,
  INDEX `biz_photo_channelId` (`channelId` ASC) ,
  INDEX `biz_photo_publicationId` (`publicationId` ASC) ,
  INDEX `biz_photo_issueId` (`issueId` ASC) ,
  UNIQUE KEY `photo_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_photo_issueId`
    FOREIGN KEY (`issueId` )
    REFERENCES `biz_issue` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_photo_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_photo_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_photo_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_photo_publicationId`
    FOREIGN KEY (`publicationId` )
    REFERENCES `biz_publication` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `biz_photo_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_photo_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_poll`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_poll` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '0' ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `kind` VARCHAR(64) NULL DEFAULT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_poll_createdBy` (`createdBy` ASC) ,
  INDEX `biz_poll_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_poll_siteId` (`siteId` ASC) ,
  INDEX `biz_poll_channelId` (`channelId` ASC) ,
  UNIQUE KEY `poll_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_poll_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_poll_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_poll_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_poll_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_poll_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_poll_choice`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_poll_choice` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `pollId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `rank` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `voteCount` INT(10) UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `pollId` (`pollId` ASC) ,
  INDEX `rank` (`rank` ASC) ,
  CONSTRAINT `biz_poll_choice_pollId`
    FOREIGN KEY (`pollId` )
    REFERENCES `biz_poll` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `biz_slideshow`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_slideshow` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '0' ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `title` TINYTEXT NOT NULL ,
  `text` TEXT NULL DEFAULT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `channelId` INT(10) UNSIGNED NULL DEFAULT '0' ,
  `templateId` VARCHAR(255) NULL DEFAULT NULL ,
  `publicationDate` DATE NULL DEFAULT NULL ,
  `expirationDate` DATE NULL DEFAULT NULL ,
  `contributionState` VARCHAR(64) NULL DEFAULT '' ,
  `moderationKind` VARCHAR(64) NULL DEFAULT '' ,
  `keywords` VARCHAR(255) NULL DEFAULT NULL ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_slideshow_createdBy` (`createdBy` ASC) ,
  INDEX `biz_slideshow_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `biz_slideshow_siteId` (`siteId` ASC) ,
  INDEX `biz_slideshow_channelId` (`channelId` ASC) ,
  UNIQUE KEY `slideshow_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_slideshow_channelId`
    FOREIGN KEY (`channelId` )
    REFERENCES `biz_channel` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_slideshow_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_slideshow_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_slideshow_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_slideshow_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `biz_webuser`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_webuser` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `source` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceVersion` VARCHAR(255) NULL DEFAULT NULL ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `permalinks` TEXT NULL DEFAULT NULL ,
  `xmlTags` TEXT NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `semanticData` LONGTEXT NULL DEFAULT NULL ,
  `mustGenerate` TINYINT(1) NULL DEFAULT '0' ,
  `workflowState` VARCHAR(64) NULL DEFAULT NULL ,
  `email` VARCHAR(128) NULL DEFAULT NULL ,
  `username` VARCHAR(255) NULL DEFAULT NULL ,
  `password` VARCHAR(128) NULL DEFAULT NULL ,
  `firstname` VARCHAR(128) NULL DEFAULT NULL ,
  `lastname` VARCHAR(128) NULL DEFAULT NULL ,
  `address` TEXT NULL DEFAULT NULL ,
  `postalCode` VARCHAR(6) NULL DEFAULT NULL ,
  `city` VARCHAR(64) NULL DEFAULT NULL ,
  `country` VARCHAR(64) NULL DEFAULT NULL ,
  `state` VARCHAR(64) NULL DEFAULT NULL ,
  `phone` VARCHAR(16) NULL DEFAULT NULL ,
  `imagePath` VARCHAR(255) NULL DEFAULT NULL ,
  `lastLogin` DATETIME NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `email` (`email` ASC) ,
  INDEX `username` (`username` ASC) ,
  INDEX `createdAt` (`createdAt` ASC) ,
  INDEX `modifiedAt` (`modifiedAt` ASC) ,
  INDEX `source` (`source` ASC) ,
  INDEX `mustGenerate` (`mustGenerate` ASC) ,
  INDEX `workflowState` (`workflowState` ASC) ,
  INDEX `biz_webuser_createdBy` (`createdBy` ASC) ,
  INDEX `biz_webuser_modifiedBy` (`modifiedBy` ASC) ,
  UNIQUE KEY `webuser_source` (`source`, `sourceId`, `sourceVersion`) ,
  CONSTRAINT `biz_webuser_worfkowState`
    FOREIGN KEY (`workflowState` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_webuser_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE,
  CONSTRAINT `biz_webuser_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `##DB_PREFIX##_sys`.`wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;



-- -----------------------------------------------------
-- Table `biz_subscription`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `biz_subscription` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `webuserId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `subscriptionStart` DATETIME NULL DEFAULT NULL ,
  `subscriptionEnd` DATETIME NULL DEFAULT NULL ,
  `subscribedClass` VARCHAR(255) NULL DEFAULT NULL ,
  `subscribedId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `webuserId` (`webuserId` ASC) ,
  INDEX `subscribedId` (`subscribedId` ASC) ,
  INDEX `subscribedClass` (`subscribedClass` ASC),
  CONSTRAINT `biz_subscription_webuserId`
    FOREIGN KEY (`webuserId` )
    REFERENCES `biz_webuser` (`id` )
    ON DELETE SET NULL
    ON UPDATE CASCADE
  )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `biz_object_url_alias`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `biz_object_url_alias` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `siteId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `objectClass` VARCHAR(255) NULL DEFAULT NULL ,
  `objectId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `alias` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `biz_object_url_alias_objectClass` (`objectClass` ASC) ,
  INDEX `biz_object_url_alias_objectId` (`objectId` ASC) ,
  UNIQUE KEY `biz_object_url_alias_alias` (`siteId`,`alias`),
  CONSTRAINT `biz_object_url_alias_siteId`
    FOREIGN KEY (`siteId` )
    REFERENCES `biz_site` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE
)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


DELIMITER //
CREATE
TRIGGER `article_onDelete_trigger`
AFTER DELETE ON `biz_article`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='article' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='article' AND `destinationId`=OLD.id) OR (`sourceClass`='article' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='article' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='article' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='article' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('article', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `channel_onDelete_trigger`
AFTER DELETE ON `biz_channel`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='channel' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='channel' AND `destinationId`=OLD.id) OR (`sourceClass`='channel' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='channel' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='channel' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='channel' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('channel', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `collection_onDelete_trigger`
AFTER DELETE ON `biz_collection`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='collection' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='collection' AND `destinationId`=OLD.id) OR (`sourceClass`='collection' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='collection' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='collection' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='collection' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('collection', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `contribution_onDelete_trigger`
AFTER DELETE ON `biz_contribution`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='contribution' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='contribution' AND `destinationId`=OLD.id) OR (`sourceClass`='contribution' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='contribution' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='contribution' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='contribution' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('contribution', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `forum_onDelete_trigger`
AFTER DELETE ON `biz_forum`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='forum' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='forum' AND `destinationId`=OLD.id) OR (`sourceClass`='forum' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='forum' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='forum' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='forum' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('forum', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `issue_onDelete_trigger`
AFTER DELETE ON `biz_issue`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='issue' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='issue' AND `destinationId`=OLD.id) OR (`sourceClass`='issue' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='issue' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='issue' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='issue' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('issue', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `item_onDelete_trigger`
AFTER DELETE ON `biz_item`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='item' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='item' AND `destinationId`=OLD.id) OR (`sourceClass`='item' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='item' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='item' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='item' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('item', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `newsitem_onDelete_trigger`
AFTER DELETE ON `biz_newsitem`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='newsitem' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='newsitem' AND `destinationId`=OLD.id) OR (`sourceClass`='newsitem' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='newsitem' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='newsitem' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='newsitem' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('newsitem', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `newsletter_onDelete_trigger`
AFTER DELETE ON `biz_newsletter`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='newsletter' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='newsletter' AND `destinationId`=OLD.id) OR (`sourceClass`='newsletter' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='newsletter' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='newsletter' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='newsletter' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('newsletter', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `photo_onDelete_trigger`
AFTER DELETE ON `biz_photo`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='photo' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='photo' AND `destinationId`=OLD.id) OR (`sourceClass`='photo' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='photo' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='photo' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='photo' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('photo', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `poll_onDelete_trigger`
AFTER DELETE ON `biz_poll`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='poll' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='poll' AND `destinationId`=OLD.id) OR (`sourceClass`='poll' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='poll' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='poll' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='poll' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('poll', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `publication_onDelete_trigger`
AFTER DELETE ON `biz_publication`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='publication' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='publication' AND `destinationId`=OLD.id) OR (`sourceClass`='publication' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='publication' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='publication' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='publication' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('publication', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `site_onDelete_trigger`
AFTER DELETE ON `biz_site`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='site' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='site' AND `destinationId`=OLD.id) OR (`sourceClass`='site' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='site' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='site' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='site' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('site', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `slideshow_onDelete_trigger`
AFTER DELETE ON `biz_slideshow`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='slideshow' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='slideshow' AND `destinationId`=OLD.id) OR (`sourceClass`='slideshow' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='slideshow' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='slideshow' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='slideshow' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('slideshow', OLD.id);
END//


DELIMITER ;

DELIMITER //
CREATE
TRIGGER `webuser_onDelete_trigger`
AFTER DELETE ON `biz_webuser`
FOR EACH ROW
BEGIN
   DELETE FROM biz__search WHERE `className`='webuser' AND `id`=OLD.id;
   DELETE FROM biz__relation WHERE (`destinationClass`='webuser' AND `destinationId`=OLD.id) OR (`sourceClass`='webuser' AND `sourceId`=OLD.id);
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_statistics` WHERE `objectClass`='webuser' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_lock` WHERE `objectClass`='webuser' AND `objectId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_design_zone` WHERE `sourceClass`='webuser' AND `sourceId`=OLD.id;
   DELETE FROM `##DB_PREFIX##_sys`.`wcm_permission` WHERE `target`=CONCAT('webuser', OLD.id);
END//


DELIMITER ;


-- -----------------------------------------------------
-- Data for table `biz_site`
-- -----------------------------------------------------
INSERT INTO `biz_site` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `source`, `sourceId`, `sourceVersion`, `xmlTags`, `properties`, `semanticData`, `mustGenerate`, `workflowState`, `title`, `description`, `language`, `code`, `permalinks`) VALUES (3, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '', '', '', '', '', 1, null, 'WCM Sample site', '', '', 'wcmSampleSite', '');
