-- -----------------------------------------------------
-- Table `wcm_user`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_user` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `login` VARCHAR(64) NULL DEFAULT NULL ,
  `password` CHAR(32) NULL DEFAULT NULL ,
  `email` VARCHAR(255) NULL DEFAULT NULL ,
  `isAdministrator` TINYINT(1) UNSIGNED NOT NULL DEFAULT '0' ,
  `defaultLanguage` CHAR(2) NULL DEFAULT NULL ,
  `nip` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `optionalEmails` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `Ix_wcm_user_login` (`login` ASC) ,
  INDEX `user_createdBy` (`createdBy` ASC) ,
  INDEX `user_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `user_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `user_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `wcm_workflow_state`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_workflow_state` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `code` VARCHAR(64) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `code` (`code` ASC) ,
  INDEX `wstate_createdBy` (`createdBy` ASC) ,
  INDEX `wstate_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `wstate_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `wstate_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;



-- -----------------------------------------------------
-- Table `wcm_workflow`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_workflow` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `initialState` VARCHAR(64) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `workflow_createdBy` (`createdBy` ASC) ,
  INDEX `workflow_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `workflow_initialState` (`initialState` ASC) ,
  CONSTRAINT `workflow_initialState`
    FOREIGN KEY (`initialState` )
    REFERENCES `wcm_workflow_state` (`code` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `workflow_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `workflow_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_connector`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_connector` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `reference` VARCHAR(16) NULL DEFAULT NULL ,
  `connectionString` VARCHAR(255) NULL DEFAULT NULL ,
  `tablePrefix` VARCHAR(16) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `wcm_connector_reference` (`reference` ASC) ,
  INDEX `connector_createdBy` (`createdBy` ASC) ,
  INDEX `connector_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `connecter_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `connector_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_bizclass`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_bizclass` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `className` VARCHAR(255) NULL DEFAULT NULL ,
  `connectorId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `connectorTable` VARCHAR(255) NULL DEFAULT NULL ,
  `workflowId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `workflowScript` VARCHAR(255) NULL DEFAULT NULL ,
  `allowOptimisticLock` TINYINT(1) NOT NULL DEFAULT '0' ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `className` (`className` ASC) ,
  INDEX `bizclass_connectorId` (`connectorId` ASC) ,
  INDEX `bizclass_workflowId` (`workflowId` ASC) ,
  CONSTRAINT `bizclass_workflowId`
    FOREIGN KEY (`workflowId` )
    REFERENCES `wcm_workflow` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `bizclass_connectorId`
    FOREIGN KEY (`connectorId` )
    REFERENCES `wcm_connector` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_design_zone`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_design_zone` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `sourceClass` VARCHAR(255) NULL DEFAULT NULL ,
  `sourceId` INT(10) UNSIGNED NOT NULL ,
  `zoneName` VARCHAR(128) NULL DEFAULT NULL ,
  `zoneContent` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `Index_zoneName` (`zoneName` ASC) ,
  INDEX `Index_source` (`sourceClass` ASC, `sourceId` ASC) )
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_generation_set`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_generation_set` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `code` VARCHAR(64) NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `location` VARCHAR(255) NULL DEFAULT NULL ,
  `context` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `code` (`code` ASC) ,
  INDEX `genset_createdBy` (`createdBy` ASC) ,
  INDEX `genset_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `genset_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `genset_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_generation`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_generation` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `code` VARCHAR(64) NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `generationSetId` SMALLINT(5) UNSIGNED NOT NULL ,
  `location` VARCHAR(255) NULL DEFAULT NULL ,
  `context` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `code` (`code` ASC) ,
  INDEX `gen_createdBy` (`createdBy` ASC) ,
  INDEX `gen_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `gen_gensetid` (`generationSetId` ASC) ,
  CONSTRAINT `gen_gensetid`
    FOREIGN KEY (`generationSetId` )
    REFERENCES `wcm_generation_set` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `gen_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `gen_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_generation_content`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_generation_content` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `code` VARCHAR(64) NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `generationId` SMALLINT(5) UNSIGNED NOT NULL ,
  `templateId` VARCHAR(255) NOT NULL ,
  `loop` TEXT NULL DEFAULT NULL ,
  `context` VARCHAR(255) NULL DEFAULT NULL ,
  `namingRule` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `code` (`code` ASC) ,
  INDEX `Ix_wcm_content_generation` (`generationId` ASC) ,
  INDEX `Ix_wcm_content_template` (`templateId` ASC) ,
  INDEX `genc_createdBy` (`createdBy` ASC) ,
  INDEX `genc_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `genc_gensetid`
    FOREIGN KEY (`generationId` )
    REFERENCES `wcm_generation` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `genc_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `genc_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `wcm_generation_autogen`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `wcm_generation_autogen` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `generationContentId` SMALLINT(5) UNSIGNED NOT NULL ,
  `objectClass` VARCHAR(50) NOT NULL ,
  `priority` INT NOT NULL ,
  PRIMARY KEY ( `id`, `generationContentId` , `objectClass` , `priority` ) ,
  CONSTRAINT `autogen_gencid`
    FOREIGN KEY (`generationContentId` )
    REFERENCES `wcm_generation_content` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `wcm_group`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_group` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `group_createdBy` (`createdBy` ASC) ,
  INDEX `group_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `group_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `group_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL) 
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_session`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_session` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `userName` VARCHAR(255) NULL DEFAULT NULL ,
  `startDate` DATETIME NULL DEFAULT NULL ,
  `endDate` DATETIME NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `userId` (`userId` ASC) ,
  INDEX `startDate` (`startDate` ASC) ,
  CONSTRAINT `session_userId`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE) 
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_lock`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_lock` (
  `sessionId` INT(10) UNSIGNED NOT NULL ,
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `objectClass` VARCHAR(255) NOT NULL DEFAULT '' ,
  `objectId` INT(10) UNSIGNED NOT NULL ,
  `lockDate` DATETIME NULL DEFAULT NULL ,
  `expirationDate` DATETIME NULL DEFAULT NULL ,
  `title` VARCHAR(255) NULL DEFAULT NULL ,
  PRIMARY KEY (`objectClass`, `objectId`) ,
  INDEX `ix_wcm_lock_objectClass` (`objectClass` ASC) ,
  INDEX `ix_wcm_lock_objectId` (`objectId` ASC) ,
  INDEX `ix_wcm_lock_date` (`lockDate` ASC) ,
  INDEX `ix_wcm_lock_expiration` (`expirationDate` ASC) ,
  INDEX `lock_session` (`sessionId` ASC) ,
  INDEX `lock_user` (`userId` ASC) ,
  CONSTRAINT `lock_user`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `lock_session`
    FOREIGN KEY (`sessionId` )
    REFERENCES `wcm_session` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_member`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_member` (
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `groupId` SMALLINT(5) UNSIGNED NOT NULL ,
  PRIMARY KEY (`userId`, `groupId`) ,
  INDEX `member_group` (`groupId` ASC) ,
  CONSTRAINT `member_group`
    FOREIGN KEY (`groupId` )
    REFERENCES `wcm_group` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `member_user`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_menu`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_menu` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `parentId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `rank` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `url` VARCHAR(255) NULL DEFAULT NULL ,
  `action` VARCHAR(64) NULL DEFAULT NULL ,
  `isDynamic` TINYINT(1) NOT NULL DEFAULT '0' ,
  PRIMARY KEY (`id`) ,
  INDEX `Ix_wcm_menu_menu` (`parentId` ASC) ,
  INDEX `menu_createdBy` (`createdBy` ASC) ,
  INDEX `menu_modifiedBy` (`modifiedBy` ASC) ,
  CONSTRAINT `menu_parentId`
    FOREIGN KEY (`parentId` )
    REFERENCES `wcm_menu` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `menu_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `menu_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_permission`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_permission` (
  `groupId` SMALLINT(5) UNSIGNED NOT NULL ,
  `target` VARCHAR(64) NOT NULL ,
  `permissions` TINYINT(3) UNSIGNED NOT NULL ,
  PRIMARY KEY (`groupId`, `target`) ,
  INDEX `action` (`target` ASC) ,
  CONSTRAINT `perm_group`
    FOREIGN KEY (`groupId` )
    REFERENCES `wcm_group` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_statistics`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_statistics` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `sessionId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `userName` VARCHAR(255) NULL DEFAULT NULL ,
  `kind` INT(10) UNSIGNED NOT NULL ,
  `dateAndTime` DATETIME NOT NULL ,
  `objectClass` VARCHAR(255) NULL DEFAULT NULL ,
  `objectId` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `info` LONGTEXT NULL DEFAULT NULL ,
  `linkable` TINYINT(4) NULL DEFAULT '1' ,
  PRIMARY KEY (`id`) ,
  INDEX `objectId,objectClass` (`objectId` ASC, `objectClass` ASC) ,
  INDEX `userId` (`userId` ASC) ,
  INDEX `stat_session` (`sessionId` ASC) ,
  CONSTRAINT `stat_user`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE,
  CONSTRAINT `stat_session`
    FOREIGN KEY (`sessionId` )
    REFERENCES `wcm_session` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_sysclass`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_sysclass` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `className` VARCHAR(255) NULL DEFAULT NULL ,
  `connectorId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `connectorTable` VARCHAR(255) NULL DEFAULT NULL ,
  `allowOptimisticLock` TINYINT(1) NOT NULL DEFAULT '1' ,
  PRIMARY KEY (`id`) ,
  UNIQUE INDEX `className` (`className` ASC) ,
  INDEX `sysclass_connectorId` (`connectorId` ASC) ,
  CONSTRAINT `sysclass_connectorId`
    FOREIGN KEY (`connectorId` )
    REFERENCES `wcm_connector` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_user_bin`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_user_bin` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `name` VARCHAR(64) NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `content` TEXT NULL DEFAULT NULL ,
  `dashboard` TINYINT(1) NOT NULL DEFAULT '0' ,
  PRIMARY KEY (`id`) ,
  INDEX `userId` (`userId` ASC) ,
  CONSTRAINT `bin_user`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE 
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_user_savedsearch`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_user_savedsearch` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `userId` SMALLINT(5) UNSIGNED NOT NULL ,
  `name` VARCHAR(64) NOT NULL ,
  `description` TEXT NULL DEFAULT NULL ,
  `queryString` TEXT NULL DEFAULT NULL ,
  `url` TEXT NULL DEFAULT NULL ,
  `dashboard` TINYINT(1) NOT NULL DEFAULT '0' ,
  `shared` TINYINT(1) NOT NULL DEFAULT '0' ,
  `showui` TEXT NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `userId` (`userId` ASC) ,
  CONSTRAINT `savesearch_user`
    FOREIGN KEY (`userId` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `wcm_workflow_transition`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_workflow_transition` (
  `id` SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `revisionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '1' ,
  `versionNumber` SMALLINT(5) UNSIGNED NOT NULL DEFAULT '0' ,
  `createdAt` DATETIME NULL DEFAULT NULL ,
  `createdBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `modifiedAt` DATETIME NULL DEFAULT NULL ,
  `modifiedBy` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `properties` TEXT NULL DEFAULT NULL ,
  `name` VARCHAR(255) NULL DEFAULT NULL ,
  `code` VARCHAR(64) NULL DEFAULT NULL ,
  `workflowId` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `fromState` VARCHAR(64) NULL DEFAULT NULL ,
  `toState` VARCHAR(64) NULL DEFAULT NULL ,
  PRIMARY KEY (`id`) ,
  INDEX `Index_fromState` (`fromState` ASC) ,
  INDEX `Index_toState` (`toState` ASC) ,
  INDEX `wtrans_createdBy` (`createdBy` ASC) ,
  INDEX `wtrans_modifiedBy` (`modifiedBy` ASC) ,
  INDEX `wtrans_workflowId` (`workflowId` ASC) ,
  CONSTRAINT `wtrans_createdBy`
    FOREIGN KEY (`createdBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `wtrans_modifiedBy`
    FOREIGN KEY (`modifiedBy` )
    REFERENCES `wcm_user` (`id` )
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `wtrans_workflowId`
    FOREIGN KEY (`workflowId` )
    REFERENCES `wcm_workflow` (`id` )
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Data for table `wcm_openid`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `wcm_openid` (
    `id` int(11) NOT NULL auto_increment,
    `user_id` int(11) NOT NULL,
    `openid` varchar(255) NOT NULL,
    PRIMARY KEY (`id`)
);

-- -----------------------------------------------------
-- Data for table `wcm_user`
-- -----------------------------------------------------
INSERT INTO `wcm_user` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `properties`, `name`, `login`, `password`, `email`, `isAdministrator`, `defaultLanguage`, `nip`, `optionalEmails`) VALUES
(1, 1, 0, '2008-01-01 12:00:00', 1, '2008-12-04 17:21:46', 1, 'a:0:{}', '_ADMINISTRATOR', 'admin', '21232f297a57a5a743894a0e4a801fc3', 'support@nstein.com', 1, 'en', 1234, ''),
(2, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Eric W.', 'eric.w', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'en', 1234, ''),
(3, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Alex D.', 'alex.d', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'en', 1234, ''),
(4, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'David G.', 'david.g', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'fr', 1234, ''),
(5, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Thomas N.', 'thomas.n', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'fr', 1234, ''),
(6, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Agostino D.', 'agostino.d', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'fr', 1234, ''),
(7, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Jean-Francois G.', 'jf.g', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'en', 1234, ''),
(8, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Pierrick C.', 'pierrick.c', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'fr', 1234, ''),
(9, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', 'Bashar A.', 'bashar.a', 'fe01ce2a7fbac8fafaed7c982a04e229', 'void@nowhere.com', 0, 'fr', 1234, '');


-- -----------------------------------------------------
-- Data for table `wcm_connector`
-- -----------------------------------------------------
INSERT INTO `wcm_connector` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `reference`, `connectionString`, `tablePrefix`) VALUES (1, 1, 0, NULL, NULL, '2008-01-01 12:00:00', 1, 'Business Connector', NULL, 'biz', 'mysql://root:@localhost:3306/##DB_PREFIX##_biz', 'biz_');

-- -----------------------------------------------------
-- Data for table `wcm_workflow_state`
-- -----------------------------------------------------
INSERT INTO `wcm_workflow_state` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `properties`, `name`, `code`) VALUES
(1, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_DRAFT', 'draft'),
(2, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_APPROVED', 'approved'),
(3, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_PUBLISHED', 'published'),
(4, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_ARCHIVED', 'archived'),
(5, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_REJECTED', 'rejected'),
(6, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_NEW', 'new'),
(7, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_SUSPICIOUS', 'suspicious'),
(8, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_PUBLISHEDMODIFIED', 'publishedModified');

-- -----------------------------------------------------
-- Data for table `wcm_workflow`
-- -----------------------------------------------------
INSERT INTO `wcm_workflow` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `properties`, `name`, `initialState`) VALUES
(1, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_PUBLICATION_WORKFLOW', 'draft'),
(2, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_MODERATION_WORKFLOW', 'new');


-- -----------------------------------------------------
-- Data for table `wcm_bizclass`
-- -----------------------------------------------------
INSERT INTO `wcm_bizclass` (`id`, `name`, `className`, `connectorId`, `connectorTable`, `workflowId`, `workflowScript`, `allowOptimisticLock`) VALUES
(1, '_BIZ_ARTICLE', 'article', 1, 'biz_article', 1, 'articleWorkflow.php', 1),
(2, '_BIZ_PHOTO', 'photo', 1, 'biz_photo', 1, 'photoWorkflow.php', 1),
(3, '_BIZ_CHANNEL', 'channel', 1, 'biz_channel', 1, 'publicationWorkflow.php', 1),
(4, '_BIZ_SITE', 'site', 1, 'biz_site', null, null, 1),
(5, '_BIZ_POLL', 'poll', 1, 'biz_poll', 1, 'publicationWorkflow.php', 1),
(6, '_BIZ_NEWSITEM', 'newsitem', 1, 'biz_newsitem', 1, 'publicationWorkflow.php', 1),
(7, '_BIZ_SLIDESHOW', 'slideshow', 1, 'biz_slideshow', 1, 'publicationWorkflow.php', 1),
(8, '_BIZ_ITEM', 'item', 1, 'biz_item', 1, 'publicationWorkflow.php', 1),
(9, '_BIZ_CONTRIBUTION', 'contribution', 1, 'biz_contribution', 2, 'moderationWorkflow.php', 1),
(10, '_BIZ_WEBUSER', 'webuser', 1, 'biz_webuser', 1, 'publicationWorkflow.php', 1),
(11, '_BIZ_FORUM', 'forum', 1, 'biz_forum', 1, 'publicationWorkflow.php', 1),
(12, '_BIZ_NEWSLETTER', 'newsletter', 1, 'biz_newsletter', 1, 'publicationWorkflow.php', 1),
(13, '_BIZ_COLLECTION', 'collection', 1, 'biz_collection', 1, 'publicationWorkflow.php', 1),
(14, '_BIZ_PUBLICATION', 'publication', 1, 'biz_publication', 1, 'publicationWorkflow.php', 1),
(15, '_BIZ_ISSUE', 'issue', 1, 'biz_issue', 1, 'publicationWorkflow.php', 1);

-- -----------------------------------------------------
-- Data for table `wcm_group`
-- -----------------------------------------------------
INSERT INTO `wcm_group` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `modifiedAt`, `createdBy`, `modifiedBy`, `name`, `properties`) VALUES
(1, 1, 0, '2006-03-13 11:50:54', '2008-01-01 12:00:00', 1, 1, '_EVERYONE', ''),
(2, 1, 0, '2006-03-13 11:50:54', '2008-01-01 12:00:00', 1, 1, '_JOURNALISTS', ''),
(3, 1, 0, '2006-03-13 11:50:54', '2008-01-01 12:00:00', 1, 1, '_ADMINISTRATORS', ''),
(4, 1, 0, '2006-03-13 11:50:54', '2008-01-01 12:00:00', 1, 1, '_PHOTOGRAPHERS', ''),
(5, 1, 0, '2006-03-13 11:51:05', '2008-01-01 12:00:00', 1, 1, '_WEBMASTERS', ''),
(6, 1, 0, '2006-03-13 11:51:05', '2008-01-01 12:00:00', 1, 1, '_MOJO', '');

-- -----------------------------------------------------
-- Data for table `wcm_member`
-- -----------------------------------------------------
INSERT INTO `wcm_member` (`userId`, `groupId`) VALUES
(1, 1),
(2, 1),
(3, 1),
(4, 1),
(5, 1),
(6, 1),
(7, 1),
(8, 1),
(9, 1),
(2, 2),
(8, 2),
(1, 3),
(5, 3),
(3, 4),
(6, 4),
(2, 5),
(4, 5),
(7, 5),
(9, 5);

-- -----------------------------------------------------
-- Data for table `wcm_menu`
-- -----------------------------------------------------
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (149, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, 'business', '', NULL, 0, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (150, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, 'system', '', NULL, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (151, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, 'user', '', NULL, 20, '', '', 0);

-- Level 2

INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (1, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_DASHBOARDS', 'a:0:{}', 149, 10, 'javascript:void(0)', 'home', 1);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (13, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_CREATE', 'a:0:{}', 149, 20, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (155, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-07 14:59:39', 1, '_MENU_IMPORT', 'a:0:{}', 149, 60, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (156, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-07 14:57:59', 1, '_MENU_BROWSE', 'a:0:{}', 149, 30, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (157, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-07 14:59:25', 1, '_MENU_MODERATE', 'a:0:{}', 149, 40, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (158, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-07 14:59:46', 1, '_MENU_PUBLISH', 'a:0:{}', 149, 70, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (361, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE', 'a:0:{}', 149, 50, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (520, 1, 0, '2008-12-05 09:17:47', 1, '2008-12-05 09:19:54', 1, '_MENU_HOME', 'a:0:{}', 149, 0, 'index.php', 'home', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (61, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM', 'a:0:{}', 150, 10, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (136, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_HELP', 'a:0:{}', 150, 70, 'javascript:void(0)', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (187, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:31:59', 1, '_MENU_USER_ADVANCED_SEARCH', 'a:0:{}', 151, NULL, 'javascript:void(0)', '', 1);

-- Level 3

INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (111, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:46:20', 1, '_MENU_CREATE_TEXTUAL', 'a:0:{}', 13, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (128, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:47:34', 1, '_MENU_CREATE_PARTICIPATIVE_CONTENT', 'a:0:{}', 13, 40, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (153, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:47:19', 1, '_MENU_CREATE_BUNDLE', 'a:0:{}', 13, 30, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (168, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_CREATE_MEDIA', 'a:0:{}', 13, 20, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (510, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_CREATE_OTHER', 'a:0:{}', 13, 50, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (144, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_IMPORT_FROM_FILES', 'a:0:{}', 155, 20, 'index.php', 'import', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (161, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:02:09', 1, '_MENU_BROWSE_TEXTUAL', 'a:0:{}', 156, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (164, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:02:15', 1, '_MENU_BROWSE_MEDIA', 'a:0:{}', 156, 20, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (165, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:02:22', 1, '_MENU_BROWSE_PARTICIPATIVE_CONTENT', 'a:0:{}', 156, 40, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (166, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:27:11', 1, '_MENU_BROWSE_BUNDLES', 'a:0:{}', 156, 30, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (512, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_BROWSE_OTHER', 'a:0:{}', 156, 50, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (183, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_MODERATE_USER_COMMENTS', 'a:0:{}', 157, 10, 'browse/contribution?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (184, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_MODERATE_FORUM_THREADS', 'a:0:{}', 157, 20, 'browse/forum?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (7, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_PUBLISH_MANAGE_TEMPLATES', 'a:0:{}', 158, 30, 'index.php', 'template', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (8, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_PUBLISH_MANAGE_GENERATION_RULES', 'a:0:{}', 158, 20, 'index.php', 'generationSet', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (95, 1, 0, '2006-11-28 12:41:09', 1, '2008-06-18 11:23:07', 1, '_MENU_PUBLISH_LAUNCH_GENERATION', 'a:0:{}', 158, 10, 'javascript:openDialog(\'ajax/controller.php\',\'view=dialogs/generate\',\'600\',\'400\',null,null,\'wcmGeneration\');', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (394, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_WEB', 'a:0:{}', 361, 20, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (395, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_PRINT', 'a:0:{}', 361, 30, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (516, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_COMMUNITY', 'a:0:{}', 361, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (517, 5, 0, '2008-10-29 16:56:04', 1, '2008-10-29 17:08:31', 1, '_MENU_MANAGE_PREFERENCES', 'a:0:{}', 361, 40, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (9, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM_ADMINISTRATION', 'a:0:{}', 61, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (185, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:17:47', 1, '_MENU_SYSTEM_MAINTENANCE', 'a:0:{}', 61, 30, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (193, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:15:21', 1, '_MENU_SYSTEM_CONFIGURATION', 'a:0:{}', 61, 20, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (137, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:21:09', 1, '_MENU_HELP_ABOUT', 'a:0:{}', 136, 10, '', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (191, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:21:41', 1, '_MENU_HELP_RESOURCES', 'a:0:{}', 136, 20, '', '', 0);

-- Level 4

INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (15, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:16:24', 1, '_MENU_SYSTEM_CONFIGURATION_DATA_SOURCES', 'a:0:{}', 193, 20, 'index.php', 'connector', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (24, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM_ADMINISTRATION_USERS', 'a:0:{}', 9, 20, 'index.php', 'group', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (35, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:15:44', 1, '_MENU_SYSTEM_CONFIGURATION_MENUS', 'a:0:{}', 193, 10, 'index.php', 'menu', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (36, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:46:26', 1, '_MENU_CREATE_ARTICLE', 'a:0:{}', 111, 10, 'index.php', 'business/article', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (39, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:46:45', 1, '_MENU_CREATE_PHOTO', 'a:0:{}', 168, 30, 'index.php', 'business/photo', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (62, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:18:06', 1, '_MENU_SYSTEM_MAINTENANCE_REINDEX_CONTENT', 'a:0:{}', 185, 40, 'index.php', 'business/indexation', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (63, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:18:16', 1, '_MENU_SYSTEM_MAINTENANCE_PURGE_CONTENT', 'a:0:{}', 185, 50, 'index.php', 'business/maintenance', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (75, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 09:57:00', 1, '_MENU_CREATE_SLIDESHOW', 'a:0:{}', 153, 40, 'index.php', 'business/slideshow', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (76, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_CREATE_POLL', 'a:0:{}', 128, 10, 'index.php', 'business/poll', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (113, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:10:57', 1, '_MENU_CREATE_ITEM', 'a:0:{}', 510, 20, 'index.php', 'business/item', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (122, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:07:42', 1, '_MENU_CREATE_COLLECTION', 'a:0:{}', 153, 10, 'index.php', 'business/collection', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (124, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:07:30', 1, '_MENU_CREATE_NEWSITEM', 'a:0:{}', 111, 20, 'index.php', 'business/newsitem', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (125, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:23:50', 1, '_MENU_CREATE_FORUM_THREAD', 'a:0:{}', 128, 20, 'index.php', 'business/forum', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (135, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM_ADMINISTRATION_BIZCLASS', 'a:0:{}', 9, 30, 'index.php', 'bizclass', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (145, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:17:56', 1, '_MENU_SYSTEM_MAINTENANCE_UNLOCK_CONTENT', 'a:0:{}', 185, 20, 'index.php', 'lock', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (148, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM_ADMINISTRATION_SYSCLASS', 'a:0:{}', 9, 40, 'index.php', 'sysclass', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (152, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:16:34', 1, '_MENU_SYSTEM_CONFIGURATION_WORKFLOWS', 'a:0:{}', 193, 30, 'index.php', 'workflow', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (162, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:25:00', 1, '_MENU_BROWSE_ARTICLES', 'a:0:{}', 161, 10, 'browse/article', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (163, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:25:11', 1, '_MENU_BROWSE_NEWS_ITEMS', 'a:0:{}', 161, 20, 'browse/newsitem', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (171, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:25:19', 1, '_MENU_BROWSE_PHOTOS', 'a:0:{}', 164, 10, 'browse/photo?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (172, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:26:20', 1, '_MENU_BROWSE_POLLS', 'a:0:{}', 165, 10, 'browse/poll?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (173, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:26:25', 1, '_MENU_BROWSE_FORUM_THREADS', 'a:0:{}', 165, 20, 'browse/forum?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (174, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:26:14', 1, '_MENU_BROWSE_SLIDESHOWS', 'a:0:{}', 166, 30, 'browse/slideshow?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (175, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:24:47', 1, '_MENU_BROWSE_COLLECTIONS', 'a:0:{}', 166, 10, 'browse/collection?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (176, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 10:26:05', 1, '_MENU_BROWSE_NEWSLETTERS', 'a:0:{}', 166, 20, 'browse/newsletter?view=grid', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (186, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '_MENU_SYSTEM_ADMINISTRATION_MESSAGE_LOG', 'a:0:{}', 9, 10, 'index.php', 'log', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (188, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:21:34', 1, '_MENU_HELP_ABOUT_COPYRIGHT_NOTICE', 'a:0:{}', 137, 20, 'javascript:openDialog(\'ajax/controller.php\',\'view=dialogs/license\',800,550);', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (190, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:21:23', 1, '_MENU_HELP_ABOUT_WCM4', 'a:0:{}', 137, NULL, 'javascript:openDialog(\'ajax/controller.php\',\'view=dialogs/about\',800,550);', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (192, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:21:58', 1, '_MENU_HELP_RESOURCES_DOC_AND_SUPPORT', 'a:0:{}', 191, NULL, 'javascript:openDialog(\'ajax/controller.php\',\'view=dialogs/support\',800,550);', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (194, 1, 0, '2008-01-01 12:00:00', 1, '2008-08-08 17:16:42', 1, '_MENU_SYSTEM_CONFIGURATION_TME', 'a:0:{}', 193, 40, 'index.php', 'tme', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (396, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_WEB_SITES', 'a:0:{}', 394, 10, 'index.php', 'business/site', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (398, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_SECTIONS', 'a:0:{}', 394, 20, 'index.php', 'business/channel', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (409, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_PRINT_PUBLICATIONS', 'a:0:{}', 395, 10, 'index.php', 'business/publication', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (410, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_PRINT_ISSUES', 'a:0:{}', 395, 20, 'index.php', 'business/issue', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (513, 1, 0, '0000-00-00 00:00:00', 1, '2008-08-08 10:31:00', 1, '_MENU_CREATE_NEWSLETTER', 'a:0:{}', 153, 20, 'index.php', 'business/newsletter', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (514, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_BROWSE_ITEMS', 'a:0:{}', 512, 10, 'browse/item', '', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (518, 3, 0, '2008-10-29 16:59:09', 1, '2008-10-29 17:06:58', 1, '_MENU_SAVED_SEARCHES', 'a:0:{}', 517, 10, 'index.php', 'savedsearches', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (519, 3, 0, '2008-12-05 09:17:47', 1, '2008-12-05 09:19:54', 1, '_MY_PREFERENCES', 'a:0:{}', 517, 0, 'index.php', 'preferences', 0);
INSERT INTO `wcm_menu` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `name`, `properties`, `parentId`, `rank`, `url`, `action`, `isDynamic`) VALUES (397, 1, 0, '0000-00-00 00:00:00', 1, '0000-00-00 00:00:00', 1, '_MENU_MANAGE_WEB_USERS', 'a:0:{}', 516, 30, 'index.php', 'business/webuser', 0);

-- -----------------------------------------------------
-- Data for table `wcm_permission`
-- -----------------------------------------------------
INSERT INTO `wcm_permission` (`groupId`, `target`, `permissions`) VALUES
(1, 'wcmBizclass_1', 1),
(1, 'wcmBizclass_10', 1),
(1, 'wcmBizclass_11', 1),
(1, 'wcmBizclass_12', 1),
(1, 'wcmBizclass_13', 1),
(1, 'wcmBizclass_14', 1),
(1, 'wcmBizclass_15', 1),
(1, 'wcmBizclass_2', 1),
(1, 'wcmBizclass_3', 1),
(1, 'wcmBizclass_4', 1),
(1, 'wcmBizclass_5', 1),
(1, 'wcmBizclass_6', 1),
(1, 'wcmBizclass_7', 1),
(1, 'wcmBizclass_8', 1),
(1, 'wcmBizclass_9', 1),
(1, 'wcmMenu_1', 1),
(1, 'wcmMenu_136', 1),
(1, 'wcmMenu_137', 1),
(1, 'wcmMenu_149', 1),
(1, 'wcmMenu_151', 1),
(1, 'wcmMenu_188', 1),
(1, 'wcmMenu_190', 1),
(1, 'wcmMenu_191', 1),
(1, 'wcmMenu_192', 1),
(1, 'wcmSysclass_1', 1),
(1, 'wcmSysclass_10', 1),
(1, 'wcmSysclass_11', 1),
(1, 'wcmSysclass_12', 1),
(1, 'wcmSysclass_13', 1),
(1, 'wcmSysclass_14', 1),
(1, 'wcmSysclass_2', 1),
(1, 'wcmSysclass_3', 1),
(1, 'wcmSysclass_4', 1),
(1, 'wcmSysclass_5', 1),
(1, 'wcmSysclass_6', 1),
(1, 'wcmSysclass_7', 1),
(1, 'wcmSysclass_8', 1),
(1, 'wcmSysclass_9', 1),
(2, 'wcmMenu_111', 1),
(2, 'wcmMenu_113', 1),
(2, 'wcmMenu_122', 1),
(2, 'wcmMenu_124', 1),
(2, 'wcmMenu_125', 1),
(2, 'wcmMenu_13', 1),
(2, 'wcmMenu_153', 1),
(2, 'wcmMenu_36', 1),
(2, 'wcmMenu_76', 1),
(2, 'wcmMenu_77', 1),
(3, 'wcmBizclass_1', 15),
(3, 'wcmBizclass_10', 15),
(3, 'wcmBizclass_11', 15),
(3, 'wcmBizclass_12', 15),
(3, 'wcmBizclass_13', 15),
(3, 'wcmBizclass_14', 15),
(3, 'wcmBizclass_15', 15),
(3, 'wcmBizclass_2', 15),
(3, 'wcmBizclass_3', 15),
(3, 'wcmBizclass_4', 15),
(3, 'wcmBizclass_5', 15),
(3, 'wcmBizclass_6', 15),
(3, 'wcmBizclass_7', 15),
(3, 'wcmBizclass_8', 15),
(3, 'wcmBizclass_9', 15),
(3, 'wcmGenerationSet_1', 20),
(3, 'wcmGenerationSet_2', 20),
(3, 'wcmMenu_135', 1),
(3, 'wcmMenu_145', 1),
(3, 'wcmMenu_148', 1),
(3, 'wcmMenu_15', 1),
(3, 'wcmMenu_150', 1),
(3, 'wcmMenu_152', 1),
(3, 'wcmMenu_185', 1),
(3, 'wcmMenu_186', 1),
(3, 'wcmMenu_193', 1),
(3, 'wcmMenu_194', 1),
(3, 'wcmMenu_24', 1),
(3, 'wcmMenu_35', 1),
(3, 'wcmMenu_61', 1),
(3, 'wcmMenu_62', 1),
(3, 'wcmMenu_63', 1),
(3, 'wcmMenu_9', 1),
(3, 'wcmSysclass_1', 15),
(3, 'wcmSysclass_10', 15),
(3, 'wcmSysclass_11', 15),
(3, 'wcmSysclass_12', 15),
(3, 'wcmSysclass_13', 15),
(3, 'wcmSysclass_14', 15),
(3, 'wcmSysclass_2', 15),
(3, 'wcmSysclass_3', 15),
(3, 'wcmSysclass_4', 15),
(3, 'wcmSysclass_5', 15),
(3, 'wcmSysclass_6', 15),
(3, 'wcmSysclass_7', 15),
(3, 'wcmSysclass_8', 15),
(3, 'wcmSysclass_9', 15),
(4, 'wcmGenerationSet_1', 4),
(4, 'wcmMenu_111', 1),
(4, 'wcmMenu_113', 1),
(4, 'wcmMenu_122', 1),
(4, 'wcmMenu_13', 1),
(4, 'wcmMenu_153', 1),
(4, 'wcmMenu_39', 1),
(4, 'wcmMenu_75', 1),
(5, 'wcmGenerationSet_1', 4),
(5, 'wcmMenu_100', 1),
(5, 'wcmMenu_111', 1),
(5, 'wcmMenu_112', 1),
(5, 'wcmMenu_113', 1),
(5, 'wcmMenu_122', 1),
(5, 'wcmMenu_125', 1),
(5, 'wcmMenu_128', 1),
(5, 'wcmMenu_13', 1),
(5, 'wcmMenu_153', 1),
(5, 'wcmMenu_38', 1),
(5, 'wcmMenu_51', 1),
(5, 'wcmMenu_53', 1),
(5, 'wcmMenu_75', 1),
(5, 'wcmMenu_76', 1),
(5, 'wcmMenu_77', 1);

-- -----------------------------------------------------
-- Data for table `wcm_sysclass`
-- -----------------------------------------------------
INSERT INTO `wcm_sysclass` (`id`, `name`, `className`, `connectorId`, `connectorTable`, `allowOptimisticLock`) VALUES
(1, '_MENU', 'wcmMenu', 1, 'wcm_menu', 1),
(2, '_CONNECTOR', 'wcmConnector', 1, 'wcm_connector', 1),
(3, '_WORKFLOW', 'wcmWorkflow', 1, 'wcm_workflow', 1),
(4, '_WORKFLOW_STATE', 'wcmWorkflowState', 1, 'wcm_workflow_state', 1),
(5, '_WORKFLOW_TRANSITION', 'wcmWorkflowTransition', 1, 'wcm_workflow_transition', 1),
(6, '_GENERATION_SET', 'wcmGenerationSet', 1, 'wcm_generation_set', 1),
(7, '_GENERATION', 'wcmGeneration', 1, 'wcm_generation', 1),
(8, '_GENERATION_CONTENT', 'wcmGenerationContent', 1, 'wcm_generation_content', 1),
(9, '_TEMPLATE', 'wcmTemplate', 1, 'wcm_template', 1),
(10, '_TEMPLATE_CATEGORY', 'wcmTemplateCategory', 1, 'wcm_template_category', 1),
(11, '_USER', 'wcmUser', 1, 'wcm_user', 1),
(12, '_GROUP', 'wcmGroup', 1, 'wcm_group', 1),
(13, '_GENERATION_AUTOGEN', 'wcmGenerationAutogen', 1, 'wcm_generation_autogen', 1);

-- -----------------------------------------------------
-- Data for table `wcm_workflow_transition`
-- -----------------------------------------------------
INSERT INTO `wcm_workflow_transition` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `properties`, `name`, `code`, `workflowId`, `fromState`, `toState`) VALUES
(1, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_PUBLISH', 'publish', 1, 'draft', 'published'),
(2, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_UNPUBLISH', 'unpublish', 1, 'published', 'draft'),
(3, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_ARCHIVE', 'archive', 1, 'published', 'archived'),
(4, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_DEARCHIVE', 'dearchive', 1, 'archived', 'published'),
(5, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_REPUBLISH', 'republish', 1, 'publishedModified', 'published'),
(6, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_NOTIFY', 'notify', 2, 'new', 'suspicious'),
(7, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_APPROVE', 'approve', 2, 'suspicious', 'approved'),
(8, 1, 0, '2008-01-01 12:00:00', 1, '2008-01-01 12:00:00', 1, '', '_WT_REJECT', 'reject', 2, '_ANY_STATE', 'rejected');

-- -----------------------------------------------------
-- Data for table `wcm_generation_set`
-- -----------------------------------------------------

INSERT INTO `wcm_generation_set` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `code`, `name`, `properties`, `location`, `context`) VALUES
(1, 1, 0, '2010-02-02 15:16:31', 1, '2010-02-02 15:16:31', 1, 'wcmSampleSite', 'WCM Sample Site', 'a:0:{}', '{''WCM_DIR''|constant}/cmf-www-sampleapp/private/views/blocks', NULL);
-- -----------------------------------------------------
-- Data for table `wcm_generation`
-- -----------------------------------------------------
INSERT INTO `wcm_generation` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `code`, `name`, `properties`, `generationSetId`, `location`, `context`) VALUES
(1, 3, 0, '2010-02-02 15:17:56', 1, '2010-02-02 15:41:09', 1, 'wcmSampleSiteArticle', 'Article', 'a:0:{}', 1, NULL, NULL);

-- -----------------------------------------------------
-- Data for table `wcm_generation_content`
-- -----------------------------------------------------

INSERT INTO `wcm_generation_content` (`id`, `revisionNumber`, `versionNumber`, `createdAt`, `createdBy`, `modifiedAt`, `modifiedBy`, `code`, `name`, `properties`, `generationId`, `templateId`, `loop`, `context`, `namingRule`) VALUES
(1, 1, 0, '2010-02-02 15:18:55', 1, '2010-02-02 15:59:34', 1, 'wcmSampleSiteArticleDetail', 'Detail', 'a:0:{}', 1, 'sampleapp/pages/article.tpl', 'class="article" of="id" where="(workflowState=\'published\' OR {$this->mode} = 1)"', '', 'article/article_{$article.id}.php'),
(2, 1, 0, '2010-02-02 16:34:15', 1, '2010-02-02 16:40:57', 1, 'wcmSampleSiteArticleCommentForm', 'Comment Form', 'a:0:{}', 1, 'sampleapp/pages/commentForm.tpl', NULL, NULL, 'article/commentForm.php'),
(3, 1, 0, '2010-02-03 11:18:28', 1, '2010-02-03 11:18:28', 1, 'wcmSampleSiteLast5Articles', 'Last 5 articles', 'a:0:{}', 1, 'sampleapp/block/last5articles.tpl', NULL, NULL, 'last5articles.php'),
(4, 1, 0, '2010-02-02 15:18:55', 1, '2010-02-02 15:59:34', 1, 'wcmSampleSiteArticleComments', 'Comments', 'a:0:{}', 1, 'sampleapp/pages/articleComments.tpl', 'class="article" of="id" where="(workflowState=\'published\' OR {$this->mode} = 1)"', '', 'article/article_comments_{$article.id}.php'),
(5, 1, 0, '2010-02-03 11:18:28', 1, '2010-02-03 11:18:28', 1, 'wcmSampleSiteLast5Photos', 'Last 5 photos', 'a:0:{}', 1, 'sampleapp/block/last5photos.tpl', NULL, NULL, 'last5photos.php');

-- -----------------------------------------------------
-- Data for table `wcm_generation_autogen
-- -----------------------------------------------------

INSERT INTO `wcm_generation_autogen` VALUES (1,1,'article',1), (2,4,'article',2);
