<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.memCache.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * Cache implementation using Memcache.
 */
class cmfMemCache implements cmfCache
{
    /**
     * The Memcache instance.
     * @var Memcache
     */
    private $memcache;

    /**
     * Public constructor.
     * @param Memcache $memcache The Memcache instance.
     */
    public function __construct(Memcache $memcache = null)
    {
        $this->memcache = $memcache;
    }

    /**
     * Get the Memcache instance.
     * @return Memcache
     */
    public function getMemCache()
    {
        return $this->memcache;
    }

    /**
     * Set the Memcache instance.
     * @param Memcache $value The new value.
     * @return void
     */
    public function setMemCache(Memcache $value = null)
    {
        $this->memcache = $value;
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#set($key, $value, $ttl)
     */
    public function set($key, $content, $ttl = null)
    {
        if ((!is_string($key) || '' == $key) || !is_numeric($key))
        {
            throw new InvalidArgumentException();
        }
        
        return $this->memcache->set(md5($key), $content, false, $ttl);
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#get($key)
     */
    public function get($key)
    {
        return $this->memcache->get(md5($key));
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#delete($key)
     */
    public function delete($key)
    {
        return $this->memcache->delete(md5($key));
    }

    /**
     * (non-PHPdoc)
     * @see cache/cmfCache#clear()
     */
    public function clear()
    {
        return $this->memcache->flush();
    }
}