<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.iceService.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-system-api
 * @version     4.x
 */

/**
 * Handles ICE features (Login, Widget saving, etc.)
 */
class cmfIceService
{
    /**
     * The login REST service URL.
     * @var string
     */
    private $loginUrl;

    /**
     * The widget REST service URL.
     * @var string
     */
    private $widgetUrl;

    /**
     * The widget manager REST service URL.
     * @var string
     */
    private $widgetManagerUrl;

    /**
     * Public constructor.
     * @param string $loginUrl The login REST service URL.
     * @param string $widgetUrl The widget REST service URL.
     * @param string $widgetManagerUrl The widget manager REST service URL.
     */
    public function __construct($loginUrl, $widgetUrl, $widgetManagerUrl)
    {
        $this->loginUrl = $loginUrl;
        $this->widgetUrl = $widgetUrl;
        $this->widgetManagerUrl = $widgetManagerUrl;
    }

    /**
     * Check if user is logged in to the ICE web service.
     * @return boolean
     */
    public function isLoggedIn()
    {
        return isset($_SESSION['cmfIce']);
    }

    /**
     * Logout user from ICE web service.
     * @return void
     */
    public function logout()
    {
        unset($_SESSION['cmfIce']);
    }

    /**
     * Call WCM ICE login Rest Service and performs a login (Check if user has rights to manage site)
     *
     * @param $username String
     * @param $password String
     * @param $siteCode String
     */
    public function login($username, $password, $siteCode)
    {
        $curl = curl_init();
        $params = array(
            'username' => $username,
            'password' => $password,
            'siteCode' => $siteCode
        );
        curl_setopt($curl, CURLOPT_URL, $this->loginUrl);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($params));
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_exec($curl);
        $status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        curl_close($curl);

        if (200 == $status)
        {
            $_SESSION['cmfIce'] = true;
        }
        else
        {
            unset($_SESSION['cmfIce']);
        }
    }

    /**
     * Save positions of widgets
     *
     * @param $request Array
     * @return void
     */
    public function save(array $request = array())
    {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->widgetUrl);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($request));
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $result = curl_exec($curl);
        curl_close($curl);

        return unserialize($result);
    }

    /**
     * callWcmWidgetManager
     *
     * @param array $request
     * @return void
     */
    public function callWcmWidgetManager(array $request = array())
    {
        $curl = curl_init();
        curl_setopt($curl, CURLOPT_URL, $this->widgetManagerUrl);
        curl_setopt($curl, CURLOPT_POSTFIELDS, http_build_query($request));
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        $result = curl_exec($curl);
        curl_close($curl);

        return $result;
    }
}