<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.queryController.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-www-mediaManager-testapp
 * @version     4.x
 */

/**
 * This controller handles queries for images to
 * the media manager.
 */
class cmfQueryController extends cmfBaseController
{
    /**
     * Handles the QUERY action.
     * @return void
     */
    public function onQuery()
    {
        if (!$this->validate())
        {
            return;
        }
        
        switch ($this['queryMode'])
        {
            case 'original':
                $url = $this->client->getImageUrl($this['id']);
                break;
                
            case 'cropped':
                $url = $this->client->getCroppedImageUrl($this['id'], $this['format']);
                break;
                
            case 'resized':
                $url = $this->client->getResizedImageUrl($this['id'], $this['width'], $this['height']);
                break;
        }
        
        if ($this->validateUrl($url))
        {
            $this['url'] = $url;
        }
    }
    
    /**
     * Validate the request arguments.
     * @return boolean True if the request is valid,
     * false otherwise.
     */
    private function validate()
    {
        $request = $this->getRequest();
        $this['id'] = cmfToolbox::getArrayParameter($request, 'id');
        $this['queryMode'] = cmfToolbox::getArrayParameter($request, 'mode');

        if (!$this['id'])
        {
            $this['message'] = 'ID is required.';
            return false;
        }
        
        if (!is_numeric($this['id']))
        {
            $this['message'] = 'ID is required.';
            return false;
        }
        
        if (!$this['queryMode'])
        {
            $this['message'] = 'Mode is required.';
            return false;
        }
        
        switch ($this['queryMode'])
        {
            case 'original':
                break;
                
            case 'cropped':
                $this['format'] = cmfToolbox::getArrayParameter($request, 'format');
                if (!$this['format'])
                {
                    $this['message'] = 'Format is required.';
                    return false;
                }
                break;
                
            case 'resized':
                $this['width'] = cmfToolbox::getArrayParameter($request, 'width');
                $this['height'] = cmfToolbox::getArrayParameter($request, 'height');
                if (!$this['width'] && !$this['height'])
                {
                    $this['message'] = 'At least one of width and height is required.';
                    return false;
                }
                if ($this['width'] && (!is_numeric($this['width']) || $this['width'] <= 0))
                {
                    $this['message'] = 'Width must be a positive integer.';
                    return false;
                }
                if ($this['height'] && (!is_numeric($this['height']) || $this['height'] <= 0))
                {
                    $this['message'] = 'Height must be a positive integer.';
                    return false;
                }
                break;
                
            default:
                $this['message'] = 'Invalid mode.';
                return false;
        }
        
        return true;
    }
    
    /**
     * Do a HTTP HEAD call on the URL to ensure it is valid.
     * @param unknown_type $url
     * @return unknown_type
     */
    private function validateUrl($url)
    {
        $curl = curl_init();

        curl_setopt($curl, CURLOPT_URL, $url);
        curl_setopt($curl, CURLOPT_NOBODY, true);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        
        curl_exec($curl);
        $status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
        
        curl_close($curl);
        
        switch ($status)
        {
            case 404:
                $this['message'] = 'Invalid image ID.';
                return false;
                
            case 400:
                $this['message'] = 'Invalid format.';
                return false;
                
            case 200:
                return true;
                
            default:
                $this['message'] = 'Unknown error.';
                return false;
        }
    }
}