<?php
/**
 * Project:     WCM
 * File:        $Id: cmf.uploadController.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     cmf-www-mediaManager-testapp
 * @version     4.x
 */

/**
 * This controller handles requests to add
 * images to the media manager.
 */
class cmfUploadController extends cmfBaseController
{
    /**
     * Handle the ADD action.
     * @return void
     */
    public function onAdd()
    {
        if (!$this->validate())
        {
            return;
        }

        try
        {
            $formats = json_decode($this['formats'], true);

            switch ($this['uploadMode'])
            {
                case 'url':
                    $this->client->addImage(
                        $this['id'], 
                        $formats, 
                        $this['url']
                    );
                    break;
                    
                case 'upload':
                    $this->client->uploadImage(
                        $this['id'], 
                        $formats, 
                        $_FILES['photo']['tmp_name']
                    );
                    break;
            }
            
            $this['message'] = 'Image #' . $this['id'] . ' was successfully added.';
            unset($this['id']);
            unset($this['formats']);
            unset($this['uploadMode']);
            unset($this['url']);
        }
        catch (Exception $e)
        {
            $this['message'] = 'Error: ' . $e->getMessage();
        }
    }
    
    /**
     * Validate the request arguments.
     * @return boolean True if the request is valid,
     * false otherwise.
     */
    private function validate()
    {
        $request = $this->getRequest();
        
        $this['id'] = cmfToolbox::getArrayParameter($request, 'id');
        $this['formats'] = cmfToolbox::getArrayParameter($request, 'formats');
        $this['uploadMode'] = cmfToolbox::getArrayParameter($request, 'mode');
        
        if (!$this['id'])
        {
            $this['message'] = 'ID is required.';
            return false;
        }
        if (!is_numeric($this['id']))
        {
            $this['message'] = 'ID must be numeric.';
            return false;
        }
        if (!$this['formats'])
        {
            $this['message'] = 'Format is required.';
            return false;
        }
        
        switch ($this['uploadMode'])
        {
            case 'url':
                $this['url'] = cmfToolbox::getArrayParameter($request, 'url');
                if (!$this['url'])
                {
                    $this['message'] = 'URL is required.';
                    return false;
                }
                break;
                
            case 'upload':
                if (!isset($_FILES['photo']['tmp_name']) || !is_uploaded_file($_FILES['photo']['tmp_name']))
                {
                    $this['message'] = 'No image was uploaded.';
                    return false;
                }
                break;
                
            default:
                $this['message'] = 'Invalid mode.';
                return false;
        }
        
        return true;
    }
}