<?php

/**
 * 
 */
class MemCacheTest extends CacheTest
{
    private $memcacheStubValue;
    
    public function setUp()
    {
        $this->cache = $this->getMock('Memcache');
    }
    
    public function testEmptyGet($key)
    {
        $this->cache->expects($this->any())->method('get')->will($this->returnValue(false));
        parent::testEmptyGet($key);
    }
    
    public function testSetInvalidKey($key, $value)
    {
        $this->cache->expects($this->any())->method('set')->will($this->returnValue(null));
        parent::testSetInvalidKey($key, $value);
    }
    
    public function testSet($key, $value)
    {
        $this->cache->expects($this->any())->method('set')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('get')->will($this->returnValue($value));
        parent::testSet($key, $value);
    }
    
    public function testSetWithTTL($key, $value)
    {
        $this->memcacheStubValue = $value;
        $this->cache->expects($this->any())->method('set')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('get')->will($this->returnCallback(array($this, 'stubGetWithTTL')));
        parent::testSet($key, $value);
    }
    
    public function stubGetWithTTL()
    {
        $value = $this->memcacheStubValue;
        $this->memcacheStubValue = null;
        return $this->memcacheStubValue;
    }
    
    public function testDelete($key, $value)
    {
        $this->cache->expects($this->any())->method('set')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('delete')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('get')->will($this->returnValue(null));
        parent::testDelete($key, $value);
    }
    
    public function testClear($key, $value)
    {
        $this->cache->expects($this->any())->method('set')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('clear')->will($this->returnValue(null));
        $this->cache->expects($this->any())->method('get')->will($this->returnValue(null));
        parent::testClear($key, $value);
    }
}