<?php

require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 * This class will test the ReST content controller
 *
 * The test strategy here is more complex, here is the order of tests:
 *
 *
 * 1. Create an object
 * 2. Retreive the object and verify it is the correct object
 * 3. Update the object, retreive it and verify it was correctly updated
 * 4. Delete the object and verify it was Deleted correctly
 *
 * All tests are then repeated but for multiple objects of the same class
 * 1. Create more than one object of the same class
 * 2. Retreive a list of the objects and verify they are the correct objects
 * 3. Delete the objects by class with a WHERE parameter so as not to Delete
 *    other objects
 *
 */

class contentTest extends WcmTest
{
    // CONSTANTS
    // The biz class used for the creation tests
    const OBJECT_BIZ_CLASS = self::WORKFLOW_BIZ_CLASS;

    // The user name to be used for creating a wcmUser
    const WCM_USER_NAME = 'tesla';

    // The clear text password for the wcmUser to be created
    const WCM_USER_PASSWORD = 'admin';

    // The md5 encrypted password(admin) of the wcmUser to be created
    const WCM_USER_ENCODED_PASSWORD = '21232f297a57a5a743894a0e4a801fc3';

    // The name of the wcmWorkflow to create for the tests
    const WCM_WORKFLOW_NAME = 'Test workflow';

    // An invalid biz object that is valid xml
    const INVALID_BIZ_OBJECT = '<X> </X>';

    private $wcmWorkflow;

    private $wcmUser;

    private $wcmWorkflowJson;

    /*
     * setup the enviroment for the tests, called before each test
     */
    public static function setUpBeforeClass()
    {

        parent::setUpBeforeClass();
        // Get a valid session Id
        self::GetSessionId();
    }

    /*
     * Gets called after all tests have finished
     */
    public static function tearDownAfterClass()
    {
        parent::tearDownAfterClass();

    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();

        // Create an xml representation of a wcmUser
        $wcmUser = '<' . self::USER_BIZ_CLASS . '>';
        $wcmUser .= '<name>' . self::WCM_USER_NAME . '</name>';
        $wcmUser .= '<login>' . self::WCM_USER_NAME . '</login>';
        $wcmUser .= '<password>' . self::WCM_USER_ENCODED_PASSWORD;
        $wcmUser .= '</password>';
        $wcmUser .= '<email>' . 'emailadress' . '</email>';
        $wcmUser .= '<className>' . self::USER_BIZ_CLASS . '</className>';
        $wcmUser .= '<objectType>' . self::USER_BIZ_CLASS . '</objectType>';
        $wcmUser .= '</' . self::USER_BIZ_CLASS . '>';

        // Create an xml representation of a wcmUser
        $wcmWorkflow = '<' . self::WORKFLOW_BIZ_CLASS . '>';
        $wcmWorkflow .= '<name>' . self::WCM_WORKFLOW_NAME . '</name>';
        $wcmWorkflow .= '<className>' . self::WORKFLOW_BIZ_CLASS;
        $wcmWorkflow .= '</className>';
        $wcmWorkflow .= '<objectType>' . self::WORKFLOW_BIZ_CLASS;
        $wcmWorkflow .= '</objectType>';
        $wcmWorkflow .= '</' . self::WORKFLOW_BIZ_CLASS . '>';

        $wcmWorkflowJson = '{"name":"' . self::WORKFLOW_BIZ_CLASS . '",';
        $wcmWorkflowJson .= '"className":"' . self::WORKFLOW_BIZ_CLASS . '",';
        $wcmWorkflowJson .= '"objectType":"' . self::WORKFLOW_BIZ_CLASS . '"}';

        // assign the local WCM objects to the class variables
        $this->wcmUser = $wcmUser;
        $this->wcmWorkflow = $wcmWorkflow;
        $this->wcmWorkflowJson = $wcmWorkflowJson;
    }

    public function testSetUpResources()
    {
        // test that the wcm workflow object is valid xml
        try
        {
            new SimpleXMLElement($this->wcmWorkflow);
        }
        catch (Exception $e)
        {
            $this->assertTrue(
                false, 'The xml of the workflow is not valid: ' . "\n" .
                $this->wcmWorkflow
            );
        }

        // test that the wcm User object is valid xml
        try
        {
            new SimpleXMLElement($this->wcmUser);
        }
        catch (Exception $e)
        {
            $this->assertTrue(
                false, 'The xml of the user is not valid:' . "\n" .
                $this->wcmUser
            );
        }
        // test that the sessionId was correctly retrieved
        if (self::$sessionIdError != null)
        {
            $this->assertTrue(false, self::$sessionIdError);
        }
    }

    /*
     * 1.a Create an object from xml
     */
    public function testPostContent201SessionidXml()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        // Create from xml representation
        $this->setupPost(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                'content'                 => $this->wcmWorkflow
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // rememeber the id	of the newly created object
        self::$idArray[self::OBJECT_BIZ_CLASS][] = $this->getId();

    }

    /*
     * 1.b Create an object from json
     */
    public function testPostContent201SessionidJson()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        // Create from json representation
        $this->setupPost(
            array(
               self::SESSIONID_PARAMETER => self::$sessionId
            ), self::CONTENT_POST_PARA . urlencode($this->wcmWorkflowJson) . '&json=true'
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // rememeber the id of the newly created object
        self::$idArray[self::OBJECT_BIZ_CLASS][] = $this->getId();

    }

    /*
     * 2.a Retreive the object in xml and verify it is the correct object
     *
     * @depends testPostContent200()
     */
    public function testGetContentId200Sessionid()
    {
        // Get the newly created object
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS . self::SEPERATOR .
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );

        $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

        // Validate the returned object is the newly created one
        $this->validateReturnedXmlObject(
            urldecode($this->wcmWorkflow),
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );
    }

    /*
     * 2.b Retreive the object in json and verify it is the correct object
     *
     * @depends testPostContent200()
     */
    public function testGetContentId200SessionidJson()
    {
        // Get the newly created object
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS . self::SEPERATOR .
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );

        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::JSON_PARAMETER      => 'true'
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsJson();

        // Validate the returned object is the newly created one
        $this->validateReturnedJsonObject(
            urldecode($this->wcmWorkflow),
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );
    }

    /*
     * 3. Update the object, retreive it and verify it was correctly updated
     *
     * @depends testPostContent200()
     * @depends testGetContentId200()
     */
    public function testPostContentId201Sessionid()
    {
        // modify the objects name
        $this->wcmWorkflow = str_replace(
            self::WCM_WORKFLOW_NAME, 'Modified name', $this->wcmWorkflow
        );

        // save the object
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS . self::SEPERATOR .
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );

        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . urlencode($this->wcmWorkflow)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        // Get the updated object
        $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();

        // Verify that the object was correctly updated
        $this->validateReturnedXmlObject(
            urldecode($this->wcmWorkflow),
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );
    }

    /*
     * 4. Delete the object and verify it was Deleted
     *
     * @depends testPostContent200()
     * @depends testGetContentId200()
     */
    public function testDeleteContentId204Sessionid()
    {
        // Delete the object
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS . self::SEPERATOR .
            self::$idArray[self::OBJECT_BIZ_CLASS][0]
        );

        $this->setupDelete(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(204);

        // Verify that the object was Deleted
        $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    /*
     * Create a few objects and retreive them as locations then validate the
     * locations and the returned objects that the locations are pointing to.
     * These items Get Deleted in the next test.
     */
    public function testGetContentWorkflow200Sessionid()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        // Create 10 objects of the specified class
        for ($i = 1; $i <= 10; $i++) {

            $this->setupPost(
                array(self::SESSIONID_PARAMETER => self::$sessionId),
                self::CONTENT_POST_PARA . urlencode($this->wcmWorkflow)
            );

            $this->executeRequest();

            $this->validateReturnStatus(201);

            // rememeber the ids for deletion in case of error
            self::$idArray[self::OBJECT_BIZ_CLASS][] = $this->getId();
        }

        // get the objects
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        $this->setupGet(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::WHERE_PARAMETER     => $this->GetSqlWhereIdEqualsQuery(
                    self::$idArray[self::OBJECT_BIZ_CLASS]
                )
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        // Validate that the locations for the newly created objects are valid
        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId),
            urldecode($this->wcmWorkflow),
            self::$idArray[self::OBJECT_BIZ_CLASS]
        );
    }

    /*
     * Delete all objects of a specified class
     *
     * Delete the objects created in the last test
     */
    public function testDeleteContent204SessionidWhere()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        $this->setupDelete(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::WHERE_PARAMETER     => $this->GetSqlWhereIdEqualsQuery(
                    self::$idArray[self::OBJECT_BIZ_CLASS]
                )
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(204);

        // do a Get for each object and verify a status code of 404 is returned
        foreach (self::$idArray[self::OBJECT_BIZ_CLASS] as $id)
        {
            $this->setResource(
                self::CONTENT_CONTROLLER . self::SEPERATOR . self::WORKFLOW_BIZ_CLASS . self::SEPERATOR . $id
            );

            $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

            $this->executeRequest();

            $this->validateReturnStatus(404);
        }
    }

    /*
     * Invalid session id
     */
    public function testGetContent400Sessionid()
    {
        $this->setResource(self::CONTENT_CONTROLLER);

        $this->setupGet(array(self::SESSIONID_PARAMETER => self::INVALID_PARA_VALUE));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid resource
     */
    public function testGetContentInvalid404SessionId()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE
        );

        $this->setupGet(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);

    }

    /*
     * Invalid session id
     */
    public function testPostContent400Sessionid()
    {
        $this->setResource(self::CONTENT_CONTROLLER);

        $this->setupPost(array(self::SESSIONID_PARAMETER => self::INVALID_PARA_VALUE));

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid session id
     */
    public function testPostContentWorkflow400SessionidXml()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . '"fktfghrtfs"'
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid json content
     */
    public function testPostContentWorkflow400SessionidJson()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        // Create from json representation
        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . 'jrdfnjreg&json=true'
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid content but valid xml
     */
    public function testPostContentWorkflow400Sessionid()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS
        );

        // Send valid xml in the content but that isn't a valid WCM class
        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . self::INVALID_BIZ_OBJECT
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }


    /*
     * Invalid resource
     */
    public function testPostContentInvalid404Sessionid()
    {
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR . self::INVALID_RESOURCE
        );

        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . 'fake content'
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }



    /*
     * Missing session id
     */
    public function testDeleteContent400()
    {
        $this->setResource(self::CONTENT_CONTROLLER);

        $this->setupDelete();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Attempt to Delete an object the user isn'T permitted to Delete
     *
     * For this test we will need to:
     * 1. Create a new user that doesn't have permission to create objects
     * 2. Get a sessionId for the user
     * 3. Post an object with the sessionId of the user that doesnt have
     *    permission to create an object
     */
    public function testDeleteContentUser401Sessionid()
    {
        // Create a new WCM user
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::USER_BIZ_CLASS
        );

        $this->setupPost(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            self::CONTENT_POST_PARA . urlencode($this->wcmUser)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        self::$idArray[self::USER_BIZ_CLASS][] = $this->getId();

        // Get a sessionId for the newly created user
        $this->setResource(self::SESSION_CONTROLLER);

        $this->setupPUT(
            array(
                self::USERNAME_PARAMETER => self::WCM_USER_NAME,
                self::PASSWORD_PARAMETER => self::WCM_USER_PASSWORD
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        $sessionId = $this->validateHeader(self::SESSION_ID_HEADER);

        // Create an article
        $articleId = self::createArticle();

        // try to Delete the article the newly created user isn't permitted to
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::ARTICLE_RESOURCE .
            self::SEPERATOR .
            $articleId
        );

        // use the newly created users sessionId
        $this->setupDelete(array(self::SESSIONID_PARAMETER => $sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(401);

        self::DeleteArticle($articleId);

        // Delete the newly created user
        $this->setResource(
            self::CONTENT_CONTROLLER .
            self::SEPERATOR .
            self::USER_RESOURCE
        );

        $query = 'login=\'' . self::WCM_USER_NAME . '\'';

        $this->setupDelete(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::WHERE_PARAMETER     => $query
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(204);
    }

    /*
     * Invalid object id
     */
    public function testDeleteContent404()
    {
        //TODO:Dont use the array just in case a previous test did something wierd,
        // instead Get the workflow with the highest id...
        //Get the id of the last workflow that was created
        $lastId = array_pop(self::$idArray[self::OBJECT_BIZ_CLASS]);
        array_push(self::$idArray[self::OBJECT_BIZ_CLASS], $lastId);

        // Ensure the id is invalid by adding 1 to the last id
        $this->setResource(
            self::CONTENT_CONTROLLER . self::SEPERATOR .
            self::WORKFLOW_BIZ_CLASS . self::SEPERATOR . ($lastId + 1)
        );

        $this->setupDelete(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }
}