<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

class generationTest extends WcmTest
{
    // The REST resource controller
    const CONTROLLER = self::GENERATION_CONTROLLER;

    // This string will act as a place holder in the xml structures of the
    // wcmGeneration and wcmGenerationContent strings
    const ID_PLACE_HOLDER = 'PLACE_HOLDER';

    // The file created when executing a generation
    const GEN_OUTPUT_FILE = '/tmp/index.html';
    
    // The template file to use the the generation content objects, 
    // this is refered to as the template id in the generation content object
    const TEMPLATE_ID = 'test/rest-test.tpl';
    
    private $generation;
    private $generationSet;
    private $generationContent;
    
    private $generationModified;
    private $generationSetModified;
    private $generationContentModified;

    static private $generationId;
    static private $generationSetId;
    static private $generationContentId;

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();

        // XML representation of a generation object
        $this->generation = '<wcmGeneration>';
        $this->generation .= '<name>Test</name>';
        $this->generation .= '<code>' . rand() . '</code>';
        $this->generation .= '<location>' . '/tmp' . '</location>';
        $this->generation .= '<className>wcmGeneration</className>';
        $this->generation .= '<objectType>wcmGeneration</objectType>';
        // the generationSetId element will be added in the create generationSet test
        $this->generation .= '<generationSetId>' . self::ID_PLACE_HOLDER . '</generationSetId>';
        $this->generation .= '</wcmGeneration>';

        // XML representation of a generation set
        $this->generationSet = '<wcmGenerationSet>';
        $this->generationSet .= '<name>Test</name>';
        $this->generationSet .= '<code>' . rand() . '</code>';
        $this->generationSet .= '<className>wcmGenerationSet</className>';
        $this->generationSet .= '<objectType>wcmGenerationSet</objectType>';
        $this->generationSet .= '</wcmGenerationSet>';

        // XML representation of a generation content object
        $this->generationContent = '<wcmGenerationContent>';
        $this->generationContent .= '<name>Test</name>';
        $this->generationContent .= '<code>' . rand() . '</code>';
        $this->generationContent .= '<templateId>' . self::TEMPLATE_ID . '</templateId>';
        $this->generationContent .= '<namingRule>' . self::GEN_OUTPUT_FILE . '</namingRule>';
        // the generationId element will be added in the create generation test
        $this->generationContent .= '<generationId>' . self::ID_PLACE_HOLDER . '</generationId>';
        $this->generationContent .= '<className>wcmGenerationContent</className>';
        $this->generationContent .= '<objectType>wcmGenerationContent</objectType>';
        $this->generationContent .= '</wcmGenerationContent>';
        
        // XML representation of a modified generation set
        $this->generationSetModified = '<wcmGenerationSet>';
        $this->generationSetModified .= '<name>Test-Modified</name>';
        $this->generationSetModified .= '<code>' . rand() . '</code>';
        $this->generationSetModified .= '<className>wcmGenerationSet</className>';
        $this->generationSetModified .= '<objectType>wcmGenerationSet</objectType>';
        $this->generationSetModified .= '</wcmGenerationSet>';
        
        // XML representation of a modified generation object
        $this->generationModified = '<wcmGeneration>';
        $this->generationModified .= '<name>Test-Modified</name>';
        $this->generationModified .= '<code>' . rand() . '</code>';
        $this->generationModified .= '<location>' . '/tmp' . '</location>';
        $this->generationModified .= '<className>wcmGeneration</className>';
        $this->generationModified .= '<objectType>wcmGeneration</objectType>';
        // the generationSetId element will be added in the create generationSet test
        $this->generationModified .= '<generationSetId>' . self::ID_PLACE_HOLDER . '</generationSetId>';
        $this->generationModified .= '</wcmGeneration>';
        
        // XML representation of a modified  content object
        $this->generationContentModified = '<wcmGenerationContent>';
        $this->generationContentModified .= '<name>Test-Modified</name>';
        $this->generationContentModified .= '<code>' . rand() . '</code>';
        $this->generationContentModified .= '<templateId>preview/article.tpl</templateId>';
        $this->generationContentModified .= '<namingRule>' . self::GEN_OUTPUT_FILE . '</namingRule>';
        // the generationId element will be added in the create generation test
        $this->generationContentModified .= '<generationId>' . self::ID_PLACE_HOLDER . '</generationId>';
        $this->generationContentModified .= '<className>wcmGenerationContent</className>';
        $this->generationContentModified .= '<objectType>wcmGenerationContent</objectType>';
        $this->generationContentModified .= '</wcmGenerationContent>';
    }

    //--------------------------------------------------------//
    // CREATING A GENERATION SET OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request to create a generation set
     */
    public function testPostGenerationSet201SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);

        //TODO: Implement the GET method for the generation controllers so the location URL is useful
        // validate the location header is present in the response
        //$url = $this->validateHeader(self::LOCATION_HEADER);
        
        // double url encode the returned location as to "fix" Apaches pre url decoding
        //$url = $this->doubleURLEncodeSessionId($url);
        
        // validate that the location is valid
        //$this->validateLocation($url);
    }

    /*
     * Invalid request
     */
    public function testPostGenerationSet400()
    {
        // Missing content
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(400);
        
        // Missing sessionId
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(array('content=' . urlencode($this->generationContent)));

        $this->executeRequest();

        $this->validateReturnStatus(400);
        
        // Missing sessionId and content
        //Missing sessionId
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(array());

        $this->executeRequest();

        $this->validateReturnStatus(400);
        
        // Invalid xml in content
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . 'fdlkjghndfkjhg'
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid request
     */
    public function testPostGenerationSet401()
    {
        // Invalid content but in valid xml
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . '<Wo>Oh!</Wo>'
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);
    }

    /*
     *
     */
    public function testPostGenerationSet404()
    {
        // Invalid object id in the url
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE . self::SEPERATOR . 'invalid'
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($this->generationContent)
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
        
         // Invalid resource
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . 'invalid'
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($this->generationContent)
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // CREATING A GENERATION OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request - Create a generation set and then a generation object that belongs to the set
     * @depends testPostGenerationSet201
     */
    public function testPostGeneration201SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);

        //TODO: Implement the GET method for the generation controllers so the location URL is useful
        // validate the location header is present in the response
        //$url = $this->validateHeader(self::LOCATION_HEADER);
        
        // double url encode the returned location as to "fix" Apaches pre url decoding
        //$url = $this->doubleURLEncodeSessionId($url);
        
        // validate that the location is valid
        //$this->validateLocation($url);
    }

    /*
     * Invalid request, missing content parameter
     */
    public function testPostGeneration400Sessionid()
    {
        $this->setResource(self::CONTROLLER);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid
     * @depends testPostGenerationSet201
     */
    public function testPostGeneration401SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        /*
         *  Missing generationSet id in the generation object
         */
        $generation = '<wcmGeneration>';
        $generation .= '<name>Test</name>';
        $generation .= '<code>xxx</code>';
        $generation .= '<className>wcmGeneration</className>';
        $generation .= '<objectType>wcmGeneration</objectType>';
        $generation .= '</wcmGeneration>';

        $this->setResource(self::CONTROLLER);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($generation)
        );

        $this->executeRequest();

        $this->validateReturnStatus(401);

        /*
         * code is not unique
         */
        $generation = '<wcmGeneration>';
        $generation .= '<name>Test</name>';
        $generation .= '<code>generic_code</code>';
        $generation .= '<generationSetId>' . self::$generationSetId . '</generationSetId>';
        $generation .= '<className>wcmGeneration</className>';
        $generation .= '<objectType>wcmGeneration</objectType>';
        $generation .= '</wcmGeneration>';

        $this->setResource(self::CONTROLLER);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($generation)
        );

        // create the wcmGeneration object
        $this->executeRequest();

        self::$idArray[self::GENERATION_BIZ_CLASS][] = $this->getId();

        // attempt to create it again
        $this->executeRequest();
        $this->validateReturnStatus(401);
    }

//    /*
//     *
//     */
//    public function testPostGeneration404()
//    {
//    }

    //--------------------------------------------------------//
    // CREATING A GENERATION CONTENT OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request
     * @depends testPostGeneration201
     */
    public function testPostGenerationContent201SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);
        
        $this->createGenerationContent($this->generationContent);

        //TODO: Implement the GET method for the generation controllers so the location URL is useful
        // validate the location header is present in the response
        //$url = $this->validateHeader(self::LOCATION_HEADER);
        
        // double url encode the returned location as to "fix" Apaches pre url decoding
        //$url = $this->doubleURLEncodeSessionId($url);
        
        // validate that the location is valid
        //$this->validateLocation($url);
    }

    /*
     * invalid requests: invalid content or invalid xml
     */
    public function testPostGenerationContent400SessionidContentinvalid()
    {
        /*
         * invalid content but valid xml
         */
        $this->setResource(self::CONTROLLER . self::SEPERATOR . self::CONTENT_RESOURCE);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode('<invalid/>')
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);

        /*
         * invalid xml
         */
        $this->setResource(self::CONTROLLER . self::SEPERATOR . self::CONTENT_RESOURCE);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode('<invalid')
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

//    public function testPostGenerationContent401()
//    {
//        $this->markTestIncomplete(
//          'Unable to test, this error is for updating a wcmGenerationContent object, not creating it.'
//        );
//    }
//
//    public function testPostGenerationContent404()
//    {
//        $this->markTestIncomplete(
//          'Unable to test, this error message signifies the core was unable to save the object in the database.'
//        );
//    }

//public function testTemplate()
//{
//    $this->setResource(
//        self::CONTROLLER . self::SEPERATOR . 'template'
//    );
//    $this->setupPUT(
//        array(self::SESSIONID_PARAMETER => self::$sessionId),
//        null, 'content=/tmp/test.tpl'
//    );
//    
//    $this->executeRequest();
//}

    //--------------------------------------------------------//
    // UPDATING A GENERATION OBJECT
    //--------------------------------------------------------//
    /*
     * 1. Create a generation set
     * 2. Create a generation object
     * 3. Update the generation object
     * 4. Validate the updated generation object
     */
    public function testPutGeneration201SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);

        // use the id of the newly created generationSet in the modified generation objects XML structure
        $this->generationModified = str_replace(self::ID_PLACE_HOLDER, self::$generationSetId, $this->generationModified);

        /* 
         * 3. Update the newly created generation object
         */
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::$generationId
        );

        $this->setupPUT(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            null, $this->generationModified
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        self::$generationId = $this->getId();
        
        self::$idArray[self::GENERATION_BIZ_CLASS][] = self::$generationId;
        
        /*
         * TODO 4. Retreive and validate the object was modified
         */
    }

//    /*
//     *
//     */
//    public function testPutGeneration400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGeneration401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGeneration404()
//    {
//    }

//    //--------------------------------------------------------//
//    // UPDATING A GENERATION CONTENT OBJECT
//    //--------------------------------------------------------//
    /*
     * 1. Create a generation set object
     * 2. Create a generation object
     * 3. Create a generation object
     * 4. Modify the generation object
     * 5. Validate the modified generation object
     */
    public function testPutGenerationContent201SessionidContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);
        
        $this->createGenerationContent($this->generationContent);
        
        // use the id of the newly created generation object for the modified generation content object
        $this->generationContentModified = str_replace(self::ID_PLACE_HOLDER, self::$generationId, $this->generationContentModified);
 
        /*
         * 4. Modify the generation content object
         */
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::CONTENT_RESOURCE . 
            self::SEPERATOR . self::$generationContentId
        );

        $this->setupPUT(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            null, $this->generationContentModified
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        self::$generationContentId = $this->getId();
        
        self::$idArray[self::GENERATION_CONTENT_BIZ_CLASS][] = self::$generationContentId;
        
        //TODO: 5. Validate the modified generation object
    }
//
//    /*
//     *
//     */
//    public function testPutGenerationContent400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationContent401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationContent404()
//    {
//    }

    //--------------------------------------------------------//
    // UPDATING A GENERATION SET OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request to update a generation set
     * 1. Create a generationSet
     * 2. Update a generationSet
     * 3. Validate the returned generationSet  has been correctly updated
     */
    public function testPutGenerationSet201SessionIdContent()
    {
        $this->createGenerationSet($this->generationSet);
        
        /*
         * 2. Update a generationSet
         */
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE . 
            self::SEPERATOR . self::$generationSetId
        );

        $this->setupPUT(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            null, $this->generationSetModified
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        self::$generationSetId = $this->getId();
        
        self::$idArray[self::GENERATION_SET_BIZ_CLASS][] = self::$generationSetId;
        
        /*
         * TODO 3. Retrieve and validate the modified object
         */
    }

//    /*
//     *
//     */
//    public function testPutGenerationSet400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationSet401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationSet404()
//    {
//    }

//    //--------------------------------------------------------//
//    // UPDATING A GENERATION TEMPLATE OBJECT
//    //--------------------------------------------------------//
//    /*
//     *
//     */
//    public function testPutGenerationTemplate201()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationTemplate400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationTemplate401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPutGenerationTemplate404()
//    {
//    }

    //--------------------------------------------------------//
    // EXECUTING A GENERATION OBJECT
    //--------------------------------------------------------//
    /*
     *
     */
    public function testPostGenerationId201Sessionid()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);

        $this->createGenerationContent($this->generationContent);
        
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::$generationId
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
    }

//    /*
//     *
//     */
//    public function testPostGenerationId400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationId401()
//    {
//    }

    /*
     * Invalid generation id
     * TODO: Get rid of hard-coded generationId
     */
    public function testPostGenerationId404Sessionid()
    {
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . rand()
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

//    /*
//     *
//     */
//    public function testPostGenerationId500()
//    {
//    }

    //--------------------------------------------------------//
    // EXECUTING A GENERATION CONTENT OBJECT
    //--------------------------------------------------------//
    /*
     * 1. Create a generation set object
     * 2. create a generation object
     * 3. create a generation content object
     * 4. Execute the generation content
     * 
     * By id
     */
    public function testPostGenerationContentId201()
    {
        $this->createGenerationSet($this->generationSet);
        
        $this->createGeneration($this->generation);

        $this->createGenerationContent($this->generationContent);
        
        $this->setResource(
            self::CONTROLLER       . self::SEPERATOR .
            self::CONTENT_RESOURCE . self::SEPERATOR .
            self::$generationContentId
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
    }

//    /*
//     * By code
//     */
//    public function testPostGenerationContent201Code()
//    {
//        $this->setResource(
//            self::CONTROLLER       . self::SEPERATOR .
//            self::CONTENT_RESOURCE
//        );
//
//        $this->setupPOST(
//            array(
//                self::SESSIONID_PARAMETER => self::$sessionId,
//                self::CODE_POST_PARA      => self::GEN_CONT_CODE
//            )
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(201);
//    }

//    /*
//     *
//     */
//    public function testPostGenerationContentId400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationContentId401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationContentId404()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationContentId500()
//    {
//    }

    //--------------------------------------------------------//
    // EXECUTING A GENERATION SET OBJECT
    //--------------------------------------------------------//
    /*
     * Execute a generation set
     * 1. Create a generation set
     * 2. Create a generaion object
     * 3. Create a generation content object
     * 4. Execute the generation set
     */
    public function testPostGenerationSetId201()
    {
        $this->createGenerationSet($this->generationSet);

        $this->createGeneration($this->generation);

        $this->createGenerationContent($this->generationContent);
        
        /*
         * Execute the generation set object
         */
        $this->setResource(
            self::CONTROLLER   . self::SEPERATOR .
            self::SET_RESOURCE . self::SEPERATOR .
            self::$generationSetId
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        // Validate that the file was generated and the contents are correct
        $relativePath = dirname(__FILE__) . '/../data';
        $absolutePath = realPath($relativePath);
        $expectedFile = $absolutePath . '/expected_generation';
        $this->assertFileEquals(self::GEN_OUTPUT_FILE, $expectedFile);
        
        // Delete the generated file if permitted
        if (substr(sprintf('%o', fileperms(self::GEN_OUTPUT_FILE)), 1) === '0' && is_writable(self::GEN_OUTPUT_FILE))
        {
            unlink(self::GEN_OUTPUT_FILE);
        }
    }

//    /*
//     *
//     */
//    public function testPostGenerationSetId400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationSetId401()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationSetId404()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationSetId500()
//    {
//    }

    //--------------------------------------------------------//
    // EXECUTING A GENERATION TEMPLATE OBJECT
    //--------------------------------------------------------//
    /*
     *
     */
//    public function testPostGenerationTemplateId201SessionidId()
//    {
//        $this->setResource(
//            self::CONTROLLER . '/template'
//        );
//
//        $this->setupPOST(
//            array(self::SESSIONID_PARAMETER => self::$sessionId,
//            'id' => 'preview/article.tpl')
//        );
//
//        $this->executeRequest();
//
//        $this->validateReturnStatus(201);
//    }

//    /*
//     *
//     */
//    public function testPostGenerationTemplateId400()
//    {
//    }
//
//    /*
//     *
//     */
//    public function testPostGenerationTemplateId401()
//    {
//    }

    /*
     *
     */
//    public function testPostGenerationTemplateIdinvalidId404Sessionid()
//    {
//        $this->setResource(
//            self::CONTROLLER . self::SEPERATOR . 'template/invalid'
//        );
//
//        $this->setupPOST(
//            array(self::SESSIONID_PARAMETER => self::$sessionId)
//        );
//
//        $this->executeRequest();
//    }

//    /*
//     *
//     */
//    public function testPostGenerationTemplateId500()
//    {
//    }

    /////////////////////////////////////////////////////////////////////////////////////////////
    //                                      HELPER METHODS                                     //
    /////////////////////////////////////////////////////////////////////////////////////////////
    /*
     * Create a WCM generation set object
     * 
     * Post-condition: self::$generationSetId will now hold the id of the newly created generationSet
     */
    private function createGenerationSet($generationSet)
    {
        $this->setResource(
            self::CONTROLLER . self::SEPERATOR . self::SET_RESOURCE
        );

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($generationSet)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);

        self::$generationSetId = $this->getId();
        
        self::$idArray[self::GENERATION_SET_BIZ_CLASS][] = self::$generationSetId;
    }
    
	/*
     * Create a WCM generation object
     * 
     * Pre-condition: self::$generationSetId must contain a valid id of a generation set
     * 
     * Post-condition: self::$generationId will now hold the id of the newly created generation
     */
    private function createGeneration($generation)
    {
        $this->assertNotNull(self::$generationSetId, 'Creation of WCM generation object failed: Invalid generationSet id');
        
        // use the id of self::$generationSetId in the generation objects XML structure
        $generation = str_replace(self::ID_PLACE_HOLDER, self::$generationSetId, $generation);

        $this->setResource(self::CONTROLLER);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($generation)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        self::$generationId = $this->getId();

        self::$idArray[self::GENERATION_BIZ_CLASS][] = self::$generationId;
    }
    
	/*
     * Create a WCM generation object
     * 
     * Pre-condition: self::$generationContentId must contain a valid id of a generation object
     * 
     * Post-condition: self::$generationContentId will now hold the id of the newly created generation content object
     */
    private function createGenerationContent($generationContent)
    {
        $this->assertNotNull(self::$generationId, 'Creation of WCM generation content object failed: Invalid generation id');
                
        $generationContent = str_replace(self::ID_PLACE_HOLDER, self::$generationId, $generationContent);

        $this->setResource(self::CONTROLLER . self::SEPERATOR . self::CONTENT_RESOURCE);

        $this->setupPOST(
            array(self::SESSIONID_PARAMETER => self::$sessionId),
            'content=' . urlencode($generationContent)
        );

        $this->executeRequest();

        $this->validateReturnStatus(201);
        
        self::$generationContentId = $this->getId();

        self::$idArray[self::GENERATION_CONTENT_BIZ_CLASS][] = self::$generationContentId;
    }
}