<?php
require_once(dirname(__FILE__) . '/../includes/WcmTest.php');

/*
 * These tests presume that a workflow object with an id of '1' exists(publication workflow)
 * and has the states {draft, submitted, approved, rejected, published, archived}
 * that have wcmWorkFlowTransitions for the states
 *
 * As the reason for this test is to test ReST functionnality, the WCM workflow logic
 * is not fully tested.
 * TODO:Verify everything that gets created gets deleted also
 *
 */
class workflowTest extends WcmTest
{
    /*
     * CONSTANTS
     */
    const WORKFLOW_ID      = 1; // id of the workflow that is used for the tests, this MUST exist and be the publication workflow
    const WORKFLOW_1_SCRIPT_NAME = 'publicationWorkflow.php'; // The name of the workflow script associated with the workflow with an id of 1

    // The REST resource controller
    const RESOURCE = self::WORKFLOW_CONTROLLER; // the resource controller

    // REST Controllers for the resource
    const WORKFLOW_STATE            = 'state'     ;
    const WORKFLOW_TRANSITION       = 'transition';
    const WORKFLOW_SCRIPT           = 'script'    ;

    // Workflow states by code
    const WORKFLOW_STATE_CODE_DRAFT              = 'draft'            ;
    const WORKFLOW_STATE_CODE_APPROVED           = 'approved'         ;
    const WORKFLOW_STATE_CODE_PUBLISHED          = 'published'        ;
    const WORKFLOW_STATE_CODE_ARCHIVED           = 'archived'         ;
    const WORKFLOW_STATE_CODE_REJECTED           = 'rejected'         ;
    const WORKFLOW_STATE_CODE_NEW                = 'new'              ;
    const WORKFLOW_STATE_CODE_SUSPICIOUS         = 'suspicious'       ;
    const WORKFLOW_STATE_CODE_PUBLISHED_MODIFIED = 'publishedModified';

    // Workflow states by id
    const WORKFLOW_STATE_ID_DRAFT              = 1;
    const WORKFLOW_STATE_ID_APPROVED           = 2;
    const WORKFLOW_STATE_ID_PUBLISHED          = 3;
    const WORKFLOW_STATE_ID_ARCHIVED           = 4;
    const WORKFLOW_STATE_ID_REJECTED           = 5;
    const WORKFLOW_STATE_ID_NEW                = 6;
    const WORKFLOW_STATE_ID_SUSPICIOUS         = 7;
    const WORKFLOW_STATE_ID_PUBLISHED_MODIFIED = 8;

    // Workflow transition codes
    const WORKFLOW_TRANS_CODE_PUBLISH   = 'publish'  ; // draft           -> published
    const WORKFLOW_TRANS_CODE_UNPUBLISH = 'unpublish'; // published       -> draft
    const WORKFLOW_TRANS_CODE_ARCHIVE   = 'archive'  ; // published       -> archived
    const WORKFLOW_TRANS_CODE_DEARCHIVE = 'dearchive'; // archived        -> published
    const WORKFLOW_TRANS_CODE_REPUBLISH = 'republish'; // publishModified -> published
    const WORKFLOW_TRANS_CODE_NOTIFY    = 'notify'   ; // new             -> suspicious
    const WORKFLOW_TRANS_CODE_APPROVE   = 'approve'  ; // suspicious      -> approved
    const WORKFLOW_TRANS_CODE_REJECT    = 'reject'   ; // suspicous       -> rejected

    // Workflow transitions by id
    const WORKFLOW_TRANS_ID_PUBLISH   = 1; // draft           -> published
    const WORKFLOW_TRANS_ID_UNPUBLISH = 2; // published       -> draft
    const WORKFLOW_TRANS_ID_ARCHIVE   = 3; // published       -> archived
    const WORKFLOW_TRANS_ID_DEARCHIVE = 4; // archived        -> published
    const WORKFLOW_TRANS_ID_REPUBLISH = 5; // publishModified -> published
    const WORKFLOW_TRANS_ID_NOTIFY    = 6; // new             -> suspicious
    const WORKFLOW_TRANS_ID_APPROVE   = 7; // suspicious      -> approved
    const WORKFLOW_TRANS_ID_REJECT    = 8; // suspicous       -> rejected

    //query string parameter names
    const PARA_STATE_CODE = 'code';
    const PARA_STATE_ID   = 'id'  ;
    const PARA_TRANS_CODE = 'code';
    const PARA_TRANS_ID   = 'id'  ;

    // STATE AND TRANSITION CODES ARRAYS
    // An array of state codes
    private static  $stateCodeArray = array(self::WORKFLOW_STATE_CODE_DRAFT,
                                            self::WORKFLOW_STATE_CODE_APPROVED,
                                            self::WORKFLOW_STATE_CODE_PUBLISHED,
                                            self::WORKFLOW_STATE_CODE_ARCHIVED,
                                            self::WORKFLOW_STATE_CODE_REJECTED ,
                                            self::WORKFLOW_STATE_CODE_NEW,
                                            self::WORKFLOW_STATE_CODE_SUSPICIOUS,
                                            self::WORKFLOW_STATE_CODE_PUBLISHED_MODIFIED);

    // And array of state IDs
    private static  $stateIdArray = array(self::WORKFLOW_STATE_ID_DRAFT,
                                          self::WORKFLOW_STATE_ID_APPROVED,
                                          self::WORKFLOW_STATE_ID_PUBLISHED,
                                          self::WORKFLOW_STATE_ID_ARCHIVED,
                                          self::WORKFLOW_STATE_ID_REJECTED,
                                          self::WORKFLOW_STATE_ID_NEW,
                                          self::WORKFLOW_STATE_ID_SUSPICIOUS,
                                          self::WORKFLOW_STATE_ID_PUBLISHED_MODIFIED);

    // An array of transition ids, the order of the transitions must be valid for the workflow
    private static $transIdArray = array (self::WORKFLOW_TRANS_ID_PUBLISH,
                                          self::WORKFLOW_TRANS_ID_UNPUBLISH,
                                          self::WORKFLOW_TRANS_ID_PUBLISH,
                                          self::WORKFLOW_TRANS_ID_ARCHIVE,
                                          self::WORKFLOW_TRANS_ID_DEARCHIVE);

    // An array of transition codes, the order must be the same as the $transIdArray
    private static $transCodeArray = array (self::WORKFLOW_TRANS_CODE_PUBLISH,
                                            self::WORKFLOW_TRANS_CODE_UNPUBLISH,
                                            self::WORKFLOW_TRANS_CODE_PUBLISH,
                                            self::WORKFLOW_TRANS_CODE_ARCHIVE,
                                            self::WORKFLOW_TRANS_CODE_DEARCHIVE);

    /*
     * setup the enviroment for the tests, called before the series of tests
     */
    public static function setUpBeforeClass()
    {
        parent::setUpBeforeClass();
        self::getSessionId();
    }

    public static function tearDownAfterClass()
    {
        parent::tearDownAfterClass();
    }

    /*
     * setup the enviroment for the tests, called before each test
     */
    protected function setUp()
    {
        parent::setUp();
        $this->setResource(self::RESOURCE);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOWS BY ID
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowId200Sessionid()
    {
        $this->setResource(self::RESOURCE . self::SEPERATOR . self::WORKFLOW_ID);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXml();

        $this->xmlBodyHasId(self::WORKFLOW_ID);
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowId400()
    {
        $this->setResource(self::RESOURCE . self::SEPERATOR . self::WORKFLOW_ID);

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid object Id
     */
    public function testGetWorkflowId404Sessionid()
    {
        // Create a workflow
        $id = $this->createWorkflow();

        // Delete the workflow
        $this->deleteWorkflow($id);

        // Attempt to retrieve the deleted workflow
        $this->setResource(self::RESOURCE . self::SEPERATOR . $id);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW LOCATIONS
    //--------------------------------------------------------//
    /*
     * TODO: where clauses for retrieving workflows
     * Valid request
     */
    public function testGetWorkflow200Sessionid()
    {
        $id = $this->createWorkflow();

        $idArray = array($id, self::WORKFLOW_ID);

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXml();

        //TODO: Test for id 1 and the id of the ccreated workflow; Might be able to do this with a new core function like validateLocationsId($idArray)
        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId)
        );

        $this->deleteWorkflow($id);
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflow400()
    {
        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW STATES
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowStateStatecode200Sessionid()
    {
        //Cycle through all state codes
        foreach (self::$stateCodeArray as $stateCode)
        {
            $this->setResource(
                self::RESOURCE . self::SEPERATOR .
                self::WORKFLOW_STATE . self::SEPERATOR .
                $stateCode
            );

            $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

            $this->executeRequest();

            $this->validateReturnStatus(200);

            $this->validateLocations(
                '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
                urlencode(self::$sessionId)
            );
        }
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowStateStatecode400()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR .
            self::WORKFLOW_STATE . self::SEPERATOR .
            self::WORKFLOW_STATE_CODE_DRAFT
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid workflow state
     */
    public function testGetWorkflowStateInvalid404Sessionid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR .
            self::WORKFLOW_STATE . self::SEPERATOR .
            self::INVALID_PARA_VALUE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW STATE LOCATIONS
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowState200Sessionid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_STATE
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId)
        );
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowState400()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_STATE
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW STATES FOR A SPECIFIC CLASS
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowState200SessionidClassname()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_STATE
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId)
        );
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowState400Classname()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_STATE
        );

        $this->setupGET(
            array(self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS)
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW TRANSITION LOCATIONS
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowTransitionId200Sessionid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION . '/2'
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);
$this->validateBodyIsXML();
        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId)
        );
    }

    public function testGetWorkflowTransitionId200SessionidJson()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION . '/2'
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId, 'json' => 'true'));

        $this->executeRequest();

        $this->validateReturnStatus(200);
$this->validateBodyIsJSON();
//        $this->validateLocations(
//            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
//            urlencode(self::$sessionId)
//        );
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowTransition400()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }
    /*
     * Both Code and Id parameters are passed
     */
    public function testGetWorkflowTransition400SessionidTranscodeinvalidTransidinvalid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER   => self::$sessionId,
                self::PARA_TRANS_CODE       => self::INVALID_PARA_VALUE,
                self::PARA_TRANS_ID         => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW TRANSITION LOCATIONS FOR A SPECIFIC OBJECT
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowTransition200SessionidClassnameObjectid()
    {
        $articleId = $this->createArticle(self::WORKFLOW_STATE_CODE_DRAFT);

        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                self::OBJECT_ID_PARAMETER => $articleId
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateLocations(
            '?' . urlencode(self::SESSIONID_PARAMETER) . '=' .
            urlencode(self::$sessionId)
        );
    }

    /*
     * Invalid class name and object id
     */
    public function testGetWorkflowTransition404SessionidClassnameinvalidObjectidinvalid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupGET(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::INVALID_PARA_VALUE,
                self::OBJECT_ID_PARAMETER => self::INVALID_PARA_VALUE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    //--------------------------------------------------------//
    // RETRIEVING WORKFLOW SCRIPT FILE NAMES
    // TODO: Verify that the script name returned for workflow 1 is the correct one
    //--------------------------------------------------------//
    /*
     * Valid request
     */
    public function testGetWorkflowScript200Sessionid()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_SCRIPT
        );

        $this->setupGET(array(self::SESSIONID_PARAMETER => self::$sessionId));

        $this->executeRequest();

        $this->validateReturnStatus(200);

        $this->validateBodyIsXML();
        //WORKFLOW_1_SCRIPT_NAME
    }

    /*
     * Missing sessionId
     */
    public function testGetWorkflowScript400()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_SCRIPT
        );

        $this->setupGET();

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    //--------------------------------------------------------//
    // EXECUTING A WORKFLOW TRANSITION ON A BIZ OBJECT
    //--------------------------------------------------------//

    /*
     * Valid request with state ids
     */
    public function testPostWorkflowTransition201SessionidClassnameObjectidIdStatecode()
    {
        // Create an article and store its id
        $articleId = $this->createArticle(self::WORKFLOW_STATE_CODE_DRAFT);

        // Transition the article through all states
        foreach (self::$transIdArray as $state)
        {

            $this->setResource(
                self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
            );

            $this->setupPOST(
                array(
                    self::SESSIONID_PARAMETER => self::$sessionId,
                    self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                    self::OBJECT_ID_PARAMETER => $articleId,
                    self::PARA_STATE_ID       => $state
                )
            );

            $this->executeRequest();

            $this->validateReturnStatus(201);
        }
    }

    /*
     * Valid request with state codes
     */
    public function testPostWorkflowTransition201SessionidClassnameObjectidStatecode()
    {
        // Create an article and store its id
        $articleId = $this->createArticle(self::WORKFLOW_STATE_CODE_DRAFT);

        // Transition the article through all states contained in the transition codes array
        foreach (self::$transCodeArray as $state)
        {
            $this->setResource(
                self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
            );

            $this->setupPOST(
                array(
                    self::SESSIONID_PARAMETER => self::$sessionId,
                    self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                    self::OBJECT_ID_PARAMETER => $articleId,
                    self::PARA_STATE_CODE     => $state
                )
            );

            $this->executeRequest();

            $this->validateReturnStatus(201);
        }
    }

    /*
     * Missing parameter
     */
    public function testPostWorkflowTransition400SessionidClassname()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupPOST(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(400);
    }

    /*
     * Invalid class name
     */
    public function testPostWorkflowTransition404SessionidClassnameinvalidStatecode()
    {
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupPOST(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::INVALID_PARA_VALUE,
                self::PARA_STATE_CODE     => self::WORKFLOW_TRANS_CODE_PUBLISH
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(404);
    }

    /*
     * Transition cannot be executed(illegal transition)
     */
    public function testPostWorkflowTransition500SessionidClassnameObjectidIdState()
    {
        // Create an article and store its id
        $articleId = $this->createArticle();

        // Transition it to an illegal state
        $this->setResource(
            self::RESOURCE . self::SEPERATOR . self::WORKFLOW_TRANSITION
        );

        $this->setupPOST(
            array(
                self::SESSIONID_PARAMETER => self::$sessionId,
                self::CLASSNAME_PARAMETER => self::ARTICLE_BIZ_CLASS,
                self::OBJECT_ID_PARAMETER => $articleId,
                self::PARA_STATE_CODE     => self::WORKFLOW_TRANS_CODE_ARCHIVE
            )
        );

        $this->executeRequest();

        $this->validateReturnStatus(500);
    }
}