<?php

require_once(dirname(__FILE__) . '/includes/WcmTest.php');

class ManageTest extends WcmTest
{

    function testCreateModifyDeleteWebuser()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='business']/li[6]//a[contains(@href,'/business/webuser')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $this->type('email', 'email@email.com');
        $this->type('username', 'username');
        $this->type('password', 'password');
        $this->type('firstname', 'Johnny');
        $this->type('lastname', 'Appleseed');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Johnny Appleseed');

        // Modify
        $this->type('firstname', 'Jimmy');
        $this->type('lastname', 'Pumpkinface');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Jimmy Pumpkinface');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteWebsite()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='business']/li[6]//a[contains(@href,'/business/site')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid());
        $this->type('title', 'My Website');
        $this->type('code', $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('My Website');

        // Modify
        $this->type('title', 'Website Modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Website Modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeleteChannel()
    {
        // Goto form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='business']/li[6]//a[contains(@href,'/business/channel')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $uniq = md5(time() . uniqid()); // Title must be unique
        $this->click('tabButton_channel_tabs.properties.channel');
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("title")!=null');
        $this->type('title', 'Section ' . $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("title")!=null');
        $this->assertTextPresent('Section');

        // Modify
        $this->type('title', 'Section Modified ' . $uniq);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Section Modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

    function testCreateModifyDeletePublicationAndIssue()
    {

        // Goto publication form
        $this->login();
        $this->click("//div[@id='navMenu']/ul[@class='business']/li[6]//a[contains(@href,'/business/publication')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error');
        $this->click('id=sysmessage');

        // Save
        $this->type('title', 'My Publication');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('My Publication');

        // Modify
        $this->type('title', 'Publication Modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Publication Modified');

        // Get id for later use
        $tmp = trim($this->getTitle());
        $matches = array();
        preg_match('/#(\d+)$/', $tmp, $matches);
        $this->assertTrue(isset($matches[1]) && filter_var($matches[1], FILTER_VALIDATE_INT));
        $publication_id = $matches[1];

        // Click add Issue button
        $this->assertTrue($this->isTextPresent("Add issue"));
        $this->click("link=Add issue");
        $this->waitForWcmToLoad();
        $this->assertSelectedLabel('publicationId', 'Publication Modified');
        $this->assertSelectedValue('publicationId', $publication_id);

        // Goto issue form
        $this->click("//div[@id='navMenu']/ul[@class='business']/li[6]//a[contains(@href,'/business/issue')]");
        $this->waitForWcmToLoad();

        // Empty values
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForCondition('
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage")!=null &&
            selenium.browserbot.getCurrentWindow().document.getElementById("sysmessage").visible()==true
            '); // Prototype
        $this->waitForTextPresent('regexp:Invalid|Error|Publication name is mandatory');
        $this->click('id=sysmessage');

        // Save
        $this->select('publicationId', "value=$publication_id");
        $this->type('title', 'My Issue');
        $this->type('issueNumber', 123);
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('My Issue');

        // Modify
        $this->type('title', 'Issue Modified');
        $this->click("//div[@id='assetbar']//a[@class='save']");
        $this->waitForWcmToLoad();
        $this->assertTextPresent('Issue Modified');

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

        // Go back to  publication
        $this->open('business/publication/' . $publication_id);
        $this->waitForWcmToLoad();

        // Delete
        $this->click("//div[@id='assetbar']//a[@class='delete']");
        $this->waitForCondition('selenium.browserbot.getCurrentWindow().document.getElementById("modalWindow")!=null');
        $this->assertTextPresent('Delete');
        $this->click('link=Yes');
        $this->waitForWcmToLoad();
        $this->assertTextPresent('<New>');

    }

}