<?php
/**
 * Project:     WCM
 * File:        $Id: biz.chapter.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Definition of a chapter
 */
class chapter extends wcmObject
{
    /**
     * Article Id
     * @var int
     */
    public $articleId;

    /**
     * Chapter rank (in siblings)
     * @var int
     */
    public $rank = 1;

    /**
     * Chapter title
     * @var string
     */
    public $title;

    /**
     * Chapter text (HTML)
     * @var string
     */
    public $text;

    public function __construct($id = null)
    {
        $this->objectType = 'chapter';
        parent::__construct($id);
    }

    /**
     * Returns the database used to store object
     *
     * @return wcmDatabase Database used for storage
     */
    public function getDatabase()
    {
        if (!$this->database)
        {
            // use same DB as article
            $this->database = wcmProject::getInstance()->bizlogic->getBizClassByClassName('article')->getConnector()->getBusinessDatabase();
            $this->tableName = '#__chapter';
        }
        return $this->database;
    }

    /**
     * Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'article':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'articleId=' . $value;
                    break;
            }
        }
        return $sql;
    }

    /**
     * Exposes 'article' to the getAssocArray
     *
     * @param bool $toXML TRUE if method is called in the context of toXML()
     *
     * @return array The chapter's article getAssocArray (or null if orphan)
     */
    function getAssoc_article($toXML = false)
    {
        if ($toXML)
        {
            return null;
        }

        $article = $this->getArticle();
        return ($article) ? $article->getAssocArray($toXML) : null;
    }

    /**
     * Returns the article associated to this chapter
     *
     * @return article The chapter's article (or null if orphan)
     */
    function getArticle()
    {
        $article = wcmObjectFactory::create('article', $this->articleId);
        return ($article->id) ? $article : null;
    }

    /**
     * Deletes object from database
     *
     * @param bool $indexParent TRUE to re-index parent (true by default)
     *
     * @return bool true on success or an error message (string)
     */
    public function delete($indexParent = true)
    {
        $sucess = parent::delete();

        if ($indexParent && $success)
        {
            // Reindex the parent bizobject (article)
            $success = wcmSearch::getInstance()->indexObject($this->getArticle());
        }
        return $success;
    }

    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if (!parent::checkValidity())
        {
            return false;
        }

        if ($this->title  && 255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_CHAPTER_TITLE_TOO_LONG;
            return false;
        }

        return true;
    }
}
