<?php
/**
 * Project:     WCM
 * File:        $Id: biz.photo.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * A photo
 */
class photo extends bizobject
{
    /**
     * site id
     * @var int
     */
    public $siteId;

    /**
     * channel id
     * @var int
     */
    public $channelId;

    /**
     * Title
     * @var string
     */
    public $title;

    /**
     * Caption
     * @var string
     */
    public $caption;

    /**
     * Keywords
     * @var string
     */
    public $keywords;

    /**
     * Credits
     * @var string
     */
    public $credits;

    /**
     * Original filename.
     * @var string
     */
    public $original;

    /**
     * Picture width
     * @var int
     */
    public $width;

    /**
     * Picture height
     * @var int
     */
    public $height;

    /**
     * Publication date
     * @var string
     */
    public $publicationDate;

    /**
     * Expiration date
     * @var string
     */
    public $expirationDate;


    //
    // Printed publication properties
    //

    /**
     * Id of the publication which current article belongs to
     * @var int
     */
    public $publicationId;

    /**
     * Id of the issue which current article belongs to
     * @var int
     */
    public $issueId;

    /*
     * First page number of article (in current issue)
     * @var int
     */
    public $pageNumber;

    /**
     * Article moderation kind - see getModerationKindList()
     * @var string
     */
    public $moderationKind;

    /**
     * Contribution mode - see getContributionStateList()
     * @var string
     */
    public $contributionState;

    /**
     * Array of all saved ratios
     * @var array
     */
    public $ratios;

    /**
     * Set all initial values of an object
     * This method is invoked by the constructor
     */
    protected function setDefaultValues()
    {
        parent::setDefaultValues();

        $this->moderationKind    = 'a_priori';
        $this->contributionState = 'none';
        $this->publicationDate    = null;

        $this->siteId = $this->channelId = $this->publicationId = $this->issueId = null;

        $this->pageNumber = $this->width = $this->height = 0;
        $this->original = null;

        $this->ratios = array();
    }

    /**
     * Unserialize some properties if needed
     * This method is called by nextEnum() and refresh()
     */
    public function unserializeProperties()
    {
        parent::unserializeProperties();
        $this->ratios = ($this->ratios) ? unserialize($this->ratios) : array();
    }

    /**
     * Returns an XML representation of a property
     *
     * @param string $propKey    Property key
     * @param mixed  $propValue  Property value
     * @return string XML string
     */
    protected function propertyToXML($propKey, $propValue)
    {
        // Treat special properties
        if ($propKey == 'ratios')
        {
            $xml = '<ratios />';
            return $xml;
        }
        return parent::propertyToXML($propKey, $propValue);
    }

    /**
     * This function can be used to customize the initialisation of a specific property
     * from a XML node (invoked by initFromXML() method)
     *
     * @param string  $property  Property name to initialize
     * @param XMLNode $node      XML node used for initialization
     */
    protected function initPropertyFromXMLNode($property, $node)
    {
        if ($property == 'ratios')
        {
            $this->ratios = array();
        }
        else
        {
            parent::initPropertyFromXMLNode($property, $node);
        }
    }

    /**
     * This function can be used to customize the initialisation of a
     * specific property from a JSON assoc value (invoked by the
     * initFromJSON method).
     *
     * @param string $property    Property name to initialize
     * @param mixed  $assocValue JSON assoc value used for initialization
     */
    protected function initPropertyFromJSONAssocValue($property, $assocValue)
    {
        if ($property == 'ratios')
        {
            $this->ratios = array();
        }
        else
        {
            parent::initPropertyFromJSONAssocValue($property, $assocValue);
        }
    }

    /**
     * Returns the JSON representation of a property.
     *
     * @param string $propKey    Property key
     * @param mixed  $propValue  Property value
     *
     * @returns string The JSON representation of the property
     */
    protected function propertyToJSON($propKey, $propValue)
    {
        if ($propKey == 'ratios')
        {
            $json = '"ratios":{}';
            return $json;
        }
        return parent::propertyToJSON($propKey, $propValue);
    }

    /**
     * Refresh photo by searching the same 'original' value in WCM
     * This method is used by the importation process
     * @param string $original Original file name
     * @return photo A pointer to this photo or null if photo does not exists (also Id will be set to zero)
     */
    function refreshByOriginal($original)
    {
        $sql = 'SELECT * FROM ' . $this->tableName . ' WHERE original=?';
        $properties = $this->database->getFirstRow($sql, array($original));
        if ($properties)
        {
            bindArrayToObject($properties, $this);
            unset($properties);
            return $this;
        }

        $this->id = 0;
        return null;
    }

    /**
     * CheckIn object in database and update search table
     *
     * @param array $source An assoc array for binding to class vars (or null)
     * @param int    $userId Id of user who is creating or updating the object
     *
     * @return bool true on success, false otherwise
     */
    public function checkin($source = null, $userId = null)
    {
        if (!parent::checkin($source, $userId))
        {
            return false;
        }

        if (!$source)
        {
            $source = $this->getAssocArray(false);
        }

        return true;
    }

    /**
     * Save object in database
     *
     * @param array $source An optional assoc array for binding to class vars (default: null)
     *
     * @return bool True on success, false otherwise
     */
    public function save($source = null, $noWorkflow = false)
    {
        try
        {
            if (is_array($source) && count($source) > 0)
            {
                // Save all ratios and regen pictures
                $cmanager = new croppingManager($this, WCM_BACKOFFICE_CONF_DIR . '/photosratios/default.xml');
                $cmanager->saveRatios($source);
            }
 
            // Save the photo object.
            if (!parent::save($source, $noWorkflow))
            {
                return false;
            }
            
            $photoManagerFactory = new photoManagerFactory();
            $photoManager = $photoManagerFactory->createDefaultPhotoManager();
            
            if (getArrayParameter($source, 'sourcePath'))
            {
                // A new image path is provided, set new image.
                $photoManager->setImage($this, $source['sourcePath']);
            }
            elseif ($photoManager->imageExists($this))
            {
                // If photo has a current image, update the cropping coordinates.
                $photoManager->updateFormats($this);
            }
            return true;
        }
        catch (Exception $e)
        {
            $this->lastErrorMsg = $e->getMessage();
            return false;
            
        }
    }




    /**
     * Created a new bizPhoto based on an HTTP POST uploaded file
     *
     * In order to use this function, you should submit an array that is the same structure
     * as $_FILES. Eg:
     *
     * photo::handleUploadedPhoto($_FILES['myPhoto']);
     *
     * Do not pass JUST $_FILES or this won't work for now.
     *
     * Returns an array with the proper location of the original and thumbnailed photos suitable
     * for database storage, identified by the keys 'original' and 'thumbnail'.
     *
     * @param array $argFile $_FILES['fileyouwantoprocess']
     *
     * @return array Array containg the original and thumbnail locations
     */
    static public function handleUploadedPhoto(Array $argFile)
    {
        $config = wcmConfig::getInstance();
        $fileParts = explode('.', $argFile['name']);
        $ext = array_pop($fileParts);
        $fileNameSansExt = join('.', $fileParts);

        $photosDir = WCM_WWW_BACKOFFICE_DIR . '/system/public/' . $config['wcm.backOffice.photosPath'];
        $destination = $photosDir . $argFile['name'];
        $thumb = $photosDir . $fileNameSansExt . '-vignette.' . $ext;

        move_uploaded_file($argFile['tmp_name'], $destination);

        $img = new wcmImageHelper($destination);
        $img->thumb($thumb, 100, 75);

        return array('original' => $config['wcm.backOffice.photosPath'] . $argFile['name'],
                     'thumbnail' => $config['wcm.backOffice.photosPath'] . $fileNameSansExt . '-vignette.' . $ext);
    }

    /**
     * Expose 'thumbnail' of cropped images to the getAssocArray()
     *
     * @param bool $toXML TRUE when called in the 'toXML' context
     * @return string the Resized photo url (or null)
     */
    public function getAssoc_thumbnail($toXML = false)
    {
        $site = $this->getSite();
        if (null === $site)
        {
            return null;
        }

        $client = new Nstein_Cmf_Mediamanager_Client(
            $site->getConfig('media-manager.rest-url')
        );
        return $client->getCroppedImageUrl($this->id, $site->getConfig('media-manager.defaultThumbnailFormat'));
    }

    /**
     * Computes the sql where clause matching foreign constraints
     * => This method must be overloaded by child class
     *
     * @param array $of Assoc Array with foreign constrains (key=className, value=id)
     *
     * @return string Sql where clause matching "of" constraints or null
     */
    function ofClause($of)
    {
        if (null === $of || !is_array($of))
        {
            return;
        }

        $sql = null;

        foreach ($of as $key => $value)
        {
            switch ($key)
            {
                case 'site':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'siteId=' . $value;
                    break;

                case 'channel':
                    if (null !== $sql)
                    {
                        $sql .= ' AND ';
                    }
                    $sql .= 'channelId=' . $value;
                    break;

                case 'article':
                case 'slideshow':
                    // TODO: override beginEnum to retrieve bizRelation
                    break;
            }
        }
        return $sql;
    }

    /**
     * Gets the 'semantic' text that will be passed to the Text-Mining Engine
     *
     * @return string The semantic text to mine
     */
    public function getSemanticText()
    {
        $content = '';

        if ($this->title)
        {
            $content .= trim($this->title, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->keywords)
        {
            $content .= trim($this->keywords, " \t\n\r\0\x0B.") . ".\n";
        }
        if ($this->caption)
        {
            $content .= trim($this->caption, " \t\n\r\0\x0B.") . ".\n";
        }

        return $content;
    }

    /**
     * Check validity of object
     *
     * A generic method which can (should ?) be overloaded by the child class
     *
     * @return bool true when object is valid
     *
     */
    public function checkValidity()
    {
        if ($this->source && 255 < strlen($this->source))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SOURCE_TOO_LONG;
            return false;
        }

        if ($this->sourceId && 255 < strlen($this->sourceId))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SOURCE_ID_TOO_LONG;
            return false;
        }

        if ($this->sourceVersion && 255 < strlen($this->sourceVersion))
        {
            $this->lastErrorMsg = _BIZ_ERROR_SOURCE_VERSION_TOO_LONG;
            return false;
        }

        if (property_exists($this, 'siteId') && '' == $this->siteId)
        {
            $this->lastErrorMsg = _BIZ_ERROR_SITE_IS_MANDATORY;
            return false;
        }

        if ('' == trim($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_IS_MANDATORY;
            return false;
        }

        if (255 < strlen($this->title))
        {
            $this->lastErrorMsg = _BIZ_ERROR_TITLE_TOO_LONG;
            return false;
        }

        if ($this->credits && 255 < strlen($this->credits))
        {
            $this->lastErrorMsg = _BIZ_ERROR_CREDITS_TOO_LONG;
            return false;
        }

        if ($this->keywords && 255 < strlen($this->keywords))
        {
            $this->lastErrorMsg = _BIZ_ERROR_KEYWORDS_TOO_LONG;
            return false;
        }

        if (property_exists($this, 'publicationDate') && property_exists($this, 'expirationDate'))
        {
            if (('' != $this->publicationDate && '' != $this->expirationDate) &&
                ($this->publicationDate > $this->expirationDate))
            {
                $this->lastErrorMsg = _BIZ_ERROR_EXP_PUB_DATE_FORMAT;
                return false;
            }
        }

        return true;
    }
}
