<?php
/**
 * Project:     WCM
 * File:        $Id: siteConfigProvider.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

class siteConfigProvider
{
    private static $configArrays = array();

    /**
     * Returns configuration filename for the site
     *
     * @param string $siteCode The site code
     *
     * @return String filename
     */
    public static function getFilename($siteCode)
    {
        $configFile = sprintf(
            '%s/sitesConfigs/%s.xml',
            WCM_BACKOFFICE_CONF_DIR,
            $siteCode
        );

        if (file_exists($configFile))
        {
            return $configFile;
        }
        else
        {
            $configFile = sprintf(
                '%s/sitesConfigs/%s.xml',
                WCM_DIR,
                $siteCode
            );

            if (file_exists($configFile))
            {
                return $configFile;
            }
        }

        return null;
    }


    /**
     * This method allow to build an array from multiple XML to feed the siteConfig colass
     *
     * @param string $siteCode The site code
     *
     * @return Array of config
     */
    public static function getArray($siteCode)
    {
        // if the site config has not been cached already, load it
        if (!array_key_exists($siteCode, self::$configArrays))
        {
            $fileName = siteConfigProvider::getFilename($siteCode);
            
            if (null === $fileName)
            {
                return array();
            }

            // Load wcm configuration infos
            $array = wcmConfig::getInstance()->getAssocArray();
            
            // allow only the overwrite of wcm.webSite configs
            $array = $array['wcm']['webSite'];

            $xml = simplexml_load_file($fileName);

            if (isset($xml))
            {
                $array = self::mergeArrays($array, self::xmlToArray($xml));
            }

            // cache the site config
            self::$configArrays[$siteCode] = $array;
        }

        return self::$configArrays[$siteCode];
    }

    /**
     * Transform a XML into an Associative Array
     *
     * @param $xml SimpleXmlElement to convert
     * @return array Representative array for the given xml
     */
    public static function xmlToArray(SimpleXmlElement $xml)
    {
        if ($childrens = $xml->children())
        {
            $array = array();
            $props = array();
            foreach ($childrens as $key => $value)
            {
                if (array_key_exists($key, $props))
                {
                    if (1 == $props[$key]++)
                    {
                        $array[$key] = array($array[$key], self::xmlToArray($value));
                    }
                    else
                    {
                        $array[$key][] = self::xmlToArray($value);
                    }
                }
                else
                {
                    $array[$key] = self::xmlToArray($value);
                    $props[$key] = 1;
                }
            }
            return $array;
        }
        else
        {
            return (string)$xml;
        }
    }

    /**
     * Merge two configuration arrays recursively. When a key is found in
     * the two arrays, the value is overrided by the second array's value only
     * if it is not empty, otherwise the first array's value is used.
     *
     * @param array $a1 The first array.
     * @param array $a2 The second array.
     *
     * @return array The result of the merge.
     */
    public static function mergeArrays(array $a1, array $a2)
    {
        $result = $a1;
        foreach ($a2 as $key => $value)
        {
            if (array_key_exists($key, $result))
            {
                if (is_array($value))
                {
                    $result[$key] = self::mergeArrays($result[$key], $value);
                }
                elseif ('' !== trim($value))
                {
                    $result[$key] = $value;
                }
            }
            else
            {
                $result[$key] = $value;
            }
        }
        return $result;
    }
}
