<?php
/**
 * Project:     WCM
 * File:        $Id: biz.toolbox.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Returns a human-readable label for an object
 * (usually the name of the title property)
 *
 * @param wcmObject $wcmObject
 * @return string Human readable label
 */
function getObjectLabel($wcmObject)
{
    if (!$wcmObject)
    {
        return null;
    }

    if ($wcmObject instanceof webuser)
    {
        return $wcmObject->firstname . ' ' . $wcmObject->lastname;
    }

    if (isset($wcmObject->title))
    {
        return getConst($wcmObject->title);
    }

    if (isset($wcmObject->name))
    {
        return getConst($wcmObject->name);
    }

    // Default label
    return $wcmObject->getType() . ' ' . $wcmObject->id;
}

/**
 * Get class list
 *
 * @return array assoc array, all bizclasses
 */
function getClassList()
{
    $project = wcmProject::getInstance();
    $bizlogic = new wcmBizlogic($project);

    $classList = array();
    foreach ($bizlogic->getBizclasses() as $bizclass)
    {
        $classList[$bizclass->className] = getConst($bizclass->name);
    }
    asort($classList);

    return $classList;
}

/**
* List of all available dates
* @return array Array of available dates
*/
function getDateList()
{
    return array(
        '7'     => _BIZ_NEXT_7_DAYS,
        '3'     => _BIZ_NEXT_3_DAYS,
        '1'     => _BIZ_TOMORROW,
        '0'     => _BIZ_TODAY,
        '-1'    => _BIZ_YESTERDAY,
        '-3'    => _BIZ_LAST_3_DAYS,
        '-7'    => _BIZ_LAST_7_DAYS,
        '-30'   => _BIZ_LAST_MONTH,
        '-365'  => _BIZ_LAST_YEAR
    );
}

/**
* List (assoc array) of moderation kinds
* @return array Kind list as array
*/
function getModerationKindList()
{
    return array(
        'a_priori'     => _BIZ_A_PRIORI,
        'a_posteriori' => _BIZ_A_POSTERIORI,
    );
}

/**
* List contribution states
* @return array Statelist as array
*/
function getContributionStateList()
{
    return array(
        'none'   => _BIZ_CONTRIBUTION_NONE,
        'closed' => _BIZ_CONTRIBUTION_CLOSED,
        'open'   => _BIZ_CONTRIBUTION_OPEN,
    );
}
