<?php
/**
 * Project:     WCM
 * File:        $Id: biz.savedSearchControl.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

/**
 * Saved search control
 */
class savedSearchControl
{
    /**
     * Project object
     * @var wcmProject
     */
    protected $project;

    /**
     * Session object
     * @var wcmSession
     */
    protected $session;

    /**
     * Constructor
     */
    public function __construct()
    {
        $this->session = wcmSession::getInstance();
        $this->project = wcmProject::getInstance();
    }

    /**
     * Get the saved searches in the control
     */
    function getSavedSearches()
    {
        $savedSearches = array();
        $where = 'userId = ' . $this->session->userId;

        $enum = new wcmEnumeration('wcmSavedSearch', $where, 'name');

        foreach ($enum as $search)
        {
            $savedSearches[$search->id] = array('name' => $search->name,
                    'queryString' => $search->queryString,
                    'description' => $search->description);
        }
        return $savedSearches;
    }

    /**
     *
     * Function that lists the current user's saved searches
     * @param string $action Saved search action
     */
    public function initialLoad($action)
    {
        $_SESSION['savedSearchAction'] = $action;

        echo '<h4>' . _BIZ_SEARCHES . '</h4>';
        echo "<select name=\"selectSearches\" id=\"selectSearches\" onChange=\"manageSaveSearch(this.value, '', '', '', '', '', 'searches', '');\">";

        echo '<option value="showSavedSearches" ';
        if ('showSavedSearches' == $action)
        {
            echo 'SELECTED';
        }
        echo '>' . _BIZ_MY_SAVED_SEARCHES . '</option>';

        echo '<option value="showPublicSavedSearches" ';
        if ('showPublicSavedSearches' == $action)
        {
            echo 'SELECTED';
        }
        echo '>' . _SHARED_SAVED_SEARCHES . '</option>';

        echo '<option value="showHistory"';
        if ('showHistory' == $action)
        {
            echo 'SELECTED';
        }
        echo '>' . _BIZ_SEARCH_HISTORY . '</option>';

        echo '</select>';

        echo '<div class="scroll">';
        $this->showSavedSearches($action);
        $this->showHistory($action);
        $this->showPublicSavedSearches($action);
        echo '</div>';

        echo '<ul class="menu">';
        echo '<li><a href="" onclick="_wcmSaveSearch(\'' . _BIZ_SAVE_SEARCH . '\');return false;">' . _BIZ_SAVE . '</a> ' . _BIZ_CURRENT_SEARCH . '</li>';
        echo '</ul>';
    }

    /**
     * Show saved searches
     * @param string $action Action to execute
     */
    public function showSavedSearches($action)
    {
        $where = 'userId = ' . $this->session->userId;

        $enum = new wcmEnumeration('wcmSavedSearch', $where, 'name');
        $config = wcmConfig::getInstance();
        $session = wcmSession::getInstance();

        echo '<ul id="savedSearches" ' . (('showSavedSearches' != $action) ? 'style="display:none;"' : '') . '>';
        foreach ($enum as $search)
        {
            if (in_array($session->userId, (null == $search->showui) ? array() : $search->showui))
            {
                $name = htmlspecialchars($search->name);

                if ($search->queryString)
                {
                    $title = htmlspecialchars($search->queryString);
                }
                else
                {
                    $title = '(' . _BIZ_ALL . ')';
                }
                if ($search->description)
                {
                    $title .= ' - ' . htmlspecialchars($search->description);
                }

                $onClickRemove = "manageSaveSearch('remove', '', '', '', '', " . $search->id . ", 'searches', '')";
                $onClickSearch = "window.location = '" . $config['wcm.backOffice.url'] . 'index.php?' . $search->url . "';";

                echo '<li><a href="#" title="' . _REMOVE . '" class="remove" onClick="' . $onClickRemove . '">';
                echo '<span>' . _BIZ_REMOVE . '</span></a>';
                echo '<a href="#" class="view" onClick="' . $onClickSearch . '" ';
                echo 'title="' . addslashes($title) . '">' . $name . '</a></li>';
            }
        }
        echo '</ul>';
    }

    /**
     * Show public saved searches
     * @param string $action Action to execute
     */
    public function showPublicSavedSearches($action)
    {
        $where = "shared='1' ";

        $config = wcmConfig::getInstance();
        $session = wcmSession::getInstance();

        $enum = new wcmEnumeration('wcmSavedSearch', $where, 'name');

        echo '<ul id="savedSearches" ' . (('showPublicSavedSearches' != $action) ? 'style="display:none;"' : '') . '>';
        foreach ($enum as $search)
        {
            if (in_array($session->userId, (null == $search->showui) ? array() : $search->showui))
            {
                $name = htmlspecialchars($search->name);

                if ($search->queryString)
                {
                    $title = htmlspecialchars($search->queryString);
                }
                else
                {
                    $title = '(' . _BIZ_ALL . ')';
                }
                if ($search->description)
                {
                    $title .= ' - ' . htmlspecialchars($search->description);
                }

                $onClickRemove = "manageSaveSearch('remove', '', '', '', '', " . $search->id . ", 'searches', '')";
                $onClickSearch = "window.location = '" . $config['wcm.backOffice.url'] . 'index.php?' . $search->url . "';";

                echo '<li><a href="#" title="' . _REMOVE . '" class="remove" onClick="' . $onClickRemove . '">';
                echo '<span>' . _BIZ_REMOVE . '</span></a>';
                echo '<a href="#" class="view" onClick="' . $onClickSearch . '" ';
                echo 'title="' . addslashes($title) . '">' . $name . '</a></li>';
            }
        }
        echo '</ul>';
    }

    /**
     * Show search history
     * @param string $action Action to execute
     */
    public function showHistory($action)
    {
        if (isset($_SESSION['searchHistory']) && $_SESSION['searchHistory'])
        {
            echo '<ul ' . (('showHistory' != $action) ? 'style="display:none;"' : '') . '>';
            foreach ($_SESSION['searchHistory'] as $query => $date)
            {
                if ($query)
                {
                    $text = htmlspecialchars($query);
                }
                else
                {
                    $text = '(' . _BIZ_ALL . ')';
                }

                echo '<li>';
                ?>
                <a href="#" onClick="javascript: document.getElementById('search_query').value = '<?php echo addslashes(str_replace('"', '&quot;', $query));?>'; launchSearch();" title="<?php echo $date; ?>" class="view"><?php echo $text; ?></a>
                <?php
                echo '</li>';
            }
            echo '</ul>';
        }
    }

    /**
     * Function that helps to save a search
     *
     * @param string      $name        Search name
     * @param string      $description Search description
     * @param string      $queryString Lucene-syntax query string
     * @param string|null $url         Optional Search URL
     * @param bool        $dashboard   Whether to add search to dashboard
     * @param bool        $shared      Whether the search must be shared
     */
    function saveSearch($name, $description, $queryString, $url = null, $dashboard = false, $shared = false)
    {
        $savedSearch = new wcmSavedSearch();
        $savedSearch->name = $name;
        $savedSearch->description = $description;
        $savedSearch->userId = $this->session->userId;
        $savedSearch->queryString = $queryString;
        $savedSearch->url = $url;
        $savedSearch->dashboard = ('false' == $dashboard) ? 0 : 1;
        $savedSearch->shared = ('false' == $shared) ? 0 : 1;

        $session = wcmSession::getInstance();
        $savedSearch->showui = array($session->userId);

        return $savedSearch->save();
    }

    /**
     * Function that helps deleting a saved search
     *
     * @param int $savedSearchId Saved search ID
     */
    function removeSearch($savedSearchId)
    {
        $savedSearch = new wcmSavedSearch($savedSearchId);
        return $savedSearch->delete();
    }
}
