<?php
/**
 * Project:     WCM
 * File:        $Id: publicationWorkflow.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-business-api
 * @version     4.x
 */

require_once(dirname(__FILE__) . '/base/wcmBaseWorkflowScript.php');

/**
 * This class is a basic publication workflow script that
 * works in conjunction with the standard 'publicationWorkflow'
 * provided in WCM 4 demo web site.
 */
class publicationWorkflow extends wcmBaseWorkflowScript
{
    /**
     * The publication helper.
     * @var publicationHelper
     */
    protected $helper;

    /**
     * Public constructor.
     * @param object $wcmObject The object.
     */
    public function __construct($wcmObject)
    {
        parent::__construct($wcmObject);
        $this->helper = new publicationHelper($this->wcmObject);
    }

    /**
     * This callback is invoked before the object has been deleted
     */
    public function beforeDelete()
    {
        switch ($this->wcmObject->workflowState)
        {
            case 'published':
            case 'publishedModified':
                $this->executeTransition('unpublish');
            default:
                return true;
                break;
        }
    }

    /**
     * This callback is invoked BEFORE the object is published
     * @return bool False to cancel transition.
     */
    public function beforePublish()
    {
        return true;
    }

    /**
     * This callback is invoked AFTER the object has been published
     */
    public function onPublish()
    {
        try
        {
            $this->helper->initializePublicationDate();
            $this->helper->mineObject();
//          $this->helper->nlikeThisIndexObject();
//          $this->helper->publishSqlAliases();
//          $this->helper->indexOn3S();
            return true;
        }
        catch (Exception $e)
        {
            wcmMVC_Action::setError($e->getMessage());
            return false;
        }    
            
    }

    /**
     * This callback is invoked AFTER the object has been published
     */
    public function afterPublish()
    {
        $this->wcmObject->generate();
    }

    /**
     * This callback is invoked before the object has been republished
     */
    public function beforeRepublish()
    {
        return $this->beforePublish();
    }

    /**
     * This callback is invoked AFTER the object has been republished
     */
    public function onRepublish()
    {
        return $this->onPublish();
    }

    /**
     * This callback is invoked AFTER the object has been published
     */
    public function afterRepublish()
    {
        return $this->afterPublish();
    }

    /**
     * This callback is invoked after the object has been saved unpublished.
     *
     */
    public function onUnpublish()
    {
        try
        {
            $this->helper->nlikeThisDeindexObject();
//          $this->helper->unpublishSqlAliases();
            $this->helper->removeGeneratedBlocks();
//          $this->helper->deindexFrom3S();
            return true;
        }
        catch (Exception $e)
        {
            wcmMVC_Action::setError($e->getMessage());
            return false;
        }    
    }

    public function beforeUpdate()
    {
        switch ($this->wcmObject->workflowState)
        {
            case 'published':
                $this->wcmObject->workflowState = 'publishedModified';
                break;
        }
        return true;
    }
}
