<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.ajaxTabs.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class helps to manage dhtml tabs loaded on demand
 * through ajax requests
 */
class wcmAjaxTabs
{
    /**
     * Wait HTML
     * @var string
     */
    private static $wait = null;

    /**
     * Unique ID
     * @var string
     */
    private $guid;

    /**
     * Use cookies?
     * @var bool
     */
    private $useCookies;

    /**
     * Tabs
     * @var array
     */
    private $tabs;

    /**
     * Ajax urls
     * @var array
     */
    private $ajaxURLs;

    /**
     * Tab ACL representation
     * @var wcmTabAcl
     */
    static private $tabAcl;

    /**
     * Constructor
     *
     * @param string $guid Unique id
     * @param bool   $useCookies true to persist selected tab through cookie
     * @param array  $tabs Optional array of assoc array representing each tab
     *                     Excepted keys are 'id, caption, selected, content, ajaxURL'
     *
     */
    public function __construct($guid, $useCookies = 0, $tabs = null)
    {
        $this->guid = $guid;
        $this->useCookies = ($useCookies) ? '1' : '0';
        $this->tabs = (is_array($tabs)) ? $tabs : array();
        $this->ajaxURLs = array();

        if (!isset($this->tabAcl))
        {
            $this->tabAcl = new wcmTabAcl(WCM_CONF_DIR . '/backoffice/acl/tabs.ini');
        }
    }

    /**
     * Add a new tab
     *
     * @param string    $id Tab id used for persistence in cookie
     * @param string    $caption Tab caption
     * @param bool      $selected TRUE to mark this tab as selected
     * @param string    $content Inner content for tab (or null)
     * @param string    $ajaxURL Optional URL used to refresh content (or null)
     * @param array		$relatedTabs Optional list of related tab ids. When the given tab is loaded, the related tabs will be loaded/reloaded as well
     */
    public function addTab($id, $caption, $selected = false, $content = null, $ajaxURL = null, $relatedTabs = array())
    {
        // Add piece of HTML to render when tab is loading...
        if (!self::$wait)
        {
            self::$wait = '<div class="wait">' . _LOADING . '</div>';
        }
        if ($this->tabAcl->isAllowed('current-user', $id))
        {
            $this->tabs[] = array('id' => $id,
                              'caption' => $caption,
                              'selected' => $selected,
                              'content' => ($content != null) ? $content : (($ajaxURL != null) ? self::$wait : null),
                              'ajaxURL' => $ajaxURL,
                              'relatedTabs' => $relatedTabs
            );
        }
    }

    /**
     * Render the HTML code for the tabs
     * @param bool $overwriteCookie Will overwrite cookie if true
     * @param array	$initialTabsToLoad Optional list of initial tab ids. The given tabs and their dependencies will be loaded once the page is loaded.
     */
    public function render($overwriteCookie = false, $initialTabsToLoad = array())
    {
        $session = wcmSession::getInstance();

        // Render html
        echo '<div id="' . $this->guid . '" class="tab-page">';
        foreach ($this->tabs as $tab)
        {
            echo '<div class="tab-page" id="' . $this->guid . '_' . $tab['id'] . '">';

            echo '<h2 class="tab" ' . (($tab['caption'] == _BIZ_TME) ? 'id=semantic-footprint' : '') . '>' . $tab['caption'] . '</h2>';

            echo $tab['content'];
            echo '</div>';
        }
        echo '</div>';

        // Prepare javascript content
        $ajaxArray = null;
        $selectedindexid = null;
        $selected = $index = 0;
        foreach ($this->tabs as $tab)
        {
            $url = getArrayParameter($tab, 'ajaxURL', null);
            if (!$ajaxArray)
            {
                $ajaxArray = ($url) ? "['" . str_replace("'", "\'", $url) . "'" : '[ null';
            }
            else
            {
                $ajaxArray .= ($url) ? ",'" . str_replace("'", "\'", $url) . "'" : ', null';
            }

            if (getArrayParameter($tab, 'selected', false))
            {
                $selectedindexid = $tab['id'];
                $selected = $index;
            }
            $index++;
        }
        if ($ajaxArray)
        {
            $ajaxArray .= ']';
        }
        else
        {
            $ajaxArray = 'null';
        }

        $this->useCookies = $overwriteCookie ? '0' : $this->useCookies;

        // Render javascript
        ?>
        <script type="text/javascript" defer="defer">//<![CDATA
        $WCM.createTabGroup('<?php echo $this->guid; ?>',<?php echo $this->useCookies; ?>, '<?php echo isset($this->tabs[$selected]['id']) ? $this->guid . '_' . $this->tabs[$selected]['id'] : ''; ?>','<?php echo $session->getUser()->id; ?>');

        <?php
        foreach ($this->tabs as $tab)
        { ?>
            $WCM.createTab('<?php echo $this->guid; ?>', '<?php echo $tab['id'];?>','<?php echo $tab['ajaxURL']; ?>', '<?php echo json_encode($tab['relatedTabs']); ?>');
        <?php } ?>

        //Load dependencies of selected tab
        $WCM.loadTabDependencies('<?php echo $this->guid; ?>', '<?php echo $selectedindexid;?>');//Load initial tabs and their dependencies
        <?php
        foreach ($initialTabsToLoad as $tabid)
        { ?>
            $WCM.reloadspecifictab('<?php echo $this->guid; ?>','<?php echo $tabid ?>');
            $WCM.loadTabDependencies('<?php echo $this->guid; ?>', '<?php echo $tabid ?>');
        <?php } /* endforeach */ ?>

        //]]>
        </script>
        <?php
    }
}
