<?php
/**
 * Project:     WCM
 * File:        $Id: initApi.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */
// preload constants and toolbox
DEFINE('AUTOLOAD_SAVE_PATH', sys_get_temp_dir());

require_once(WCM_SYS_API_DIR . '/languages/constants.php');
require_once(WCM_SYS_API_DIR . '/toolbox/toolbox.php');
require_once(WCM_INCLUDES_DIR . '/autoloadManager/autoloadManager.php');

autoloadManager::addFolder(WCM_SYS_API_DIR);
autoloadManager::addFolder(WCM_INCLUDES_DIR . '/debugBar');
autoloadManager::addFolder(WCM_INCLUDES_DIR . '/Nstein');

// Register autoload
spl_autoload_register('_wcm_autoload');

/**
 * Remember classes paths in a global array to
 * facilitate dynamic autoload
 *
 * @param $className string Name of the class to load
 */
function _wcm_autoload($classToLoad)
{
    // Handle Zend class
    if (substr($classToLoad, 0, 5) == 'Zend_')
    {
        _wcm_zend_autoload($classToLoad);
        return;
    }

    // Handle Solr PHP Client class
    if (substr($classToLoad, 0, 12) == 'Apache_Solr_')
    {
        _wcm_apache_solr_autoload($classToLoad);
        return;
    }

    // Handle Stomp client class
    if (substr($classToLoad, 0, 5) == 'Stomp')
    {
        _wcm_stomp_autoload($classToLoad);
        return;
    }

    // Handle Smarty class
    if (substr($classToLoad, 0, 6) == 'Smarty')
    {
        _wcm_smarty_autoload($classToLoad);
        return;
    }

    // Include auto-load file
    autoloadManager::loadClass($classToLoad);
}


/**
 * Autoload a zend class
 * @param string $classToLoad Class to load
 */
function _wcm_zend_autoload($classToLoad)
{
    // Zend classes follow a pattern such as Zend_[a-z]+_[a-z]+_[a-z]+
    $parts = explode('_', $classToLoad);

    // Last part is the filename, other parts are directory names
    $filename = array_pop($parts);
    $path = (count($parts)) ? join(DIRECTORY_SEPARATOR, $parts) . DIRECTORY_SEPARATOR : '';

    require_once WCM_INCLUDES_DIR . DIRECTORY_SEPARATOR . $path . $filename . '.php';
}

/**
 * Autoload an apache/solr class
 * @param string $classToLoad Class to load
 */
function _wcm_apache_solr_autoload($classToLoad)
{
    // Zend classes follow a pattern such as Zend_[a-z]+_[a-z]+_[a-z]+
    $parts = explode('_', $classToLoad);

    // Last part is the filename, other parts are directory names
    $filename = array_pop($parts);
    $path = (count($parts)) ? join(DIRECTORY_SEPARATOR, $parts) . DIRECTORY_SEPARATOR : '';

    require_once APACHE_SOLR_DIR . DIRECTORY_SEPARATOR . $path . $filename . '.php';
}

/**
 * Autoload a stomp class
 * @param string $classToLoad Class to load
 */
function _wcm_stomp_autoload($classToLoad)
{
    // Stomp classes follow a pattern such as Stomp_[a-z]+_[a-z]+_[a-z]+
    $parts = explode('_', $classToLoad);

    // Last part is the filename, other parts are directory names
    $filename = array_pop($parts);
    $path = (count($parts)) ? join(DIRECTORY_SEPARATOR, $parts) . DIRECTORY_SEPARATOR : '';

    require_once STOMP_DIR . DIRECTORY_SEPARATOR . $path . $filename . '.php';
}

/**
* Autoload a Smarty class
* @param string $classToLoad Class to load 
*/
function _wcm_smarty_autoload($classToLoad)
{
    
    // define absolute path to Smarty directory in case is not already defined
    if (!defined('SMARTY_DIR'))
    {
        define('SMARTY_DIR', WCM_INCLUDES_DIR . '/Smarty/');
    }

    // Smarty classes follow a pattern such as Smarty(_)*[a-z]+.class.php
    require_once SMARTY_DIR . $classToLoad . '.class.php';
}
