<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.enumerable.php 9387 2010-04-06 19:48:13Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This interface describe a common enumerable object
 */
interface wcmEnumerable
{
    /**
     * Initialize and starts a new enumeration on current object
     *
     * @param string $where     Optional where clause
     * @param string $orderby   Optional order clause
     * @param int    $offset    Optional offset of first row (default is zero)
     * @param int    $limit     Optional maximum number of returned rows (default is zero which means return all rows)
     * @param array $of        Optional assoc Array with foreign constrain (key=className, value=id)
     *
     * @return bool  True on success, false on failure
     */
    public function beginEnum($where = null, $orderby = null, $offset = 0, $limit = 0, $of = null);

    /**
     * Stops current enumeration
     */
    public function endEnum();

    /**
     * Moves to the next item of current enumeration
     *
     * @return bool True if enumeration has succeed, false otherwise
     */
    public function nextEnum();

    /**
     * Returns the total number of objects which can be enumerated (regardless of the
     * offset and limit parameters passed in the {@link beginEnum()} method)
     *
     * @return int Total number of enumerable objects
     */
    public function enumCount();
}

