<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.zip.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * This class is used to zip folders content
 */
class wcmZip
{
    /**
     * Zip archive object
     * @var ZipArchive
     */
    protected $zip;

    /**
     * Root of the files to zip
     * @var string
     */
    protected $root;

    /**
     * Names to ignore
     * @var array
     */
    protected $ignored_names;

    /**
     * Constructor
     *
     * @param string $file      File to create
     * @param string $folder    Path of folder to zip
     * @param mixed $ignored    Ignored files (a string or an array of string) or null
     * @param mixed $ignoredext Ignored extensions (a string or an array of string) or null
     * @throws Exception
     */
    function __construct($file, $folder, $ignored=null, $ignoredext=null)
    {

        $this->zip = new ZipArchive();
        $this->ignored_names = is_array($ignored) ? $ignored : $ignored ? array($ignored) : array();
        $this->ignored_extensions = is_array($ignoredext) ? $ignoredext : $ignoredext ? array($ignoredext) : array();

        if ($this->zip->open($file, ZIPARCHIVE::CREATE) !== true)
        {
            throw new Exception('cannot open <' . $file . '>' . PHP_EOL);
        }
        $folder = substr($folder, -1) == '/' ? substr($folder, 0, strlen($folder)-1) : $folder;

        if (strstr($folder, '/'))
        {
            $this->root = substr($folder, 0, strrpos($folder, '/')+1);
            $folder = substr($folder, strrpos($folder, '/')+1);
        }
        $this->zip($folder);
        $this->zip->close();
    }

    /**
     * Recursive zip
     *
     * @param string $folder Path of folder to zip
     * @param string $parent Parent path
     */
    private function zip($folder, $parent=null)
    {
        $full_path = $this->root . $parent . $folder;
        $zip_path = $parent . $folder;
        $this->zip->addEmptyDir($zip_path);
        $dir = new DirectoryIterator($full_path);

        foreach ($dir as $file)
        {
            if (!$file->isDot())
            {
                $filename = $file->getFilename();
                $extension = explode('.', $file->getFilename());
                $extension = $extension[count($extension)-1];

                if (!in_array($filename, $this->ignored_names) && !in_array($extension, $this->ignored_extensions))
                {
                    if ($file->isDir())
                    {
                        $this->zip($filename, $zip_path . '/');
                    }
                    else
                    {
                        $this->zip->addFile($full_path . '/' . $filename, $zip_path . '/' . $filename);
                    }
                }
            }
        }
    }
}
