<?php
/**
 * Project:     WCM
 * File:        $Id: wcm.IWorkflowScript.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-system-api
 * @version     4.x
 */

/**
 * The wcmIWorkflowScript defines the methods required for any user
 * defined workflow script.
 */
interface wcmIWorkflowScript
{
    /**
     * Construct the workflow script
     *
     * @param wcmObject $wcmObject Related wcmObject
     */
    function __construct($wcmObject);

    /**
     * This callback is invoked BEFORE an object is created
     * If this function return false, the operation will be canceled!
     *
     * @return bool FALSE to cancel creation
     */
    public function beforeCreate();

    /**
     * This callback is invoked AFTER the object has been created
     */
    public function afterCreate();

    /**
     * This callback is invoked BEFORE the object is updated
     * If this function return false, the operation will be canceled!
     *
     * @return bool FALSE to cancel creation
     */
    public function beforeUpdate();

    /**
     * This callback is invoked AFTER the object has been updated
     */
    public function afterUpdate();

    /**
     * This callback is invoked AFTER the object has been deleted
     */
    public function beforeDelete();

    /**
     * This callback is invoked AFTER the object has been deleted
     */
    public function afterDelete();

    /**
     * This callback is invoked BEFORE a generic transition is execute
     * and ONLY IF the dedicated function was not provided.
     *
     * For instance, when executing a transition with code 'Publish', WCM
     * will search for 'beforePublish()' method. If not found, beforeTransition()
     * will by called.
     *
     * @param wcmWorkflowTransition $transition The transition to execute
     *
     * @return bool FALSE to cancel transition
     */
    public function beforeTransition(wcmWorkflowTransition $transition);

    /**
     * This callback is invoked AFTER a generic transition has been executed
     * (means that the state has been changed) but BEFORE the object has been saved.
     * Also, the callback will be execute ONLY IF the dedicated function was not provided.
     *
     * For instance, when executing a transition with code 'Publish', WCM
     * will search for 'onPublish()' method. If not found, onTransition()
     * will by called.
     *
     * IMPORTANT: if this method raise an exception the transition will be canceled,
     * and the object will returned to its previous state without beeing saved.
     *
     * @param wcmWorkflowTransition $transition The transition to execute
     */
    public function onTransition(wcmWorkflowTransition $transition);

    /**
     * This callback is invoked AFTER a generic transition has been executed.
     * (means that the state has been changed and saved).
     * Also, the callback will be execute ONLY IF the dedicated function was not provided.
     *
     * For instance when executing a transition with code 'Publish', WCM
     * will search for 'afterPublish()' method. If not found, afterTransition()
     * will be called.
     *
     * @param wcmWorkflowTransition $transition The transition to execute
     */
    public function afterTransition(wcmWorkflowTransition $transition);
}
