<?php
/**
 * Project:     WCM
 * File:        indexer.php
 *
 * @copyright   (c)2008 Nstein Technologies
 * @package     WCM
 * @version     4.x
 *
 */

###
# WCM v4.x - (c) Nstein 2008,2009
#
# Mass indexer for vBulletin
###


##############################################################################
# Setup the UI stuff here
##############################################################################

$spinner[1] = '-';
$spinner[2] = '\\';
$spinner[3] = '|';
$spinner[4] = '/';

$spinnerKey = 0;

$totalDots = 40;


global $spinnerKey, $spinner;

/**
 * New line
 * @param string $argLine Prefix to new line
 */
function nl($argLine = null)
{
    echo $argLine . PHP_EOL;
}

/**
 * Prints a line
 * @param string $argLine Output
 */
function line($argLine)
{
    esc('2K');
    echo spinner() . ' ' . $argLine;
}

/**
 * Prints escape character + value
 * @param string $value Value to output
 */
function esc($value)
{
    echo chr(27) . '[' . $value;
}

/**
 * Get a spinner key
 * @return int Spinner key
 */
function spinner()
{
    global $spinnerKey, $spinner;
    $spinnerKey++;
    if ($spinnerKey == 5)
    {
        $spinnerKey = 1;
    }

    return $spinner[$spinnerKey];
}

/**
 * Echo the usage help
 */
function help()
{

    $help = <<<HELP
        Usage: php indexer.php [args]
        You must specify the location of the wcm.restForPlugins.php file as well as
        the database configuration. From there, this indexer will use the plugin
        configuration created in vBulletin to do proper indexing.

        Required Arguments:
        --dbhost         Database host
        --dbname         Name of the database
        --dbuser         Database username
        --dbpass         Database password
        --client         Location to the wcm.restForPlugins.php file.
        --url            Location of your vBulletin forum

        Additional Arguments:
        --table-prefix   If you setup vBulletin with a table prefix, specify that
        prefix here
        --help           This help page

HELP;

    echo $help . PHP_EOL;
    die;

}

/*****************************************************************************
* Process supplied arguments here
*****************************************************************************/

$validArgs[] = 'client';
$validArgs[] = 'dbhost';
$validArgs[] = 'dbname';
$validArgs[] = 'table-prefix';
$validArgs[] = 'dbuser';
$validArgs[] = 'dbpass';
$validArgs[] = 'help';
$validArgs[] = 'url';

$reqArgs['client'] = 1;
$reqArgs['dbhost'] = 1;
$reqArgs['dbuser'] = 1;
$reqArgs['dbpass'] = 1;
$reqArgs['dbname'] = 1;
$reqArgs['url'] = 1;

array_shift($argv);

if (count($argv) < 1)
{
    help();
}

foreach ($argv as $arg)
{
    if (substr($arg, 0, 2) != '--')
    {
        help();
        break;
    }

    $parts = explode('=', $arg);
    $argName = substr($parts[0], 2, strlen($parts[0]));

    if (!in_array($argName, $validArgs))
    {
        help();
        break;
    }

    $args[$argName] = $parts[1];
}

foreach ($args as $argName => $value)
{
    if (isset($reqArgs[$argName]))
    {
        unset($reqArgs[$argName]);
    }
}

if (count($reqArgs) > 0)
{
    help();
}

if (isset($args['help']))
{
    help();
}


###############################################################################
# Setup the screen
###############################################################################


$header = <<<HEADER

WCM v4.1 - (c) Nstein Inc 2009
Mass indexer for vBulletin

-- STATUS --
HEADER;

echo $header . "\n";

$file = $args['client'] . '/wcm.restForPlugins.php';
if (!file_exists($file))
{
    die(nl('REST Client not found'));
}
require_once($file);

nl('Connecting to database');


if (!@mysql_connect($args['dbhost'], $args['dbuser'], $args['dbpass']))
{
    nl(mysql_error());
    die;
}

nl('Selecting database');
if (!mysql_select_db($args['dbname']))
{
    nl(mysql_error());
    die;
}

nl('Fetching configuration');
$query = 'SELECT opt_name, opt_value FROM wcm_setup';
$res = mysql_query($query);
if (!$res)
{
    nl(mysql_error());
    die;
}
while ($row = mysql_fetch_assoc($res))
{
    $vbOptions[$row['opt_name']] = $row['opt_value'];
}
$tbl = (isset($args['table-prefix'])) ? $args['table-prefix'] . '_' : '';



nl('Calculating Total');
    $query = '
SELECT COUNT(threadid)
    FROM ' . $tbl . 'thread AS vbthread, wcm_maps, ' . $tbl . 'user AS vbuser, ' . $tbl . 'usergroup AS vbgroup, wcm_groups
    WHERE vbthread.forumid=wcm_maps.forum_id
    AND vbuser.userid=vbthread.postuserid
    AND vbgroup.usergroupid=vbuser.usergroupid
    AND vbgroup.usergroupid=wcm_groups.group_id
    AND wcm_maps.indexing=1';

    $sql = mysql_query($query);
if (!$sql)
{
    nl(mysql_error());
    die;
}

$row = mysql_fetch_row($sql);
$totalPosts = $row[0];

nl('TOTAL: ' . $totalPosts);
nl();

echo '[' . str_repeat(' ', $totalDots) . ']';

$masterQuery = '
SELECT IF(wcm_maps.site_id <> 0,wcm_maps.site_id, wcm_setup.opt_value) AS site_id,
       vbthread.threadid AS threadid, vbthread.title AS title,vbthread.firstpostid AS firstpost, vbpost.pagetext
       FROM ' . $tbl . 'thread AS vbthread, ' . $tbl . 'post AS vbpost, wcm_setup, wcm_maps, ' . $tbl . 'user AS vbuser, ' . $tbl . 'usergroup AS vbusergroup, wcm_groups
       WHERE wcm_setup.opt_name=\'wcm-site-id\'
       AND vbthread.forumid=wcm_maps.forum_id
       AND vbpost.postid=vbthread.firstpostid
       AND wcm_maps.indexing = 1
       AND vbuser.userid = vbpost.userid
       AND vbusergroup.usergroupid = vbuser.usergroupid
       AND vbusergroup.usergroupid = wcm_groups.group_id
       ';

       $sql = mysql_query($masterQuery);
if (!$sql)
{
    nl(mysql_error());
    die;
}

$currentPost = 0;
$rest = new wcmRestForPlugins($vbOptions['wcm-url'], $vbOptions['wcm-username'], $vbOptions['wcm-password']);

while ($row = mysql_fetch_assoc($sql))
{

    esc('1A');
    esc('K');
    esc('1K');
    echo spinner() . ' Fetching: ' . $row['title'];



    $data['title'] = $row['title'];
    $data['text'] = $row['pagetext'];
    $data['location'] = $args['url'] . '/showthread.php?t=' . $row['threadid'];
    $data['source'] = $vbOptions['wcm-sourceName'];
    $data['sourceId'] = $row['threadid'];
    $data['siteId'] = $row['site_id'];

    esc('1K');
    esc('1000D');
    echo spinner() . ' Making XML: ' . $row['title'];

    $xml = '<item>';
    foreach ($data as $key => $value)
    {
        $xml .= '<' . $key . '>' . $value . '</' . $key . '>';
    }
    $xml .= '</item>';

    esc('1K');
    esc('1000D');
    echo spinner() . ' Sending: ' . $row['title'];
    if ($rest->sendMessage('/rest/content/item', 'post', array('content' => $xml), false))
    {
        $currentPost++;
        $percent = $currentPost / $totalPosts;
        $dots = ceil($totalDots * $percent);
        $space = $totalDots - $dots;
        esc('1B');
        esc('2K');
        esc('1000D');
        echo '[' . str_repeat('.', $dots) . str_repeat(' ', $space) . ']';
    }
    else
    {
        nl();
        nl();
        nl('Something failed with rest');
        die;
    }
}

echo "\n\n -- Done!\n";


