<?php
/**
 * Project:     WCM
 * File:        $Id$
 *
 * @copyright   (c)2010 Nstein Technologies
 * @version     4.x
 * @package     Indexation script
 */

/**
 * Indexation script for v4
 */
$HELP = <<<EOH
Usage: php {$_SERVER['argv'][0]} [className1 [className2 [...]]] [-v] [-s] [-h] [-a]
-a, --all                 index all objects
-l, --list                list all objects
-v, --verbose             enable verbose mode
-s, --stats               display complete stats
-h, --help                print a summary of the options
-o, --offset              offset
-l, --limit               limit

EOH;

require(dirname(__FILE__) . '/../../initWcmApi.php');
require('wcm.cli.php');

$offset     = 0;
$limit      = 0;
$worker     = false;
$verbose    = false;
$showStats  = false;
$classes    = array();

$search = wcmSearch::getInstance();
// Launch purge process?

if ($_SERVER['argc'] <= 1)
{
    die($HELP);
}

for ($i = 1 ; $i < $_SERVER['argc'] ; $i++)
{
    switch ($_SERVER['argv'][$i])
    {
        case '-h':
        case '--help':
            die($HELP);
        case '-a':
        case '--all':
            $classes = array_keys(getClassList());
            break;
        case '-l':
        case '--list':
            die('List of indexable objects :' . PHP_EOL . implode(PHP_EOL . "\t - ", array_keys(getClassList())) . PHP_EOL);

            break;
        case '-v':
        case '--verbose':
            $verbose = true;
            break;
        case '-s':
        case '--stats':
            $showStats = true;
            break;
        case '-o':
        case '--offset':
            $offset = $_SERVER['argv'][++$i];
            break;
        case '-l':
        case '--limit':
            $limit = $_SERVER['argv'][++$i];
            break;
        case '-w':
        case '--worker':
            $worker = true;
            break;
        default:
            $classes[] = $_SERVER['argv'][$i];
            break;
    }
}

$stats = array();
if (!$worker)
{
    echo PHP_EOL . 'Starting indexation' . PHP_EOL;
}

foreach ($classes as $className)
{
    if (!class_exists($className))
    {
        continue;
    }

    $stats[$className]['errors'] = array();
    $stats[$className]['count'] = 0;
    $startTime = microtime(true);

    if (!$worker) 
    {
        echo 'Indexing ' . $className . '...' . PHP_EOL;
        // Reindex all implies removing previously indexed content
        $search->deindexObjects($className);
    }

    $enum = new wcmEnumeration($className, null, null, $offset, $limit);
    $count = count($enum);

    foreach($enum as $bizobject)
    {
        $ok = $search->indexObject($bizobject);
        $stats[$className]['count'] = $stats[$className]['count'] +  1;
        
        if (!$worker)
        {
            if ($verbose)
            {
                echo wcmCli::clearLine();
                echo "\t" . $className . ' ' . $bizobject->id .  wcmCli::displayState($ok);
            }
            echo wcmCli::displayProgress(round(($stats[$className]['count'] / $count) * 100));

        }
        if (!$ok)
        {
            $stats[$className]['errors'][] = $bizobject->id;
        }
    }

    if (!$worker)
    {
        echo PHP_EOL . PHP_EOL;
    }
    $stats[$className]['time'] = microtime(true) - $startTime;
}
if ($worker)
{
    die(serialize($stats));
} 

if (!$showStats)
{
    die();
}


$totalTime = 0;
$totalError = 0;


foreach ($stats as $className => $stat)
{

    echo PHP_EOL . 'Stats for ' . $className . PHP_EOL;
    $totalError += ($errors = count($stat['errors']));
    echo PHP_EOL . "\tIndexed Objects : " . ($stat['count'] - $errors) . '/' . $stat['count'] . PHP_EOL;
    if ($errors)
    {
        echo "\tErrors = " . implode($stat['errors'], ',') . PHP_EOL;
    }
    echo "\tProcessing time : " . $stat['time'] . PHP_EOL;
    $totalTime += $stat['time'];
}

echo PHP_EOL . 'Total errors : ' . ($totalError ? wcmCli::COLOR_RED : wcmCli::COLOR_GREEN) . $totalError . wcmCli::COLOR_NORMAL . PHP_EOL;
echo 'Total indexing time ' . $totalTime . PHP_EOL . PHP_EOL;
