<?php
/**
 * Project:     WCM
 * File:        tools/indexation.php
 *
 * @copyright   (c)2008 Nstein Technologies
 * @package     WCM
 * @version     4.x
 *
 */

/**
 * Class for Nice CLI
 */
class wcmCli
{
    /**
     * Green color
     */
    const COLOR_GREEN   = "\033[1;32m";

    /**
     * Red color
     */
    const COLOR_RED     = "\033[1;31m";

    /**
     * Normal color
     */
    const COLOR_NORMAL  = "\033[0;39m";

    /**
     * End position
     */
    const POS_END       = "\033[60G";

    /**
     * Start position
     */
    const POS_START     = "\033[0G";

    /**
     * Ok message
     */
    const OK            = '  OK  ';

    /**
     * Failed message
     */
    const FAILED        = 'FAILED';

    /**
     * Progress bar width
     */
    const PROGRESS_WIDTH = 65;

    /**
     * Screen width
     */
    const SCREEN_WIDTH   = 80;

    /**
     * Display state of indexation
     * @param string $state State to display
     * @return string Output
     */
    public static function displayState($state)
    {
        $output  = self::POS_END . '[';
        $output .= ($state === true) ?  self::COLOR_GREEN . self::OK : self::COLOR_RED . self::FAILED;
        $output .= self::COLOR_NORMAL . ']' . PHP_EOL;
        return $output;
    }

    /**
     * Display progress
     * @param int $pourcentage Percentage of progress completed
     * @return string Output
     */
    public static function displayProgress($pourcentage)
    {
        static $steps = array('|', '/', '-', '\\');
        static $step = 0;
        $output  = self::POS_START;
        $output .= '[' ;

        $output .= str_pad('', (int)($pourcentage * self::PROGRESS_WIDTH / 100), '=');
        $output .= str_pad('', self::PROGRESS_WIDTH - (int)($pourcentage * self::PROGRESS_WIDTH / 100), ' ');

        $output .= '] ';

        $step = ($step+1)%count($steps);
        $output .= $steps[$step] . ' ' . str_pad((int)$pourcentage, 3, ' ', STR_PAD_LEFT) . '%';
        return $output ;
    }

    /**
     * Clear the line
     * @return string Output
     */
    public static function clearLine()
    {
        return self::POS_START . str_pad('', self::SCREEN_WIDTH, ' ') . self::POS_START;
    }
}
