<?php
/**
 * Project:     WCM
 * File:        $Id: generationContent.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */


/**
 * This class implements the action controller for the generationContent page
 */
class wcmGenerationContentAction extends wcmMVC_SysAction
{

    /**
     * afterSave is called by onCheckin and onSave after storing the sysobject
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function afterSave($session, $project)
    {
		// remove current autogens
		$this->deleteAutogens($this->context->id);

        if ($autogens = json_decode(getArrayParameter($_REQUEST, 'autogens', '')))
		{
        	foreach ($autogens as $objectClass => $priority)
        	{
        	    $wcmAutogen = new wcmGenerationAutogen();
        	    $wcmAutogen->generationContentId = $this->context->id;
        	    $wcmAutogen->objectClass = $objectClass;
        	    $wcmAutogen->priority = $priority;
        	    $wcmAutogen->save();
        	}
		}

        wcmMVC_Action::refreshTree();
    }	

    /**
     * overrites the delete function to delete the autogens related
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function onDelete($session, $project)
    {
        $this->deleteAutogens($this->context->id);

        parent::onDelete($session, $project);
    }

    /**
     * Method used to delete generationContentAutogens related to the generationContentId.
     *
     * @param  mixed  $generationContentId
     *
     * @return (boolean) true if delete succeed / false otherwise.
     */
    private function deleteAutogens($generationContentId)
    {
        $wcmAutogen = new wcmGenerationAutogen();
        return $wcmAutogen->deleteByGenerationContentId($this->context->id);
    }

    /**
     * afterDelete is called by onDelete after deleting the sysobject
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function afterDelete($session, $project)
    {
        wcmMVC_Action::refreshTree();
    }

    /**
     * Instanciate context (usually a wcmObject)
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function setContext($session, $project)
    {
        parent::setContext($session, $project);

        // Set default generationId if given in $_REQUEST
        if ($this->context->id == 0)
        {
            $this->context->generationId = getArrayParameter($_REQUEST, 'generationId', null);
        }
    }
}
