<?php
/**
 * Project:     WCM
 * File:        $Id: user.php 9341 2010-03-26 19:47:48Z charronp $
 *
 * @copyright   (c)2010 Nstein Technologies
 * @package     wcm-www-backoffice
 * @version     4.x
 */


/**
 * This class implements the action controller for the user page
 */
class wcmUserAction extends wcmMVC_SysAction
{
    /**
     * Set new groups before save
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function beforeSave($session, $project)
    {
        parent::beforeSave($session, $project);
        // Set new groups
        $groups = array();
        if (isset($_REQUEST['_groups']))
        {
            foreach ($_REQUEST['_groups'] as $id => $active)
            {
                if ($active)
                {
                    $groups[] = $id;
                }
            }
        }
        $this->context->setGroups($groups);
    }
    /**
     * onSave
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function onSave($session, $project)
    {
        if (isset($_REQUEST['optionalEmails']))
        {
            $_REQUEST['optionalEmails'] = explode('|', $_REQUEST['optionalEmails']);
        }
        $this->beforeSave($session, $project);

        // Add statistics
        $session->addStat(wcmSession::STAT_SAVE_OBJECT, $this->context);

        $db = $project->database;

        // Create a new version?
        if (isset($_REQUEST['_comment']))
        {
            $this->onCreateVersion($session, $project);
        }

        $obj = self::getContext();

        $result = parent::onSave($session, $project);

        // Redirect to 'view' URL
        $this->redirect(self::computeObjectURL($this->context->getClass(), $this->context->id));

        return $result;
    }

    /**
     * afterSave is called by onCheckin and onSave after storing the sysobject
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function afterSave($session, $project)
    {
        $db = $project->database;
        $obj = self::getContext();

        if (isset($_REQUEST['openid_resources']) && (0 < $obj->id))
        {
            $openid_resources = ($_REQUEST['openid_resources'] != '') ? explode('|', $_REQUEST['openid_resources']) : array();

            //delete all resources
            $query = 'DELETE FROM wcm_openid WHERE user_id=?';
            if (-1 == $db->executeStatement($query, array($obj->id)))
            {
                wcmMVC_Action::setError(_BIZ_ERROR . $db->getErrorMsg());
                return;
            }
            //add the ones specified in the openid's list field
            $query = 'INSERT INTO wcm_openid (user_id,openid) VALUES (?,?)';
            foreach ($openid_resources as $openid)
            {
                // Check if openid is already in use

                $searchQuery = 'SELECT COUNT(id) FROM wcm_openid WHERE openid=?';
                $records = $db->executeScalar($searchQuery, array($openid));

                if (0 < $records)
                {
                    wcmMVC_Action::setError(_OPENID_IN_USE . ': ' . $openid);
                    return;
                }
                else
                {
                    if (-1 == $db->executeStatement($query, array($obj->id, $openid)))
                    {
                        wcmMVC_Action::setError(_BIZ_ERROR . $db->getErrorMsg());
                        return;
                    }
                }
            }
        }

        wcmMVC_Action::refreshTree();
    }

    /**
     * afterDelete is called by onDelete after deleting the sysobject
     *
     * @param wcmSession $session Current session
     * @param wcmProject $project Current project
     */
    protected function afterDelete($session, $project)
    {
        $db = $project->database;
        $query = 'DELETE FROM wcm_openid WHERE user_id=?';
        $db->executeStatement($query, array($this->context->id));
        wcmMVC_Action::refreshTree();
    }
}
