/**
 * 
 * Context object should contain various information about front end related things
 * 
 * 1) Full URL of the window
 * 2) State of Help
 *    i.: windowed or not
 *    ii.: active or not
 *    iii.: what is it displaying?
 * 3) Tabs
 *    i.: current active tab
 *    ii.: list of available tabs
 *    iii.: list of tab panes
 * 4) ???
 * 5) Profit!
 * 
 * Some ideas include:
 * 1) Is a modal box active or not?
 * 2) Is an error message active or not?
 * 3) Session timer should be moved here.
 * 
 * 
 */

function wcmContext(argBaseUrl, argCurrentAction)
{
    /**
     * Private properties
     */
    var fullUrl = window.location.href;
    var baseUrl = argBaseUrl;
    
    var debug = {
        window: false,
        enabled: false
    };
    
    var help = {
        window: false,
        enabled: false,
        panel: false
    };
    
    // FIXME Jquery vs. Prototype
    var activeTabs = new Hash();
    var tabGroups = new Hash();
    var tabRelations = new Hash();
    var loadedTabs = new Hash();
    
    var lastClickedTab = new Hash();
    
    var currentAction = argCurrentAction;
    
    var self = this;
    
    /**
     * Private methods
     */
    function setActiveTab(tabId, onChange)
    {
        if (typeof onChange == "undefined") 
            onChange = true;
  
        // Process the tab accordingly.
        // Tab ID Structure: sdlgkhsdg_GUID_skdh_TABID
        // FIXME Not reliabe, what if there are no prefixes?
        var tabIdParts = tabId.split('_');
        
        var tabId = tabIdParts.pop();
        tabGibs = tabId.split('.');
        var cleanTabId = tabGibs[1];
        
        
        var guid = tabIdParts.join('_');
        
        var activeTab = {
            id: cleanTabId,
            groupId: guid,
            title: self.getTabTitle(guid,tabId)
        };
        
        activeTabs.set(guid,activeTab);
        
        
        
        lastClickedTab = $H(activeTab);
    
        loadedTabs[guid+"_"+tabId] = true;
        //load dependencies only if all tabs already exist. When the event is onChange, not onCreate    
        if(onChange == true)
            $WCM.loadTabDependencies(guid, tabId);
    }

    
    function addTabGroup(argTabGroup)
    {
        tabGroups.set(argTabGroup.id,argTabGroup);
    }
    
    function addTab(argGuid, argTabId, argAjaxUrl)
    {
        // FIXME Prototype vs. Jquery
        var el = $(argGuid + '_' + argTabId);
        tabGroups.get(argGuid).set.addTabPage(el,argAjaxUrl);
    }
    

    
    // Priveleged methods
    
    this.getTabTitle = function(argGuid, argTabId)
    {
        
        var tabButtonId = 'tabButton_' + argGuid + '_' + argTabId;
        return $(tabButtonId).innerHTML;
    }
    
    this.createTabGroup = function(argGuid, argUseCookies, argSelected, argUserId)
    {
        try
        {
            tabGroup = {
                // FIXME Prototype vs. jQuery
                set: new WebFXTabPane($(argGuid),argUseCookies,argSelected,argUserId),
                id: argGuid
            };
            addTabGroup(tabGroup);
            
            // WebFXTabPane sets cookies and stuff so while we pass it a selected index
            // it might override that with the contents of a cookie.
        } catch (e) {
            this.exception(e);
        }
    };
    
    this.createTab = function(argGuid, argTabId, argAjaxUrl, relatedTabs)
    {
        try{
            addTab(argGuid,argTabId,argAjaxUrl);
            
            // FIXME Jquery vs. Prototype
            var el = document.getElementById(argGuid + '_' + argTabId);
            $('tabButton_' + el.id).observe('click', self.tabChange.bind(self));
            //set related tabs matrix:

            tabRelations[argGuid + '_' + argTabId] = relatedTabs.evalJSON(); 
            if (tabGroups.get(argGuid).set.selectedIndex == argGuid + '_' + argTabId)
            {
                setActiveTab(tabGroups.get(argGuid).set.selectedIndex, false);                         
            }
         }
         catch(e)
         {
            this.exception(e);
         }
    };
    
    this.loadTabDependencies = function(guid ,tabId)
    {
        if(tabRelations[guid+"_"+tabId] != null)
        {
            var relatedTabs = (tabRelations[guid+"_"+tabId]); 
            for (i=0;i<relatedTabs.length;i++)
            {
                this.reloadspecifictab(guid, relatedTabs[i]);       
            }
        }
    };
    
    this.tabChange = function(event)
    {
        // We might have to clean the ID because there is an A tag there
        // and that A tab is prefixed with 'tabButton_'
        if (event.element().id.startsWith('tabButton_'))
        {
            setActiveTab(event.element().id.replace(/tabButton_/, ''));
        } else {
            // Sometimes it's not necessary.
            setActiveTab(event.element().id);
        }                       
    };
    
    this.activateHelp = function(type)
    {
        if ((!help.enabled) || (help.panel && !help.panel.isPanelActive()))
        {
            // Help needs the following
            // Current action
            // Current list of active tabs
            // Last clicked tab.
            
            help.panel = new wcmContextHelp($WCM.getCurrentAction(), $WCM.getActiveTabs(), $WCM.getLastClickedTab());
            if (type != 'window')
            {
                help.panel.renderPanel();
                help.enabled = true;
            } else {
                help.panel.popupPanel();
                help.enabled = true;
            }
            return help.panel
        } else {
            help.panel.refresh($WCM.getCurrentAction(), $WCM.getActiveTabs(), $WCM.getLastClickedTab());
            return help.panel
        }
    };

    this.reloadtab = function (guid)
    {   
        guid = guid.replace("wcmTabs_", "");        
        tabGroups.get(guid).set.reloadSelectedPage();   
    };
    
    this.reloadspecifictab = function (guid, id)
    {   
        if(tabGroups.get(guid).set.pages[guid+'_'+id] != null)
        {           
            //make sure not to load the same tab more than once since relations can be recursive/interdependant     
            if(loadedTabs[guid+"_"+id] == null)
            {
                tabGroups.get(guid).set.pages[guid+'_'+id].reload(true);
                loadedTabs[guid+"_"+id] = true;
            }           
        }
    };
    
    this.getFullUrl    = function() { return url;        };
    this.getBaseUrl    = function() { return baseUrl;    };
    this.getHelp       = function() { return help;       };
    this.getDebug      = function() { return debug;      };
    this.getLastClickedTab = function() { return lastClickedTab };
    this.getCurrentAction = function() { return currentAction };
    this.getTabGroups  = function() { return tabGroups; };
    this.getActiveTabs = function() { return activeTabs; };
    this.getHelp       = function() { return help; };
    
    return this;
};


// Public Methods

wcmContext.prototype.exception = function(e)
{
    throw 'ERROR -- Type: ' + e.name + ' -- Content: ' + e.message;
}

// FIXME Prototype vs. JQuery
wcmContext.prototype.checkSessionTimeout = function()
{
    new Ajax.Request($WCM.getBaseUrl() + 'ajax/controller.php?ajaxHandler=wcm.ajaxCheckSession',
    {
        method: 'get',
        onComplete: function(response)
        {
            if (response.responseText != 'false')
            {
                logOutURL = $WCM.getBaseUrl() + '?lastPage=' + window.location.href; 
                window.location.href=logOutURL;
            }
        }
    });
}
