<?php
/**
 * Adaptation of Brian W. Bosh script
 * Source : http://www.alternateinterior.com/2007/05/multi-threading-strategies-in-php.html
 */

/**
 * Multi thread class helper
 * Allows to "simulate" some form of multi-threading with PHP
 */
class wcmThreadManager
{
    /**
     * Process Reference
     */
    public $pref ; 

    /**
     * Stdio
     */
	private $pipes; 

    /**
     * Output buffer
     */
	private $buffer; 

    /**
     * Array of environment variables
     */
    private $envVariables; 

    /**
     * Message
     */
	public $message; 


    /**
     * __construct 
     * 
     * @param array $envVar 
     * @return void
     */
	private function __construct($envVar = array())
	{
		$this->pref = 0;
		$this->buffer = "";
		$this->pipes = array();
		$this->envVariables = $envVar;
	}
	
    /**
     * create 
     * 
     * @param mixed $file 
     * @param array $params 
     * @return void
     */
 	public static function create($file, $params = array(), $asynch = false) 
	{
		$t = new wcmThreadManager();

		$descriptor = array(0 => array ("pipe", "r"), 
							1 => array ("pipe", "w"), 
							2 => array ("pipe", "w"));


		$paramString = ' ';
		foreach($params as $key => $value)
		{
			if(is_int($key))
				$paramString .= ' ' . $value;
			else
				$paramString .= ' ' . $key . ' ' . $value;
		}

		if($asynch)
			$asynchCmd = ' &';
		else
			$asynchCmd = '';

		$t->pref = proc_open ("php -q $file" . $paramString . $asynchCmd, $descriptor, $t->pipes, null, $t->envVariables);

		if(false === $t->pref)
		{
			throw new exception('Couldnt create process ' . $file . $paramString);
			return false;
		}

		stream_set_blocking ($t->pipes[1], 0);
		$t->message = "php -q $file" . $paramString . $asynchCmd . ' (PID:' . self::getPID($t->pref) . ')';

		return $t;
	}

    /**
     * isActive 
     * 
     * @return void
     */
	public function isActive() 
	{
		$this->buffer .= $this->listen();
		$f = stream_get_meta_data ($this->pipes[1]);

		return !$f["eof"];
	}
	
    /**
     * close 
     * 
     * @return void
     */
	public function close() 
	{
		foreach($this->pipes as $pipe)
		{
			fclose($pipe);
		}

		$r = proc_terminate ($this->pref);
		$this->pref = NULL;

		return $r;
	}

    /**
     * tell 
     * 
     * @param mixed $thought 
     * @return void
     */
	public function tell ($thought) 
	{
		fwrite ($this->pipes[0], $thought);
	}

    /**
     * listen 
     * 
     * @return void
     */
	public function listen() 
	{
		$buffer = $this->buffer;
		$this->buffer = "";
		while ($r = fgets ($this->pipes[1], 1024)) 
		{
			$buffer .= $r;
		}

		return $buffer;
	}
	
    /**
     * getError 
     * 
     * @return void
     */
	public function getError() 
	{
		$buffer = "";
		while ($r = fgets ($this->pipes[2], 1024)) 
		{
			$buffer .= $r;
		}

		return $buffer;
	}

	/**
     * Check if a thread is still active from an array of threads
     * 
     * @param mixed $threads 
     * @return void
     */
	public static function areActive($threads) 
	{ 
    	foreach($threads as $thread) 
	    { 
    	    if($thread->isActive()) 
        	{ 
            	return true; 
	        } 
    	} 
 
    	return false; 
	}

    /**
     * getPID 
     * 
     * @param mixed $process 
     * @return void
     */
	public static function getPID($process)
	{
		$array = proc_get_status($process);
		return $array['pid'];		
	}
}
